import Dashboard from "components/Dashboard/Dashboard";
import ElefantLogin from "components/Elefant/ElefantLogin";
import ElefantTree from "components/Elefant/ElefantTree";
import ChangePassword from "components/ForgotPassword/ChangePassword";
import ForgotPassword from "components/ForgotPassword/ForgotPassword";
import GetJSONFlatForCatID from "components/getJSONFlat/GetJSONFlatForCatID";
import Login from "components/Login/Login";
import Register from "components/Register/Register";
import RegisterInvitation from "components/Register/Register";
import ThankYouPage from "components/Register/ThankYouPage";
import UserSignup from "components/Signup/UserSignup";
import AuthLayout from "containers/Auth";
import RegisterLayout from "containers/Register";
import { getAuthToken, isValidArray } from "modules/utils";
import React, { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import {
  BrowserRouter as Router,
  Redirect,
  Route,
  Switch,
} from "react-router-dom";
import { fetchUserDetail } from "redux/actions/auth/getUserDetail";

const AuthRoute = (props) => {
  const dispatch = useDispatch();

  const {
    isLoginLoading = false,
    loginData = null,
    loginUserDetails = null,
  } = useSelector((state) => ({
    isLoginLoading: state.login?.isLoading ?? false,
    loginData: state.login?.data ?? null,
    loginUserDetails: state.getUserDetail?.data || null,
  }));

  const hasAuthToken = getAuthToken();
  const hasAuthData = !isLoginLoading && loginData;

  useEffect(() => {
    if (hasAuthToken && !isValidArray(loginUserDetails)) {
      dispatch(fetchUserDetail());
    }
  }, []);

  if (hasAuthToken || hasAuthData) {
    return <Route {...props} />;
  }
  return <Redirect to="/login" />;
};

const NoAuthRoute = ({ component: Component, ...rest }) => (
  <Route {...rest} render={(props) => <Component {...props} />} />
);

const Routes = () => {
  return (
    <Router>
      <Switch>
        <NoAuthRoute exact path="/login" component={Login} />
        <NoAuthRoute exact path="/elefant/login" component={ElefantLogin} />
        <NoAuthRoute exact path="/pricing/signup/:ID" component={Register} />
        <NoAuthRoute exact path="/password/reset" component={ForgotPassword} />
        <NoAuthRoute exact path="/thankyou" component={ThankYouPage} />
        <NoAuthRoute exact path="/userSignup/:token" component={UserSignup} />
        <Route exact path="/elefant" component={ElefantTree} />
        <Route
          exact
          path="/GetJSONFlatForCatID/:id"
          component={GetJSONFlatForCatID}
        />
        <NoAuthRoute
          exact
          path="/resellerSignup/:token"
          component={UserSignup}
        />

        <NoAuthRoute
          exact
          path="/resetPassword/:token"
          component={ChangePassword}
        />
        <AuthRoute component={AuthLayout} />
      </Switch>
    </Router>
  );
};

export default Routes;
