import Loader from "components/Common/Loader";
import { Steps } from "intro.js-react";
import { isValidArray } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useHistory } from "react-router-dom";
import { useLocation } from "react-router-dom/cjs/react-router-dom.min";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import Block from "./tabs/blocks/Block";
import CatalogPages from "./tabs/catalogPages/CatalogPages";
import Headings from "./tabs/catalogPages/Headings";
import NewCatalogPages from "./tabs/catalogPages/NewCatalogPagesTab.js/NewCatalogPages";

const BodyPart = () => {
  const initialActiveTab = {
    catalogPages: "active",
    blocks: "",
    activeTab: "catalogPages",
    // activeTab: "blocks", //correct
  };
  const dispatch = useDispatch();

  const layoutID = useLocation().state?.blockId;
  const history = useHistory();
  const [activeTab, setActivetab] = useState(initialActiveTab);
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [steps, setSteps] = useState([]);

  const { isLoading = false, isCategoryLoading = false } = useSelector(
    (state) => ({
      isLoading: state.blockListing?.loading || false,
      isCategoryLoading: state.getCategoryMergeLevels?.loading || false,
    })
  );

  const onExit = () => {
    setStepsEnabled(false);
  };
  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = `#${d.elementIDName}`;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };
  useEffect(() => {
    dispatch(getIntroJs("layout")).then((data) => {
      if (isValidArray(data?.data)) {
        //TODO: make it dynamic using the api
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  const handleTab = (tabName) => {
    if (tabName == "catalogPages") {
      setActivetab({
        catalogPages: "active",
        blocks: "",
        activeTab: "catalogPages",
      });
    } else if (tabName == "blocks") {
      setActivetab({
        catalogPages: "",
        blocks: "active",
        activeTab: "blocks",
      });
    }
  };

  const isStepEnabled =
    !isLoading && !isCategoryLoading && stepsEnabled && !layoutID;

  return (
    <>
      {isLoading && isCategoryLoading && <Loader />}
      <Steps
        enabled={false}
        steps={steps}
        initialStep={0}
        onExit={onExit}
        onComplete={() => {
          setStepsEnabled(false);
        }}
        options={{ doneLabel: "Next" }}
      />
      <div className="catalog-body-full" style={{ width: "auto" }}>
        <Nav tabs id={"nav-tabs-layout-listing"}>
          <NavItem>
            <NavLink
              className={activeTab.catalogPages}
              onClick={() => handleTab("catalogPages")}
            >
              Catalog Pages
            </NavLink>
          </NavItem>
          <NavItem>
            <NavLink
              className={activeTab.blocks}
              onClick={() => {
                handleTab("blocks");

                history.push({
                  pathname: "/Layout",
                  search: null,
                  state: null,
                });
              }}
            >
              Blocks
            </NavLink>
          </NavItem>
        </Nav>

        <TabContent activeTab={activeTab.activeTab}>
          <TabPane tabId="catalogPages">
            {activeTab.activeTab === "catalogPages" && <NewCatalogPages />}
          </TabPane>

          <TabPane tabId="blocks">
            {activeTab.activeTab === "blocks" && !layoutID && (
              <Block
                setActivetab={setActivetab}
                activeTab={activeTab}
                handleTab={handleTab}
              />
            )}
            {activeTab.activeTab === "blocks" && layoutID && <CatalogPages />}
          </TabPane>
        </TabContent>
      </div>
    </>
  );
};

export default BodyPart;
