import React, { useEffect, useState } from "react";
import Select from "react-select";
import InputField from "components/Common/InputField";
import SelectField from "components/Common/SelectField";
import Headings from "./Headings";
import { isValidArray, isValidObject, mmTopx, pxTomm } from "modules/utils";
import { useDispatch, useSelector } from "react-redux";
import { fetchGetAllAttributeSchemaList } from "redux/actions/output/getAllAttributeSchemaList";
import {
  fetchGetSchemaTable,
  fetchGetSchemaTableCleanUp,
} from "redux/actions/blockBuilder/getSchemaTable";
import {
  Button,
  Modal,
  ModalBody,
  ModalFooter,
  ModalHeader,
  Nav,
  NavItem,
  NavLink,
  TabContent,
  TabPane,
} from "reactstrap";
import Accordion from "react-bootstrap/Accordion";
import { fetchGetMergeFields } from "redux/actions/blockBuilder/getMergeFields";
import classNames from "classnames";
import { fetchCatalogChildList } from "redux/actions/masterAdmin/catalogChildList";
import { fetchBlockPreviewData } from "redux/actions/blockBuilder/blockPreviewData";
import jsPDF from "jspdf";
import autoTable from "jspdf-autotable";
import { fetchCatalogTree } from "redux/actions/manageCatalog/catalogTree";
import { fetchGetCategoryColors } from "redux/actions/blockBuilder/getCategoryColors";
import { $CombinedState } from "redux";
import { fetchGetCatalogTreeForBlocks } from "redux/actions/manageCatalog/getCatalogTreeForBlocks";
import { toast } from "react-toastify";

const BlockSettingHandler = (props) => {
  const {
    attrSetup,
    blockHeight,
    blockName,
    blockWidth,
    blockSettingUnit,
    setBlockSettingUnit,
    setAttrSetup,
    setBlockHeight,
    setBlockName,
    setBlockWidth,
    updateElement,
    selectedElement,
    displayHeight,
    displayWidth,
    privateProps,
    activeId,
    toolbarData,
    onAddMore,
    blockId,
  } = props;

  const [isTableModelOpen, setIsTableModelOpen] = useState(false);
  const [tableData, setTableData] = useState({});
  const [schemaId, setSchemaId] = useState({});
  const [activeLeftTab, setActiveLeftTab] = useState("create");
  const [catalogDataList, setCatalogDataList] = useState([]);
  const [categoryID, setCategoryID] = useState([]);
  const [categoryIDTwo, setCategoryIDTwo] = useState([]);

  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(fetchGetCatalogTreeForBlocks(blockId)).then((res) => {
      let updated = res?.data?.map((item) => {
        return {
          label: item.text,
          value: item.id,
          level: item?.data?.CategoryLevel > 3 ? 3 : item?.data?.CategoryLevel,
          // label: item.text,
          // value: item.id,
          // level: item?.data?.CategoryLevel > 3 ? 3 : item?.data?.CategoryLevel,
          // name1: `<div className="level-${item.level}" dangerouslySetInnerHTML={{__html: ${item.text}}}></div>`,
        };
      });
      setCatalogDataList(updated);
    });
    dispatch(fetchGetAllAttributeSchemaList());
    dispatch(fetchGetMergeFields());
    dispatch(fetchGetCategoryColors());
  }, []);

  const {
    getAllAttributeSchemaList = null,
    getAllAttributeSchemaDetails = null,
    getSchemaTableData = null,
    getSchemaTableLoading = false,
    getSchemaTableError = null,
    getMergeFieldData = null,
    getMergeFieldLoading = false,
    currentBlock = false,
    getCategoryColors = null,
  } = useSelector((state) => ({
    getAllAttributeSchemaList: state.getAllAttributeSchemaList?.data?.data,
    getAllAttributeSchemaDetails:
      state.getAllAttributeSchemaDetails?.data?.data,
    getSchemaTableData: state.getSchemaTableData?.data?.data,
    getSchemaTableLoading: state.getSchemaTableData?.loading,
    getSchemaTableError: state.getSchemaTableData?.error,
    getMergeFieldData: state.getMergeField?.data?.data,
    getMergeFieldLoading: state.getMergeField?.loading,
    currentBlock: state.getBlock?.data?.data,
    getCategoryColors: state.getCategoryColors?.data?.data,
  }));

  const tableSubmitted = () => {
    onAddMore(
      "table",
      getSchemaTableData?.tableData,
      getSchemaTableData?.tableWidth,
      schemaId
    );
    toggleEditModel();
  };

  const blockSettingUnitChange = (value) => {
    setBlockSettingUnit(value);
  };

  const handleSchema = (val) => {
    setSchemaId(val);
    dispatch(fetchGetSchemaTable(val));
  };

  const mergeData = [
    "[Collection Image 1]",
    "[Collection Image 2]",
    "[Collection Image 3]",
    "[Collection Image 4]",
    "[Collection Image 5]",
    "[Collection Image 6]",
  ];

  const isEditable = isValidArray(activeId) ? false : true;

  const onButtonClick = (btnName) => {
    switch (btnName) {
      case "Rectangle":
      case "Triangle":
      case "Circle":
      case "Text":
      case "Image":
        return onAddMore(btnName.toLowerCase());

      case "Table":
        setIsTableModelOpen(true);
        break;
      default:
        break;
    }
  };

  const renderToolbarIcons = () => {
    const filterData = toolbarData
      ? toolbarData.filter((d) => {
          return d?.ToolbarID === 5 || d?.ToolbarName === "Draw";
        })
      : [];

    return filterData?.map((d, i) => {
      return (
        <div className="" key={i} id="toolbar">
          {d.iconGroups.map((d, i) => {
            return (
              <span key={i} className="btns-wrapper mb-1">
                {d.icons.map((d, ind) => (
                  <button
                    key={ind}
                    className={"btn"}
                    onClick={() => onButtonClick(d.ButtonName)}
                  >
                    <i className={d?.ButtonIcon} title={d?.ButtonName} />
                  </button>
                ))}
              </span>
            );
          })}
        </div>
      );
    });
  };

  const toggleEditModel = () => {
    setIsTableModelOpen((val) => !val);
    setTableData({});
    dispatch(fetchGetSchemaTableCleanUp());
  };

  const renderDrawSection = () => {
    return (
      <div className="block-setting-merge shape-btns">
        {renderToolbarIcons()}
      </div>
    );
  };

  const renderMerge = () => {
    return (
      <div className="merge-scroll merge-wrapper">
        {!getMergeFieldLoading &&
          isValidObject(getMergeFieldData) &&
          Object.keys(getMergeFieldData).map((d, i) => {
            return (
              <>
                <p
                  key={`${d}${i}`}
                  style={{
                    cursor: "pointer",
                    color: "#000058",
                    fontWeight: "500",
                    height: 22,
                    fontSize: "12px",
                  }}
                  className="w-100 mx-auto"
                >
                  {d}
                </p>
                {isValidArray(getMergeFieldData[d])
                  ? getMergeFieldData[d].map((attr, iin) => {
                      return (
                        <>
                          <p
                            key={`${attr}${iin}${d}`}
                            style={{
                              cursor: "pointer",
                              height: 22,
                              fontSize: "12px",
                            }}
                            onClick={() => {
                              updateElement({
                                innerTextValue: attr,
                              });
                            }}
                            className="w-100 mx-auto"
                          >
                            {attr}
                          </p>
                          {isValidObject(attr)
                            ? Object.keys(attr).map((objectAttr, index) => {
                                return (
                                  <p
                                    key={`${index}${objectAttr}${d}`}
                                    className="mw-75 mx-auto"
                                    style={{
                                      height: 50,
                                      color: "red",
                                    }}
                                  >
                                    {objectAttr}
                                  </p>
                                );
                              })
                            : null}
                        </>
                      );
                    })
                  : isValidObject(getMergeFieldData[d]) &&
                    Object.keys(getMergeFieldData[d]).map((objData, ind) => {
                      return (
                        <>
                          <p
                            key={`${objData}${ind}`}
                            style={{
                              cursor: "pointer",
                              color: "#000058",
                              fontWeight: "500",
                              height: 22,
                              fontSize: "12px",
                            }}
                            className="w-100 mx-auto"
                          >
                            {objData}
                          </p>
                          {isValidArray(getMergeFieldData[d][objData]) &&
                            getMergeFieldData[d][objData].map(
                              (innerObj, objIn) => {
                                return (
                                  <p
                                    key={`${innerObj}${objIn}`}
                                    style={{
                                      cursor: "pointer",
                                      height: 22,
                                      fontSize: "12px",
                                    }}
                                    onClick={() => {
                                      updateElement({
                                        innerTextValue: innerObj,
                                      });
                                    }}
                                    className="w-100 mx-auto"
                                  >
                                    {innerObj}
                                  </p>
                                );
                              }
                            )}
                        </>
                      );
                    })}
              </>
            );
          })}
      </div>
    );
  };

  const renderControl = () => {
    return (
      <div className="merge-scroll mb-3 control-wrapper">
        <table className="element-control-table" style={{ width: "100%" }}>
          <tr>
            <th>Option</th>
            <th>Value</th>
          </tr>
          <tr>
            <td>Priority</td>
            <td>
              <select
                disabled={isEditable}
                value={privateProps?.priority}
                onChange={(value) => {
                  updateElement({ priority: value.target.value });
                }}
              >
                <option value="0">0</option>
                <option value="1">1</option>
                <option value="2">2</option>
                <option value="3">3</option>
                <option value="4">4</option>
                <option value="5">5</option>
                <option value="6">6</option>
                <option value="7">7</option>
                <option value="8">8</option>
                <option value="9">9</option>
                <option value="10">10</option>
              </select>
            </td>
          </tr>
          <tr>
            <td>Expansion</td>
            <td>
              <select
                disabled={isEditable}
                onChange={(e) => {
                  updateElement({
                    expansion: e.target.value,
                  });
                }}
                value={
                  privateProps?.expansion ? privateProps?.expansion : "height"
                }
              >
                <option value="none">None</option>
                <option value="height">Height</option>
                <option value="width">Width</option>
                <option value="both">Both</option>
              </select>
            </td>
          </tr>
          <tr>
            <td>Expansion Anchor</td>
            <td>
              <select
                disabled={isEditable}
                onChange={(e) => {
                  updateElement({
                    expansionAnchor: e.target.value,
                    expansionClass: "expansion-element",
                  });
                }}
                value={privateProps.expansionAnchor}
              >
                <option value="">N/A</option>
                <option value="tl">TL</option>
                <option value="tc">TC</option>
                <option value="tr">TR</option>
                <option value="ml">ML</option>
                <option value="mc">MC</option>
                <option value="mr">MR</option>
                <option value="bl">BL</option>
                <option value="bc">BC</option>
                <option value="br">BR</option>
              </select>
            </td>
          </tr>
          <tr>
            <td>Delete if Empty</td>
            <td>
              <select
                disabled={isEditable}
                value={privateProps?.deleteIfEmpty}
                onChange={(e) => {
                  updateElement({
                    deleteIfEmpty: e.target.value,
                  });
                }}
              >
                <option value={"false"}>No</option>
                <option value={"true"}>Yes</option>
              </select>
            </td>
          </tr>
          <tr>
            <td>Color</td>
            <td>
              <select
                disabled={isEditable}
                onChange={(e) => {
                  updateElement({
                    color: e.target.value ? e.target.value : null,
                  });
                }}
                value={privateProps?.color}
              >
                <option value="">N/A</option>
                {isValidArray(getCategoryColors) &&
                  getCategoryColors?.map((d, k) => (
                    <option value={d} key={k}>
                      {d}
                    </option>
                  ))}
              </select>
            </td>
          </tr>
          <tr>
            <td>Vertical Offset </td>
            <td>
              <InputField
                id="verticalOffset"
                isDisabled={isEditable}
                className="details-single-element"
                name="verticalOffset"
                type="text"
                isLabelRequired={false}
                onChange={(e) => {
                  updateElement({
                    verticalOffset: e.target.value ? e.target.value : null,
                  });
                }}
                value={selectedElement?.verticalOffset || 0}
              />
            </td>
          </tr>
        </table>
      </div>
    );
  };

  const getBlockPreviewData = () => {
    dispatch(
      fetchBlockPreviewData({
        CategoryID: categoryID?.value,
        BlockID: currentBlock?.BlockID,
        ProductID: null,
      })
    ).then((data) => {
      console.log(
        "🚀 ~ file: BlockSettingHandler.js ~ line 465 ~ ).then ~ data",
        data
      );
      if (data?.message && !data?.flag) {
        toast.error(data?.message);
      }
      if (data && data?.data) {
        const resData = data?.data.elements;
        console.log(
          "🚀 ~ file: BlockSettingHandler.js ~ line 474 ~ ).then ~ resData",
          resData
        );
        const bd = data?.data.block;
        const cat = data?.data.category;

        //Create the PDF document
        const oldDoc = new jsPDF(
          bd.orientation,
          bd.BlockUnitType,
          [bd.BlockWidth, bd.BlockHeight],
          true
        );

        let height = 0;

        //Loop through response and get height of table first.
        resData.map((d) => {
          if (d.name === "table") {
            if (
              d.expansionAnchor === "bl" ||
              d.expansionAnchor === "bc" ||
              d.expansionAnchor === "br"
            ) {
              const arr = d.tableWidths;

              const tabWidth = {};

              Object.keys(arr).map((i, index) => {
                tabWidth[i] = arr[i];
              });

              oldDoc.autoTable({
                head: [d.tableHeaders],
                body: d.originalTableBody,
                // html: '#mytable',
                theme: "plain",
                tableWidth: d.widthInMm,
                // tableLineColor: [0, 0, 0],
                // tableLineWidth: 0.1,

                styles: {
                  fontSize: d.fontSize,
                  minCellHeight: 1,
                  cellPadding: { top: 0, right: 0, bottom: 0, left: 0 },
                  overflow: "linebreak",
                },
                headStyles: {
                  lineWidth: 0.1,
                  lineColor: [0, 0, 0],
                  // fillColor : [124, 95, 240]
                  valign: "middle",
                  halign: "center",
                },
                bodyStyles: {
                  lineWidth: 0.1,
                  lineColor: [0, 0, 0],
                },
                // pageBreak: 'avoid',
                // rowPageBreak: 'avoid',
                margin: { top: 0, left: d.leftInMm, bottom: 0 },

                // startY: th,
                startY: 0,
                columnStyles: tabWidth,
                didDrawPage: function (data) {
                  height = data.cursor.y;
                },
              });
            }

            console.log("Height: " + height);
            console.log("Height: " + mmTopx(height));
          }
        });

        //Create the PDF document
        const doc = new jsPDF(
          bd.orientation,
          bd.BlockUnitType,
          [bd.BlockWidth, bd.BlockHeight],
          true
        );

        let newHeight = 0;

        //Loop through response and get height of table first.
        resData.map((d) => {
          if (d.name === "table") {
            if (
              d.expansionAnchor === "bl" ||
              d.expansionAnchor === "bc" ||
              d.expansionAnchor === "br"
            ) {
              const arr = d.tableWidths;

              const tabWidth = {};

              Object.keys(arr).map((i, index) => {
                tabWidth[i] = arr[i];
              });

              doc.autoTable({
                head: [d.tableHeaders],
                body: d.tableBody,
                // html: '#mytable',
                theme: "plain",
                tableWidth: d.widthInMm,
                // tableLineColor: [0, 0, 0],
                // tableLineWidth: 0.1,

                styles: {
                  fontSize: d.fontSize,
                  minCellHeight: 1,
                  cellPadding: { top: 0, right: 0, bottom: 0, left: 0 },
                  overflow: "linebreak",
                },
                headStyles: {
                  lineWidth: 0.1,
                  lineColor: [0, 0, 0],
                  // fillColor : [124, 95, 240]
                  valign: "middle",
                  halign: "center",
                },
                bodyStyles: {
                  lineWidth: 0.1,
                  lineColor: [0, 0, 0],
                },
                // pageBreak: 'avoid',
                // rowPageBreak: 'avoid',
                margin: { top: 0, left: d.leftInMm, bottom: 0 },

                // startY: th,
                startY: 0,
                columnStyles: tabWidth,
                didDrawPage: function (data) {
                  newHeight = data.cursor.y;
                },
              });
            }

            console.log("New Height: " + newHeight);
            console.log("New Height: " + mmTopx(newHeight));
          }
        });

        //Create the PDF document
        const newDoc = new jsPDF(
          bd.orientation,
          bd.BlockUnitType,
          [bd.BlockWidth, bd.BlockHeight],
          true
        );

        resData.map((d) => {
          //Rectangle
          if (d.name === "rectangle") {
            newDoc.setPage(1);
            newDoc.setFillColor(d.backgroundColor);
            newDoc.rect(d.leftInMm, d.topInMm, d.widthInMm, d.heightInMm, "F");
          }

          //Image
          if (d.name === "image") {
            newDoc.setPage(1);
            const img = d.ImageSource;
            
            if (img !== null) {
              newDoc.addImage(
                d.ImageSource.encoded,
                d.ImageExtension,
                d.leftInMm,
                d.topInMm,
                pxTomm(d.ImageWidth),
                pxTomm(d.ImageHeight),
                undefined,
                "FAST",
                0
              );
            }
          }

          //Text
          if (d.name === "text") {
            newDoc.setPage(1);
            const textArray = d.ReplacedText;

            newDoc.setFontSize(d.fontSize);
            // newDoc.addFont('Roboto', 'Roboto', 'normal');
            newDoc.setFont("helvetica");
            newDoc.setTextColor(d.fontColor);

            //extra 2 mm for text in the box.
            let topPos = parseInt(d.topInMm + 3);
            let numbersLength = textArray.length;
            for (let i = 0; i < numbersLength; i++) {
              var splitTitle = newDoc.splitTextToSize(
                textArray[i],
                d.widthInMm
              );

              newDoc.text(splitTitle, d.leftInMm, topPos, {
                align: "justify",
                baseline: "top",
              });

              topPos =
                parseInt(topPos) +
                parseInt(d.heightInMm) +
                parseInt(d.verticalOffset);
            }
          }

          //Table
          if (d.name === "table") {
            // var height = 0;
            var th = d.topInMm - newHeight + d.heightInMm;
            console.log("Final start point: " + th);
            const arr = d.tableWidths;

            const tabWidth = {};

            Object.keys(arr).map((i, index) => {
              tabWidth[i] = arr[i];
            });

            newDoc.autoTable({
              head: [d.tableHeaders],
              body: d.tableBody,
              // html: '#mytable',
              theme: "plain",
              tableWidth: d.widthInMm,
              // tableLineColor: [0, 0, 0],
              // tableLineWidth: 0.1,

              styles: {
                fontSize: d.fontSize,
                minCellHeight: 1,
                cellPadding: { top: 0, right: 0, bottom: 0, left: 0 },
                overflow: "linebreak",
              },
              headStyles: {
                lineWidth: 0.1,
                lineColor: [0, 0, 0],
                // fillColor : [124, 95, 240]
                valign: "middle",
                halign: "center",
              },
              bodyStyles: {
                lineWidth: 0.1,
                lineColor: [0, 0, 0],
              },
              // pageBreak: 'avoid',
              // rowPageBreak: 'avoid',
              margin: { top: 0, left: d.leftInMm, bottom: 0 },

              startY: th,
              // startY: d.topInMm,
              columnStyles: tabWidth,
              didDrawPage: function (data) {
                // height = data.cursor.y;
              },
              willDrawCell: function (data) {
                newDoc.setFillColor(67, 160, 71);
              },
              // willDrawCell: (data) => {
              //     if (data.section == "body" && data.column.index != 0) {
              //         newDoc.setDrawColor(41, 128, 186)
              //         newDoc.setLineWidth(.5);
              //         newDoc.line(data.cell.x, data.cell.y + data.row.height, data.cell.x, data.cell.y);
              //     }
              // }
            });
          }
        });
        // newDoc.save(categoryID?.value + "_" + cat.CategoryName +"_BlockPreview.pdf");
        newDoc.setProperties({
          title: bd.BlockName,
        });
        // newDoc.output("dataurlnewwindow");
        window.open(newDoc.output("bloburl"));
      }
    });
  };

  const accordionData = [
    {
      id: 1,
      title: "DRAW",
      html: renderDrawSection(),
    },
    {
      id: 1,
      title: "CONTROL",
      html: renderControl(),
    },
    {
      id: 1,
      title: "MERGE",
      html: renderMerge(),
    },
  ];
  const customStyles = {
    control: (provided, state) => ({
      ...provided,
      background: "#fff",
      borderColor: "#9e9e9e",
      minHeight: "30px",
      height: "30px",
      boxShadow: state.isFocused ? null : null,
      marginTop: "10px",
    }),

    valueContainer: (provided, state) => ({
      ...provided,
      height: "30px",
      padding: "0 6px",
    }),

    input: (provided, state) => ({
      ...provided,
      margin: "20px",
    }),
    indicatorSeparator: (state) => ({
      display: "none",
    }),
    indicatorsContainer: (provided, state) => ({
      ...provided,
      height: "30px",
    }),
  };
  return (
    <div
      className="shadow-lg sidebar sidebar-elements"
      id="left-sidebar-layout"
    >
      <Nav tabs>
        <NavItem>
          <NavLink
            className={classNames({
              "active nav-link": activeLeftTab === "create",
            })}
            onClick={() => setActiveLeftTab("create")}
          >
            <Headings>CREATE</Headings>
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={classNames({
              "active nav-link": activeLeftTab === "merge",
            })}
            onClick={() => setActiveLeftTab("merge")}
          >
            <Headings>MERGE</Headings>
          </NavLink>
        </NavItem>
      </Nav>
      <TabContent activeTab={activeLeftTab}>
        {/* Element Properties Tab */}
        <TabPane tabId="create">
          <Accordion defaultActiveKey="0">
            <Accordion.Item eventKey="0">
              <Accordion.Header className="blockTitle">
                <Headings>DRAW</Headings>
              </Accordion.Header>
              <Accordion.Body>{renderDrawSection()}</Accordion.Body>
            </Accordion.Item>
          </Accordion>
          <Accordion>
            <Accordion.Item eventKey="1">
              <Accordion.Header className="blockTitle">
                <Headings>Library</Headings>
              </Accordion.Header>
              <Accordion.Body></Accordion.Body>
            </Accordion.Item>
          </Accordion>
          <Accordion>
            <Accordion.Item eventKey="1">
              <Accordion.Header className="blockTitle">
                <Headings>Preview</Headings>
              </Accordion.Header>
              <Accordion.Body>
                <div className="create-box catalog-category-select-menu">
                  <div className="create-box-label">
                    Select Catalog/Category
                  </div>
                  <Select
                    className="custom-select-box"
                    options={catalogDataList}
                    placeholder="Select an option"
                    formatOptionLabel={function (data) {
                      return (
                        <span
                          className={`custom-select-box-option ${
                            data?.value
                              ? `level-${data.level}`
                              : `level-${data.level}`
                          }`}
                          // dangerouslySetInnerHTML={{ __html: data.label }}
                        >
                          {data.label}
                        </span>
                      );
                    }}
                    onChange={(value) => {
                      setCategoryID(value?.value ? value : {});
                    }}
                    isSearchable={true}
                    value={categoryID}
                    styles={customStyles}
                  />

                  <Button
                    onClick={() => {
                      getBlockPreviewData();
                    }}
                    className="mt-2"
                  >
                    Apply
                  </Button>
                </div>
              </Accordion.Body>
            </Accordion.Item>
          </Accordion>
        </TabPane>
        <TabPane tabId="merge">
          <Accordion>
            <Accordion.Item eventKey="1">
              <Accordion.Header className="blockTitle">
                <Headings>CONTROL</Headings>
              </Accordion.Header>
              <Accordion.Body>{renderControl()}</Accordion.Body>
            </Accordion.Item>
          </Accordion>
          <Accordion>
            <Accordion.Item eventKey="1">
              <Accordion.Header className="blockTitle">
                <Headings>MERGE</Headings>
              </Accordion.Header>
              <Accordion.Body>{renderMerge()}</Accordion.Body>
            </Accordion.Item>
          </Accordion>
        </TabPane>
      </TabContent>
      {isTableModelOpen && (
        <Modal
          className="conformation-popup"
          isOpen={isTableModelOpen}
          toggle={toggleEditModel}
          size="xl"
          // fullscreen={true}
        >
          <ModalHeader>Create Table</ModalHeader>
          <ModalBody>
            <div className="d-flex">
              <select
                onChange={(e) => {
                  handleSchema(e.target.value);
                }}
              >
                <option>Select Attribute Schema</option>
                {getAllAttributeSchemaList &&
                  getAllAttributeSchemaList.map((d, i) => {
                    return (
                      <option key={i} value={d?.CatalogAttributeSchemaID}>
                        {d?.CatalogAttributeSchemaName}
                      </option>
                    );
                  })}
              </select>
            </div>
            <div>
              <label className="form-label">
                <div className="black-text mt-4 mb-0 ml-0 mr-5">
                  <strong>Table Preview</strong>
                </div>
              </label>
              {blockWidth < parseInt(getSchemaTableData?.tableWidth) ? (
                <div>
                  <label className="form-label">
                    <div className="black-text mt-4 mb-0 ml-0 mr-5">
                      <strong style={{ color: "red" }}>
                        Table width is larger than the canvas
                      </strong>
                    </div>
                  </label>
                </div>
              ) : null}
              <div>
                {getSchemaTableLoading ? (
                  <label className="form-label">
                    <div className="black-text mt-4 mb-0 ml-0 mr-5">
                      <strong>Loading Table Preview</strong>
                    </div>
                  </label>
                ) : (
                  <div
                    dangerouslySetInnerHTML={{
                      __html: getSchemaTableData?.tableData,
                    }}
                  ></div>
                )}
              </div>
            </div>
          </ModalBody>
          <ModalFooter>
            <Button
              color="primary"
              onClick={tableSubmitted}
              disabled={blockWidth < parseInt(getSchemaTableData?.tableWidth)}
            >
              Add Table
            </Button>
            <Button color="primary" onClick={toggleEditModel}>
              Cancel
            </Button>
          </ModalFooter>
        </Modal>
      )}

      {/* <div className="d-flex flex-column elements-list block-setting overflow-auto">
        <Headings className="mb-2">BLOCK SETTING</Headings>
        {accordionData.map((d, i) => {
          return (
            <Accordion defaultActiveKey="0" key={i}>
              <Accordion.Item eventKey="0">
                <Accordion.Header className="blockTitle">
                  <Headings>{d?.title}</Headings>
                </Accordion.Header>
                <Accordion.Body>{d?.html}</Accordion.Body>
              </Accordion.Item>
            </Accordion>
          );
        })}
      </div> */}
    </div>
  );
};

export default BlockSettingHandler;
