import React, { useEffect, useState } from "react";
import { isValidArray } from "modules/utils";
import InputField from "components/Common/InputField";
import { Button, Modal, ModalBody, ModalFooter, ModalHeader } from "reactstrap";

import binIcon from "assets/images/bin.png";
import iconDelete from "assets/images/delete-selected.png";
import Headings from "./Headings";
import { isEqual } from "lodash";
import { useDispatch, useSelector } from "react-redux";
import { fetchGetAllAttributeSchemaList } from "redux/actions/output/getAllAttributeSchemaList";
import {
  fetchGetSchemaTable,
  fetchGetSchemaTableCleanUp,
} from "redux/actions/blockBuilder/getSchemaTable";

const CanvasHeader = (props) => {
  const {
    onAddMore,
    onRemove,
    selectedElement,
    onRemoveAll,
    targets,
    setTargets,
    updateElement,
    toolbarData,
    templateScale,
    updateTemplateScale,
    activeId,
    setActiveId,
    isGroupBTNSelected,
    setIsGroupBTNSelected,
    onBlockSave,
    blockWidth,
  } = props;

  const [isTableModelOpen, setIsTableModelOpen] = useState(false);
  const [tableStructure, setTableStructure] = useState({ rows: 3, columns: 2 });
  const [tableData, setTableData] = useState({});
  const [schemaId, setSchemaId] = useState({});
  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(fetchGetAllAttributeSchemaList());
  }, []);

  const {
    getAllAttributeSchemaList = null,
    getAllAttributeSchemaDetails = null,
    getSchemaTableData = null,
    getSchemaTableLoading = false,
    getSchemaTableError = null,
  } = useSelector((state) => ({
    getAllAttributeSchemaList: state.getAllAttributeSchemaList?.data?.data,
    getAllAttributeSchemaDetails:
      state.getAllAttributeSchemaDetails?.data?.data,
    getSchemaTableData: state.getSchemaTableData?.data?.data,
    getSchemaTableLoading: state.getSchemaTableData?.loading,
    getSchemaTableError: state.getSchemaTableData?.error,
  }));

  const onGroup = () => {
    if (
      activeId?.length > 1 &&
      !isEqual(activeId, selectedElement?.groupWith || [])
    ) {
      const updated = targets.map((d) => {
        if (activeId.includes(d.id)) {
          return {
            ...d,
            groupWith: activeId,
          };
        }
        return d;
      });

      setTargets(updated);
    }
  };

  const updateTableData = (key, value) =>
    setTableData({
      ...tableData,
      [key]: value,
    });

  const toggleEditModel = () => {
    setIsTableModelOpen((val) => !val);
    setTableData({});
    dispatch(fetchGetSchemaTableCleanUp());
  };

  const onUnGroup = () => {
    if (activeId?.length > 1) {
      const updated = targets.map((d) => {
        if (activeId.includes(d.id)) {
          return {
            ...d,
            groupWith: [],
          };
        }
        return d;
      });

      setTargets(updated);
      setActiveId([]);
    }
  };

  const onButtonClick = (btnName) => {
    switch (btnName) {
      case "Rectangle":
      case "Triangle":
      case "Circle":
      case "Text":
      case "Image":
        return onAddMore(btnName.toLowerCase());

      case "Table":
        setIsTableModelOpen(true);
        break;

      case "Bold":
      case "Italic":
      case "Underline":
        return updateElement({
          [btnName.toLowerCase()]: !selectedElement?.[btnName.toLowerCase()],
        });

      case "Zoom to fit":
        return updateElement({
          templateScale: 1,
        });

      case "Left":
      case "Center":
      case "Right":
        return updateElement({
          textAlign: btnName.toLowerCase(),
        });

      case "Zoom in":
        return updateTemplateScale(templateScale + 0.1);

      case "Zoom out":
        return updateTemplateScale(templateScale - 0.1);

      case "Group":
        return onGroup();

      case "Ungroup":
        onUnGroup();
        break;

      case "Bring forward":
        return updateElement({
          zIndex: selectedElement?.zIndex + 1,
        });
      case "Send backward":
        return updateElement({
          zIndex: selectedElement?.zIndex - 1,
        });
      case "Bring to front":
        return updateElement({
          zIndex: targets.length + 1,
        });
      case "Send to back":
        return updateElement({
          zIndex: 0,
        });

      case "Save":
        return onBlockSave();

      case "Rotate":
        return updateElement({
          rotate: selectedElement?.rotate + 180,
        });
      case "Rotate 90&deg; clockwise":
        return updateElement({
          rotate: selectedElement?.rotate + 90,
        });
      case "Rotate 90&deg; counter-clockwise":
        return updateElement({
          rotate: selectedElement?.rotate - 90,
        });
      default:
        break;
    }
  };

  const btnDisabled = (btnName) => {
    switch (btnName) {
      case "Bring forward":
        return targets?.length + 1 < selectedElement?.zIndex || !selectedElement
          ? true
          : false;
      case "Send backward":
        return selectedElement?.zIndex < 1 || !selectedElement ? true : false;

      case "Rectangle":
      case "Triangle":
      case "Circle":
      case "Text":
      case "Image":
      case "Table":
      case "Group":
      case "Ungroup":
      case "Layers":
      case "Zoom in":
      case "Zoom out":
        return false;

      case "Bold":
      case "Italic":
      case "Underline":
        return selectedElement?.name === "text" ? false : true;

      default:
        return !selectedElement ? true : false;
    }
  };

  const renderToolbarIcons = () => {
    return toolbarData?.map((d, i) => {
      return (
        <div key={i}>
          <p className="fileTitle">{d.ToolbarName}</p>
          {d.iconGroups.map((d, i) => {
            return (
              <span key={i} className="btns-wrapper">
                {d.icons.map((d, i) => (
                  <button
                    key={i}
                    className={
                      d.ButtonName === "Group" && isGroupBTNSelected
                        ? "btn selected"
                        : "btn"
                    }
                    disabled={btnDisabled(d.ButtonName)}
                    onClick={() => onButtonClick(d.ButtonName)}
                  >
                    <i className={d?.ButtonIcon} title={d?.ButtonName} />
                  </button>
                ))}
              </span>
            );
          })}
        </div>
      );
    });
  };

  const tableRow = Number(tableStructure?.rows) || 1;
  const tableColumn = Number(tableStructure?.columns) || 1;

  const tableSubmitted = () => {
    // let tableHtml = "";

    // tableHtml += "<table class='layoutTable'>";
    // for (let i = 0; i < tableRow; i++) {
    //   tableHtml += "<tr>";
    //   for (let j = 0; j < tableColumn; j++) {
    //     if (i === 0) {
    //       tableHtml += "<th>";
    //       tableHtml += tableData[`table-${i}-${j}`] || "";
    //       tableHtml += "</th>";
    //     } else {
    //       tableHtml += "<td>";
    //       tableHtml += tableData[`table-${i}-${j}`] || "";
    //       tableHtml += "</td>";
    //     }
    //   }
    //   tableHtml += "</tr>";
    // }
    // tableHtml += "</table>";

    onAddMore(
      "table",
      getSchemaTableData?.tableData,
      getSchemaTableData?.tableWidth,
      schemaId
    );
    toggleEditModel();
  };

  const getColumn = (n, i) => {
    return [...Array(n)].map((_d, j) => {
      const key = `table-${i}-${j}`;
      return (
        <td key={`${j}-${i}`}>
          <input
            type="text"
            className="w-100"
            onChange={(e) => updateTableData(key, e.target.value)}
            value={tableData?.[key] || ""}
          />
        </td>
      );
    });
  };

  const generatedTable = [...Array(tableRow)].map((_d, i) => (
    <tr key={i}>{getColumn(tableColumn, i)}</tr>
  ));

  const handleSchema = (val) => {
    setSchemaId(val);
    dispatch(fetchGetSchemaTable(val));
  };

  return <></>;
};

export default CanvasHeader;
