import { Steps } from "intro.js-react";
import { isValidArray } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import NewCanvas from "./NewCanvas";

const CatalogPages = () => {
  const initialActiveTab = {
    blockEditor: "active",
    blocks: "",
    activeTab: "blockEditor",
  };
  const dispatch = useDispatch();

  const [activeTab, setActivetab] = useState(initialActiveTab);
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [steps, setSteps] = useState([]);

  const { isToolbarDataLoading = false } = useSelector((state) => ({
    isToolbarDataLoading: state.getAllToolbars?.loading,
  }));

  const handleTab = (tabName) => {
    if (tabName == "blockEditor") {
      setActivetab({
        blockEditor: "active",
        blocks: "",
        activeTab: "blockEditor",
      });
    }
  };

  const onExit = () => {
    setStepsEnabled(false);
  };

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = `#${d.elementIDName}`;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  useEffect(() => {
    dispatch(getIntroJs("block-builder")).then((data) => {
      if (isValidArray(data?.data)) {
        //TODO: make it dynamic using the api
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  const isStepEnabled = !isToolbarDataLoading && stepsEnabled;

  return (
    <div className="catalog-body-full">
      <Steps
        enabled={isStepEnabled}
        steps={steps}
        initialStep={0}
        onExit={onExit}
        onComplete={() => {
          setStepsEnabled(false);
        }}
        options={{ doneLabel: "Next" }}
      />
      <Nav tabs>
        <NavItem>
          <NavLink
            className={activeTab.blockEditor}
            onClick={() => handleTab("blockEditor")}
          >
            Block Editor
          </NavLink>
        </NavItem>
      </Nav>

      <TabContent activeTab={activeTab.activeTab}>
        <TabPane tabId="blockEditor">
          {activeTab.activeTab === "blockEditor" && <NewCanvas />}
        </TabPane>
      </TabContent>
    </div>
  );
};

export default CatalogPages;
