import React, { useCallback, useEffect, useRef, useState } from "react";

import InputField from "components/Common/InputField";
import SelectField from "components/Common/SelectField";
import { Button, Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import TextArea from "components/Common/TextArea";
import {
  capitalizeFirstLetter,
  handleDecimalsOnValue,
  isValidArray,
  mmTopx,
  pxTomm,
} from "modules/utils";
import Headings from "./Headings";
import fontColor from "assets/images/capitalA.png";
import classNames from "classnames";
import { Accordion } from "react-bootstrap";
import { useDispatch, useSelector } from "react-redux";
import { fetchGetCategoryMergeLevels } from "redux/actions/blockBuilder/getCategoryMergeLevels";

const ElementPropertiesHandler = (props) => {
  const {
    activeId,
    blockHeight,
    blockName,
    blockSettingUnit,
    blockWidth,
    displayHeight,
    displayWidth,
    elementPropsUnit,
    isEditable,
    privateProps,
    selectedElement,
    setActiveId,
    setAttrSetup,
    setBlockHeight,
    setBlockName,
    setBlockSettingUnit,
    setBlockWidth,
    setElementPropsUnit,
    setIsEditable,
    targets,
    updateElement,
    blockId,
    updateElementChanges,
    blockCategory,
  } = props;

  const blockSettingUnitChange = (value) => {
    setBlockSettingUnit(value);
  };
  const { isCategoryLoading = true, getCategoryMergeLevels } = useSelector(
    (state) => ({
      isCategoryLoading: state.getCategoryMergeLevels?.loading || false,
      getCategoryMergeLevels: state.getCategoryMergeLevels?.data?.data,
    })
  );
  const [tempCSSstore, setTempCSSstore] = useState();
  const [elementPropsErrors, setElementPropsErrors] = useState({});
  const [activeLeftTab, setActiveLeftTab] = useState("element");
  const [fontUnit, setFontUnit] = useState();
  const [tableFontUnit, setTableFontUnit] = useState();

  const getCategoryOptions = () => {
    const options = getCategoryMergeLevels.map((d) => {
      return {
        label: d,
        value: d,
      };
    });
    return options;
  };
  const cssSubmit = () => {
    try {
      const json = JSON.parse(tempCSSstore);
      updateElement({
        customCSS: json,
      });
    } catch (e) {
      setElementPropsErrors({
        ...elementPropsErrors,
        cssProperties: "Invalid CSS Format/Properties",
      });
    }
  };
  const dispatch = useDispatch();

  useEffect(() => {
    setElementPropsErrors({});
    setTempCSSstore(JSON.stringify(privateProps?.customCSS));
    setIsEditable(true);
    setFontUnit(privateProps?.fontUnit);
    setTableFontUnit(privateProps?.fontUnit);
  }, [activeId]);

  useEffect(() => {
    if (blockSettingUnit === "mm" && elementPropsUnit === "px") {
      setElementPropsUnit("mm");
    }
  }, [blockSettingUnit]);

  useEffect(() => {
    dispatch(fetchGetCategoryMergeLevels());
  }, []);
  const elementPropsError = (field, errorMsg) => {
    setElementPropsErrors({
      ...elementPropsErrors,
      [field]: "Maximum value can not be greater than Canvas size",
    });
  };

  const changeRotateValue = (value) => {
    let rounds = 0;

    if (value >= 0) {
      for (let i = 0; i < parseInt(value / 360); i++) {
        rounds++;
      }
      return (value - 360 * rounds).toFixed(0);
    } else {
      let positiveValue = Math.abs(value);
      for (let i = 0; i < parseInt(positiveValue / 360); i++) {
        rounds++;
      }
      let totalValue = positiveValue - 360 * rounds;
      return (360 - totalValue).toFixed(0);
    }
  };

  const handleElementPropsChanges = (value) => {
    setElementPropsUnit(value);
    setElementPropsErrors({
      ...elementPropsErrors,
      elementValGTBlockValue: "",
    });
  };

  return (
    <div
      className="right-sidebar shadow-lg sidebar sidebar-elements"
      id="right-sidebar"
    >
      <Nav tabs>
        <NavItem>
          <NavLink
            className={classNames({
              "active nav-link": activeLeftTab === "element",
            })}
            onClick={() => setActiveLeftTab("element")}
          >
            <Headings>ELEMENT</Headings>
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={classNames({
              "active nav-link": activeLeftTab === "objects",
            })}
            onClick={() => setActiveLeftTab("objects")}
          >
            <Headings>OBJECTS</Headings>
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={classNames({
              "active nav-link": activeLeftTab === "block",
            })}
            onClick={() => setActiveLeftTab("block")}
          >
            <Headings>BLOCK</Headings>
          </NavLink>
        </NavItem>
      </Nav>
      <div className="d-flex flex-column elements-list block-setting ">
        <TabContent activeTab={activeLeftTab}>
          {/* Element Properties Tab */}
          <TabPane tabId="element">
            {/* Element Properties section */}
            <Accordion defaultActiveKey="0">
              <Accordion.Item eventKey="0">
                <Accordion.Header className="blockTitle">
                  <div className="object-listing">
                    <Headings>PROPERTIES</Headings>
                  </div>
                </Accordion.Header>
                <Accordion.Body>
                  {isValidArray(activeId) && (
                    <p className="text-danger">
                      {elementPropsErrors?.elementValGTBlockValue}
                    </p>
                  )}
                  <div className="d-flex align-items-center justify-content-between dimensions-field">
                    <InputField
                      id="blockWidth"
                      // isDisabled={isEditable}
                      className="details-single-element"
                      name="blockWidth"
                      type="text"
                      label={<Headings align="right">Width</Headings>}
                      isLabelRequired={true}
                      onChange={(e) => {
                        const mmWidth = blockWidth;
                        const widthVal = handleDecimalsOnValue(e.target.value);

                        if (widthVal <= mmWidth) {
                          updateElement({
                            width: Number(
                              parseFloat(mmTopx(e.target.value)).toFixed(2)
                            ),
                            widthInMm: handleDecimalsOnValue(e.target.value),
                          });
                          setElementPropsErrors({
                            ...elementPropsErrors,
                            blockWidth: "",
                          });
                        } else {
                          elementPropsError(
                            "blockWidth",
                            `Maximum width value can be ${
                              blockWidth - privateProps?.left
                            }`
                          );
                        }
                      }}
                      //NOTE - below is without any unit conversion
                      // value={
                      //   isValidArray(activeId) ? Number(privateProps?.width) : 0
                      // }
                      value={
                        isValidArray(activeId) ? privateProps?.widthInMm : 0
                      }
                    />
                    <InputField
                      id="blockHeight"
                      // isDisabled={isEditable}
                      className="details-single-element"
                      name="blockHeight"
                      type="text"
                      label={<Headings align="right">Height</Headings>}
                      isLabelRequired={true}
                      onChange={(e) => {
                        const mmHeight = blockHeight;

                        const heightVal = handleDecimalsOnValue(e.target.value);

                        if (heightVal <= mmHeight) {
                          updateElement({
                            height: Number(
                              parseFloat(mmTopx(e.target.value)).toFixed(2)
                            ),
                            heightInMm: handleDecimalsOnValue(e.target.value),
                          });
                          setElementPropsErrors({
                            ...elementPropsErrors,
                            blockHeight: "",
                          });
                        } else {
                          elementPropsError(
                            "blockHeight",
                            `Maximum height value can be ${
                              blockHeight - privateProps?.top
                            }`
                          );
                        }
                      }}
                      //NOTE - below is without any unit conversion
                      // value={
                      //   isValidArray(activeId)
                      //     ? Number(privateProps?.height)
                      //     : 0
                      // }
                      value={
                        isValidArray(activeId) ? privateProps?.heightInMm : 0
                      }
                    />
                  </div>
                  {isValidArray(activeId) && (
                    <p className="text-danger">
                      {elementPropsErrors?.blockWidth}
                    </p>
                  )}
                  {isValidArray(activeId) && (
                    <p className="text-danger">
                      {elementPropsErrors?.blockHeight}
                    </p>
                  )}
                  <div className="d-flex align-items-center justify-content-between dimensions-field">
                    <InputField
                      id="xPos"
                      // isDisabled={isEditable}
                      className="details-single-element border-color-disabled"
                      name="xPos"
                      type="text"
                      label={<Headings align="right">X Pos</Headings>}
                      isLabelRequired={true}
                      onChange={(e) => {
                        if (
                          e.target.value <=
                          Number(
                            pxTomm(parseInt(blockHeight)) -
                              privateProps?.heightInMm
                          )
                        ) {
                          updateElement(
                            {
                              top: Number(
                                parseFloat(mmTopx(e.target.value)).toFixed(2)
                              ),
                              topInMm: parseFloat(e.target.value).toFixed(2),
                            },
                            "table"
                          );
                          setElementPropsErrors({
                            ...elementPropsErrors,
                            xPos: "",
                          });
                        } else {
                          elementPropsError(
                            "xPos",
                            `Maximum value can be ${
                              blockHeight - privateProps?.height
                            }`
                          );
                        }
                      }}
                      value={
                        isValidArray(activeId)
                          ? Number(privateProps?.topInMm)
                          : 0
                      }
                      isDisabled={true}
                    />
                    <InputField
                      id="yPos"
                      // isDisabled={isEditable}
                      className="details-single-element border-color-disabled"
                      name="yPos"
                      type="text"
                      label={<Headings align="right">Y Pos</Headings>}
                      isLabelRequired={true}
                      onChange={(e) => {
                        if (
                          e.target.value <=
                          Number(pxTomm(parseInt(blockHeight))) -
                            privateProps?.widthInMm
                        ) {
                          updateElement(
                            {
                              left: Number(
                                parseFloat(e.target.value).toFixed(2)
                              ),
                              leftInMm: parseFloat(e.target.value).toFixed(2),
                            },
                            "table"
                          );
                          setElementPropsErrors({
                            ...elementPropsErrors,
                            yPos: "",
                          });
                        } else {
                          elementPropsError(
                            "yPos",
                            `Maximum value can be ${
                              blockHeight - privateProps?.width
                            }`
                          );
                        }
                      }}
                      value={
                        isValidArray(activeId)
                          ? Number(privateProps?.leftInMm)
                          : 0
                      }
                      isDisabled={true}
                    />
                  </div>
                  {isValidArray(activeId) && (
                    <p className="text-danger">{elementPropsErrors?.xPos}</p>
                  )}
                  <div className="d-flex align-items-center justify-content-between dimensions-field"></div>
                  {isValidArray(activeId) && (
                    <p className="text-danger">{elementPropsErrors?.yPos}</p>
                  )}
                  <div className="d-flex align-items-center justify-content-between dimensions-field">
                    <InputField
                      id="rotate"
                      // isDisabled={isEditable}
                      className="details-single-element"
                      name="rotate"
                      type="text"
                      label={<Headings align="right">Rotation</Headings>}
                      isLabelRequired={true}
                      onChange={(e) =>
                        updateElement({
                          rotate: Number(e.target.value),
                        })
                      }
                      value={
                        isValidArray(activeId)
                          ? changeRotateValue(privateProps?.rotate)
                          : 0
                      }
                    />
                  </div>
                  <Headings>Padding</Headings>
                  <div
                    className="px-1"
                    style={{
                      display: "flex",
                      flexDirection: "row",
                      marginTop: 10,
                    }}
                  >
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingTop"
                        // isDisabled={isEditable}
                        className="details-single-element"
                        name="paddingTop"
                        type="text"
                        label={<>Top</>}
                        isLabelRequired={true}
                        onChange={(e) => {
                          updateElement({
                            padding: {
                              ...privateProps.padding,
                              top: Number(e.target.value),
                            },
                          });
                        }}
                        value={
                          isValidArray(activeId)
                            ? Number(privateProps?.padding?.top)
                            : 0
                        }
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingRight"
                        // isDisabled={isEditable}
                        className="details-single-element"
                        name="paddingRight"
                        type="text"
                        label={<>Right</>}
                        isLabelRequired={true}
                        onChange={(e) =>
                          updateElement({
                            padding: {
                              ...privateProps.padding,
                              right: Number(e.target.value),
                            },
                          })
                        }
                        value={
                          isValidArray(activeId)
                            ? Number(privateProps?.padding?.right)
                            : 0
                        }
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingBottom"
                        // isDisabled={isEditable}
                        className="details-single-element"
                        name="paddingBottom"
                        type="text"
                        label={<>Bottom</>}
                        isLabelRequired={true}
                        onChange={(e) =>
                          updateElement({
                            padding: {
                              ...privateProps.padding,
                              bottom: Number(e.target.value),
                            },
                          })
                        }
                        value={
                          isValidArray(activeId)
                            ? Number(privateProps?.padding?.bottom)
                            : 0
                        }
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingLeft"
                        // isDisabled={isEditable}
                        className="details-single-element"
                        name="paddingLeft"
                        type="text"
                        label={<div className="mr=5">Left</div>}
                        isLabelRequired={true}
                        onChange={(e) =>
                          updateElement({
                            padding: {
                              ...privateProps.padding,
                              left: Number(e.target.value),
                            },
                          })
                        }
                        value={
                          isValidArray(activeId)
                            ? Number(privateProps?.padding?.left)
                            : 0
                        }
                      />
                    </div>
                  </div>
                  <div>
                    <Headings>Stroke Color</Headings>
                    <div className="px-3">
                      <InputField
                        id="bgColor"
                        isDisabled={
                          privateProps?.name === "image" || activeId.length > 1
                        }
                        className="details-single-element"
                        name="strokeColor"
                        type="color"
                        isLabelRequired={false}
                        onChange={(e) => {
                          if (privateProps.name === "rectangle") {
                            updateElement({
                              strokeColor: e.target.value,
                            });
                          }
                        }}
                        value={
                          isValidArray(activeId) ? privateProps?.strokeColor : 0
                        }
                      />
                    </div>
                  </div>
                  <div>
                    <Headings>Fill Color</Headings>
                    <div className="px-3">
                      <InputField
                        id="bgColor"
                        isDisabled={
                          privateProps?.name === "image" || activeId.length > 1
                        }
                        className="details-single-element"
                        name="bgColor"
                        type="color"
                        isLabelRequired={false}
                        onChange={(e) => {
                          if (privateProps.name === "triangle") {
                            updateElement({
                              triangleColor: e.target.value,
                            });
                          } else
                            updateElement({
                              backgroundColor: e.target.value,
                            });
                        }}
                        value={
                          isValidArray(activeId)
                            ? privateProps?.name === "triangle"
                              ? privateProps?.triangleColor
                              : privateProps?.backgroundColor
                            : 0
                        }
                      />
                    </div>
                  </div>
                </Accordion.Body>
              </Accordion.Item>
            </Accordion>
            {/* table  || text properties section */}
            {(selectedElement && selectedElement?.name === "table") ||
            selectedElement?.name === "text" ? (
              <div className="object-listing">
                <Accordion defaultActiveKey="0">
                  <Accordion.Item eventKey="0">
                    <Accordion.Header className="blockTitle">
                      <Headings>
                        {" "}
                        {selectedElement?.name === "table"
                          ? "TABLE PROPERTIES"
                          : selectedElement?.name === "text"
                          ? "TEXT PROPERTIES"
                          : null}
                      </Headings>
                    </Accordion.Header>
                    <Accordion.Body>
                      {" "}
                      <div className="px-3">
                        {selectedElement?.name === "text" ? (
                          <>
                            <div className="d-flex align-items-center justify-content-between dimensions-field">
                              <InputField
                                id="bgColor"
                                isDisabled={
                                  !isValidArray(activeId) ||
                                  privateProps?.name === "image" ||
                                  activeId.length > 1
                                }
                                className="details-single-element"
                                name="bgColor"
                                type="color"
                                label={
                                  <Headings align="end">Font Color</Headings>
                                }
                                onChange={(e) => {
                                  updateElement({
                                    fontColor: e.target.value,
                                  });
                                }}
                                value={
                                  isValidArray(activeId)
                                    ? privateProps?.triangleColor
                                    : 0
                                }
                                isLabelRequired={true}
                              />
                            </div>
                            <div className="d-flex align-items-center justify-content-between dimensions-field">
                              <InputField
                                id="fontSize"
                                className="details-single-element"
                                name="fontSize"
                                type="text"
                                label={
                                  <Headings align="end">Font Size</Headings>
                                }
                                onChange={(e) => {
                                  if (privateProps?.height > e.target.value) {
                                    updateElement({
                                      fontSize: Number(e.target.value),
                                    });
                                  }
                                }}
                                value={privateProps?.fontSize || 0}
                                isLabelRequired={true}
                              />
                            </div>
                            <div className="d-flex align-items-center justify-content-between dimensions-field">
                              <SelectField
                                id="fontUnit"
                                name="fontUnit"
                                label={
                                  <Headings align="end">Font Unit</Headings>
                                }
                                placeholder=""
                                isLabelRequired={true}
                                onChange={(value) => {
                                  updateElement({
                                    fontUnit: value,
                                  });
                                  setFontUnit(value);
                                }}
                                options={[
                                  { label: "mm", value: "mm" },
                                  { label: "pt", value: "pt" },
                                ]}
                                value={fontUnit}
                                // isDisabled={true}
                              />
                            </div>
                            <div className="d-flex align-items-center justify-content-between dimensions-field">
                              <SelectField
                                id="fontUnit"
                                name="fontUnit"
                                label={
                                  <Headings align="end">Font Family</Headings>
                                }
                                placeholder=""
                                isLabelRequired={true}
                                onChange={(value) =>
                                  updateElement({ fontFamily: value })
                                }
                                options={[{ label: "Roboto", value: "Roboto" }]}
                                value={{ label: "Roboto", value: "Roboto" }}
                                // isDisabled={true}
                              />
                            </div>
                          </>
                        ) : selectedElement?.name === "table" ? (
                          <>
                            <div className="d-flex align-items-center justify-content-between dimensions-field">
                              <InputField
                                id="bgColor"
                                isDisabled={
                                  !isValidArray(activeId) ||
                                  privateProps?.name === "image" ||
                                  activeId.length > 1
                                }
                                className="details-single-element"
                                name="bgColor"
                                type="color"
                                label={
                                  <Headings align="end">Font Color</Headings>
                                }
                                onChange={(e) => {
                                  updateElement(
                                    {
                                      fontColor: e.target.value,
                                    },
                                    "table"
                                  );
                                  // updateElementChanges(targets);
                                }}
                                value={
                                  isValidArray(activeId)
                                    ? privateProps?.fontColor
                                    : 0
                                }
                                isLabelRequired={true}
                              />
                            </div>
                            <div className="d-flex align-items-center justify-content-between dimensions-field">
                              <InputField
                                id="fontSize"
                                className="details-single-element"
                                name="fontSize"
                                type="text"
                                label={
                                  <Headings align="end">Font Size</Headings>
                                }
                                onChange={(e) => {
                                  if (privateProps?.height > e.target.value) {
                                    updateElement(
                                      { fontSize: e.target.value },
                                      "table",
                                      "fontSize"
                                    );
                                  }
                                }}
                                value={privateProps?.fontSize || 0}
                                isLabelRequired={true}
                              />
                            </div>

                            <div className="d-flex align-items-center justify-content-between dimensions-field">
                              <SelectField
                                id="fontUnit"
                                name="fontUnit"
                                label={<Headings>Font Unit</Headings>}
                                placeholder=""
                                isLabelRequired={true}
                                onChange={(value) =>
                                  updateElement({ fontUnit: value }, "table")
                                }
                                options={[
                                  { label: "mm", value: "mm" },
                                  { label: "pt", value: "pt" },
                                ]}
                                value={privateProps?.fontUnit}
                              />
                            </div>
                            <div className="d-flex align-items-center justify-content-between dimensions-field">
                              <SelectField
                                id="fontUnit"
                                name="fontUnit"
                                label={<Headings>Font Family</Headings>}
                                placeholder=""
                                isLabelRequired={true}
                                onChange={(value) =>
                                  updateElement({ fontFamily: value })
                                }
                                options={[{ label: "Roboto", value: "Roboto" }]}
                                value={{ label: "Roboto", value: "Roboto" }}
                                // isDisabled={true}
                              />
                            </div>
                            {/* <Button
                              onClick={() => window.location.reload()}
                              className="mt-2"
                            >
                              Reload For Change Reflection
                            </Button> */}
                          </>
                        ) : null}
                      </div>
                    </Accordion.Body>
                  </Accordion.Item>
                </Accordion>
              </div>
            ) : null}
            {/* apply css section */}
            <Accordion defaultActiveKey="0">
              <Accordion.Item eventKey="0">
                <Accordion.Header className="blockTitle">
                  <Headings>CSS</Headings>
                </Accordion.Header>
                <Accordion.Body className="text-center">
                  <div>
                    <TextArea
                      id="customCSS"
                      className=""
                      disabled={privateProps?.name === "triangle"}
                      name="customCSS"
                      onChange={(e) => setTempCSSstore(e.target.value)}
                      value={isValidArray(activeId) ? tempCSSstore : ""}
                    />
                    {isValidArray(activeId) && (
                      <p className="text-danger">
                        {elementPropsErrors?.cssProperties}
                      </p>
                    )}
                  </div>
                  <Button onClick={() => cssSubmit()} className="mt-2">
                    Apply CSS
                  </Button>
                </Accordion.Body>
              </Accordion.Item>
            </Accordion>
          </TabPane>

          {/* object tab */}
          <TabPane tabId="objects">
            <div className="block-setting-merge">
              <div className="object-listing">
                {targets.map((d, i) => (
                  <p
                    style={{
                      cursor: "pointer",
                      color: "#000058",
                      fontWeight: "500",
                      height: 22,
                      fontSize: "12px",
                    }}
                    className="w-100 mx-auto"
                    key={i}
                    onClick={(e) => {
                      e.preventDefault();
                      e.stopPropagation();
                      // if (!isActive) {
                      if (e?.shiftKey) {
                        setActiveId([...activeId, d?.id]);
                      } else {
                        if (isValidArray(d?.groupWith)) {
                          setActiveId([...d.groupWith]);
                        } else {
                          setActiveId([d?.id]);
                        }
                      }
                      // }
                    }}
                  >
                    {capitalizeFirstLetter(d?.name)}
                  </p>
                ))}
              </div>
            </div>
          </TabPane>

          {/* block tab */}
          <TabPane tabId="block">
            <Accordion defaultActiveKey="0">
              <Accordion.Item eventKey="0">
                <Accordion.Header className="blockTitle">
                  <Headings>SETTINGS</Headings>
                </Accordion.Header>
                <Accordion.Body>
                  {" "}
                  <div className="d-flex align-items-center dimensions-field">
                    <SelectField
                      className="merge-level"
                      id="MergeLevel"
                      label={<Headings>Unit Type</Headings>}
                      placeholder=""
                      isLabelRequired={true}
                      onChange={(value) => blockSettingUnitChange(value)}
                      options={[
                        { label: "mm", value: "mm" },
                        { label: "px", value: "px" },
                      ]}
                      value={blockSettingUnit}
                      isDisabled={true}
                    />
                  </div>
                  <div className="d-flex align-items-center dimensions-field">
                    <InputField
                      id="name"
                      className="details-single-element"
                      name="name"
                      type="text"
                      label={<Headings>Name</Headings>}
                      isLabelRequired={true}
                      onChange={(e) => setBlockName(e.target.value)}
                      value={blockName}
                      isDisabled={true}
                    />
                  </div>
                  <div className="d-flex align-items-center dimensions-field">
                    <InputField
                      id="blockWidth"
                      className="details-single-element"
                      name="blockWidth"
                      type="text"
                      label={<Headings>Width</Headings>}
                      isLabelRequired={true}
                      onChange={(e) =>
                        setBlockWidth(
                          blockWidth.length === 7
                            ? blockWidth
                            : e.target.value.replace(/\D/, "")
                        )
                      }
                      value={displayWidth}
                      isDisabled={true}
                    />
                  </div>
                  <div className="d-flex align-items-center dimensions-field">
                    <InputField
                      id="blockHeight"
                      className="details-single-element"
                      name="blockHeight"
                      type="text"
                      label={<Headings>Height</Headings>}
                      isLabelRequired={true}
                      onChange={(e) =>
                        setBlockHeight(
                          blockHeight.length === 7
                            ? blockHeight
                            : e.target.value.replace(/\D/, "")
                        )
                      }
                      value={displayHeight}
                      isDisabled={true}
                    />
                  </div>
                  <div className="d-flex align-items-center dimensions-field">
                    <SelectField
                      className="merge-level"
                      id="MergeLevel"
                      name="MergeLevel"
                      label={<Headings>Merge Level</Headings>}
                      placeholder=""
                      isLabelRequired={true}
                      onChange={(value) => blockSettingUnitChange(value)}
                      options={getCategoryMergeLevels && getCategoryOptions()}
                      value={blockCategory}
                      isDisabled={true}
                    />
                  </div>
                </Accordion.Body>
              </Accordion.Item>
            </Accordion>
          </TabPane>
        </TabContent>
      </div>
    </div>
  );
};

export default ElementPropertiesHandler;
