import React, { useEffect, useState } from "react";
import { Input, Label } from "reactstrap";
import { useDispatch, useSelector } from "react-redux";
import { Container, Row, Col } from "reactstrap";
import InputField from "components/Common/InputField";
import { fetchGetUserCatalogDetail } from "redux/actions/output/getUserCatalogDetail";
import { fetchSaveLayoutOptions } from "redux/actions/blockBuilder/saveLayoutOptions";
import { useCustomHook } from "./CustomHook";
import { fetchSavePageOptions } from "redux/actions/blockBuilder/savePageOptions";
import { isValidArray, showSuccessErrorToast } from "modules/utils";
import { fetchGetPageOptions } from "redux/actions/blockBuilder/getPageOption";
import { fetchGetLayoutOptions } from "redux/actions/blockBuilder/getLayoutOptions";
import Loader from "components/Common/Loader";
import { fetchGetCategoryMergeLevels } from "redux/actions/blockBuilder/getCategoryMergeLevels";
import { fetchGetDefaultBlockSizeOptions } from "redux/actions/blockBuilder/getDefaultBlockSizeOption";
import { fetchGetBuildPagesOptions } from "redux/actions/blockBuilder/getBuildPagesOptions";
import { fetchSaveBuildPagesOptions } from "redux/actions/blockBuilder/saveBuildPageOptions";
import { fetchGetBuildPagesDetails } from "redux/actions/blockBuilder/getBuildPagesDetails";

const orientationOptions = [
  { label: "Landscape", value: "landscape" },
  { label: "Portrait", value: "portrait" },
];

export default function BuildPages() {
  const dispatch = useDispatch();

  useEffect(() => {
    loadMergeLevelAndBlockSize();
    loadPageInitData();
    loadLayoutInitData();
    dispatch(fetchGetUserCatalogDetail());
  }, []);

  const {
    getPageOptionsLoading = false,
    getLayoutOptionsLoading = false,
    getBlockSizeOptionLoading = false,
    getBuildPagesOptionLoading = false,
    saveBuildPagesOptionsLoading = false,
    getCategoryMergeLevelLoading = false,
    getBlockSizeOption = null,
    getLayoutOptions = null,
    getCategoryMergeLevel = null,
  } = useSelector((state) => ({
    getPageOptionsLoading: state.getUserCatalogDetail.loading,
    getLayoutOptionsLoading: state.getUserCatalogDetail.loading,
    getLayoutOptions: state.getLayoutOptions.data?.data,
    getCategoryMergeLevel: state.getCategoryMergeLevels.data?.data,
    getCategoryMergeLevelLoading: state.getCategoryMergeLevels.loading,
    getBlockSizeOptionLoading: state.getDefaultBlockSizeOptions.loading,
    getBuildPagesOptionLoading: state.getBuildPageOptions.loading,
    saveBuildPagesOptionsLoading: state.saveBuildPagesOptions.loading,
    getBlockSizeOption: state.getDefaultBlockSizeOptions.data?.data,
  }));

  const {
    layoutVariant,
    columnLayoutVariant,
    assembly,
    sectionValue,
    pageSize,
    orientation,
    marginTop,
    marginBottom,
    marginLeft,
    marginRight,
    verticalGutter,
    horizontalGutter,
    layoutError,
    columnError,
    assemblyError,
    sectionsError,
    pageSizeError,
    orientationError,
    marginLeftError,
    marginRightError,
    marginTopError,
    marginBottomError,
    gutterVerticalError,
    gutterHorizontalError,
    blockSizes,
    setLayoutVariant,
    setColumnLayoutVariant,
    setAssembly,
    setSectionValue,
    setPageSize,
    setOrientation,
    setMarginTop,
    setMarginBottom,
    setMarginLeft,
    setMarginRight,
    setVerticalGutter,
    setHorizontalGutter,
    setBlockSize,
  } = useCustomHook();

  const loadMergeLevelAndBlockSize = () => {
    dispatch(fetchGetCategoryMergeLevels()).then((levels) => {
      dispatch(fetchGetDefaultBlockSizeOptions()).then((data) => {
        if (data?.data) {
          getBuildPage();
          // let newData = {};
          // const blockData =
          //   levels?.data &&
          //   levels?.data.map((d) => {
          //     newData = { ...newData, [d]: { blockSizeID: 0, newPage: 0 } };
          //   });

          // setBlockSize(newData);
        }
      });
    });
  };

  const loadPageInitData = () => {
    dispatch(fetchGetPageOptions()).then((data) => {
      if (data?.data) {
        console.log("pageSize", data?.data);
        setMarginTop(data?.data?.topMargin);
        setMarginBottom(data?.data?.bottomMargin);
        setMarginLeft(data?.data?.leftMargin);
        setMarginRight(data?.data?.rightMargin);
        setVerticalGutter(data?.data?.verticalGutter);
        setHorizontalGutter(data?.data?.horizontalGutter);
        setOrientation(data?.data?.orientation);
        setPageSize(data?.data?.pageSize);
      }
    });
  };

  const loadLayoutInitData = () => {
    dispatch(fetchGetLayoutOptions()).then((data) => {
      if (data?.data) {
        setLayoutVariant(data?.data?.layout);
        setColumnLayoutVariant(data?.data?.columnLayout);
        setAssembly(data?.data?.assembly);
        setSectionValue(data?.data?.section);
      }
    });
  };

  const [isSubmitLayout, setSubmitLayout] = useState("");
  const [isSubmitPage, setSubmitPage] = useState("");

  const submitLayoutOption = () => {
    setSubmitLayout(isSubmitLayout + 1);
    if (!(layoutError || columnError || assemblyError || sectionsError)) {
      const passData = {
        layout: layoutVariant,
        columnLayout: columnLayoutVariant,
        assembly: assembly,
        section: sectionValue,
      };

      dispatch(fetchSaveLayoutOptions(passData));
    }
  };
  const submitPageOption = () => {
    setSubmitPage(isSubmitPage + 1);
    if (
      !(
        pageSizeError ||
        orientationError ||
        marginLeftError ||
        marginRightError ||
        marginTopError ||
        marginBottomError ||
        gutterVerticalError ||
        gutterHorizontalError
      )
    ) {
      const passData = {
        pageSize: pageSize,
        orientation: orientation,
        topMargin: marginTop,
        bottomMargin: marginBottom,
        leftMargin: marginLeft,
        rightMargin: marginRight,
        verticalGutter,
        horizontalGutter,
      };

      dispatch(fetchSavePageOptions(passData)).then((d) => {
        loadPageInitData();
      });
    }
  };

  const submitBuildPagesOption = () => {
    const passData = {
      data: blockSizes,
    };

    dispatch(fetchSaveBuildPagesOptions(passData));
    getBuildPage();
  };

  const getBuildPages = () => {
    dispatch(fetchGetBuildPagesDetails()).then((data) => {
      showSuccessErrorToast(true, data?.message);
    });
  };

  const getBuildPage = () => {
    dispatch(fetchGetBuildPagesOptions()).then((data) => {
      if (data) {
        let newData = {};
        Object.keys(data?.data).map((d) => {
          newData = {
            ...newData,
            [d]: {
              blockSizeID: data?.data?.[d]?.blockSizeID
                ? data?.data?.[d]?.blockSizeID
                : 0,
              newPage: data?.data?.[d]?.newPage || 0,
              level: d,
            },
          };
        });

        // // setBlockSize(newData);
        setBlockSize(newData);
      }
    });
  };

  const getErrorFlag = (error) => !!error && !!isSubmitLayout;
  const getErrorFlagPage = (error) => !!error && !!isSubmitPage;

  const showError = (error) => {
    if (getErrorFlag(error)) {
      return (
        <div className="text-danger input-feedback font12 mt-2">{error}</div>
      );
    }
    return null;
  };
  const showErrorPage = (error) => {
    if (getErrorFlagPage(error)) {
      return (
        <div className="text-danger input-feedback font12 mt-2">{error}</div>
      );
    }
    return null;
  };

  if (
    getPageOptionsLoading ||
    getLayoutOptionsLoading ||
    getBuildPagesOptionLoading ||
    saveBuildPagesOptionsLoading ||
    getCategoryMergeLevelLoading
  ) {
    return <Loader />;
  }

  const categoryLevelBlockSize =
    getCategoryMergeLevel &&
    getBlockSizeOption &&
    getCategoryMergeLevel.map((d) => {
      return {
        catName: d,
        defaultBlockSizeOption: getBlockSizeOption || [],
        startOnNewPage: false,
      };
    });

  const handleBlockSize = (catName, sizeId) => {
    setBlockSize({
      ...blockSizes,
      [catName]: {
        ...blockSizes?.[catName],
        blockSizeID: sizeId,
      },
    });
  };

  const handleNewPage = (catName, check) => {
    setBlockSize({
      ...blockSizes,
      [catName]: {
        ...blockSizes?.[catName],
        newPage: check ? 1 : 0,
      },
    });
  };

  return (
    <div className="bg-white common-space output-create-file-section">
      <div className="row">
        <div className="col-6">
          <Container className="cat-log mt-3">
            <h6 className="mb-5">
              {`Catalog pages have not yet been built for your catalog. Clicking the
            "Check setup" button below will check that you catalog/categories
            have been setup correctly prior to building wireframes. Clicking the
            "Build" button below will build wireframe catalog pages for all of
            your content. Depending on the number of products and your selected
            page layouts this process may take up to 5 minutes.`}
            </h6>
            <Row className="mb-4">
              <Col sm="4">
                <h6 className="text-left">Category Level</h6>
              </Col>
              <Col sm="4">
                <Label check className="mr-3 ml-3">
                  <h6 className="text-left">Default Block Size</h6>
                </Label>
              </Col>
              <Col sm="4">
                <Label check className="mr-3 ml-3">
                  <h6 className="text-left">Start on new page</h6>
                </Label>
              </Col>
            </Row>
            {categoryLevelBlockSize &&
              categoryLevelBlockSize.map((d, i) => {
                return (
                  <>
                    <Row className="mb-4" key={`${d?.catName}${i}`}>
                      <Col sm="4">
                        <h6 className="text-left">{d?.catName} </h6>
                      </Col>
                      <Col sm="4">
                        <Input
                          type="select"
                          name="sections"
                          isFirstOption={true}
                          isLower={true}
                          isSearchable={true}
                          options={d?.defaultBlockSizeOption}
                          selected={blockSizes?.[d?.catName]?.blockSizeID}
                          value={blockSizes?.[d?.catName]?.blockSizeID}
                          onChange={(e) => {
                            handleBlockSize(
                              d?.catName,
                              parseInt(e.target.value)
                            );
                          }}
                        >
                          {
                            <option disabled={false} value={0}>
                              N/A
                            </option>
                          }
                          {isValidArray(d?.defaultBlockSizeOption) &&
                            d?.defaultBlockSizeOption.map((item, i) => {
                              return (
                                <option key={i} value={item?.BlockSizeID}>
                                  {item?.BlockSizeName}
                                </option>
                              );
                            })}
                        </Input>
                      </Col>
                      <Col sm="4">
                        <Input
                          type="checkbox"
                          name={blockSizes?.[d?.catName]}
                          checked={
                            blockSizes?.[d?.catName]?.newPage === 1
                              ? true
                              : false
                          }
                          onChange={() => {
                            handleNewPage(
                              d?.catName,
                              blockSizes?.[d?.catName]?.newPage === 1 ? 0 : 1
                            );
                          }}
                          style={{ marginLeft: "20%" }}
                        />
                      </Col>
                    </Row>
                  </>
                );
              })}
            <Row className="mb-4">
              {/* <Col sm="4">
                <div
                  className="create-file-btn-section"
                  style={{ alignContent: "center" }}
                >
                  <button
                    type="button"
                    className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                    value="submit_export"
                    name="submit_export"
                    // onClick={() => {
                    //   submitBuildPagesOption();
                    // }}
                    disabled
                  >
                    Check setup
                  </button>
                </div>
              </Col> */}
              <Col sm="4">
                <Label check className="mr-3 ml-3">
                  <div
                    className="create-file-btn-section"
                    style={{ alignContent: "center" }}
                  >
                    <button
                      type="button"
                      className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                      value="submit_export"
                      name="submit_export"
                      onClick={() => {
                        getBuildPages();
                      }}
                    // disabled
                    >
                      Build pages
                    </button>
                  </div>
                </Label>
              </Col>
              <Col sm="4">
                <Label check className="mr-3 ml-3">
                  <div
                    className="create-file-btn-section"
                    style={{ alignContent: "center" }}
                  >
                    <button
                      type="button"
                      className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                      value="submit_export"
                      name="submit_export"
                      onClick={() => {
                        submitBuildPagesOption();
                      }}
                    >
                      Save
                    </button>
                  </div>
                </Label>
              </Col>
            </Row>
          </Container>
        </div>
      </div>
      <div className="row">
        <div className="col-6">
          <div className="export-name">
            <h4 className="output-tab-title mb-5 mt-0">
              <strong>Layout Option</strong>
            </h4>
          </div>
          <Container className="cat-log">
            <Row className="mb-4">
              <Col sm="4">
                <h6 className="text-left">Layout </h6>
              </Col>
              <Col
                sm="4"
                onClick={(e) => {
                  setLayoutVariant("Flow");
                }}
              >
                <Input
                  type="radio"
                  name="flow"
                  checked={layoutVariant === "Flow"}
                />
                <Label check className="mr-3 ml-3">
                  Flow
                </Label>
              </Col>
              <Col
                sm="4"
                onClick={(e) => {
                  setLayoutVariant("Grid");
                }}
              >
                <Input
                  type="radio"
                  name="grid"
                  checked={layoutVariant === "Grid"}
                />
                <Label check className="mr-3 ml-3">
                  Grid
                </Label>
              </Col>
              {showError(layoutError)}
            </Row>
            <Row className="mb-4">
              <Col sm="4">
                <h6 className="text-left">Column Layout </h6>
              </Col>
              <Col sm="4" onClick={() => setColumnLayoutVariant("Across")}>
                <Input
                  type="radio"
                  name="across"
                  checked={columnLayoutVariant === "Across"}
                />
                <Label check className="mr-3 ml-3">
                  Across, Down
                </Label>
              </Col>
              <Col sm="4" onClick={() => setColumnLayoutVariant("Down")}>
                <Input
                  type="radio"
                  name="down"
                  checked={columnLayoutVariant === "Down"}
                />
                <Label check className="mr-3 ml-3">
                  Down, Accross
                </Label>
              </Col>
              {showError(columnError)}
            </Row>
            <Row className="mb-4">
              <Col sm="4">
                <h6 className="text-left">Assembly </h6>
              </Col>

              <Col sm="4" onClick={() => setAssembly("Spreads")}>
                <Input
                  type="radio"
                  name="spreads"
                  checked={assembly === "Spreads"}
                />
                <Label check className="mr-3 ml-3">
                  Spreads
                </Label>
              </Col>
              <Col sm="4" onClick={() => setAssembly("SinglePages")}>
                <Input
                  type="radio"
                  name="singlePages"
                  checked={assembly === "SinglePages"}
                />
                <Label check className="mr-3 ml-3">
                  Single Pages
                </Label>
              </Col>
              {showError(assemblyError)}
            </Row>
            <Row className="mb-4">
              <Col sm="4">
                <h6 className="text-left">Sections </h6>
              </Col>
              <Col sm="6">
                <Input
                  type="select"
                  name="sections"
                  isFirstOption={true}
                  isLower={true}
                  isSearchable={true}
                  options={getCategoryMergeLevel}
                  selected={sectionValue}
                  value={sectionValue}
                  onChange={(e) => {
                    setSectionValue(e.target.value);
                  }}
                >
                  {<option disabled={true}>Select Option</option>}
                  {isValidArray(getCategoryMergeLevel) &&
                    getCategoryMergeLevel.map((item, i) => {
                      return (
                        <option key={i} value={item}>
                          {item}
                        </option>
                      );
                    })}
                </Input>
                {showError(sectionsError)}
              </Col>
            </Row>
            <Row>
              <div
                className="create-file-btn-section"
                style={{ float: "right" }}
              >
                <button
                  type="button"
                  className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                  value="submit_export"
                  name="submit_export"
                  onClick={() => {
                    submitLayoutOption();
                  }}
                >
                  Save
                </button>
              </div>
            </Row>
          </Container>
        </div>

        {/* ///page setup */}

        <div className="col-6">
          <div className="export-name">
            <h4 className="output-tab-title mb-5 mt-0">
              <strong>Page Setup</strong>
            </h4>
          </div>
          <Container className="cat-log">
            <Row>
              <Col sm="6">
                <div className="catalog-layout-setup-box">
                  <div className="catalog-layout-setup-label">Page Size</div>

                  <Input
                    type="select"
                    name="sections"
                    isFirstOption={true}
                    isLower={true}
                    isSearchable={true}
                    options={[{ label: "A4", value: "A4" }]}
                    onChange={(e) => {
                      setPageSize(e.target.value);
                    }}
                    value={pageSize}
                  >
                    {<option disabled={pageSize && true}>Select Option</option>}
                    {<option value="A4">A4</option>}
                  </Input>
                  {showErrorPage(pageSizeError)}
                </div>
                <div className="catalog-layout-setup-box">
                  <div className="catalog-layout-setup-label">Orientation</div>

                  <Input
                    type="select"
                    name="sections"
                    isFirstOption={true}
                    isLower={true}
                    isSearchable={true}
                    options={orientationOptions}
                    value={orientation}
                    defaultValue={orientation}
                    selected={orientation}
                    onChange={(e) => {
                      setOrientation(e.target.value);
                    }}
                  >
                    {isValidArray(orientationOptions) &&
                      orientationOptions.map((item, i) => {
                        return (
                          <option key={i} value={item.value}>
                            {item.label}
                          </option>
                        );
                      })}
                  </Input>
                  {showErrorPage(orientationError)}
                </div>
                <div className="catalog-layout-setup-box">
                  <div className="catalog-layout-setup-label">Margins</div>
                  <div
                    className="px-1"
                    style={{
                      display: "flex",
                      flexDirection: "row",
                      marginTop: 10,
                    }}
                  >
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingTop"
                        className="layout-single-element"
                        name="paddingTop"
                        type="text"
                        label={<>Top</>}
                        isLabelRequired={true}
                        value={marginTop}
                        onChange={(e) => {
                          setMarginTop(e.target.value);
                        }}
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingRight"
                        className="layout-single-element"
                        name="paddingRight"
                        type="text"
                        label={<>Right</>}
                        isLabelRequired={true}
                        value={marginRight}
                        onChange={(e) => {
                          setMarginRight(e.target.value);
                        }}
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingBottom"
                        className="layout-single-element"
                        name="paddingBottom"
                        type="text"
                        label={<>Bottom</>}
                        isLabelRequired={true}
                        value={marginBottom}
                        onChange={(e) => {
                          setMarginBottom(e.target.value);
                        }}
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingLeft"
                        className="layout-single-element"
                        name="paddingLeft"
                        type="text"
                        label={<div className="mr=5">Left</div>}
                        isLabelRequired={true}
                        value={marginLeft}
                        onChange={(e) => {
                          setMarginLeft(e.target.value);
                        }}
                      />
                    </div>
                  </div>
                  {showErrorPage(
                    marginTopError ||
                    marginRightError ||
                    marginBottomError ||
                    marginLeftError
                  )}
                </div>
                <div className="catalog-layout-setup-box">
                  <div className="catalog-layout-setup-label">Gutter</div>
                  <div
                    className="px-1"
                    style={{
                      display: "flex",
                      flexDirection: "row",
                      marginTop: 10,
                    }}
                  >
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingTop"
                        className="layout-single-element"
                        name="paddingTop"
                        type="text"
                        label={<>Vert</>}
                        isLabelRequired={true}
                        value={verticalGutter}
                        onChange={(e) => {
                          setVerticalGutter(e.target.value);
                        }}
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingRight"
                        className="layout-single-element"
                        name="paddingRight"
                        type="text"
                        label={<>Horiz</>}
                        isLabelRequired={true}
                        value={horizontalGutter}
                        onChange={(e) => {
                          setHorizontalGutter(e.target.value);
                        }}
                      />
                    </div>
                  </div>
                  {showErrorPage(gutterVerticalError || gutterHorizontalError)}
                </div>
                <div className="create-file-btn-section">
                  <button
                    type="button"
                    className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                    value="submit_export"
                    name="submit_export"
                    onClick={() => submitPageOption()}
                  >
                    Save
                  </button>
                </div>
              </Col>
            </Row>
          </Container>
        </div>
      </div>
    </div>
  );
}
