import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { fetchGetLayoutOptions } from "redux/actions/blockBuilder/getLayoutOptions";
import { fetchGetPageOptions } from "redux/actions/blockBuilder/getPageOption";

export const useCustomHook = (getLayoutOptions, getPageOptions) => {
  const [layoutVariant, setLayoutVariant] = useState("");
  const [columnLayoutVariant, setColumnLayoutVariant] = useState("");
  const [assembly, setAssembly] = useState("");
  const [pageBreak, setPageBreak] = useState("");
  const [categoryValue, setCategoryValue] = useState("Category1");
  const [pageNumberValue, setPageNumberValue] = useState("NotSpecified");
  const [pageSizeWidth, setPageSizeWidth] = useState(getPageOptions?.pageSizeWidth);
  const [pageSizeHeight, setPageSizeHeight] = useState(getPageOptions?.pageSizeWidth);
  const [orientation, setOrientation] = useState();
  const [gridWidth, setGridWidth] = useState({ label: "12", value: "12" });
  const [gridHeight, setGridHeight] = useState({ label: "12", value: "12" });
  const [marginTop, setMarginTop] = useState(getPageOptions?.topMargin);
  const [marginBottom, setMarginBottom] = useState(getPageOptions?.bottomMargin);
  const [marginLeft, setMarginLeft] = useState(
    getPageOptions ? getPageOptions.leftMargin : null
  );

  const [marginRight, setMarginRight] = useState(getPageOptions?.rightMargin);
  const [verticalGutter, setVerticalGutter] = useState();
  const [horizontalGutter, setHorizontalGutter] = useState();
  const [blockSizes, setBlockSize] = useState();

  const getLayoutError = () => {
    if (!layoutVariant) {
      return "Layout field is required";
    }
  };
  const getColumnError = () => {
    if (!columnLayoutVariant) {
      return "Column field is required";
    }
  };
  const getAssemblyError = () => {
    if (!assembly) {
      return "Assembly field is required";
    }
  };
  const getPageBreakError = () => {
    if (!pageBreak) {
      return "PageBreak field is required";
    }
  };
  // const getSectionsError = () => {
  //   if (!categoryValue) {
  //     return "Section field is required";
  //   }
  // };

  const getPageSizeWidthError = () => {
    if (!pageSizeWidth) {
      return "Page width field is required";
    }
  };

  const getPageSizeHeightError = () => {
    if (!pageSizeHeight) {
      return "Page height field is required";
    }
  };

  const getOrientationError = () => {
    if (!orientation) {
      return "Orientation field is required";
    }
  };

  const getGridWidthError = () => {
    if (!gridWidth) {
      return "This field is required";
    }
  };

  const getGridHeightError = () => {
    if (!gridHeight) {
      return "This field is required";
    }
  };
  const getMarginRightError = () => {
    if (!marginRight) {
      return "Margin Right field is required";
    }
  };
  const getMarginLeftError = () => {
    if (!marginLeft) {
      return "Margin Left is required";
    }
  };
  const getMarginTopError = () => {
    if (!marginTop) {
      return "Margin Top field is required";
    }
  };
  const getMarginBottomError = () => {
    if (!marginBottom) {
      return "Margin Bottom field is required";
    }
  };
  const getGutterVerticalError = () => {
    if (!verticalGutter) {
      return "Gutter Vertical field is required";
    }
  };
  const getGutterHorizontalError = () => {
    if (!horizontalGutter) {
      return "Gutter Horizontal field is required";
    }
  };

  const layoutError = getLayoutError();
  const columnError = getColumnError();
  const assemblyError = getAssemblyError();
  const pageBreakError = getPageBreakError();
  // const sectionsError = getSectionsError();
  const pageSizeWidthError = getPageSizeWidthError();
  const pageSizeHeightError = getPageSizeHeightError();
  const orientationError = getOrientationError();
  const gridWidthError = getGridWidthError();
  const gridHeightError = getGridHeightError();
  const marginLeftError = getMarginLeftError();
  const marginRightError = getMarginRightError();
  const marginTopError = getMarginTopError();
  const marginBottomError = getMarginBottomError();
  const gutterVerticalError = getGutterVerticalError();
  const gutterHorizontalError = getGutterHorizontalError();

  return {
    layoutVariant,
    columnLayoutVariant,
    assembly,
    pageBreak,
    categoryValue,
    pageNumberValue,
    pageSizeWidth,
    pageSizeHeight,
    orientation,
    gridWidth,
    gridHeight,
    marginTop,
    marginBottom,
    marginLeft,
    marginRight,
    verticalGutter,
    horizontalGutter,
    layoutError,
    columnError,
    assemblyError,
    pageBreakError,
    // sectionsError,
    pageSizeWidthError,
    pageSizeHeightError,
    orientationError,
    gridWidthError,
    gridHeightError,
    marginLeftError,
    marginRightError,
    marginTopError,
    marginBottomError,
    gutterVerticalError,
    gutterHorizontalError,
    blockSizes,
    setLayoutVariant,
    setColumnLayoutVariant,
    setAssembly,
    setPageBreak,
    setCategoryValue,
    setPageNumberValue,
    setPageSizeWidth,
    setPageSizeHeight,
    setOrientation,
    setGridWidth,
    setGridHeight,
    setMarginTop,
    setMarginBottom,
    setMarginLeft,
    setMarginRight,
    setVerticalGutter,
    setHorizontalGutter,
    setBlockSize,
  };
};
