import Loader from "components/Common/Loader";
import Table from "components/Common/Table";
import jsPDF from "jspdf";
import { filterFieldData, mmTopx, pxTomm } from "modules/utils";
import React, { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import ReactTable from "react-table-6";
import { toast } from "react-toastify";
import { Button } from "reactstrap";
import { fetchGetCatalogPreview } from "redux/actions/blockBuilder/getCatalogPreview";
import {
  fetchGetSectionData,
  fetchGetSectionDataSuccess,
} from "redux/actions/blockBuilder/getSectionData";
import Headings from "../Headings";

export default function LayoutSections() {
  const dispatch = useDispatch();

  const { sectionDataLoading = false, sectionData = null } = useSelector(
    (state) => ({
      sectionDataLoading: state.getSectionData.loading,
      sectionData: state.getSectionData.data?.data || null,
    })
  );
  // console.log(
  //   "🚀 ~ file: LayoutSections.js ~ line 18 ~ LayoutSections ~ sectionDataLoading",
  //   sectionDataLoading,
  //   sectionData
  // );
  useEffect(() => {
    dispatch(fetchGetSectionData());
  }, []);

  const ReactTableColumns = [
    {
      Header: "Section Number.",
      id: "SectionIDNumber",
      accessor: "SectionID",
    },
    {
      Header: "Section Name",
      id: "SectionName",
      accessor: "SectionName",
    },
    {
      Header: "Content Type",
      id: "SectionContentType",
      accessor: "SectionContentType",
    },
    {
      Header: "Page Count",
      id: "PageCount",
      accessor: "PageCount",
    },
    {
      Header: "Last Generated",
      id: "SectionLastGenerated",
      accessor: "SectionLastGenerated",
    },
    {
      Header: "Content Last Updated",
      id: "-",
      accessor: "-",
    },
    {
      Header: "Generate",
      id: "-",
      accessor: "-",
    },
    {
      Header: "",
      id: "SectionID",
      accessor: (d) => (
        <>
          <Button
          // onClick={() => {
          //   handleAddUnitModal(d.UnitID);
          // }}
          >
            View
          </Button>
        </>
      ),
    },
  ];

  if (sectionDataLoading) {
    return <Loader />;
  }

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, sectionData, ["SectionName"]);
    }
    return sectionData;
  };

  const handlePDF = () => {
    dispatch(fetchGetCatalogPreview()).then((data) => {
      if (data?.message && !data?.flag) {
        toast.error(data?.message);
      }
      if (data && data?.data) {
        // console.log(
        //   "🚀 ~ file: LayoutSections.js ~ line 106 ~ dispatch ~ data?.data",
        //   data?.data
        // );

        // console.log(
        //   "🚀 ~ file: LayoutSections.js ~ line 111 ~ dispatch ~ pageData",
        //   pageData
        // );

        const bd = data?.data.pageSetup;
        // const cat = data?.data.category;
        const pageContent = data?.data.PDFContent;

        bd.forEach((singleDoc) => {

          //Create dummy PDF document
          var doc = new jsPDF({
            orientation: singleDoc.orientation,
            unit: singleDoc.pageUnitType
          });

          //Create the actual PDF document
          var newDoc = new jsPDF({
            orientation: singleDoc.orientation,
            unit: singleDoc.pageUnitType
          });
          
          pageContent.forEach((content, counter) => {
            
            const blockData = content.blockData;

            console.log(blockData);

            if(content.newPage == "1")
            {
              newDoc.addPage();
            }

            //Incrementing through each element
            //Rectangle
            blockData.forEach((d, i) => {
              if(singleDoc.CategoryID == d.CategoryID)
              {
                
                newDoc.setPage(d.PageNumber);

                if (d.name === "rectangle") {
                  newDoc.setFillColor(d.backgroundColor);
                  newDoc.rect(
                    d.newleftInMm,
                    d.newtopInMm,
                    d.widthInMm,
                    d.heightInMm,
                    "F"
                  );
                }

                //Image
                if (d.name === "image") {
                  // newDoc.setPage(counter);
                  const img = d.ImageSource;

                  if (img !== null) {
                    newDoc.addImage(
                      d.ImageSource.encoded,
                      d.ImageExtension,
                      d.newleftInMm,
                      d.newtopInMm,
                      pxTomm(d.ImageWidth),
                      pxTomm(d.ImageHeight),
                      undefined,
                      "FAST",
                      0
                    );
                  }
                }

                //Text
                if (d.name === "text") {
                  // newDoc.setPage(counter);
                  const textArray = d.ReplacedText;

                  newDoc.setFontSize(d.fontSize);
                  // newDoc.addFont('Roboto', 'Roboto', 'normal');
                  newDoc.setFont("helvetica");
                  newDoc.setTextColor(d.fontColor);

                  //extra 2 mm for text in the box.
                  let topPos = parseInt(d.newtopInMm + 3);
                  let numbersLength = textArray.length;
                  for (let i = 0; i < numbersLength; i++) {
                    var splitTitle = newDoc.splitTextToSize(
                      textArray[i],
                      d.widthInMm
                    );

                    newDoc.text(splitTitle, d.newleftInMm, topPos, {
                      align: "left",
                      baseline: "top"
                    });

                    topPos =
                      parseInt(topPos) +
                      parseInt(d.heightInMm) +
                      parseInt(d.verticalOffset);
                  }
                }

                //Table
                if (d.name === "table") {
                  //Loop through response and get height of table first.
                  var newHeight = 0;
                  if (
                    d.expansionAnchor === "bl" ||
                    d.expansionAnchor === "bc" ||
                    d.expansionAnchor === "br"
                  ) {
                    const arr = d.tableWidths;

                    const tabWidth = {};

                    Object.keys(arr).map((i, index) => {
                      tabWidth[i] = arr[i];
                    });

                    //Creating a dummy table to determine height.
                    doc.autoTable({
                      head: [d.tableHeaders],
                      body: d.tableBody,
                      // html: '#mytable',
                      theme: "plain",
                      tableWidth: d.widthInMm,
                      // tableLineColor: [0, 0, 0],
                      // tableLineWidth: 0.1,

                      styles: {
                        fontSize: d.fontSize,
                        minCellHeight: 1,
                        cellPadding: { top: 0, right: 0, bottom: 0, left: 0 },
                        overflow: "linebreak",
                      },
                      headStyles: {
                        lineWidth: 0.1,
                        lineColor: [0, 0, 0],
                        // fillColor : [124, 95, 240]
                        valign: "middle",
                        halign: "center",
                      },
                      bodyStyles: {
                        lineWidth: 0.1,
                        lineColor: [0, 0, 0],
                      },
                      // pageBreak: 'avoid',
                      // rowPageBreak: 'avoid',
                      margin: { top: 0, left: d.newleftInMm, bottom: 0 },

                      // startY: th,
                      startY: 0,
                      columnStyles: tabWidth,
                      didDrawPage: function (data) {
                        newHeight = data.cursor.y;
                      },
                    });
                  }

                  console.log("New Height: " + newHeight);
                  console.log("New Height: " + mmTopx(newHeight));


                  //End of Loop through response and get height of table first.

                  // newDoc.setPage(counter);
                  // var height = 0;
                  var th = d.newtopInMm - newHeight + d.heightInMm;
                  console.log("Final start point: " + th);
                  const arr = d.tableWidths;

                  const tabWidth = {};

                  Object.keys(arr).map((i, index) => {
                    tabWidth[i] = arr[i];
                  });

                  //Printing new table on PDF.
                  newDoc.autoTable({
                    head: [d.tableHeaders],
                    body: d.tableBody,
                    // html: '#mytable',
                    theme: "plain",
                    tableWidth: d.widthInMm,
                    // tableLineColor: [0, 0, 0],
                    // tableLineWidth: 0.1,

                    styles: {
                      fontSize: d.fontSize,
                      minCellHeight: 1,
                      cellPadding: { top: 0, right: 0, bottom: 0, left: 0 },
                      overflow: "linebreak",
                    },
                    headStyles: {
                      lineWidth: 0.1,
                      lineColor: [0, 0, 0],
                      // fillColor : [124, 95, 240]
                      valign: "middle",
                      halign: "center",
                    },
                    bodyStyles: {
                      lineWidth: 0.1,
                      lineColor: [0, 0, 0],
                    },
                    // pageBreak: 'avoid',
                    // rowPageBreak: 'avoid',
                    margin: { top: 0, left: d.newleftInMm, bottom: 0 },

                    startY: th,
                    // startY: d.newtopInMm,
                    columnStyles: tabWidth,
                    didDrawPage: function (data) {
                      // height = data.cursor.y;
                    },
                    willDrawCell: function (data) {
                      newDoc.setFillColor(67, 160, 71);
                    },
                    // willDrawCell: (data) => {
                    //     if (data.section == "body" && data.column.index != 0) {
                    //         newDoc.setDrawColor(41, 128, 186)
                    //         newDoc.setLineWidth(.5);
                    //         newDoc.line(data.cell.x, data.cell.y + data.row.height, data.cell.x, data.cell.y);
                    //     }
                    // }
                  });
                }

                // if(d.IsCollection != "1")
                // {
                //   newDoc.addPage();
                // }
              }
            });
          });

          // newDoc.save(categoryID?.value + "_" + cat.CategoryName +"_BlockPreview.pdf");
          newDoc.setProperties({
            title: singleDoc.BlockName,
          });
          // newDoc.output("dataurlnewwindow");
          window.open(newDoc.output("bloburl"));
        })
      }
    });
  };

  return (
    <div>
      <Headings>Layout Sections</Headings>
      <Headings>
        <Button
          onClick={() => {
            handlePDF();
          }}
        >
          Generate PDF
        </Button>
      </Headings>

      <div className="justify-content-center"></div>

      <div className="tableorganisation bg-white manage-user-tbl-section center-text-tbl product-tableBorder">
        <Table
          columns={ReactTableColumns}
          isLoading={sectionDataLoading}
          Data={sectionData}
          getFilterData={getFilterData}
        />
      </div>
    </div>
  );
}
