import React, { useEffect, useState } from "react";
import ManageCatalog from "components/ManageCatalog/ManageCatalog";
import { useLocation } from "react-router-dom";
import CatalogPlanner from "components/ManageCatalog/tabs/catalogPlanner/CatalogPlanner";
import { getLocalStorageItem, isValidArray } from "modules/utils";
import { useDispatch, useSelector } from "react-redux";
import Loader from "components/Common/Loader";
import {
  ButtonBack,
  ButtonNext,
  CarouselProvider,
  Slide,
  Slider,
} from "pure-react-carousel";
import "pure-react-carousel/dist/react-carousel.es.css";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import "intro.js/introjs.css";
import { Steps } from "intro.js-react";

export default function PagePlanner() {
  const dispatch = useDispatch();
  const search = useLocation().search;
  const catId = new URLSearchParams(search).get("id");
  const id = getLocalStorageItem("idForPagePlanner");
  const [catalogId, setCatalogId] = useState(catId);
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [stepsEnabledForSidebar, setStepsEnabledForSidebar] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);

  const {
    getUserCatalogDetailsPages = null,
    getUserCatalogDetailsPagesLoading = false,
    getPagePlannerByPageData = null,
    getPagePlannerByPageLoading = false,
  } = useSelector((state) => ({
    getUserCatalogDetailsPages: state.getUserCatalogDetail.data?.data?.Pages,
    getUserCatalogDetailsPagesLoading: state.getUserCatalogDetail?.loading,
    getPagePlannerByPageData: state.getPagePlannerByPage.data?.data,
    getPagePlannerByPageLoading: state.getPagePlannerByPage?.loading,
  }));

  const onExit = () => {
    setStepsEnabled(false);
  };

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = d.elementIDName;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  useEffect(() => {
    setCatalogId(id);
  }, [id]);

  useEffect(() => {
    dispatch(getIntroJs("layout")).then((data) => {
      console.log("getintro layout", data?.data);
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  // const pageSlider = () => {
  //   return (
  //     <>
  //       <CarouselProvider
  //         naturalSlideWidth={100}
  //         naturalSlideHeight={125}
  //         totalSlides={getUserCatalogDetailsPages?.length}
  //         visibleSlides={8}
  //       >
  //         <ButtonBack>
  //           <i className="fa-solid fa-angle-left"></i>
  //         </ButtonBack>
  //         <Slider>
  //           {getUserCatalogDetailsPages?.map((d) => {
  //             return (
  //               <Slide
  //                 key={d}
  //                 index={d}
  //                 onClick={() => getPageGridDataHandle(d)}
  //               >
  //                 <div style={{ textAlign: "center" }}>
  //                   <div
  //                     style={{
  //                       border: "1px solid",
  //                       backgroundColor: "white",
  //                       height: "100px",
  //                       width: "80px",
  //                       margin: "auto",
  //                     }}
  //                   ></div>
  //                   <span style={{ display: "block", textAlign: "center" }}>
  //                     {d}
  //                   </span>
  //                 </div>
  //               </Slide>
  //             );
  //           })}
  //         </Slider>

  //         <ButtonNext className="my-custom-next-btn">
  //           <i className="fa-solid fa-angle-right"></i>
  //         </ButtonNext>
  //       </CarouselProvider>
  //     </>
  //   );
  // };

  const pageBody = () => {
    return (
      <>
        <CatalogPlanner
          catalogId={catalogId}
          // slider={pageSlider()}
          pagePlannerDataLoading={getPagePlannerByPageLoading}
          pagePlannerData={getPagePlannerByPageData}
        />
      </>
    );
  };

  if (getUserCatalogDetailsPagesLoading) {
    return <Loader />;
  }

  return (
    <>
      <Steps
        enabled={stepsEnabled}
        steps={steps}
        initialStep={initialStep}
        onExit={onExit}
        onComplete={() => {
          setStepsEnabled(false);
          setStepsEnabledForSidebar(true);
        }}
        options={{ doneLabel: "Next" }}
      />
      <div>
        <ManageCatalog bodyPart={pageBody()} pagePlanner={true} />
      </div>
    </>
  );
}
