import { mmTopx } from "modules/utils";
import React, { Component } from "react";
import ContentEditable from "react-contenteditable";

class TextField extends Component {
  constructor(props) {
    super(props);
    this.contentEditable = React.createRef();
    this.state = { html: "", isEditable: false };

    this.setEditable = this.setEditable.bind(this);
    this.handleClick = this.handleClick.bind(this);
    this.handleChange = this.handleChange.bind(this);
    this.getBlockStyle = this.getBlockStyle.bind(this);
    this.handleBlur = this.handleBlur.bind(this);
  }

  componentDidMount() {
    const { properties } = this.props;
    this.setState({ html: properties?.innerTextValue || "" });
  }

  componentDidUpdate(prevProps, prevState) {
    const { properties } = this.props;
    if (prevProps?.properties?.innerTextValue !== properties.innerTextValue) {
      this.setState({ html: properties?.innerTextValue || "" });
    }
  }

  setEditable(flag) {
    this.setState({ isEditable: !!flag });
  }

  handleClick() {
    const { isEditable } = this.state;
    const { isActive } = this.props;

    if (isActive && !isEditable) {
      this.setEditable(true);
      setTimeout(() => {
        this.contentEditable.current.focus();
      }, 0);
    }
  }

  handleChange(evt) {
    const text = evt.target.value;
    this.setState({ html: text });
    this?.props?.updateText?.(text);
  }

  handleBlur() {
    const { isEditable } = this.state;
    if (isEditable) {
      this.setEditable(false);
    }
  }

  getBlockStyle() {
    const { properties } = this.props;

    const {
      backgroundColor,
      bold,
      fontColor,
      fontSize,
      italic,
      textAlign,
      underline,
      fontUnit,
    } = properties || {};
    const fontSizePtTomm = fontSize / 2.835;
    const fontSizeWithUnit =
      fontUnit === "mm"
        ? mmTopx(fontSize)
        : fontUnit === "pt"
        ? `${mmTopx(fontSizePtTomm)}px`
        : `${fontSize}${fontUnit}`;

    return {
      backgroundColor: backgroundColor,
      border: "none",
      color: fontColor,
      fontSize: fontSizeWithUnit,
      fontStyle: italic && "italic",
      fontWeight: bold && "bold",
      height: "100%",
      textAlign: textAlign,
      textDecoration: underline && "underline",
      width: "100%",
    };
  }

  render() {
    const { html, isEditable } = this.state;
    const { isActive } = this.props;

    const textCSS = this.getBlockStyle();

    if (isActive) {
      return (
        <ContentEditable
          disabled={!isEditable}
          html={html}
          innerRef={this.contentEditable}
          onBlur={this.handleBlur}
          onChange={this.handleChange}
          onClick={this.handleClick}
          style={textCSS}
        />
      );
    }

    return <div style={textCSS}>{html || ""}</div>;
  }
}

export default TextField;
