import { isValidObject, removeAuthToken } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useHistory } from "react-router";
import { Link } from "react-router-dom";
import downchevron from "../../assets/images/downchevron.png";
import bellIcon from "../../assets/images/bellicon.png";
import Producty_rev from "../../assets/images/Producty_rev.png";
import {
  Dropdown,
  DropdownItem,
  DropdownMenu,
  DropdownToggle,
} from "reactstrap";
import { useDispatch, useSelector } from "react-redux";
import { fetchNotificationList } from "redux/actions/notification.js/notificationList";
import { fetchNotificationMarkRead } from "redux/actions/notification.js/notificationMarkRead";

const Header = () => {
  const history = useHistory();
  const activePath = window.location.pathname;

  const dispatch = useDispatch();
  const [isProfileDropdownOpen, setProfileDropdown] = useState(false);
  const [isNotificationOpen, setNotificationDropdown] = useState(false);

  const {
    loginUserDetails = null,
    notificationLoading = false,
    notificationList = null,
  } = useSelector((state) => ({
    loginUserDetails: state.getUserDetail?.data?.data || null,
    notificationList: state.notificationList?.data?.data || null,
    notificationLoading: state.notificationList?.loading || null,
  }));

  const logoutHandle = () => {
    removeAuthToken();
    history.push("/login");
  };

  useEffect(() => {
    dispatch(fetchNotificationList());
  }, []);

  const handleNotificationDropDown = () => {
    if (Number(notificationList?.count) > 0) {
      setNotificationDropdown(!isNotificationOpen);
    }
  };

  const handleMarkRead = () => {
    dispatch(fetchNotificationMarkRead()).then((data) => {
      dispatch(fetchNotificationList());
    });
  };
  const isCatalogActive = () => {
    const catalogRoutes = [
      "/Catalog",
      "/Catalog/Products",
      "/Catalog/Planner",
      "/Catalog/Media",
      "/Catalog/CategorySetup",
    ];
    return catalogRoutes.some((route) => location.pathname.includes(route));
  };

  const isExactRouteActive = (routeName) => {
    const pathname = history?.location?.pathname;
    return pathname === routeName;
  };
  const isMediaExactRouteActive = (...routes) => {
    const currentPath = history?.location?.pathname;
    return routes.some((route) => {
      if (route.includes(":")) {
        // If the route contains route parameters, use startsWith to match the beginning of the path
        return currentPath.startsWith(route.split(":")[0]);
      } else {
        return currentPath === route;
      }
    });
  };
  return (
    <>
      <nav className="navbar navbar-default header-nav myNav" id="myNavbar">
        <div
          id="navbarCollapse"
          className="navbar-collapse d-flex justify-content-between custom-navbar"
        >
          <ul className="nav navbar-nav" id="myMenu">
            <li className="cursor-pointer">
              <a onClick={() => history.push("/home")}>
                <img src={Producty_rev} alt="Producty" />
              </a>
            </li>
            {activePath === "/elefant" ? (
              <></>
            ) : (
              <>
                <li
                  className={`cursor-pointer ${history?.location?.pathname.includes("home") ? "active" : ""
                    }`}
                >
                  <Link className="nav-link" to={"/home"}>
                    Home
                  </Link>
                </li>
                <li
                  className={`cursor-pointer ${isCatalogActive() ? "active" : ""
                    }`}
                >
                  <Link className="nav-link" to={"/Catalog/Products"}>
                    Catalog
                  </Link>
                </li>
                {loginUserDetails?.Admin ? (
                  <li
                    className={`cursor-pointer ${history?.location?.pathname.includes("/Layout")
                      ? "active"
                      : ""
                      }`}
                  >
                    <Link className="nav-link" to={"/Layout"}>
                      Layout{" "}
                      <sup style={{ color: "#FFFFFF", fontWeight: "bold" }}>
                        &nbsp;BETA
                      </sup>
                    </Link>
                  </li>
                ) : (
                  <></>
                )}

                <li
                  className={`cursor-pointer ${isExactRouteActive("/Products") ? "active" : ""
                    }`}
                >
                  <Link className="nav-link" to={"/Products"}>
                    Products
                  </Link>
                </li>

                <li
                  className={`cursor-pointer ${isExactRouteActive("/Import") ? "active" : ""
                    }`}
                >
                  <Link className="nav-link" to={"/Import"}>
                    Import
                  </Link>
                </li>

                <li
                  className={`cursor-pointer ${isMediaExactRouteActive(
                    "/Media/ViewMedia",
                    "/Media/MediaSetup",
                    "/Media/ImportMedia",
                    "/Media/MediaIntegration",
                  )
                    ? "active"
                    : ""
                    }`}
                >
                  <Link className="nav-link" to={"/Media/ViewMedia"}>
                    Media
                  </Link>
                </li>

                <li
                  className={`cursor-pointer ${history?.location?.pathname.includes("/Setup")
                    ? "active"
                    : ""
                    }`}
                >
                  <Link className="nav-link" to={"/Setup/Attributes"}>
                    Setup
                  </Link>
                </li>

                <li
                  className={`cursor-pointer ${history?.location?.pathname.includes("Reports")
                    ? "active"
                    : ""
                    }`}
                >
                  <Link className="nav-link" to={"/Reports"}>
                    Reports
                  </Link>
                </li>

                <li
                  className={`cursor-pointer ${history?.location?.pathname.includes("Output")
                    ? "active"
                    : ""
                    }`}
                >
                  <Link className="nav-link" to={"/Output/CreateFile"}>
                    Output
                  </Link>
                </li>

                <li
                  className={`cursor-pointer ${history?.location?.pathname.includes("Admin")
                    ? "active"
                    : ""
                    }`}
                >
                  <Link className="nav-link" to={"/Admin/Organisations"}>
                    Admin
                  </Link>
                </li>

                <div className="navbar-btn-section bell-icon-btn-section">
                  <Dropdown
                    isOpen={isNotificationOpen}
                    toggle={() => handleNotificationDropDown()}
                  >
                    <DropdownToggle className="bell-icon-btn">
                      <img className="header-btn-drp" src={bellIcon} />
                      <span className="badge-no">
                        ({notificationList?.count ? notificationList?.count : 0}
                        )
                      </span>
                    </DropdownToggle>
                    <DropdownMenu
                      className="bell-icon-drp-menu"
                      container="body"
                    >
                      <DropdownItem onClick={handleMarkRead}>
                        <span className="markallas-read-btn">
                          Mark All as Read
                        </span>
                      </DropdownItem>
                      {notificationList?.data &&
                        notificationList?.data.map((item, i) => {
                          return (
                            <DropdownItem key={i} onClick={() => { }}>
                              {item?.message}
                            </DropdownItem>
                          );
                        })}
                    </DropdownMenu>
                  </Dropdown>
                  {/* </div> */}
                </div>
              </>
            )}
          </ul>

          <div className="navbar-btn-section">
            <Dropdown
              isOpen={isProfileDropdownOpen}
              toggle={() => setProfileDropdown(!isProfileDropdownOpen)}
            >
              {activePath === "/elefant" ? (
                <>
                  <DropdownToggle className="sign-out-btn">
                    <i className={"fa-solid fa-bars"}></i>
                  </DropdownToggle>
                </>
              ) : (
                <>
                  <DropdownToggle className="sign-out-btn">
                    {isValidObject(loginUserDetails) &&
                      loginUserDetails?.FirstName}
                    {<img className="header-btn-drp" src={downchevron} />}
                  </DropdownToggle>
                </>
              )}
              <DropdownMenu
                className="profile-icon-drp-menu"
                container="body"
                style={{ maxWidth: "20%" }}
              >
                {activePath === "/elefant" ? (
                  <>
                    <DropdownItem onClick={() => logoutHandle()}>
                      Logout
                    </DropdownItem>
                  </>
                ) : (
                  <>
                    <DropdownItem
                      onClick={() => history.push("/WpIntegration")}
                    >
                      Wordpress integration
                    </DropdownItem>
                    <DropdownItem onClick={() => { }}>
                      Dropbox integration
                    </DropdownItem>
                    <DropdownItem onClick={() => logoutHandle()}>
                      Logout
                    </DropdownItem>
                  </>
                )}
              </DropdownMenu>
            </Dropdown>
            {/* </div> */}
          </div>
        </div>
      </nav>
    </>
  );
};

export default Header;
