import React, { useState } from "react";
import Select, { components } from "react-select";
import { isValidArray } from "../../modules/utils";
import { AsyncPaginate } from "react-select-async-paginate";

const SelectDropdownSearchable = ({
  name,
  isClearable = true,
  isDisabled = false,
  isLoading = false,
  isRtl = false,
  isSearchable = true,
  options,
  handleChange,
  value,
  isMulti = false,
  placeholder,
  // selectedOption=""
}) => {
  const { SingleValue, Option } = components;
  const IconOption = (props) => (
    <Option {...props}>
      {props.data.image && (
        <img src={props.data.image} style={{ width: 30, height: 30 }} />
      )}
      {props.data.label}
    </Option>
  );
  const IconSingleValue = (props) => (
    <SingleValue {...props}>
      {props.data.image && (
        <img src={props.data.image} style={{ width: 30, height: 30 }} />
      )}
      {props.data.label}
    </SingleValue>
  );

  const sleep = (ms) =>
    new Promise((resolve) => {
      setTimeout(() => {
        resolve();
      }, ms);
    });

  const loadOptions = async (search, prevOptions) => {
    //await sleep(1000);

    let filteredOptions;
    if (!search) {
      filteredOptions = options;
    } else {
      const searchLower = search.toLowerCase();

      filteredOptions = options.filter(({ label }) =>
        label.toLowerCase().includes(searchLower)
      );
    }

    const hasMore = filteredOptions.length > prevOptions.length + 10;
    const slicedOptions = filteredOptions.slice(
      prevOptions.length,
      prevOptions.length + 10
    );

    return {
      options: slicedOptions,
      hasMore,
    };
  };
  return (
    <>
      {/* <Select
        components={{ SingleValue: IconSingleValue, Option: IconOption }}
        className="basic-single"
        classNamePrefix="select"
        isDisabled={isDisabled}
        isLoading={isLoading}
        isClearable={isClearable}
        isRtl={isRtl}
        isSearchable={isSearchable}
        name={name}
        options={options}
        onChange={handleChange}
        value={value}
        defaultValue={value}
      /> */}

      <AsyncPaginate
        isLoading={isLoading}
        components={{ SingleValue: IconSingleValue, Option: IconOption }}
        value={value}
        loadOptions={loadOptions}
        onChange={handleChange}
        isMulti={isMulti}
        placeholder={placeholder}
      />
    </>
  );
};

export default SelectDropdownSearchable;
