import { isValidArray, getRowPerPageArray } from "modules/utils";
import strings from "data/strings";

import React, { useEffect, useState } from "react";
import Pagination from "react-js-pagination";

import ReactTable from "react-table-6";
import { Input, Label } from "reactstrap";

function ServerSideTable({
  columns = [],
  Data = [],
  isLoading,
  searchField,
  pageChangeFunction,
  searchTermFunction,
  searchTextVisible = true,
}) {
  const [perPage, setPerPage] = useState(Number(Data?.per_page) || 50);
  const [searchTerm, setSearchTerm] = useState("");

  const [page, setPageChange] = useState(Data?.current_page || 1);

  const handlePagination = (value, key) => {
    if (key === "page") {
      setPageChange(value);
    }
  };

  // useEffect(() => {
  //   searchTermFunction(page, perPage, searchTerm);
  // }, [searchTerm]);

  useEffect(() => {
    pageChangeFunction(page, perPage, searchTerm);
  }, [page, perPage, searchTerm]);

  const getPagination = () => {
    return (
      <div className="d-flex align-center show-page-section justify-content-between">
        {isValidArray(filterData) && getTotalRecordFromTo()}
        {isValidArray(filterData) && (
          <Pagination
            activePage={page}
            itemsCountPerPage={perPage}
            pageRangeDisplayed={10}
            totalItemsCount={Data?.total || 0}
            nextPageText={"Next"}
            prevPageText={"Previous"}
            onChange={(e) => {
              handlePagination(e, "page");
              //   setActivePage(e);
            }}
            innerClass="pagination"
          />
        )}
      </div>
    );
  };

  const getTotalRecordFromTo = () => {
    return (
      <div className="">
        Showing {Data?.from} to {Data?.to} of {Data?.total} entries
      </div>
    );
  };

  const getRowPerPage = () => {
    return (
      <div className="d-flex justify-content-between align-center mb-2">
        <div className="d-flex justify-content-left filter-tab align-center">
          <Label>Show</Label>
          <div style={{ minWidth: "20px" }}>
            <Input
              type="select"
              onChange={(e) => {
                setPerPage(Number(e.target.value));
              }}
              value={perPage}
            >
              {isValidArray(getRowPerPageArray) &&
                getRowPerPageArray.map((item, i) => {
                  return (
                    <option key={i} value={item.value}>
                      {item.label}
                    </option>
                  );
                })}
            </Input>
          </div>
          <Label style={{ marginLeft: "10px" }}>entries</Label>
        </div>
        <div className="tabcontent">
          {searchTextVisible && <Label>Search: </Label>}
          <Input
            placeholder={searchTextVisible ? "" : "Search..."}
            name="search"
            onChange={(e) => {
              setSearchTerm(e.target.value);
            }}
            value={searchTerm}
          />
        </div>
      </div>
    );
  };

  //   const getFilterData = () => {
  //     if (searchTerm) {
  //       const value = searchTerm.toLowerCase();
  //       return Data?.data?.filter(
  //         (item) => item[searchField].toLowerCase().search(value) !== -1
  //       );
  //     }
  //     return Data?.data;
  //   };

  const filterData = isValidArray(Data?.data) ? Data?.data : [];

  const getTableData = () => {
    const indexOfLastData = page * perPage;
    const indexOfFirstData = indexOfLastData - perPage;
    const currentData = isValidArray(filterData) ? filterData : [];
    return currentData;
  };

  const tableData = getTableData();

  return (
    <div>
      <div className="">
        {getRowPerPage()}
        <ReactTable
          loading={isLoading}
          data={tableData}
          columns={columns}
          defaultPageSize={perPage}
          minRows={0}
          className="-striped -highlight"
          showPagination={false}
          sortable={false}
          multiSort={false}
          resizable={true}
          filterable={false}
          noDataText={strings.messages.dataNotAvailable}
        />

        {getPagination()}
      </div>
    </div>
  );
}

export default ServerSideTable;
