import { isValidArray, getRowPerPageArray } from "modules/utils";
import strings from "data/strings";
import * as FileSaver from "file-saver";
import * as XLSX from "xlsx";

import React, { useEffect, useState } from "react";
import Pagination from "react-js-pagination";

import ReactTable from "react-table-6";
import { Input, Label } from "reactstrap";

function Table({
  columns = [],
  Data = [],
  isLoading,
  searchField,
  getFilterData = () => {},
  sortColumn,
  isSearchRequired = true,
  isDataPerPage = true,
  totalRecordVisible = true,
  showPagination = true,
  downloadName = "",
  isDownloadExcel = false,
  className = "asas",
  getTrProps, // Add getTrProps as a prop
  handleRowExpand,
}) {
  const fileType =
    "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet;charset=UTF-8";
  const fileExtension = ".xlsx";

  const [activePage, setActivePage] = useState(1);
  const [perPage, setPerPage] = useState(50);
  const [searchTerm, setSearchTerm] = useState("");

  const CustomPage = (props) => {
    return (
      <div className="d-flex align-center show-page-section justify-content-between table-footer">
        {isValidArray(filterData) &&
          totalRecordVisible &&
          getTotalRecordFromTo()}
        {isValidArray(filterData) && (
          <Pagination
            activePage={activePage}
            itemsCountPerPage={perPage}
            pageRangeDisplayed={10}
            totalItemsCount={filterData?.length || 0}
            nextPageText={"Next"}
            prevPageText={"Previous"}
            onChange={(e) => {
              setActivePage(e);
            }}
            innerClass="pagination"
          />
        )}
      </div>
    );
  };

  useEffect(() => {
    setSearchTerm(searchField);
  }, [searchField]);

  const getTotalRecordFromTo = () => {
    return (
      <div className="">
        Showing{" "}
        {(activePage - 1) * perPage + tableData.length - tableData.length + 1}{" "}
        to {(activePage - 1) * perPage + tableData.length} of{" "}
        {filterData?.length} entries
      </div>
    );
  };

  const getRowPerPage = () => {
    return (
      <div className="d-flex justify-content-between align-center mb-2 table-header">
        <div className="d-flex justify-content-left filter-tab align-center">
          <Label>Show</Label>
          <div style={{ minWidth: "20px" }}>
            <Input
              type="select"
              onChange={(e) => {
                setPerPage(Number(e.target.value));
              }}
              value={perPage}
            >
              {isValidArray(getRowPerPageArray) &&
                getRowPerPageArray?.map((item, i) => {
                  return (
                    <option key={i} value={item.value}>
                      {item.label}
                    </option>
                  );
                })}
            </Input>
          </div>
          <Label style={{ marginLeft: "10px" }}>entries</Label>
        </div>
        {isSearchRequired && (
          <div className="tabcontent">
            <Label>Search: </Label>
            <Input
              name="search"
              onChange={(e) => {
                setSearchTerm(e.target.value);
                setActivePage(1);
              }}
              value={searchTerm}
            />
          </div>
        )}
      </div>
    );
  };

  const filterData = getFilterData(searchTerm);

  const getTableData = () => {
    const indexOfLastData = activePage * perPage;
    const indexOfFirstData = indexOfLastData - perPage;
    const currentData = isValidArray(filterData)
      ? filterData.slice(indexOfFirstData, indexOfLastData)
      : [];
    return currentData;
  };

  const tableData = getTableData();

  const getCSVData = () => {
    const result1 = columns.map((d) => d?.id);
    let result = [];

    for (var i in Data) {
      result.push(Object.keys(Data[i]).map((key, index) => Data[i][key]));
    }

    const updated = [result1, ...result];

    return updated;
  };

  const fitToColumn = (data) => {
    const columnWidths = [];
    for (const property in data[0]) {
      columnWidths.push({
        wch: Math.max(
          property ? property.toString().length : 0,
          ...data.map((obj) =>
            obj[property] ? obj[property].toString().length : 0
          )
        ),
      });
    }
    return columnWidths;
  };

  const exportToCSV = (csvData, fileName) => {
    const worksheet = XLSX.utils.aoa_to_sheet(csvData);
    worksheet["!cols"] = fitToColumn(csvData);

    const wb = { Sheets: { data: worksheet }, SheetNames: ["data"] };
    const excelBuffer = XLSX.write(wb, { bookType: "xlsx", type: "array" });
    const data = new Blob([excelBuffer], { type: fileType });
    FileSaver.saveAs(data, fileName + fileExtension);
  };

  return (
    <div>
      <div className="" id="block-layout-table">
        {isDataPerPage && getRowPerPage()}
        {isDownloadExcel && (
          <div className="excel-btn">
            <button onClick={(e) => exportToCSV(getCSVData(), downloadName)}>
              Excel
            </button>
          </div>
        )}
        {filterData && (
          <ReactTable
            PaginationComponent={CustomPage}
            loading={isLoading}
            data={filterData}
            columns={columns}
            showPageSizeOptions={true}
            defaultPageSize={perPage}
            pageSize={perPage}
            page={activePage - 1}
            minRows={0}
            className="-striped -highlight"
            showPagination={showPagination}
            sortable={true}
            multiSort={false}
            resizable={true}
            filterable={false}
            noDataText={strings.messages.dataNotAvailable}
            defaultSorted={sortColumn ? [{ ...sortColumn }] : []}
            // getTrProps={getTrProps}
            getTrProps={(state, rowInfo) => ({
              onClick: () => {
                handleRowExpand(rowInfo);
              },
            })}
          />
        )}
      </div>
    </div>
  );
}

export default Table;
