import React, { useEffect, useState } from "react";
import GridLayout from "react-grid-layout";
import { Card, CardBody, CardHeader, CardText } from "reactstrap";
import { useDispatch, useSelector } from "react-redux";
import { useHistory } from "react-router";

import KeyStatisticsCard from "./KeyStatisticsCard";
import UserStatisticsCard from "./UserStatisticsCard";

import { fetchDashboardItems } from "redux/actions/home/getDashboardItem";
import { fetchUpdateDashboardItem } from "redux/actions/home/updateDashboardItem";
import { isValidArray } from "modules/utils";
import ProductCard from "./ProductCard";
import { fetchHideDashboardItems } from "redux/actions/home/hideDashboardItems";

import { Steps } from "intro.js-react";
import "intro.js/introjs.css";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import { set } from "lodash";

const Dashboard = () => {
  const history = useHistory();
  const dispatch = useDispatch();
  const apiData = useSelector((state) => state.getIntroJs);

  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);

  const onExit = () => {
    setStepsEnabled(false);
  };

  const [layout, setLayout] = useState([]);

  const getWindowDimensions = () => {
    const { innerWidth: width, innerHeight: height } = window;
    return {
      width,
      height,
    };
  };

  const { dashboardItem = null } = useSelector((state) => ({
    dashboardItem: state.dashboardItem.data?.data,
  }));

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = d.elementIDName;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  useEffect(() => {
    document.title = "Home | Producty®";
    dispatch(getIntroJs("home")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
    getDashboardItems();
    // dispatch(fetchDashboardItems()).then((data) => {
    //   if (data?.flag) {
    //     getLayout(data?.data);
    //   }
    // });
  }, []);

  const getDashboardItems = () => {
    dispatch(fetchDashboardItems()).then((data) => {
      if (data?.flag) {
        getLayout(data?.data);
      }
    });
  };

  const useWindowDimensions = () => {
    const [windowDimensions, setWindowDimensions] = useState(
      getWindowDimensions()
    );

    useEffect(() => {
      function handleResize() {
        setWindowDimensions(getWindowDimensions());
      }

      window.addEventListener("resize", handleResize);
      return () => window.removeEventListener("resize", handleResize);
    }, []);

    return windowDimensions;
  };

  const { width } = useWindowDimensions();

  const getLayout = (data = []) => {
    const single = data?.map((item) => {
      return {
        i: item.key,
        x: item.xPosition,
        y: item.yPosition,
        w: item.GridWidth,
        h: item.GridHeight,
      };
    });

    setLayout(single);
  };

  const hideDashboardItem = (id) => {
    dispatch(fetchHideDashboardItems(id)).then(() => {
      getDashboardItems();
    });
  };

  const getCardContent = (data) => {
    switch (data.key) {
      case "welcome_section":
        return (
          <>
            <Card id="welcomeSectionHome">
              <CardHeader>
                {data.title}
                {data.CanHide ? (
                  <div
                    onClick={() => hideDashboardItem(data.DashboardItemID)}
                    className="cross-icon-header"
                  ></div>
                ) : null}
              </CardHeader>
              <CardBody
                className={
                  data?.title == "Key Statistics" ? "key_statistics_body" : ""
                }
              >
                <CardText>{data.content.description1}</CardText>
                <CardText>{data.content.description2}</CardText>
                <CardText>{data.content.description3}</CardText>
              </CardBody>
            </Card>
          </>
        );

      case "latest_updates":
        return (
          <>
            <Card id="latestUpdatesHome">
              <CardHeader>
                {data.title}
                {data.CanHide ? (
                  <div
                    onClick={() => hideDashboardItem(data.DashboardItemID)}
                    className="cross-icon-header"
                  ></div>
                ) : null}
              </CardHeader>
              <CardBody
                className={
                  data?.title == "Key Statistics" ? "key_statistics_body" : ""
                }
              >
                <div className="latest-update-section">
                  {data?.content.map((item) => {
                    return (
                      <>
                        <p>{item?.date}</p>
                        <ul
                          className="latest-listtype"
                          style={{ listStyleType: "square" }}
                        >
                          <li>{item?.description}</li>
                        </ul>
                      </>
                    );
                  })}
                  <CardText>{data.content.description1}</CardText>
                  <CardText>{data.content.description2}</CardText>
                  <CardText>{data.content.description3}</CardText>
                </div>
              </CardBody>
            </Card>
          </>
        );

      case "key_statistics":
        return (
          <Card id="keyStaticsHome">
            <CardHeader>
              {data.title}
              {data.CanHide ? (
                <div
                  onClick={() => hideDashboardItem(data.DashboardItemID)}
                  className="cross-icon-header"
                ></div>
              ) : null}
            </CardHeader>
            <CardBody>
              <KeyStatisticsCard data={data} />
            </CardBody>
          </Card>
        );
      case "reports_section":
        return (
          <Card id="reportSectionHome">
            <CardHeader>
              {data.title}
              {data.CanHide ? (
                <div
                  onClick={() => hideDashboardItem(data.DashboardItemID)}
                  className="cross-icon-header"
                ></div>
              ) : null}
            </CardHeader>
            <CardBody>
              <ProductCard data={data} />
            </CardBody>
          </Card>
        );
      case "multilanguage_catalogs":
        return (
          <>
            <Card id="multiLanguageHome">
              <CardHeader>
                {data.title}
                {data.CanHide ? (
                  <div
                    onClick={() => hideDashboardItem(data.DashboardItemID)}
                    className="cross-icon-header"
                  ></div>
                ) : null}
              </CardHeader>
              <div className="latest-update-section">
                <CardBody
                  className={
                    data?.title == "Key Statistics" ? "key_statistics_body" : ""
                  }
                >
                  <CardText>{data.content.description1}</CardText>
                  <CardText>{data.content.description2}</CardText>
                  <CardText>{data.content.description3}</CardText>
                  <CardText>{data.content.description4}</CardText>
                </CardBody>
              </div>
            </Card>
          </>
        );
      case "getting_started":
        return (
          <>
            <Card id="gettingStartedHome">
              <CardHeader>
                {data.title}
                {data.CanHide ? (
                  <div
                    onClick={() => hideDashboardItem(data.DashboardItemID)}
                    className="cross-icon-header"
                  ></div>
                ) : null}
              </CardHeader>
              <CardBody>
                <CardText>{data.content.description1}</CardText>
                <CardText>
                  {data.content.description2}{" "}
                  <a
                    style={{ textDecoration: "none" }}
                    href={data.content.adminURL}
                  >
                    Admin &gt; Catalogs
                  </a>
                  .
                </CardText>
                <CardText>
                  {data.content.description3}{" "}
                  <a
                    style={{ textDecoration: "none" }}
                    href={data.content.setupURL}
                  >
                    Setup &gt; Attributes
                  </a>
                  .
                </CardText>
                <CardText>{data.content.description4}</CardText>
              </CardBody>
            </Card>
          </>
        );
      case "recent_exports":
        return (
          <Card id="recentExportHome">
            <CardHeader>
              {data.title}
              {data.CanHide ? (
                <div
                  onClick={() => hideDashboardItem(data.DashboardItemID)}
                  className="cross-icon-header"
                ></div>
              ) : null}
            </CardHeader>
            <CardBody
              className={
                data?.title == "Key Statistics" ? "key_statistics_body" : ""
              }
            >
              <div className="report-exports-section">
                <table>
                  <th>Date/Time</th>
                  <th>File Name </th>
                  <th>Name</th>
                  <tbody>
                    {data?.content.map((item) => {
                      return (
                        <>
                          <tr>
                            <td>{item?.datetime}</td>
                            <td>
                              <a
                                className="filepath-name"
                                //download
                                target="_blank"
                                rel="noreferrer"
                                href={`${item.downloadLink}`}
                              >
                                {item?.filePath}
                              </a>
                            </td>
                            <td>{item?.user}</td>
                          </tr>
                        </>
                      );
                    })}
                  </tbody>
                </table>
              </div>
            </CardBody>
          </Card>
        );
      case "user_statistics":
        return (
          <Card id="userStaticsHome">
            <CardHeader>
              {data.title}
              {data.CanHide ? (
                <div
                  onClick={() => hideDashboardItem(data.DashboardItemID)}
                  className="cross-icon-header"
                ></div>
              ) : null}
            </CardHeader>
            <CardBody>
              <UserStatisticsCard data={data} />
            </CardBody>
          </Card>
        );
      default:
        break;
    }
  };

  const onLayoutChange = (a, change) => {
    const updatedData = a.filter((d) => d.i === change.i);
    const apiData = {
      key: updatedData[0]?.i,
      positionX: updatedData[0]?.x,
      positionY: updatedData[0]?.y,
      width: updatedData[0]?.w,
      height: updatedData[0]?.h,
    };
    dispatch(fetchUpdateDashboardItem(apiData));
  };

  return (
    <div className="dashboard">
      <GridLayout
        className="layout gridLayout"
        layout={layout}
        cols={5}
        height={200}
        width={width > 1500 ? width - 70 : width - 50}
        isDraggable
        isResizable
        onDragStop={onLayoutChange}
        onResizeStop={onLayoutChange}
      >
        {isValidArray(dashboardItem) &&
          dashboardItem.map((item) => {
            if (item.key) {
              return (
                <div
                  key={item.key}
                  data-grid={{
                    x: item?.xPosition,
                    y: item?.yPosition,
                    w: item?.GridWidth,
                    h: item?.GridHeight,
                  }}
                  className={
                    item?.title === "Key Statistics"
                      ? "key_statistics_outer"
                      : ""
                  }
                >
                  <Steps
                    enabled={stepsEnabled}
                    steps={steps}
                    initialStep={initialStep}
                    onExit={onExit}
                    onComplete={() => setStepsEnabled(false)}
                    // {...{done}}
                    options={{ doneLabel: "Done" }}
                  />{" "}
                  {/* <Card style={{ backgroundColor: "red" }} id="latestUpdates">
                    <CardHeader>
                      {item.title}
                      {item.CanHide ? (
                        <div
                          onClick={() =>
                            hideDashboardItem(item.DashboardItemID)
                          }
                          className="cross-icon-header"
                        ></div>
                      ) : null}
                    </CardHeader>
                    <CardBody
                      className={
                        item?.title == "Key Statistics"
                          ? "key_statistics_body"
                          : ""
                      }
                    > */}
                  {item && getCardContent(item)}{" "}
                  {/* </CardBody>
                  </Card> */}
                </div>
              );
            }
          })}
      </GridLayout>
    </div>
  );
};

export default Dashboard;
