import React, { useEffect, useState } from "react";
import { Formik } from "formik";
import { changePasswordForm, displayFormErrors } from "modules/validations";
import { useDispatch } from "react-redux";
import InputField from "components/Common/InputField";
import { Form } from "reactstrap";
import { fetchResetPassword } from "redux/actions/users/resetPassword";
import { fetchGetPasswordResetTokenDetail } from "redux/actions/users/getPasswordResetTokenDetail";
import { useHistory } from "react-router-dom";

const ChangePassword = (props) => {
  const dispatch = useDispatch();
  const [email, setEmail] = useState("");
  let history = useHistory();

  useEffect(() => {
    if (props?.match?.params?.token) {
      dispatch(
        fetchGetPasswordResetTokenDetail(props?.match?.params?.token)
      ).then((data) => {
        if (!data?.data?.flag) {
          history.push("/password/reset");
        } else {
          setEmail(data?.data?.data?.email);
        }
      });
    }
  });

  const handleSubmit = (values) => {
    const formData = {
      email: email,
      password: values.password,
      confirmPassword: values.confirmPassword,
      token: props.match.params.token,
    };
    dispatch(fetchResetPassword(formData)).then((data) => {
      if (data?.data?.flag) {
        history.push("/login");
      }
    });
  };

  return (
    <Formik
      initialValues={{
        password: "",
        confirmPassword: "",
      }}
      validationSchema={changePasswordForm()}
      onSubmit={handleSubmit}
    >
      {({
        values,
        errors,
        touched,
        handleChange,
        handleBlur,
        handleSubmit,
        submitCount,
        setFieldValue,
      }) => {
        const showError = (key) =>
          displayFormErrors(key, errors, touched, submitCount);

        return (
          <div className="register-page">
            <div className="product-login">Reset Password</div>
            <div className="register-welcome">
              <Form>
                <div>
                  <InputField
                    type="password"
                    name="password"
                    placeholder="Password"
                    className="login-text"
                    onChange={handleChange}
                    value={values.password || ""}
                  />
                  {showError("password")}
                  <InputField
                    type="password"
                    name="confirmPassword"
                    placeholder="Confirm Password"
                    className="login-text"
                    onChange={handleChange}
                    value={values.confirmPassword || ""}
                  />
                  {showError("confirmPassword")}
                  <button
                    className="login loginmodal-submit"
                    type="submit"
                    onClick={handleSubmit}
                  >
                    Submit
                  </button>
                </div>
              </Form>
            </div>
          </div>
        );
      }}
    </Formik>
  );
};

export default ChangePassword;
