import React, { useEffect, useState } from "react";
import { useDispatch } from "react-redux";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import ImportHistory from "./importHistory/importHistory";
import ImportWizard from "./importWizard/ImportWizard";
import { Steps } from "intro.js-react";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import "intro.js/introjs.css";
import { isValidArray } from "modules/utils";

function Import() {
  const dispatch = useDispatch();
  const initialActiveTab = {
    importWizard: "active",
    importHistory: "",
    activeTab: "importWizard",
  };
  const [activeTab, setActivetab] = useState(initialActiveTab);
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);

  const onExit = () => {
    setStepsEnabled(false);
  };

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = d.elementIDName;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  useEffect(() => {
    document.title = "Import | Producty®";

    dispatch(getIntroJs("import")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  const handleTab = (tabName) => {
    if (tabName == "importWizard") {
      setActivetab({
        importWizard: "active",
        importHistory: "",
        productAttGrid: "",
        activeTab: "importWizard",
      });
    } else if (tabName == "importHistory") {
      setActivetab({
        importWizard: "",
        importHistory: "active",
        productAttGrid: "",
        activeTab: "importHistory",
      });
    }
  };
  return (
    <>
      <Steps
        enabled={stepsEnabled}
        steps={steps}
        initialStep={initialStep}
        onExit={onExit}
        onComplete={() => setStepsEnabled(false)}
        options={{ doneLabel: "Done" }}
      />
      <div>
        <Nav tabs>
          <NavItem>
            <NavLink
              className={activeTab.importWizard}
              onClick={() => handleTab("importWizard")}
            >
              Import Wizard
            </NavLink>
          </NavItem>
          <NavItem>
            <NavLink
              className={activeTab.importHistory}
              onClick={() => handleTab("importHistory")}
            >
              Import History
            </NavLink>
          </NavItem>
        </Nav>
        <TabContent activeTab={activeTab.activeTab}>
          <TabPane tabId="importWizard">
            {activeTab.activeTab === "importWizard" && <ImportWizard />}
          </TabPane>
          <TabPane tabId="importHistory">
            {activeTab.activeTab === "importHistory" && (
              <ImportHistory handleTab={handleTab} />
            )}
          </TabPane>
        </TabContent>
      </div>
    </>
  );
}

export default Import;
