import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { fetchImportHistory } from "redux/actions/import/importHistory";
import InputField from "components/Common/InputField";
import Table from "components/Common/Table";
import { filterFieldData } from "modules/utils";
import { fetchCancelImportFile } from "redux/actions/import/cancelImportFile";

const ImportHistory = ({ handleTab }) => {
  const [importHistoryList, setImportHistoryList] = useState([]);
  const { importHistory = null, isLoading = false } = useSelector((state) => ({
    importHistory: state.importHistory?.data?.data,
    isLoading: state.importHistory?.loading,
  }));

  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(fetchImportHistory()).then((data) => {
      const result = data?.data?.map((item) => {
        return {
          ImportsID: item?.ImportsID,
          ImportedFile: item?.ImportedFile,
          ImportedBy: `${item?.FirstName}${" "}${item?.LastName}`,
          ImportedAt: item?.ImportedAt,
          status: item?.status,
        };
      });
      setImportHistoryList(result);
    });
  }, []);
  const getStatus = (status) => {
    if (status === "Completed") return "status-btn label-success";
    if (status === "Failed" || status === "Cancelled")
      return "status-btn label-danger";
    if (status === "Currently In Progress" || status === "In Progress")
      return "status-btn label-in-progress";
    return "status-btn label-danger";
  };
  const cancelImport = (importId) => {
    dispatch(fetchCancelImportFile(importId)).then((data) => {
      handleTab("importWizard");
    });
  };
  const ReactTableColumns = [
    {
      Header: "No.",
      id: "ImportsID",
      accessor: "ImportsID",
    },
    {
      Header: "File Name",
      id: "ImportedFile",
      accessor: "ImportedFile",
    },
    {
      Header: "Imported By",
      id: "ImportedBy",
      accessor: "ImportedBy",
    },
    {
      Header: "Imported on Date/Time",
      id: "ImportedAt",
      accessor: "ImportedAt",
    },
    {
      Header: "Status",
      id: "status",
      accessor: "status",
      Cell: ({ original, value }) => {
        switch (value) {
          case "Completed":
            return <div className="status-btn label-success">{value}</div>;
          case "In Progress":
            return (
              <>
                <div className="status-btn bg-info">In Progress</div>
                <div
                  className="status-btn label-danger"
                  style={{ cursor: "pointer" }}
                  onClick={() => cancelImport(original?.ImportsID)}
                >
                  Cancel
                </div>
              </>
            );
          case "Currently In Progress":
            return (
              <>
                <div className="status-btn bg-info">In Progress</div>
                <div
                  className="status-btn label-danger"
                  style={{ cursor: "pointer" }}
                  onClick={() => cancelImport(original?.ImportsID)}
                >
                  Cancel
                </div>
              </>
            );
          default:
            return <div className="status-btn label-danger">{value}</div>;
        }
      },
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, importHistoryList, [
        "ImportedFile",
        "FirstName",
        "ImportedAt",
        "status",
        "ImportedBy",
      ]);
    }
    return importHistoryList;
  };

  return (
    <div className="tableorganisation import-history-section bg-white product-tableBorder">
      <Table
        columns={ReactTableColumns}
        Data={importHistoryList}
        isLoading={isLoading}
        getFilterData={getFilterData}
      />
    </div>
  );
};

export default ImportHistory;
