import Loader from "components/Common/Loader";
import { isValidArray } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Button } from "reactstrap";
import { fetchImportConfirmSetup } from "redux/actions/import/importConfirmSetup";
import { fetchImportSchedule } from "redux/actions/import/importSchedule";
import importSchedule from "redux/reducers/import/importSchedule";

const ConfirmSetup = ({ dataObject, handleTab }) => {
  const dispatch = useDispatch();

  const [apiHTMLData, setApiHTMLData] = useState();

  const {
    addImportFile = null,
    importSchedule = false,
    importConfirmSetup = false,
  } = useSelector((state) => ({
    addImportFile: state.addImportFile?.data,
    importSchedule: state.importSchedule?.loading,
    importConfirmSetup: state.importConfirmSetup?.loading,
  }));

  useEffect(() => {
    if (isValidArray(dataObject)) {
      const result = dataObject?.map((item) => {
        let destinationAttrId;
        if (
          item.destination_attribute_id === "new" ||
          item.destination_attribute_id === "newInstance" ||
          item.destination_field == "ignore"
        ) {
          destinationAttrId = "";
        } else {
          destinationAttrId = item.destination_attribute_id;
        }
        return {
          ...item,
          ignore: item.destination_field == "ignore" ? "Yes" : "No",
          destination_field:
            item.destination_field == "ignore" ? "" : item.destination_field,
          destination_attribute_id: destinationAttrId,
          isProduct:
            item.source_field === localStorage.getItem("uniqueProduct")
              ? "Yes"
              : "No",
          uniqueProduct: localStorage.getItem("uniqueProduct"),
          new:
            item.destination_attribute_id === "new"
              ? "new"
              : item.destination_attribute_id === "newInstance"
              ? "newInstance"
              : "",
          destination_attribute:
            item.destination_field == "category" ||
            item.destination_field == "categoryText" ||
            item.destination_field == "products" ||
            item.destination_attribute_id == "new" ||
            item.destination_attribute_id === "newInstance" ||
            item.destination_field == "ProductCode"
              ? item.source_field
              : item.destination_attribute,
          import: item.destination_field == "ignore" ? "" : "import",
        };
      });

      const formData = {
        productData: result,
        ImportsID: addImportFile?.data?.ImportsID,
      };

      dispatch(fetchImportConfirmSetup(formData)).then((data) => {
        setApiHTMLData(data?.data?.htmlData);
      });
    }
  }, []);

  const handleSubmitImport = () => {
    const formData = {
      ImportsID: String(addImportFile?.data?.ImportsID),
    };
    dispatch(fetchImportSchedule(formData)).then((data) => {
      if (data?.flag) {
        handleTab("result");
      }
    });
  };

  function createMarkup() {
    return { __html: apiHTMLData };
  }

  return (
    <div className="bg-white common-space">
      {(importSchedule || importConfirmSetup) && <Loader />}
      {apiHTMLData && (
        <div className="tabbing-container text-start confirmation-setup-tab">
          <div dangerouslySetInnerHTML={createMarkup()}></div>
          <div className="confirmation-btn-section mt-4 text-center">
            <p>Please check the above</p>
            <Button
              onClick={() => {
                handleSubmitImport();
              }}
            >
              Import
            </Button>
          </div>
        </div>
      )}
    </div>
  );
};

export default ConfirmSetup;
