import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import { fetchImportCountProductReset } from "redux/actions/import/importCountProduct";
import { fetchImportNameRangeReset } from "redux/actions/import/importNameRange";
import ConfirmSetup from "./ConfirmSetup";
import InitialCheck from "./InitialCheck";
import MapField from "./MapField";
import Result from "./Result";
import SelectFile from "./SelectFile";

const ImportWizard = () => {
  const dispatch = useDispatch();
  const { importNameRange = null, importCountProduct = null } = useSelector(
    (state) => ({
      importNameRange: state.importNameRange?.data,
      importCountProduct: state.importCountProduct?.data,
    })
  );

  useEffect(() => {
    dispatch(fetchImportNameRangeReset());
    dispatch(fetchImportCountProductReset());
  }, []);

  const initialActiveTab = {
    selectFile: "active",
    initialCheck: "",
    mapField: "",
    confirmSetup: "",
    result: "",
    activeTab: "selectFile",
  };
  const [activeTab, setActivetab] = useState(initialActiveTab);
  const [importArrayObject, setImportArrayObject] = useState([]);
  const [dataObject, setDataObject] = useState([]);
  const [matchingField, setMatchingField] = useState("");

  const handleTab = (tabName) => {
    if (tabName == "selectFile") {
      setActivetab({
        selectFile: "active",
        initialCheck: "",
        mapField: "",
        confirmSetup: "",
        result: "",
        activeTab: "selectFile",
      });
    } else if (tabName == "initialCheck") {
      setActivetab({
        selectFile: "",
        initialCheck: "active",
        mapField: "",
        confirmSetup: "",
        result: "",
        activeTab: "initialCheck",
      });
    } else if (tabName == "mapField") {
      setActivetab({
        selectFile: "",
        initialCheck: "",
        mapField: "active",
        confirmSetup: "",
        result: "",
        activeTab: "mapField",
      });
    } else if (tabName == "confirmSetup") {
      setActivetab({
        selectFile: "",
        initialCheck: "",
        mapField: "",
        confirmSetup: "active",
        result: "",
        activeTab: "confirmSetup",
      });
    } else if (tabName == "result") {
      setActivetab({
        selectFile: "",
        initialCheck: "",
        mapField: "",
        confirmSetup: "",
        result: "active",
        activeTab: "result",
      });
    }
  };

  return (
    <div>
      <Nav tabs>
        <NavItem>
          <NavLink
            className={activeTab.selectFile}
            onClick={() => handleTab("selectFile")}
          >
            Select File
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.initialCheck}
            onClick={() => handleTab("initialCheck")}
            disabled={importNameRange ? false : true}
          >
            Initial Checks
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.mapField}
            onClick={() => handleTab("mapField")}
            disabled={importNameRange && importCountProduct ? false : true}
          >
            Map Fields
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.confirmSetup}
            onClick={() => handleTab("confirmSetup")}
            disabled={importNameRange && importCountProduct ? false : true}
          >
            Confirm Setup
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.result}
            onClick={() => handleTab("result")}
            disabled={importNameRange && importCountProduct ? false : true}
          >
            Result
          </NavLink>
        </NavItem>
      </Nav>
      <TabContent activeTab={activeTab.activeTab}>
        <TabPane tabId="selectFile">
          {activeTab.activeTab === "selectFile" && (
            <SelectFile handleTab={handleTab} />
          )}
        </TabPane>
        <TabPane tabId="initialCheck">
          {activeTab.activeTab === "initialCheck" && <InitialCheck />}
        </TabPane>
        <TabPane tabId="mapField">
          {activeTab.activeTab === "mapField" && (
            <MapField
              dataObject={dataObject}
              setDataObject={setDataObject}
              matchingField={matchingField}
              setMatchingField={setMatchingField}
            />
          )}
        </TabPane>
        <TabPane tabId="confirmSetup">
          {activeTab.activeTab === "confirmSetup" && (
            <ConfirmSetup dataObject={dataObject} handleTab={handleTab} />
          )}
        </TabPane>
        <TabPane tabId="result">
          {activeTab.activeTab === "result" && <Result />}
        </TabPane>
      </TabContent>
    </div>
  );
};

export default ImportWizard;
