import Loader from "components/Common/Loader";
import SelectField from "components/Common/SelectField";
import { isValidArray, isValidObject } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Button } from "reactstrap";
import { fetchImportCountProduct } from "redux/actions/import/importCountProduct";

const InitialCheck = () => {
  const dispatch = useDispatch();
  const [productOptions, setProductOptions] = useState([
    { label: "Select unique identifier option", value: "" },
  ]);
  const [uniqueProduct, setUniqueProduct] = useState("");
  const [apiHTMLRes, setApiHTMLRes] = useState();

  const {
    importNameRange = null,
    importCountProduct = null,
    addImportFile = null,
    importCountProductLoading = false,
  } = useSelector((state) => ({
    importNameRange: state.importNameRange?.data,
    importCountProduct: state.importCountProduct?.data,
    importCountProductLoading: state.importCountProduct?.loading,
    addImportFile: state.addImportFile?.data?.data,
  }));

  useEffect(() => {
    if (importNameRange) {
      getUniqueProductOptions();
    }
  }, []);

  useEffect(() => {
    // const result = productOptions?.find((item, i) => {
    //   if (i == 1) {
    //     return true;
    //   }
    // });

    //previously passed init value from result as result?.value

    setUniqueProduct(addImportFile?.ProductCodeSyncField);
  }, [productOptions]);

  const getUniqueProductOptions = () => {
    let options = importNameRange?.data?.headers?.map((item) => {
      return {
        label: item.columnData,
        value: item.columnData,
      };
    });
    options = [
      { label: "Select unique identifier option", value: "" },
      ...options,
    ];
    setProductOptions(options);
  };

  const handleOnChangeUniqueProduct = (e) => {
    setUniqueProduct(e);
  };

  const handleConfirm = () => {
    if (uniqueProduct) {
      localStorage.setItem("uniqueProduct", uniqueProduct);
      const formData = {
        ImportsID: importNameRange?.data?.file_insert_id,
        SelectedColumn: uniqueProduct,
      };

      dispatch(fetchImportCountProduct(formData)).then((data) => {
        setApiHTMLRes(data.data);
      });
    }
  };

  return (
    <div className="bg-white common-space">
      {importCountProductLoading && <Loader />}
      <div className="tabbing-container">
        <div className="mb-3">
          <h3 className="tabbing-select-title">Check 1 - Unique Columns</h3>
          <h2 className="greentext tabbing-select-title mb-0">Success</h2>
          {isValidObject(importNameRange) && (
            <p>{importNameRange?.data?.uniqueColumnCount}</p>
          )}
        </div>
        <div className="pt-1">
          <h3 className="tabbing-select-title">
            Check 2 - Unique Product Records
          </h3>
          <div className="d-flex initial-checks-tab inital-check-select justify-content-center">
            <SelectField
              type="select"
              name="selectOrganization"
              id="selectOrganization"
              placeholder="Select Organization"
              options={productOptions}
              onChange={handleOnChangeUniqueProduct}
              value={uniqueProduct}
            />
            <Button className="ml-1" onClick={handleConfirm}>
              Confirm
            </Button>
          </div>
          {apiHTMLRes && isValidObject(importCountProduct) && (
            <>
              <h5
                className="mt-2"
                style={{ color: apiHTMLRes.ProductLimitTextColor }}
              >
                {apiHTMLRes?.ProductLimitText}
              </h5>
              <div>
                <span style={{ color: apiHTMLRes.totalProductColor }}>
                  {apiHTMLRes?.totalProductsBeforeImport}
                </span>
                <br />
                <span>{apiHTMLRes?.totalProductsAddedAfterImport}</span>
                <br />
                <span>{apiHTMLRes?.totalProductsUpdatedAfterImport}</span>
                <br />
                <span>{apiHTMLRes?.totalProductsAfterImport}</span>
                <br />
                <span>{apiHTMLRes?.totalPackageProducts}</span>
                <br />
                <span style={{ color: apiHTMLRes.additionalChargeColor }}>
                  {apiHTMLRes?.additionalChargeText}
                </span>
              </div>
            </>
          )}
        </div>
      </div>
    </div>
  );
};

export default InitialCheck;
