import React, { useEffect, useState } from "react";
import SelectField from "components/Common/SelectField";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
  Tooltip,
} from "reactstrap";
import Table from "components/Common/Table";
import infowhiteicon from "../../../assets/images/infowhiteicon.png";
import { useDispatch, useSelector } from "react-redux";
import { fetchPastImportList } from "redux/actions/import/pastImportList";
import { isValidArray } from "modules/utils";
import { fetchAttributeList } from "redux/actions/masterSetup/attributeList";
import SelectFieldImport from "components/Common/SelectFieldImport";
import { fetchGetPastImportDetails } from "redux/actions/import/getPastImportDetails";
import { fetchAttributeWithoutVirtual } from "redux/actions/masterSetup/attributeWithoutVirtualList";
import { fetchTextBlockList } from "redux/actions/masterSetup/textBlocksList";

const MapField = ({
  dataObject,
  setDataObject,
  matchingField,
  setMatchingField,
}) => {
  const dispatch = useDispatch();
  const categoryTextOption = [
    { value: "Category Text 1", label: "Level 1" },
    { value: "Category Text 2", label: "Level 2" },
    { value: "Category Text 3", label: "Level 3" },
    { value: "Category Text 4", label: "Level 4" },
    { value: "Category Text 5", label: "Level 5" },
    { value: "Category Text 6", label: "Level 6" },
    { value: "Category Text 7", label: "Level 7" },
    { value: "Category Text 8", label: "Level 8" },
    { value: "Category Text 9", label: "Level 9" },
    { value: "Category Text 10", label: "Level 10" },
  ];
  const categoryStructureOption = [
    { value: "Category 1", label: "Level 1" },
    { value: "Category 2", label: "Level 2" },
    { value: "Category 3", label: "Level 3" },
    { value: "Category 4", label: "Level 4" },
    { value: "Category 5", label: "Level 5" },
    { value: "Category 6", label: "Level 6" },
    { value: "Category 7", label: "Level 7" },
    { value: "Category 8", label: "Level 8" },
    { value: "Category 9", label: "Level 9" },
    { value: "Category 10", label: "Level 10" },
  ];
  const createNewDropdown = [
    { value: "longtext", label: "Choose Data Type" },
    { value: "varchar(255)", label: "Text" },
    { value: "int(10)", label: "Number" },
    { value: "decimal(10,2)", label: "Decimal" },
    { value: "longtext", label: "Long Description" },
  ];
  const [ProductID, setProductID] = useState(false);
  const [productOptions, setProductOptions] = useState([]);
  const [selectedPastImport, setPastImport] = useState("");
  const [uniqueColumn, setUniqueColumn] = useState("");
  console.log("🚀 ~ file: MapField.js:65 ~ uniqueColumn:", uniqueColumn);

  const [attributeOption, setAttributeOption] = useState([]);
  const [textBlockOption, setTextBlockOption] = useState([]);
  const [showDestinationDropDown, setShowDestinationDropDown] = useState(false);

  const { importNameRange, attributeWithoutVirtualList } = useSelector(
    (state) => ({
      importNameRange: state.importNameRange?.data?.data,
      attributeWithoutVirtualList:
        state.attributeWithoutVirtualList?.data?.data || null,
    })
  );

  useEffect(() => {
    dispatch(fetchPastImportList()).then((data) => {
      if (data?.flag) {
        getProductOptions(data?.data);
      }
    });
    setUniqueColumn(localStorage.getItem("uniqueProduct"));

    dispatch(fetchAttributeWithoutVirtual()).then((data) => {
      const result = data?.data
        .map((d) => {
          return {
            label: d?.AttributeDisplayName,
            value: d?.AttributeID,
          };
        })
        .sort((a, b) => a.label.localeCompare(b.label));
      setAttributeOption(result);
    });

    dispatch(fetchTextBlockList()).then((data) => {
      const result = data?.data
        .map((d) => {
          return {
            label: d?.TextBlockName,
            value: d?.TextBlockID,
          };
        })
        .sort((a, b) => a.label.localeCompare(b.label));
      setTextBlockOption(result);
    });
  }, []);

  useEffect(() => {
    setTableData();
  }, [attributeOption]);

  const setTableData = () => {
    const result = importNameRange?.headers.map((d) => {
      const result =
        isValidArray(attributeOption) &&
        attributeOption.find((item) => item.label == d.columnData);

      return {
        source_field: d.columnData,
        preview_field: d.previewData,
        destination_field:
          d.columnData === localStorage.getItem("uniqueProduct")
            ? d.columnData
            : "ignore",
        destination_attribute: "",
        destination_attribute_id: result ? result.value : "",
        destination_dataType: "",
        destination_textblock_id: "",
        new: "",
        import: "",
        isProduct: "",
        uniqueProduct:
          d.columnData === localStorage.getItem("uniqueProduct")
            ? d.columnData
            : "",
        matchingFields: "Ignore",
        ignore: "",
      };
    });
    setDataObject(result);
  };

  const getProductOptions = (data = []) => {
    setPastImport(data[0]?.ImportsID);
    const single = data?.map((item) => {
      return {
        label: item.ImportedFile,
        value: item.ImportsID,
      };
    });
    setProductOptions(single);
  };

  const handlePastImportChange = (item) => {
    dispatch(fetchGetPastImportDetails(item)).then((data) => {
      setPastImport(item);
      if (data?.flag) {
        const updatedData = data?.data?.map((d) => {
          setUniqueColumn(d.uniqueProduct);
          localStorage.setItem("uniqueProduct", d.uniqueProduct);

          return {
            ...d,
            destination_field:
              d.ignore == "Yes" ? "ignore" : d.destination_field,
          };
        });
        setDataObject(updatedData);
      }
    });
  };

  const handleRadioChange = (id, e) => {
    const result = dataObject.map((d, i) => {
      if (i === id) {
        let destinationAttributeId;
        if (e.target.value === "category") {
          destinationAttributeId = "Category 1";
        } else if (e.target.value === "categoryText") {
          destinationAttributeId = "Category Text 1";
        } else {
          destinationAttributeId = d.destination_attribute_id;
          // destinationAttributeId =
          // e.target.value === "products" ? "new" : d.destination_attribute_id;
        }
        return {
          ...d,
          destination_field: e.target.value,
          destination_attribute_id: destinationAttributeId,
          destination_attribute_id_show: false,
          import: e.target.value === "ignore" ? "import" : "",
          destination_attribute:
            d.destination_field === "category" ||
            d.destination_field === "categoryText"
              ? d?.source_field
              : e.target.value == "ignore"
              ? d?.source_field
              : "",
          new: e.target.value === "products" ? "new" : "",
        };
      }
      return d;
    });

    setDataObject(result);
  };

  const handleSelectChange = (id, e, name) => {
    console.log(
      "🚀 ~ file: MapField.js:243 ~ handleSelectChange ~ name:",
      name
    );
    const result = dataObject.map((d, i) => {
      if (i === id) {
        return {
          ...d,
          destination_attribute_id:
            name === "textBlock"
              ? d.destination_attribute_id
              : name != "destination_dataType"
              ? e.target.value
              : d.destination_attribute_id,
          destination_attribute:
            d.destination_field === "category" ||
            d.destination_field === "categoryText" ||
            d.destination_field === "textBlock"
              ? d?.source_field
              : Array.from(
                  e.target.selectedOptions,
                  (option) => option.label
                )[0],
          destination_dataType:
            name == "destination_dataType" ? e.target.value : "",
          destination_textblock_id:
            name === "textBlock"
              ? parseInt(e.target.value)
              : d?.destination_textblock_id,
          //destination_field
        };
      }
      return d;
    });
    setDataObject(result);
  };
  console.log("🚀 ~ file: MapField.js:243 ~ result ~ dataObject:", dataObject);
  const newAttributeOption = [
    {
      label: "Create New",
      value: "new",
    },
    {
      label: "Create New Instance",
      value: "newInstance",
    },
  ];

  const newTextBlockOption = [
    {
      label: "Create New",
      value: 0,
    }
  ]
  return (
    <div className="bg-white common-space">
      <div className="tabbing-container map-filed-section">
        <div className="mb-3">
          <h4 className="tabbing-select-title map-field-title">
            Use Past Import Structure
          </h4>
          <div className="d-flex initial-checks-tab justify-content-center">
            <SelectField
              type="select"
              name="selectOrganization"
              id="selectOrganization"
              placeholder="Select Organization"
              options={productOptions}
              onChange={handlePastImportChange}
              value={selectedPastImport}
            />
          </div>
          {/* <h4 className="tabbing-select-title map-field-title mt-3">
            Matching fields
          </h4>
          <div className="d-flex align-items-center justify-content-center">
            <div className="custom-radio-btn">
              <Input
                type="radio"
                name="matchingFields"
                value="Ignore"
                checked={matchingField === "Ignore"}
                onChange={(e) => setMatchingField(e.target.value)}
              />
              <Label check>Ignore</Label>{" "}
            </div>
            <div className="custom-radio-btn">
              <Input
                type="radio"
                name="matchingFields"
                value="Overwrite"
                checked={matchingField === "Overwrite"}
                onChange={(e) => setMatchingField(e.target.value)}
              />
              <Label check>Overwrite</Label>{" "}
            </div>
          </div> */}

          <div className="tableorganisation map-filed-table-section mt-3 p-0">
            <table className="w-100">
              <thead>
                <tr>
                  <th>Source Field</th>
                  <th>Preview</th>
                  <th>Destination Field</th>
                </tr>
              </thead>
              <tbody>
                {isValidArray(dataObject) &&
                  dataObject.map((d, i) => {
                    console.log("123141244", d);
                    return (
                      <tr
                        key={i}
                        className={
                          d?.source_field === uniqueColumn
                            ? "unique-tr-cls"
                            : "normal-tr-cls"
                        }
                      >
                        <td>
                          <div className="info-btn">
                            {d?.source_field}
                            {d?.source_field === uniqueColumn && (
                              <>
                                <img
                                  src={infowhiteicon}
                                  alt="ProductID"
                                  data-toggle="tooltip"
                                  id="ProductIDExample"
                                  title=""
                                />
                                <Tooltip
                                  flip
                                  className="productId-popup"
                                  target="ProductIDExample"
                                  placement="top"
                                  toggle={() => setProductID(!ProductID)}
                                  isOpen={ProductID}
                                  autohide={false}
                                >
                                  This is your selected unique product
                                </Tooltip>
                              </>
                            )}
                          </div>
                        </td>
                        <td>
                          <div className="info-btn">{d?.preview_field}</div>
                        </td>
                        <td>
                          <div className="d-flex align-items-center">
                            <Input
                              type="radio"
                              name={`radioButton${i}`}
                              value="category"
                              checked={d?.destination_field === "category"}
                              onChange={(e) => handleRadioChange(i, e)}
                              disabled={d?.source_field === uniqueColumn}
                            />
                            <Label check disabled className="me-1">
                              Category structure
                            </Label>{" "}
                            <SelectFieldImport
                              type="select"
                              name="selectOrganization"
                              id="selectOrganization"
                              placeholder="Level 1"
                              options={categoryStructureOption}
                              isDisabled={
                                d?.destination_field !== "category" ||
                                d?.source_field === uniqueColumn
                              }
                              handleSelectChange={handleSelectChange}
                              index={i}
                              column="category"
                              value={d?.destination_attribute_id}
                            />
                            <Input
                              type="radio"
                              name={`radioButton${i}`}
                              value="categoryText"
                              checked={d?.destination_field === "categoryText"}
                              onChange={(e) => handleRadioChange(i, e)}
                              disabled={d?.source_field === uniqueColumn}
                            />
                            <Label check disabled className="me-1">
                              Category text
                            </Label>{" "}
                            <SelectFieldImport
                              type="select"
                              name="selectOrganization"
                              className="me-1"
                              id="selectOrganization"
                              placeholder="Level 1"
                              options={categoryTextOption}
                              isDisabled={
                                d?.destination_field !== "categoryText" ||
                                d?.source_field === uniqueColumn
                              }
                              handleSelectChange={handleSelectChange}
                              index={i}
                              column="categoryText"
                              value={d?.destination_attribute_id}
                            />
                            {/* <Input
                              type="radio"
                              name={`radioButton${i}`}
                              value="products"
                              checked={
                                d?.destination_field === uniqueColumn ||
                                d?.destination_field === "products"
                              }
                              onChange={(e) => handleRadioChange(i, e)}
                              disabled={d?.source_field === uniqueColumn}
                            /> 
                            <Label check disabled className="me-1">
                              Text Block
                            </Label>{" "}
                            */}
                            <SelectFieldImport
                              type="select"
                              name="selectOrganization"
                              id="selectOrganization"
                              placeholder="Select Text Block"
                              options={[
                                ...newTextBlockOption,
                                ...textBlockOption
                              ]}
                              isDisabled={
                                d?.destination_field !== "categoryText" ||
                                d?.source_field === uniqueColumn
                              }
                              handleSelectChange={handleSelectChange}
                              index={i}
                              column="textBlock"
                              value={d?.destination_textblock_id}
                            />
                            <Input
                              type="radio"
                              name={`radioButton${i}`}
                              value="products"
                              checked={
                                d?.destination_field === uniqueColumn ||
                                d?.destination_field === "products"
                              }
                              onChange={(e) => handleRadioChange(i, e)}
                              disabled={d?.source_field === uniqueColumn}
                            /> 
                            <Label check disabled className="me-1">
                              Product attribute
                            </Label>{" "}
                            <SelectFieldImport
                              className="create-new-product"
                              type="select"
                              name="selectOrganization"
                              id="selectOrganization"
                              placeholder="Create New"
                              options={[
                                ...newAttributeOption,
                                ...attributeOption,
                              ]}
                              isDisabled={
                                d?.destination_field !== "products" ||
                                d?.source_field === uniqueColumn
                              }
                              handleSelectChange={handleSelectChange}
                              index={i}
                              column="products"
                              value={d?.destination_attribute_id}
                            />
                            {(d?.destination_attribute_id == "new" ||
                              d?.destination_attribute_id == "newInstance") && (
                              <SelectFieldImport
                                className="create-new-product"
                                type="select"
                                name="destination_dataType"
                                id="destination_dataType"
                                placeholder="Create New"
                                options={[...createNewDropdown]}
                                handleSelectChange={handleSelectChange}
                                index={i}
                                column="destination_dataType"
                                value={d?.destination_dataType}
                              />
                            )}
                            <Input
                              type="radio"
                              name={`radioButton${i}`}
                              value="ignore"
                              checked={d?.destination_field === "ignore"}
                              //  checked={d?.source_field !== uniqueColumn}
                              onChange={(e) => handleRadioChange(i, e)}
                              disabled={d?.source_field === uniqueColumn}
                            />
                            <Label check disabled>
                              Ignore
                            </Label>{" "}
                          </div>
                        </td>
                      </tr>
                    );
                  })}
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </div>
  );
};

export default MapField;
