import SelectField from "components/Common/SelectField";
import { fileToBase64 } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Button, Input, Label } from "reactstrap";
import {
  fetchAddImportFile,
  fetchAddImportFileReset,
} from "redux/actions/import/addImportFile";
import { fetchImportCountProductReset } from "redux/actions/import/importCountProduct";
import {
  fetchImportNameRange,
  fetchImportNameRangeReset,
} from "redux/actions/import/importNameRange";
import checkSquareIcon from "../../../assets/images/checkSquareIcon.png";
import Loader from "components/Common/Loader";

const SelectFile = ({ handleTab }) => {
  const sheetOption = [{ value: "", label: "Choose your sheet" }];
  const [fileUpload, setFileUpload] = useState([]);
  const [sheetOptions, setSheetOptions] = useState([
    { label: "Choose your sheet", value: "" },
  ]);
  const [nameChangeOptions, setNameChangeOptions] = useState([
    { label: "Choose your name", value: "" },
  ]);
  const [nameChange, setNameChange] = useState("");
  const [selectSheet, setSelectSheet] = useState("");
  const dispatch = useDispatch();

  const {
    addImportFile = null,
    addImportLoading = false,
    importNameRangeCheckLoading = false,
  } = useSelector((state) => ({
    addImportFile: state.addImportFile?.data,
    addImportLoading: state.addImportFile?.loading,
    importNameRangeCheckLoading: state.importNameRange?.loading,
  }));

  useEffect(() => {
    dispatch(fetchAddImportFileReset());
  }, []);

  const getFileUpload = (file) => {
    const formData = new FormData();
    formData.append("import_file", file);
    dispatch(fetchAddImportFile(formData)).then((data) => {
      if (data?.flag) {
        getSheetOptions(data?.data?.sheetNames);
        getNameRangeOptions(data?.data?.nameRangeText);
      }
    });
  };

  const getSheetOptions = (data = []) => {
    const options = data?.map((item) => {
      return {
        label: item,
        value: item,
      };
    });
    const final = [{ label: "Choose your sheet", value: "" }, ...options];
    setSelectSheet(final[1]?.value);
    setSheetOptions(final);
  };

  const getNameRangeOptions = (data = []) => {
    const options = data?.map((item) => {
      return {
        label: item,
        value: item,
      };
    });
    const final = [{ label: "Choose your name", value: "" }, ...options];
    setNameChange(final[1]?.value);
    setNameChangeOptions(final);
  };

  const handleOnChangeNameRange = (e) => {
    setNameChange(e);
    // const formData = {
    //   ImportsID: String(addImportFile?.data?.ImportsID),
    //   namedRange: e,
    //   sheetName: selectSheet,
    // };
    // if (e) {
    //   dispatch(fetchImportNameRange(formData)).then((data) => {
    //     if (data?.flag) {
    //       handleTab("initialCheck");
    //     }
    //   });
    // }
  };

  const handleOnChangeSelectSheet = (e) => {
    setSelectSheet(e);
  };

  const onNext = () => {
    const formData = {
      ImportsID: String(addImportFile?.data?.ImportsID),
      namedRange: nameChange,
      sheetName: selectSheet,
    };
    dispatch(fetchImportNameRange(formData)).then((data) => {
      if (data?.flag) {
        handleTab("initialCheck");
      }
    });
  };

  return (
    <div className="bg-white common-space">
      {(addImportLoading || importNameRangeCheckLoading) && <Loader />}
      <div className="tabbing-container">
        <h4 className="tabbing-select-title select-file-tab">
          Import from your existing data file
        </h4>
        <p>
          Using this wizard you will be able to import your existing data to
          populate your product and catalog structure, including mapping fields
          to display category text and product attributes (including images).
          Files need to contain unique column headings and a unique row
          identifier (usually the product code or product instance ID)
        </p>
        <div>
          <h5 className="select-file-title">Select File (xlsx, xls or csv)</h5>
          <input
            className="upload-file"
            type="file"
            onChange={(e) => {
              getFileUpload(e.target.files[0]);
            }}
          />
        </div>

        <p className={"uploadFile-message"}>
          {addImportFile?.message && (
            <>
              {addImportFile?.flag && (
                <img className="uploadfile-check-img" src={checkSquareIcon} />
              )}
              {addImportFile?.message}
            </>
          )}
        </p>

        <div className="select-file-bottom">
          <div className="mb-3">
            <h5 className="select-file-title">Select sheet (if Excel file)</h5>
            <h5 className="select-file-title">Select list:</h5>
            <div className="custom-select">
              <SelectField
                type="select"
                name="selectOrganization"
                id="selectOrganization"
                placeholder="Select Organization"
                options={sheetOptions}
                onChange={handleOnChangeSelectSheet}
                value={selectSheet}
              />
            </div>
          </div>
          <div>
            <h5 className="select-file-title">
              Select Named Range (if Excel file)
            </h5>
            <h5 className="select-file-title">Select list:</h5>
            <SelectField
              type="select"
              name="nameRange"
              id="nameRange"
              placeholder="Select Name Range"
              options={nameChangeOptions}
              onChange={handleOnChangeNameRange}
              value={nameChange}
            />
          </div>
        </div>
        <Button
          disabled={!(nameChange && selectSheet)}
          className="mt-3"
          onClick={() => onNext()}
        >
          Next
        </Button>
      </div>
      {/* )} */}
    </div>
  );
};

export default SelectFile;
