import React, { useEffect } from "react";
import { Formik, Field, Form, ErrorMessage } from "formik";
import { displayFormErrors, loginValidation } from "modules/validations";
import { useDispatch, useSelector } from "react-redux";
import { fetchLogin } from "redux/actions/auth/login";
import logomain from "../../assets/images/logomain.png";
import { valuesIn } from "lodash";
import { Input } from "reactstrap";
import { Redirect, useHistory } from "react-router";
import { getAuthToken } from "modules/utils";
import { Link } from "react-router-dom";

const Login = () => {
  const dispatch = useDispatch();
  const history = useHistory();

  useEffect(() => {
    const hasAuthToken = getAuthToken();
    if (hasAuthToken) {
      history.push("/home");
    }
  }, []);

  const { isLoginLoading = false } = useSelector((state) => ({
    loginData: state.login?.data ?? null,
    isLoginLoading: state.login?.loading ?? false,
  }));

  const handleSubmit = (values) => {
    const formData = {
      email: values.userName,
      password: values.password,
    };
    dispatch(fetchLogin(formData)).then((data) => {
      if (data?.data?.flag) {
        history.push("/home");
      }
    });
  };

  return (
    <Formik
      initialValues={{
        userName: "",
        password: "",
      }}
      validationSchema={loginValidation()}
      onSubmit={handleSubmit}
    >
      {({
        values,
        errors,
        touched,
        handleChange,
        handleBlur,
        handleSubmit,
        submitCount,
        setFieldValue,
      }) => {
        const showError = (key) =>
          displayFormErrors(key, errors, touched, submitCount);
        return (
          <div className="login-page">
            <div className="login-page-logo">
              <div className="product-text ">
                <img src={logomain} width="200" height="auto" alt="Producty" />
              </div>
              <div className="product-login">Subscriber Login</div>
            </div>
            <Form>
              <div className="input-field">
                <Input
                  type="text"
                  name="userName"
                  className="form-control"
                  placeholder="Email address"
                  onChange={handleChange}
                  value={values.userName || ""}
                />
                {showError("userName")}
                {/* <div className="input-error">
                  <ErrorMessage name="password" />
                </div> */}
              </div>
              <div className="input-field">
                <Input
                  type="password"
                  className="form-control"
                  name="password"
                  placeholder="Password"
                  onChange={handleChange}
                  value={values.password || ""}
                />
                {showError("password")}
              </div>
              <div className="login-page-btn">
                <button
                  className="loginmodal-submit btn"
                  type="submit"
                  loading={isLoginLoading}
                >
                  Login
                </button>
              </div>
              <div className="login-help">
                {/* <a className="forgot-pass" href="#">
                  Forgot Your Password?
                </a> */}
                <Link to={{ pathname: `/password/reset` }}>
                  <a className="forgot-pass"> Forgot Your Password?</a>
                </Link>
              </div>
            </Form>
          </div>
        );
      }}
    </Formik>
  );
};

export default Login;
