import React from "react";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import { Form, Formik } from "formik";
import { displayFormErrors } from "modules/validations";
import InputField from "components/Common/InputField";
import { useDispatch } from "react-redux";
import { fetchAddCategory } from "redux/actions/manageCatalog/addCategory";
import { getLocalStorageItem } from "modules/utils";
import { fetchCatalogTree } from "redux/actions/manageCatalog/catalogTree";

const AddCategoryModal = ({ isOpen, toggle, parentId }) => {
  const dispatch = useDispatch();

  const getInitialValues = () => {
    return {
      categoryName: "",
      isCollection: false,
      IsPanel: false,
      isStatic: false,
    };
  };

  const doSubmit = (values) => {
    const apiData = {
      ParentCategoryId: getLocalStorageItem("idForPagePlanner"),
      CategoryName: values?.categoryName,
      IsCollection: values?.isCollection ? 1 : 0,
      IsPanel: values?.IsPanel ? 1 : 0,
      IsStaticContent: values?.isStatic ? 1 : 0,
    };

    dispatch(fetchAddCategory(apiData)).then((res) => {
      if (res?.flag) {
        toggle();
        dispatch(fetchCatalogTree());
      }
    });
  };

  const handleStaticChange = (val, setFieldValue) => { };

  return (
    <Modal
      className="conformation-popup catalog-popup home-sidebar-modelbody"
      isOpen={isOpen}
      toggle={toggle}
      size={"lg"}
    >
      <ModalHeader>Add New Category / Collection</ModalHeader>
      <ModalBody>
        <Formik
          initialValues={getInitialValues()}
          // validationSchema={addCatalogForm}
          onSubmit={doSubmit}
          enableReinitialize
        >
          {({
            values,
            errors,
            touched,
            handleChange,
            handleBlur,
            handleSubmit,
            submitCount,
            setFieldValue,
          }) => {
            const showError = (key) =>
              displayFormErrors(key, errors, touched, submitCount);
            return (
              <Form>
                <div className="model-label-input">
                  <div className="row mb-3">
                    <div className="col-4">
                      <Label>Category Name: </Label>
                    </div>
                    <div className="col-8">
                      <InputField
                        type="text"
                        name="categoryName"
                        placeholder="Category Name"
                        onChange={handleChange}
                        value={values.categoryName || ""}
                      />
                      {showError("categoryName")}
                    </div>
                  </div>
                  <div className="row align-center mb-3">
                    <div className="col-4">
                      <Label check>Collection: </Label>{" "}
                    </div>
                    <div className="col-8">
                      <Input
                        type="checkbox"
                        name="isCollection"
                        onChange={handleChange}
                        checked={values.isCollection || ""}
                        disabled={values.isStatic}
                      />
                    </div>
                  </div>
                  <div className="row align-center mb-3">
                    <div className="col-4">
                      <Label check>Panel: </Label>{" "}
                    </div>
                    <div className="col-8">
                      <Input
                        type="checkbox"
                        name="IsPanel"
                        onChange={handleChange}
                        checked={values.IsPanel || ""}
                        disabled={values.isStatic}
                      />
                    </div>
                  </div>
                  {/* <div className="row align-center mb-3">
                    <div className="col-4">
                      <Label check>Static: </Label>{" "}
                    </div>
                    <div className="col-8">
                      <Input
                        type="checkbox"
                        name="isStatic"
                        onChange={(e) => {
                          setFieldValue("isStatic", !values.isStatic);
                          setFieldValue(
                            "isCollection",
                            values.isStatic ? false : true
                          );
                        }}
                        checked={values.isStatic || ""}
                      />
                    </div>
                  </div> */}
                </div>
                <div className="model-bottom-btn-section home-sidebar-model">
                  <Button color="primary cancel-btn confirm-n" onClick={toggle}>
                    Cancel
                  </Button>
                  <Button
                    color="primary save-btn confirm-y"
                    onClick={handleSubmit}
                  >
                    Ok
                  </Button>
                </div>
              </Form>
            );
          }}
        </Formik>
      </ModalBody>
    </Modal>
  );
};

export default AddCategoryModal;
