import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Button, Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import { fetchCategoryDisplaySetup } from "redux/actions/manageCatalog/categoryDisplaySetup";
import { fetchGetCategoryDetails } from "redux/actions/manageCatalog/getCategoryDetails";
import CatalogPlanner from "./tabs/catalogPlanner/CatalogPlanner";
import CategorySetup from "./tabs/categorySetup/CategorySetup";

import Products from "./tabs/products/Products";
import {
  getLocalStorageItem,
  isValidArray,
  setLocalStorageItem,
} from "modules/utils";
import { fetchAddStaticContent } from "redux/actions/manageCatalog/addStaticContent";
import Planner from "./tabs/planner/Planner";
import RestrictUserType from "components/Common/RestrictUserType";
import strings from "data/strings";
import DisplaySetup from "./tabs/categorySetup/tabs/DisplaySetup";
import { Link, useLocation } from "react-router-dom/cjs/react-router-dom.min";
import CatalogMedia from "./tabs/media/Media";
import Loader from "components/Common/Loader";
const BodyPart = ({
  catalogId,
  categoryId,
  isRoot,
  isAddHighlightClass,
  setIsAddHighlightClass,
  loadInitDataTree,
  pagePlannerEnabled,
  setIsRoot,
  catalogDataList,
}) => {
  const priorityActiveTab = getLocalStorageItem("isShowPlannerTab");
  const location = useLocation();

  const initialActiveTab = priorityActiveTab ? "planner" : "products";

  const [activeTab, setActivetab] = useState(initialActiveTab); // Default active tab

  const handleTab = (tabName) => {
    setActivetab(tabName);
  };
  const [catalogPlanner, setCatalogPlanner] = useState();
  const [isPage, setIsPage] = useState();
  const dispatch = useDispatch();
  const [fileData, setFileData] = useState();

  const {
    categoryDetails = null,
    isLoading = false,
    isCollection = false,
  } = useSelector((state) => ({
    categoryDetails: state.getCategoryDetails?.data?.data || null,
    isLoading: state.getCategoryDetails?.loading || null,
    isCollection: state.getCategoryDetails?.data?.data?.IsCollection || null,
  }));

  useEffect(() => {
    dispatch(fetchCategoryDisplaySetup(catalogId)).then((data) => {
      if (data?.data?.CatalogPlanner) {
        setCatalogPlanner(data?.data?.CatalogPlanner);
      } else if (activeTab.activeTab === "catalogPlanner") {
        handleTab("categorySetup");
      }
    });
    dispatch(fetchGetCategoryDetails(catalogId)).then((data) => {
      if (data?.flag) {
        setIsPage(data?.data?.IsPage);
      }
    });
    const path = location.pathname;
    console.log("🚀 ~ useEffect ~ path:", path);
    if (path.includes("/Catalog/Products")) {
      setActivetab("products");
    } else if (path.includes("/Catalog/Planner")) {
      setActivetab("planner");
    } else if (path.includes("/Catalog/Media")) {
      setActivetab("media");
    } else if (path.includes("/Catalog/CategorySetup")) {
      setActivetab("categorySetup");
    } else {
      setActivetab(initialActiveTab);
    }
  }, [catalogId, catalogPlanner, location.pathname, isRoot, priorityActiveTab]);

  useEffect(() => {
    if (!isRoot && activeTab === "planner" && !priorityActiveTab) {
      setActivetab(initialActiveTab);
    }
  }, [isRoot, priorityActiveTab]);

  const getFileUpload = () => {
    const formData = new FormData();
    formData.append("file", fileData);
    dispatch(fetchAddStaticContent(formData, catalogId)).then((data) => {
      dispatch(fetchGetCategoryDetails(catalogId)).then((data) => {
        if (data?.flag) {
          setIsPage(data?.data?.IsPage);
        }
      });
    });
  };

  // if (isLoading) {
  //   return <Loader />;
  // }

  return (
    <div
      className={`catalog-body ${activeTab.activeTab == "blockBuilder" ? "block-builder-wrap" : ""
        }`}
      style={{ width: "1612px" }}
      /* Used to identify the element. */
      id="catalog-body"
    >
      {categoryDetails?.IsStaticContent === 1 ? (
        <>
          {!isLoading && (
            <>
              <div className="bg-white common-space">
                <div className="alert-success">Add PDF file</div>
                <div className="d-flex justify-content-center mt-5">
                  <input
                    className="upload-file"
                    type="file"
                    onChange={(e) => {
                      setFileData(e.target.files[0]);
                    }}
                  />
                </div>
                <div
                  className="d-flex justify-content-center mt-5"
                  style={{ marginRight: "45px" }}
                >
                  <Button
                    onClick={() => {
                      fileData && getFileUpload();
                    }}
                    type="submit"
                    disabled={isLoading}
                  >
                    Submit
                  </Button>
                </div>
              </div>
              <iframe
                src={categoryDetails?.StaticContentFilePath}
                style={{ height: "100%", width: "100%" }}
              ></iframe>
            </>
          )}
        </>
      ) : (
        <>
          <div id="nav-tabs">
            <Nav tabs id="nav nav-tabs">
              <NavItem>
                <NavLink
                  tag={Link}
                  to={`/Catalog/Products?id=${catalogId}`}
                  className={activeTab === "products" ? "active" : ""}
                  onClick={() => handleTab("products")}
                >
                  {isCollection ? "Products" : "Dashboard"}
                </NavLink>
              </NavItem>
              <NavItem>
                <NavLink
                  tag={Link}
                  to={`/Catalog/Planner?id=${catalogId}`}
                  className={activeTab === "planner" ? "active" : ""}
                  onClick={() => handleTab("planner")}
                >
                  Planner
                </NavLink>
              </NavItem>
              <NavItem>
                <NavLink
                  tag={Link}
                  to={`/Catalog/Media?id=${catalogId}`}
                  className={activeTab === "media" ? "active" : ""}
                  onClick={() => handleTab("media")}
                >
                  Media
                </NavLink>
              </NavItem>
              <NavItem>
                <NavLink
                  tag={Link}
                  to={`/Catalog/CategorySetup?id=${catalogId}`}
                  className={activeTab === "categorySetup" ? "active" : ""}
                  onClick={() => handleTab("categorySetup")}
                >
                  Category Setup
                </NavLink>
              </NavItem>

              {/* {catalogPlanner && isPage ? (
                <NavItem>
                  <NavLink
                    className={activeTab.catalogPlanner}
                    onClick={() => handleTab("catalogPlanner")}
                  >
                    Catalog Planner
                  </NavLink>
                </NavItem>
              ) : null} */}
            </Nav>
          </div>

          <TabContent activeTab={activeTab}>
            <TabPane tabId="products">
              {activeTab === "products" && (
                <Products
                  catalogId={catalogId}
                  categoryId={categoryId}
                  isRoot={isRoot}
                  isAddHighlightClass={isAddHighlightClass}
                  setIsAddHighlightClass={setIsAddHighlightClass}
                  loadInitDataTree={loadInitDataTree}
                />
              )}
            </TabPane>
            <TabPane tabId="media">
              {activeTab === "media" && (
                <CatalogMedia catalogId={catalogId} isRoot={isRoot} />
              )}
            </TabPane>
            <TabPane tabId="categorySetup">
              {activeTab === "categorySetup" && (
                // <CategorySetup
                //   catalogId={catalogId}
                //   isRoot={isRoot}
                //   setCatalogPlanner={setCatalogPlanner}
                // />
                <DisplaySetup
                  catalogId={catalogId}
                  isRoot={isRoot}
                  changeCatalogPlanner={setCatalogPlanner}
                />
              )}
            </TabPane>
            {/* <TabPane tabId="catalogPlanner">
              {activeTab === "catalogPlanner" && (
                <CatalogPlanner catalogId={catalogId} isRoot={isRoot} />
              )}
            </TabPane> */}
            <TabPane tabId="planner">
              {activeTab === "planner" && (
                <Planner
                  catalogId={catalogId}
                  isRoot={isRoot}
                  pagePlannerEnabled={pagePlannerEnabled}
                  catalogDataList={catalogDataList}
                // setIsRoot={setIsRoot}
                />
              )}
            </TabPane>
          </TabContent>
        </>
      )}
    </div>
  );
};

export default BodyPart;
