import React, { useState } from "react";
import { Button, Modal, ModalBody } from "reactstrap";
import { useDispatch } from "react-redux";

import InputField from "components/Common/InputField";
import { fetchAddCategory } from "redux/actions/manageCatalog/addCategory";
import { fetchDeleteCategory } from "redux/actions/manageCatalog/deleteCategory";
import { getLocalStorageItem, removeLocalStorageItem } from "modules/utils";

const DeleteCategoryModal = ({
  isOpen,
  toggle,
  categoryId,
  isDeleted,
  catelogTreeList,
}) => {
  const dispatch = useDispatch();

  const [deleteInput, setDeleteInput] = useState("");
  const [isSubmit, setIsSubmit] = useState(false);

  const doSubmit = () => {
    setIsSubmit(true);

    if (deleteInput == "DELETE") {
      const formData = {
        CategoryId: String(categoryId),
      };
      const passParentCategoryId = getLocalStorageItem("parentID");

      dispatch(fetchDeleteCategory(formData)).then((res) => {
        if (res?.flag) {
          toggle();
          isDeleted(true);
          catelogTreeList(true, passParentCategoryId);
        }
      });
    }
  };

  return (
    <>
      <Modal
        className="conformation-popup catalog-popup delect-catalog-model home-sidebar-modelbody"
        isOpen={isOpen}
        toggle={toggle}
        size={"lg"}
      >
        <ModalBody className="text-center">
          <h4>Do you want to delete the current category?</h4>

          <span className="lead text-center">
            Type <b>DELETE</b> to delete. This action cannot be undone!
          </span>
          <div
            className={
              deleteInput !== "DELETE" && isSubmit ? "input-msg-error" : ""
            }
          >
            <InputField
              type="text"
              placeholder="Type DELETE to proceed"
              onChange={(e) => setDeleteInput(e?.target?.value)}
              value={deleteInput}
            />
          </div>
          {deleteInput !== "DELETE" && isSubmit ? (
            <p className="error-msg-icon" style={{ color: "red" }}>
              You need to type &apos;DELETE&lsquo;
            </p>
          ) : (
            ""
          )}
          <div className="model-bottom-btn-section">
            <Button color="primary cancel-btn confirm-n" onClick={toggle}>
              Cancel
            </Button>
            <Button
              color="primary save-btn confirm-y"
              onClick={doSubmit}
              //   disabled={deleteInput !== "DELETE"}
            >
              OK
            </Button>
          </div>
        </ModalBody>
      </Modal>
    </>
  );
};

export default DeleteCategoryModal;
