import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import Split from "react-split";
import { fetchCatalogTree } from "redux/actions/manageCatalog/catalogTree";
import BodyPart from "./BodyPart";
import Breadcrum from "./Breadcrum";
import {
  getLocalStorageItem,
  insertParam,
  isValidArray,
  removeLocalStorageItem,
  setLocalStorageItem,
} from "modules/utils";
import { useLocation } from "react-router-dom";
import { fetchCheckCategoryCatalog } from "redux/actions/manageCatalog/checkCategoryCatalog";
import CatalogChangeModal from "./tabs/products/CatalogChangeModal";
import SideBarTree from "./SideBarTree";
import { Steps } from "intro.js-react";
import "intro.js/introjs.css";
import Loader from "components/Common/Loader";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import { fetchOrganizationList } from "redux/actions/masterAdmin/organizationList";
import { fetchCatalogList } from "redux/actions/masterAdmin/catalogList";
import { fetchUpdateUserCatalog } from "redux/actions/masterSetup/updateUserCatalog";
import { fetchUserDetail } from "redux/actions/auth/getUserDetail";
import { Input, Label } from "reactstrap";
import SelectField from "components/Common/SelectField";
import { fetchGetCatalogTreeWithPageNumbers } from "redux/actions/manageCatalog/getCatalogTreeWithPageNumbers";
import { fetchGetUserCatalogDetail } from "redux/actions/output/getUserCatalogDetail";

const ManageCatalog = ({ bodyPart, pagePlanner, isElefant }) => {
  // console.log(
  //   "🚀 ~ file: ManageCatalog.js:31 ~ ManageCatalog ~ bodyPart",
  //   bodyPart,
  //   pagePlanner
  // );
  const dispatch = useDispatch();
  const [catalogId, setCatalogId] = useState(0);
  const [parentCatalogId, setParentCatalogId] = useState(0);
  const [breadcrumbLoading, setBreadcrumbLoading] = useState(true);
  const [openChangeCatalogModal, setOpenChangeCatalogModal] = useState(false);
  const [catArray, setCatArray] = useState([]);

  const [isAddHighlightClass, setIsAddHighlightClass] = useState(false);

  const [isRoot, setIsRoot] = useState(1);

  const [catelogIdList, setCatelogIdList] = useState([]);

  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [stepsEnabledForSidebar, setStepsEnabledForSidebar] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);
  const [selectOrganization, setSelectOrganization] = useState("");

  const [selectCatalog, setSelectCatalog] = useState("");

  const {
    isLoading = false,
    catalogTree = null,
    categoryTextData = null,
    organizationListIsLoading = false,
    organizationList = null,
    loginUserDetails = null,
    catalogListData = null,
    loginUserDetailsLoading = false,
    checkCategoryCatalogLoading = false,
    updateCatlogLoading = false,
    breadCrumbLoading = false,
    sidebarTreeLoading,
    // getUserCatalogDetails = null,
    pagePlannerEnabled,
  } = useSelector((state) => ({
    catalogTree: state.catalogTree?.data?.data || null,
    isLoading: state.catalogTree?.loading || false,
    categoryTextData: state.categoryTextData?.data?.data || null,
    organizationList: state.organizationList?.data?.data || null,
    organizationListIsLoading: state.organizationList?.loading || null,
    loginUserDetails: state.getUserDetail?.data?.data || null,
    loginUserDetailsLoading: state.getUserDetail?.loading || null,
    catalogListData: state.catalogList?.data?.data || null,
    checkCategoryCatalogLoading: state.checkCategoryCatalog.loading,
    updateCatlogLoading: state.updateCatalog.loading,
    breadCrumbLoading: state.breadCrumb.loading,
    // getUserCatalogDetails: state?.getUserCatalogDetails?.data?.data || null,
    sidebarTreeLoading: state.catalogTree.loading || false,
    pagePlannerEnabled:
      state.getUserCatalogDetail?.data?.data?.VisualDesigner || null,
  }));

  const search = useLocation().search;
  const catId = new URLSearchParams(search).get("id");

  const onExit = () => {
    setStepsEnabled(false);
  };
  // console.log(
  //   "🚀 ~ file: ManageCatalog.js:98 ~ ManageCatalog ~ getUserCatalogDetails:",
  //   getUserCatalogDetails
  // );

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = `#${d.elementIDName}`;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  const loadInitDataTree = (flag = false) => {
    document.title = "Manage Catalog | Producty®";
    catelogTreeList(flag);
  };

  useEffect(() => {
    if (!pagePlanner) {
      dispatch(fetchGetUserCatalogDetail());
    }
    loadInitDataTree();
    setStepsEnabled(true);
    dispatch(getIntroJs("catalog")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });

    dispatch(fetchUserDetail()).then((res) => {
      if (res) {
        dispatch(fetchOrganizationList()).then((data) => {
          if (data?.flag) {
            setSelectOrganization(String(res?.data?.OrganisationID));

            dispatch(fetchCatalogList(Number(res?.data?.OrganisationID))).then(
              (d) => {
                setSelectCatalog(String(res?.data?.CatalogID));
              }
            );
          }
        });
      }
    });
  }, []);

  const initData = () => {
    loadInitDataTree();
    setStepsEnabled(true);
    dispatch(getIntroJs("catalog")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
    dispatch(fetchUserDetail()).then((res) => {
      if (res) {
        dispatch(fetchOrganizationList()).then((data) => {
          if (data?.flag) {
            setSelectOrganization(String(res?.data?.OrganisationID));

            dispatch(fetchCatalogList(Number(res?.data?.OrganisationID))).then(
              (d) => {
                setSelectCatalog(String(res?.data?.CatalogID));
              }
            );
          }
        });
      }
    });
  };

  const catelogTreeList = (flag = false, passedParentCategoryId) => {
    if (catId && !flag) {
      dispatch(fetchCheckCategoryCatalog(catId)).then((data) => {
        if (data?.data?.match == "1") {
          setLocalStorageItem("parentID", catId);
          setLocalStorageItem("idForPagePlanner", `${catId}`);
          catalogDataList();
        } else {
          setLocalStorageItem("parentID", catId);
          setLocalStorageItem("idForPagePlanner", `${catId}`);
          handleChangeCatalogModal();
        }
      });
    } else {
      catalogDataList(passedParentCategoryId, "", flag);
    }
  };

  const handleChangeCatalogModal = () => {
    setOpenChangeCatalogModal(!openChangeCatalogModal);
  };

  const getParentIds = (data = [], id = 0) => {
    if (!(isValidArray(data) && id)) {
      return [];
    }

    let checkId = id;
    const parentIds = [];

    const findElem = (index) => data.find((d) => d.id === index);

    while (checkId !== 0) {
      const selected = findElem(checkId);

      if (selected && selected.parent) {
        checkId = selected.parent;
        parentIds.push(selected.parent);
      } else {
        checkId = 0;
      }
    }

    return parentIds;
  };

  const catalogDataList = (paramId = "", search = "", flag = false) => {
    dispatch(fetchCatalogTree(search)).then((data) => {
      const nodeId = getLocalStorageItem("idForPagePlanner");

      setParentCatalogId(data?.data[0]?.id);
      const initialCatalogId = parseInt(nodeId) || data?.data[0]?.id;
      if (flag) {
        setCatalogId(parseInt(paramId));
      } else {
        setCatalogId(initialCatalogId);
      }

      const parentIds = getParentIds(data?.data, initialCatalogId);
      console.log("🚀 ~ dispatch ~ parentIds:", parentIds);
      setCatArray(parentIds.length > 0 ? parentIds : [initialCatalogId]);
      // nodeId == 0
      //   ? setCatArray([data?.data[0]?.id])
      //   : setCatArray(getParentIds(data?.data, parseInt(nodeId)));
      // setCatArray([data?.data[0]?.id]);
      setIsRoot(1);

      insertParam("id", paramId || nodeId);
    });
  };

  let result = [];

  const findInitialArrOfCat = (id, data = []) => {
    const updated = isValidArray(data)
      ? data.find((d) => d?.id == id)
      : catalogTree.find((d) => d?.id == id);
    // if (!updated) {
    //   setCatArray([data[0]?.id]);
    //   setCatalogId(data[0]?.id);
    //   setLocalStorageItem("parentID", data[0]?.id);

    //   setIsRoot(1);
    //   return;
    // }
    result = [...result, updated?.id];

    if (updated?.parent !== 0)
      result = [...result, findInitialArrOfCat(updated?.parent, data)];
    else {
      result = result.reverse();
      setCatArray(result);
    }
  };

  const catalogList = () => {
    dispatch(fetchCatalogTree()).then((data) => {
      setLocalStorageItem("parentID", catId);
      setCatalogId(catId);
      insertParam("id", catId);
      setIsRoot(data?.data[0]?.id == catId ? 1 : 0);
      findInitialArrOfCat(Number(catId), data?.data);
      setSelectCatalog(Number(catId));
    });
  };
  const getChildrenIds = (data) => {
    if (isValidArray(data)) {
      let ids = [];

      data.forEach((d) => {
        const childIds = getChildrenIds(d?.children || []);
        ids = [...ids, d.id, ...childIds];
        ids = [...new Set(ids)].sort(function (a, b) {
          return a - b;
        });
      });

      return ids;
    }
    return [];
  };

  const processChildren = (data, parentIds) => {
    if (isValidArray(data)) {
      return data.map((d) => {
        return {
          ...d,
          children: processChildren(d?.children || [], [...parentIds, d.id]),
          childrenIds: getChildrenIds(d?.children || []),
          parent: parentIds,
        };
      });
    }
    return data;
  };

  //breadcrumbs dropdown
  const organizationOptions = () => {
    let updated =
      isValidArray(organizationList) &&
      organizationList?.map((item) => {
        return {
          label: item.OrganisationName,
          value: item.OrganisationID,
        };
      });
    return updated;
  };

  const catalogOptions = () => {
    let updated =
      isValidArray(catalogListData) &&
      catalogListData?.map((item) => {
        return {
          label: item.CatalogName,
          value: item.CatalogID,
        };
      });

    return updated;
  };

  const handleOnChangeOrg = (itemId) => {
    setSelectOrganization(itemId);
    setSelectCatalog(0);
    dispatch(fetchCatalogList(Number(itemId))).then((data) => {
      if (data?.flag) {
        // setSelectCatalog(String(data?.data[0]?.CatalogID));
      }
    });
  };

  const handleOnChangeCatalog = (itemId) => {
    setSelectCatalog(itemId);
    if (itemId != 0) {
      const formData = {
        organisationId: String(selectOrganization),
        catalogId: String(itemId),
      };

      dispatch(fetchUpdateUserCatalog(formData)).then((data) => {
        if (data) {
          catalogDataList(`${data?.data?.CategoryID}`, "");
          setLocalStorageItem("idForPagePlanner", `${data?.data?.CategoryID}`);
          dispatch(fetchUserDetail()).then((d) => {
            dispatch(fetchGetUserCatalogDetail());
            loadInitDataTree(true);
            removeLocalStorageItem("parentID");
            // history.push("/Catalog");
          });
        }
      });
    }
  };

  const isLoadedEverything =
    catArray.length > 0 &&
    categoryTextData &&
    catalogId &&
    isValidArray(catalogTree);

  if (
    (isLoading &&
      !isValidArray(catArray) &&
      catArray.length > 0 &&
      !isValidArray(catalogTree)) ||
    checkCategoryCatalogLoading ||
    loginUserDetailsLoading ||
    updateCatlogLoading
  ) {
    return (
      <div className="category-display-template m-4">
        <div className="tableorganisation category-table table-drag-drop center-text-tbl product-tableBorder">
          <Loader />
        </div>
      </div>
    );
  }

  const isStepEnabled = isLoadedEverything && stepsEnabled;
  const catalogOptionsList = catalogOptions() || [];

  return (
    <>
      <Steps
        enabled={isStepEnabled}
        steps={steps}
        initialStep={0}
        onExit={onExit}
        onComplete={() => {
          setStepsEnabled(false);
          setStepsEnabledForSidebar(true);
        }}
        options={{ doneLabel: "Next" }}
      />
      <div className="manage-catalog" id="manage-catalog">
        <div className="Breadcrum-text">
          {isLoading && loginUserDetailsLoading && breadCrumbLoading ? (
            <div>Loading...</div>
          ) : (
            <>
              <div className="selectcatalog-tab justify-content-center align-items-center">
                <div className="dropdown-1">
                  <SelectField
                    type="select"
                    name="selectOrganization"
                    id="selectOrganization"
                    placeholder="Select Organization"
                    options={organizationOptions()}
                    onChange={handleOnChangeOrg}
                    value={selectOrganization}
                    //   isFirstOpDisable={true}
                  />
                </div>
                <div className="dropdown-1">
                  {/* <SelectField
                    type="select"
                    name="selectCatalog"
                    id="selectCatalog"
                    placeholder="Select Catalog"
                    options={catalogOptions()}
                    onChange={handleOnChangeCatalog}
                    value={selectCatalog}
                    //   isFirstOpDisable={true}
                  /> */}
                  <Input
                    type="select"
                    name="sections"
                    isFirstOption={true}
                    isLower={true}
                    isSearchable={true}
                    options={catalogOptionsList}
                    selected={selectCatalog}
                    value={selectCatalog}
                    onChange={(e) => {
                      handleOnChangeCatalog(e.target.value);
                    }}
                  >
                    {<option value={0}>Select catalog</option>}
                    {isValidArray(catalogOptionsList) &&
                      catalogOptionsList.map((item, i) => {
                        return (
                          <option key={i} value={item.value}>
                            {item.label}
                          </option>
                        );
                      })}
                  </Input>
                </div>
                {isElefant ? (
                  <></>
                ) : (
                  <Breadcrum catalogId={catalogId}></Breadcrum>
                )}
              </div>
            </>
          )}
        </div>
      </div>
      {catArray.length > 0 && (
        <Split
          sizes={[0, 100]}
          minSize={260}
          direction="horizontal"
          cursor="col-resize"
          className="split-flex"
        >
          <div
            className="catalog-sidebar catalog-sidebar-body"
            id="catalog-sidebar"
          >
            {sidebarTreeLoading && <Loader />}
            <SideBarTree
              stepsEnabledForSidebar={stepsEnabledForSidebar}
              catalogId={catalogId}
              setCatalogId={setCatalogId}
              catalogList={catalogList}
              catArray={catArray}
              catelogTreeList={catelogTreeList}
              setIsRoot={setIsRoot}
              isRoot={isRoot}
              catalogDataList={catalogDataList}
              isAddHighlightClass={isAddHighlightClass}
              setIsAddHighlightClass={setIsAddHighlightClass}
              pagePlanner={pagePlanner}
              isElefant={isElefant}
              displayPageNumber={pagePlannerEnabled}
            />
          </div>
          {bodyPart ? (
            bodyPart
          ) : (
            <BodyPart
              catalogId={catalogId}
              isRoot={isRoot}
              isAddHighlightClass={isAddHighlightClass}
              setIsAddHighlightClass={setIsAddHighlightClass}
              loadInitDataTree={loadInitDataTree}
              setIsRoot={setIsRoot}
              catalogDataList={catalogDataList}
            />
          )}
        </Split>
      )}
      {openChangeCatalogModal && (
        <CatalogChangeModal
          toggle={handleChangeCatalogModal}
          isOpen={openChangeCatalogModal}
          catalogId={catId}
          catalogList={catalogDataList}
          catalogDataList={catalogDataList}
          setSelectCatalog={setSelectCatalog}
          catalogOptions={catalogOptionsList}
        />
      )}
    </>
  );
};

export default ManageCatalog;
