import React, { useCallback, useEffect, useRef, useState } from "react";
import { Tree } from "@minoru/react-dnd-treeview";
import editIcon from "assets/images/editicon.png";
import classNames from "classnames";
import { debounce } from "lodash";
import { useDispatch, useSelector } from "react-redux";
import downSideArrow from "assets/images/iconArrowfill.png";
import { CustomDragPreview } from "components/ManageCatalog/CustomDragPreview";
import { Placeholder } from "components/ManageCatalog/Placeholder";
import SideBar from "components/ManageCatalog/SideBar";
import styles from "components/ManageCatalog/sidebarTree.module.css";
import {
  getLocalStorageItem,
  insertParam,
  isValidArray,
  setLocalStorageItem,
} from "modules/utils";
import { fetchCategoryProduct } from "redux/actions/manageCatalog/categoryProducts";
import { fetchMoveCategory } from "redux/actions/manageCatalog/moveCategory";
import { fetchGetPagePlannerByPage } from "redux/actions/blockBuilder/getPagePlannerByPage";
import { Button, Input, Label, Modal, ModalBody } from "reactstrap";
import { fetchRenameCategory } from "redux/actions/manageCatalog/renameCategory";
import { fetchCatalogTree } from "redux/actions/manageCatalog/catalogTree";
import axios from "axios";
import { fetchGetCategoryDetails } from "redux/actions/manageCatalog/getCategoryDetails";
import Loader from "components/Common/Loader";
import { useHistory } from "react-router-dom/cjs/react-router-dom.min";

const childNodeIdPrefix = "catalogTree-node-li-";

const CategoryTitle = ({ modal = false, setModal, id = 0, text = "" }) => {
  console.log("🚀 ~ CategoryTitle ~ id:", id);
  const dispatch = useDispatch();
  // const [modal, setModal] = useState(false);
  const [updatedText, setUpdatedText] = useState();
  const [isPanelFlag, setIsPanelFlag] = useState(false);
  const [isLoading, setIsLoading] = useState(false);

  const handleOnChange = (event) => {
    setUpdatedText(event.target.value);
  };
  useEffect(() => {
    setIsLoading(true);
    dispatch(fetchGetCategoryDetails(id)).then((res) => {
      console.log("🚀 ~ dispatch ~ res:", res);
      if (res?.data) {
        setUpdatedText(res?.data?.CategoryName);
        setIsPanelFlag(res?.data?.IsPanel);
        setIsLoading(false);
      }
    });
  }, []);

  return (
    <>
      {modal && (
        <Modal isOpen={modal} toggle={() => setModal(!modal)}>
          <ModalBody>
            <div>
              <h5 className="text-center">Edit Category</h5>
              {isLoading ? (
                <div className="d-flex justify-content-center">
                  <Loader />
                </div>
              ) : (
                <>
                  <div>
                    <input
                      type="text"
                      className="sidebar-modal-input w-100 mb-2"
                      onChange={(e) => handleOnChange(e)}
                      value={updatedText}
                    />
                    <Input
                      type="checkbox"
                      className="sidebar-modal-input mb-2"
                      name="isPanel"
                      checked={isPanelFlag}
                      onChange={() => setIsPanelFlag(!isPanelFlag)}
                    />
                    <Label check>Panel</Label>{" "}
                  </div>
                  <button
                    type="button"
                    className="title-save-btn btn btn-secondary"
                    onClick={() => {
                      dispatch(
                        fetchRenameCategory(id, {
                          CategoryName: updatedText,
                          IsPanel: isPanelFlag,
                        })
                      ).then(() => {
                        dispatch(fetchCatalogTree());
                        setModal(false);
                      });
                    }}
                  >
                    Save
                  </button>
                  <button
                    type="button"
                    className="title-cancel-btn btn btn-secondary"
                    onClick={() => setModal(false)}
                  >
                    Cancel
                  </button>
                </>
              )}
            </div>
          </ModalBody>
        </Modal>
      )}
    </>
  );
};

const SideBarTree = ({
  setCatalogId,
  catalogId,
  catalogList,
  catArray,
  isRoot,
  setIsRoot,
  catelogTreeList,
  catalogDataList,
  isAddHighlightClass,
  stepsEnabledForSidebar,
  pagePlanner,
  isElefant,
  displayPageNumber,
  searchedNodeIds,
}) => {
  // console.log("🚀 ~ catArray:", catArray);
  const dispatch = useDispatch();
  const ref = useRef(null);

  const {
    catalogTree = [],
    catalogTreeWithPageNumber = [],
    getPagePlannerByPageLoading = false,
  } = useSelector((state) => ({
    catalogTree: state.catalogTree.data?.data,
    catalogTreeWithPageNumber: state.getCatalogTreeWithPageNumbers.data?.data,
    getPagePlannerByPageLoading: state.getPagePlannerByPage?.loading,
  }));

  const text = useRef("");
  const [modal, setModal] = useState(false);
  const [editModalId, setEditModalId] = useState(null);
  const [isDragDrop, setIsDragDrop] = useState(false);
  const [categoryName, setCategoryName] = useState("");
  // console.log("🚀 ~ file: SideBarTree.js:115 ~ categoryName:", categoryName);
  const [nodeId, setNodeId] = useState(0);
  const [treeData, setTreeData] = useState([]);

  const toggleModal = () => {
    setModal(!modal);
  };
  const handleSelect = (node) => {
    setNodeId(node);
  };

  const currenId = getLocalStorageItem("idForPagePlanner");

  useEffect(() => {
    setNodeId(catalogId);

    if (isValidArray(catalogTree)) {
      setTreeData(catalogTree);
      // const singleCatagory =
      //   catalogTree &&
      //   catalogTree?.filter((d) => {
      //     return d?.id === catalogId;
      //   });
      // dispatch(
      //   fetchGetPagePlannerByPage(singleCatagory?.[0]?.data?.PageNumber)
      // );
    }
  }, [catalogTree, categoryName, catalogId]);

  useEffect(() => {
    setNodeId(catalogId);

    if (isValidArray(catalogTreeWithPageNumber)) {
      setTreeData(catalogTreeWithPageNumber);
    }
  }, [catalogTreeWithPageNumber, catalogId]);

  const handleDrop = (
    newTree,
    { dragSourceId, dropTargetId, dragSource, destinationIndex }
  ) => {
    if (!isDragDrop) return false;
    setTreeData(newTree);

    const droppedOn = document.querySelector(
      `#${childNodeIdPrefix}${dropTargetId}`
    );
    if (droppedOn && !droppedOn?.classList?.contains("is-open")) {
      document
        .querySelector(`#${childNodeIdPrefix}${dropTargetId} > span`)
        .click();
    }

    setTimeout(() => {
      const eleMain = document.querySelector(
        `#${childNodeIdPrefix}${dragSource.id}`
      );
      const eleLi = eleMain?.parentElement;
      const eleUl = eleLi?.parentElement;

      const index =
        eleMain && eleLi && eleUl
          ? [...eleUl.childNodes].findIndex((item) => item === eleLi)
          : destinationIndex;

      const childQuery = `#${childNodeIdPrefix}${dropTargetId} ~ ul > li > div`;
      const childrenEle = document.querySelectorAll(childQuery);

      const childrenIds = [...childrenEle]
        .filter((d) => d?.id.startsWith(childNodeIdPrefix))
        .map((d) => d.id.replace(childNodeIdPrefix, ""));

      //! IDs of Children Elements
      // console.log(
      //   "NJ ~ setTimeout ~ childrenIds",
      //   childrenIds,
      //   dropTargetId,
      //   dragSourceId
      // );

      const formData = {
        ParentCategoryId: dropTargetId,
        CategoryId: dragSourceId,
        Position: index,
        catArray: childrenIds,
      };

      dispatch(fetchMoveCategory(formData)).then((data) => {
        if (data?.flag) {
          catalogDataList();
          if (currenId == dragSourceId) {
            setLocalStorageItem("idForPagePlanner", dragSourceId);
          } else {
            setLocalStorageItem("idForPagePlanner", dropTargetId);
          }
        }
        setIsDragDrop(false);
      });
    }, 100);
  };

  const categoryProduct = (id) => {
    dispatch(fetchCategoryProduct(id));
  };

  const debounceLoadData = useCallback(debounce(catalogDataList, 1000), []);

  const searchNodesData = (search) => {
    dispatch(fetchCatalogTree(search)).then((data) => {
      // console.log(
      //   "🚀 ~ file: ManageCatalog.js:231 ~ dispatch ~ data:",
      //   data?.data?.[0]
      // );
      const nodeId = getLocalStorageItem("idForPagePlanner");
      if (search) {
        //TODO: for opening multiple nodes for search result
        // for (let index = 0; index < data?.data?.length; index++) {
        //   const element = data?.data[index];
        //   const passIds = element.map((d) => {
        //     return d?.id;
        //   });
        //   setTimeout(() => {
        //     ref.current?.open(passIds);
        //   }, 100);
        // }
        const searchedParentIds = data?.data?.[0]?.map((d) => {
          return d?.id;
        });
        ref.current?.open(searchedParentIds);
      }
    });
  };
  const SearchData = useCallback(debounce(searchNodesData, 1000), []);

  const searchCategory = (e) => {
    setCategoryName(e.target.value);
    SearchData(e?.target?.value);
  };
  // console.log(
  //   "🚀 ~ file: SideBarTree.js:226 ~ searchCategory ~ searchedNodeIds:",
  //   searchedNodeIds
  // );
  // searchedNodeIds
  // ref.current?.open([25901,25902,25903]);

  const getPageGridDataHandle = (id) => {
    if (getPagePlannerByPageLoading === false) {
      dispatch(fetchGetPagePlannerByPage(id));
    }
  };
  const history = useHistory();

  return (
    <>
      <SideBar
        catalogId={catalogId}
        setCatalogId={setCatalogId}
        setIsRoot={setIsRoot}
        catelogTreeList={catelogTreeList}
        isRoot={isRoot}
        isDragDrop={isDragDrop}
        setIsDragDrop={setIsDragDrop}
        catalogDataList={catalogDataList}
        categoryName={categoryName}
        setCategoryName={setCategoryName}
        searchCategory={searchCategory}
        isAddHighlightClass={isAddHighlightClass}
        isElefant={isElefant}
      />
      <div id="catalogTree" className="custom-catalogTree-sidebar">
        {isValidArray(treeData) && (
          <Tree
            ref={ref}
            placeholderRender={(node, { depth }) => (
              <Placeholder node={node} depth={depth} />
            )}
            insertDroppableFirst={false}
            canDrag={() => {
              if (isDragDrop) return true;
              return false;
            }}
            sort={false}
            tree={treeData}
            rootId={0}
            initialOpen={catArray}
            render={(node, { depth, isOpen, onToggle }) => {
              return (
                <div
                  className={classNames({
                    "active-sidebar-color":
                      nodeId == node.id && nodeId == catalogId,
                    "static-active": node.data?.IsStaticContent,
                    "is-open": isOpen,
                    "menu-toggle-inner": true,
                  })}
                  // className={
                  //   nodeId == node.id && nodeId == catalogId
                  //     ? "active-sidebar-node-color"
                  //     : ""
                  // }
                  style={{ marginInlineStart: depth * 4 }}
                  id={`${childNodeIdPrefix}${node?.id}`}
                  key={`${childNodeIdPrefix}${node?.id}`}
                >
                  {node.droppable && (
                    <span
                      onClick={() => {
                        // handleSelect(node?.id);
                        // setCatalogId(node?.id);

                        onToggle();
                      }}
                    >
                      {isOpen ? (
                        <img className="upDownArrow" src={downSideArrow} />
                      ) : (
                        <img className="downArrow" src={downSideArrow} />
                      )}
                    </span>
                  )}
                  <div
                    onClick={() => {
                      if (pagePlanner || displayPageNumber) {
                        if (node?.data?.PageNumber) {
                          getPageGridDataHandle(node?.data?.PageNumber);
                        } else {
                          getPageGridDataHandle(0);
                        }
                        setLocalStorageItem("idForPagePlanner", node?.id);
                        handleSelect(node?.id);
                        setCatalogId(node?.id);
                        setLocalStorageItem("parentID", node?.parent);

                        history.push(`/Catalog/Products?id=${node?.id}`);
                        // insertParam("id", node?.id);
                        categoryProduct(node?.id);
                        setIsRoot(node.parent == 0 ? 1 : 0);
                      }
                      // onToggle();
                      setLocalStorageItem("idForPagePlanner", node?.id);
                      handleSelect(node?.id);
                      setCatalogId(node?.id);
                      setLocalStorageItem("parentID", node?.parent);
                      history.push(`/Catalog/Products?id=${node?.id}`);
                      // insertParam("id", node?.id);
                      categoryProduct(node?.id);
                      setIsRoot(node.parent == 0 ? 1 : 0);
                      setLocalStorageItem("isShowPlannerTab", "");
                    }}
                    className={
                      node?.data?.icon == "fa fa-th-list"
                        ? "low-level-child"
                        : ""
                    }
                  >
                    <i
                      className={
                        node.data?.IsStaticContent
                          ? "fa-solid fa-file-pdf"
                          : node?.data?.icon == "fa fa-th-list"
                            ? "fa fa-list"
                            : node?.data?.icon
                      }
                      style={
                        categoryName &&
                          node.text
                            .toLowerCase()
                            .includes(categoryName.toString().toLowerCase())
                          ? { color: "#8b0000" }
                          : {}
                      }
                    ></i>

                    <span
                      className={
                        categoryName &&
                          node.text
                            .toLowerCase()
                            .includes(categoryName.toString().toLowerCase())
                          ? "tree-view-txt"
                          : ""
                      }
                      style={{ width: "190px" }}
                    >
                      {node.text}
                      <span className="grayTxt">
                        {" "}
                        ({node?.data?.TreeCount})
                        <img
                          src={editIcon}
                          className="sidebarTree-edit"
                          onClick={() => {
                            setEditModalId(node?.id);
                            toggleModal();
                          }}
                          id={node?.id}
                        />
                      </span>
                      {pagePlanner || displayPageNumber ? (
                        <>
                          {
                            <>
                              <div
                                className={classNames({
                                  "gray-bg": true,
                                  "d-none": node?.data?.IsRoot,
                                  "orange-color": !node?.data?.PageNumber,
                                })}
                                onClick={(event) => {
                                  event.stopPropagation();
                                  setLocalStorageItem(
                                    "isShowPlannerTab",
                                    "planner"
                                  );
                                  if (pagePlanner || displayPageNumber) {
                                    if (node?.data?.PageNumber) {
                                      getPageGridDataHandle(
                                        node?.data?.PageNumber
                                      );
                                    } else {
                                      getPageGridDataHandle(0);
                                    }
                                    setLocalStorageItem(
                                      "idForPagePlanner",
                                      node?.id
                                    );
                                    handleSelect(node?.id);
                                    setCatalogId(node?.id);
                                    setLocalStorageItem(
                                      "parentID",
                                      node?.parent
                                    );
                                    history.push(
                                      `/Catalog/Planner?id=${node?.id}`
                                    );

                                    // insertParam("id", node?.id);
                                    categoryProduct(node?.id);
                                    setIsRoot(node.parent == 0 ? 1 : 0);
                                  }
                                  // onToggle();
                                  setLocalStorageItem(
                                    "idForPagePlanner",
                                    node?.id
                                  );
                                  handleSelect(node?.id);
                                  setCatalogId(node?.id);
                                  setLocalStorageItem("parentID", node?.parent);
                                  history.push(
                                    `/Catalog/Planner?id=${node?.id}`
                                  );
                                  insertParam("id", node?.id);
                                  categoryProduct(node?.id);
                                  setIsRoot(node.parent == 0 ? 1 : 0);
                                }}
                              >
                                <span className="pageNumber">
                                  {node?.data?.PageNumber}
                                  {node?.data?.IsPanel == '1' ? 'P' : ''}
                                </span>
                              </div>
                            </>
                          }
                        </>
                      ) : (
                        <></>
                      )}
                    </span>
                  </div>
                </div>
              );
            }}
            classes={{
              root: styles.treeRoot,
              draggingSource: styles.draggingSource,
              dropTarget: styles.dropTarget,
              placeholder: styles.placeholderTree,
            }}
            dragPreviewRender={(monitorProps) => (
              <CustomDragPreview monitorProps={monitorProps} />
            )}
            onDrop={handleDrop}
            canDrop={
              isDragDrop
                ? (tree, { dragSource, dropTargetId, dropTarget }) => {
                  if (dragSource?.parent === dropTargetId) {
                    return true;
                  }
                }
                : false
            }
          />
        )}
      </div>
      {modal && (
        <CategoryTitle
          modal={modal}
          setModal={toggleModal}
          id={editModalId}
        // text={node.text}
        />
      )}
    </>
  );
};

export default SideBarTree;
