import React, { useCallback, useEffect, useRef, useState } from "react";
import { Tree } from "@minoru/react-dnd-treeview";
import classNames from "classnames";
import { debounce } from "lodash";
import { useDispatch, useSelector } from "react-redux";
import downSideArrow from "assets/images/iconArrowfill.png";
import { CustomDragPreview } from "components/ManageCatalog/CustomDragPreview";
import { Placeholder } from "components/ManageCatalog/Placeholder";
import SideBar from "components/ManageCatalog/SideBar";
import styles from "components/ManageCatalog/sidebarTree.module.css";
import { insertParam, isValidArray, setLocalStorageItem } from "modules/utils";
import { fetchCategoryProduct } from "redux/actions/manageCatalog/categoryProducts";
import { fetchMoveCategory } from "redux/actions/manageCatalog/moveCategory";
import { fetchGetPagePlannerByPage } from "redux/actions/blockBuilder/getPagePlannerByPage";

const childNodeIdPrefix = "catalogTree-node-li-";

const SideBarTree = ({
  setCatalogId,
  catalogId,
  catalogList,
  catArray,
  isRoot,
  setIsRoot,
  catelogTreeList,
  catalogDataList,
  isAddHighlightClass,
  stepsEnabledForSidebar,
  pagePlanner,
  isElefant,
}) => {
  console.log("🚀 ~ file: SideBarTree.js:31 ~ isRoot", isRoot);
  const dispatch = useDispatch();
  const ref = useRef(null);

  const {
    catalogTree = [],
    catalogTreeWithPageNumber = [],
    getPagePlannerByPageLoading = false,
  } = useSelector((state) => ({
    catalogTree: state.catalogTree.data?.data,
    catalogTreeWithPageNumber: state.getCatalogTreeWithPageNumbers.data?.data,
    getPagePlannerByPageLoading: state.getPagePlannerByPage?.loading,
  }));
  console.log(
    "🚀 ~ file: SideBarTree.js:37 ~ catalogTreeWithPageNumber",
    catalogTreeWithPageNumber
  );

  const [isDragDrop, setIsDragDrop] = useState(false);
  const [categoryName, setCategoryName] = useState("");
  const [nodeId, setNodeId] = useState(0);
  const [treeData, setTreeData] = useState([]);

  const handleSelect = (node) => {
    setNodeId(node);
  };

  useEffect(() => {
    setNodeId(catalogId);

    if (isValidArray(catalogTree)) {
      setTreeData(catalogTree);
    }
    if (isValidArray(catalogTreeWithPageNumber)) {
      setTreeData(catalogTreeWithPageNumber);
    }
  }, [catalogTree, categoryName, catalogId, catalogTreeWithPageNumber]);

  const handleDrop = (
    newTree,
    { dragSourceId, dropTargetId, dragSource, destinationIndex }
  ) => {
    if (!isDragDrop) return false;
    setTreeData(newTree);

    const droppedOn = document.querySelector(
      `#${childNodeIdPrefix}${dropTargetId}`
    );
    if (droppedOn && !droppedOn?.classList?.contains("is-open")) {
      document
        .querySelector(`#${childNodeIdPrefix}${dropTargetId} > span`)
        .click();
    }

    setTimeout(() => {
      const eleMain = document.querySelector(
        `#${childNodeIdPrefix}${dragSource.id}`
      );
      const eleLi = eleMain?.parentElement;
      const eleUl = eleLi?.parentElement;

      const index =
        eleMain && eleLi && eleUl
          ? [...eleUl.childNodes].findIndex((item) => item === eleLi)
          : destinationIndex;

      const childQuery = `#${childNodeIdPrefix}${dropTargetId} ~ ul > li > div`;
      const childrenEle = document.querySelectorAll(childQuery);

      const childrenIds = [...childrenEle]
        .filter((d) => d?.id.startsWith(childNodeIdPrefix))
        .map((d) => d.id.replace(childNodeIdPrefix, ""));

      //! IDs of Children Elements
      // console.log("NJ ~ setTimeout ~ childrenIds", childrenIds);

      const formData = {
        ParentCategoryId: dropTargetId,
        CategoryId: dragSourceId,
        Position: index,
        catArray: childrenIds,
      };

      dispatch(fetchMoveCategory(formData)).then((data) => {
        if (data?.flag) {
          catalogDataList();
        }
        setIsDragDrop(false);
      });
    }, 100);
  };
  const categoryProduct = (id) => {
    dispatch(fetchCategoryProduct(id));
  };
  const debounceLoadData = useCallback(debounce(catalogDataList, 1000), []);

  const searchCategory = (e) => {
    setCategoryName(e.target.value);
    debounceLoadData(e?.target?.value);
  };

  const getPageGridDataHandle = (id) => {
    console.log(
      "🚀 ~ file: PagePlanner.js:39 ~ getPageGridDataHandle ~ id",
      id
    );
    if (getPagePlannerByPageLoading === false) {
      dispatch(fetchGetPagePlannerByPage(id));
    }
  };

  return (
    <>
      <SideBar
        catalogId={catalogId}
        setCatalogId={setCatalogId}
        setIsRoot={setIsRoot}
        catelogTreeList={catelogTreeList}
        isRoot={isRoot}
        isDragDrop={isDragDrop}
        setIsDragDrop={setIsDragDrop}
        catalogDataList={catalogDataList}
        categoryName={categoryName}
        setCategoryName={setCategoryName}
        searchCategory={searchCategory}
        isAddHighlightClass={isAddHighlightClass}
        isElefant={isElefant}
      />
      <div id="catalogTree" className="custom-catalogTree-sidebar">
        {isValidArray(treeData) && (
          <Tree
            ref={ref}
            placeholderRender={(node, { depth }) => (
              <Placeholder node={node} depth={depth} />
            )}
            insertDroppableFirst={false}
            canDrag={() => {
              if (isDragDrop) return true;
              return false;
            }}
            sort={false}
            tree={treeData}
            rootId={0}
            initialOpen={catArray}
            render={(node, { depth, isOpen, onToggle }) => {
              console.log("🚀 ~ file: SideBarTree.js:268 ~ node", node);

              return (
                <div
                  className={classNames({
                    "active-sidebar-color":
                      nodeId == node.id && nodeId == catalogId,
                    "static-active": node.data?.IsStaticContent,
                    "is-open": isOpen,
                    "menu-toggle-inner": true,
                  })}
                  // className={
                  //   nodeId == node.id && nodeId == catalogId
                  //     ? "active-sidebar-node-color"
                  //     : ""
                  // }
                  style={{ marginInlineStart: depth * 4 }}
                  id={`${childNodeIdPrefix}${node?.id}`}
                  key={`${childNodeIdPrefix}${node?.id}`}
                >
                  {node.droppable && (
                    <span
                      onClick={() => {
                        // handleSelect(node?.id);
                        // setCatalogId(node?.id);

                        onToggle();
                      }}
                    >
                      {isOpen ? (
                        <img className="upDownArrow" src={downSideArrow} />
                      ) : (
                        <img className="downArrow" src={downSideArrow} />
                      )}
                    </span>
                  )}
                  <div
                    onClick={() => {
                      if (pagePlanner) {
                        if (node?.data?.PageNumber) {
                          getPageGridDataHandle(node?.data?.PageNumber);
                        }
                        setLocalStorageItem("idForPagePlanner", node?.id);
                        handleSelect(node?.id);
                        setCatalogId(node?.id);
                        setLocalStorageItem("parentID", node?.id);
                        insertParam("id", node?.id);
                        categoryProduct(node?.id);
                        setIsRoot(node.parent == 0 ? 1 : 0);
                      }
                      // onToggle();
                      setLocalStorageItem("idForPagePlanner", node?.id);
                      handleSelect(node?.id);
                      setCatalogId(node?.id);
                      setLocalStorageItem("parentID", node?.id);
                      insertParam("id", node?.id);
                      categoryProduct(node?.id);
                      setIsRoot(node.parent == 0 ? 1 : 0);
                    }}
                    className={
                      node?.data?.icon == "fa fa-th-list"
                        ? "low-level-child"
                        : ""
                    }
                  >
                    <i
                      className={
                        node.data?.IsStaticContent
                          ? "fa-solid fa-file-pdf"
                          : node?.data?.icon == "fa fa-th-list"
                            ? "fa fa-list"
                            : node?.data?.icon
                      }
                      style={
                        categoryName &&
                          node.text
                            .toLowerCase()
                            .includes(categoryName.toString().toLowerCase())
                          ? { color: "#8b0000" }
                          : {}
                      }
                    ></i>
                    <span
                      className={
                        categoryName &&
                          node.text
                            .toLowerCase()
                            .includes(categoryName.toString().toLowerCase())
                          ? "tree-view-txt"
                          : ""
                      }
                      style={{ width: "190px" }}
                    >
                      {node.text}{" "}
                      <span className="grayTxt">
                        {" "}
                        ({node?.data?.TreeCount})
                      </span>
                      {pagePlanner ? (
                        <>
                          {
                            <div
                              className={classNames({
                                "gray-bg": true,
                                "d-none": node?.data?.IsRoot,
                                "orange-color": !node?.data?.PageNumber,
                              })}
                            >
                              <span className="pageNumber">
                                {node?.data?.PageNumber}
                                {node?.data?.IsPanel == '1' ? 'P' : ''}
                              </span>
                            </div>
                          }
                        </>
                      ) : (
                        <></>
                      )}
                    </span>
                  </div>
                </div>
              );
            }}
            classes={{
              root: styles.treeRoot,
              draggingSource: styles.draggingSource,
              dropTarget: styles.dropTarget,
              placeholder: styles.placeholderTree,
            }}
            dragPreviewRender={(monitorProps) => (
              <CustomDragPreview monitorProps={monitorProps} />
            )}
            onDrop={handleDrop}
            canDrop={
              isDragDrop
                ? (tree, { dragSource, dropTargetId, dropTarget }) => {
                  if (dragSource?.parent === dropTargetId) {
                    return true;
                  }
                }
                : false
            }
          />
        )}
      </div>
    </>
  );
};

export default SideBarTree;
