import {
  getLocalStorageItem,
  insertParam,
  isValidArray,
  setLocalStorageItem,
} from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch } from "react-redux";
import { fetchCategoryProduct } from "redux/actions/manageCatalog/categoryProducts";
import SidebarUL from "./SidebarUL";
import upSideArrow from "../../assets/images/iconArrow.png";
import downSideArrow from "../../assets/images/iconArrowfill.png";

const SidebarList = ({
  data,
  setCatalogId,
  setIsRoot,
  setParentId,
  catalogId,
}) => {
  const [isOpen, setIsOpen] = useState(false);
  const dispatch = useDispatch();

  const toggleOpen = () => setIsOpen(!isOpen);

  const liClick = (flagSaveToLS = true) => {
    // toggleOpen();
    setParentId(!data?.isCollection ? data?.id : "");
    if (!isValidArray(data?.children)) {
      dispatch(fetchCategoryProduct(data?.id));
    }

    if (flagSaveToLS) {
      setLocalStorageItem("parentID", data?.id);
      insertParam("id", data?.id);
    }
  };

  const handleOnChildClick = (flagSaveToLS = true) => {
    liClick(flagSaveToLS);
    setIsRoot(data?.isRoot);
    setCatalogId(data.id);
  };

  const handleImageClick = () => {
    setIsOpen((val) => !val);
  };

  useEffect(() => {
    const { id: checkId, childrenIds } = data;

    const id = parseInt(getLocalStorageItem("parentID") || "0");

    if (id && (checkId === id || childrenIds.includes(id))) {
      if (checkId === id) {
        handleOnChildClick(data, false);
      }
      setIsOpen(true);
    }
  }, []);

  return (
    <li className="">
      <div className={catalogId == data.id ? "activeSidebar" : ""}>
        <div onClick={handleImageClick}>
          {isValidArray(data?.children) &&
            (isValidArray(data?.children) && isOpen === true ? (
              <img className="upDownArrow" src={downSideArrow} />
            ) : (
              <img className="downArrow" src={upSideArrow} />
            ))}
        </div>
        <div onClick={handleOnChildClick}>
          <i className={data?.icon}></i> {data?.text}
        </div>
      </div>
      {isValidArray(data?.children) && isOpen === true && (
        <SidebarUL
          data={data}
          setCatalogId={setCatalogId}
          setIsRoot={setIsRoot}
          setParentId={setParentId}
          catalogId={catalogId}
        />
      )}
    </li>
  );
};

export default SidebarList;
