import React, { useEffect, useRef, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import GridLayout from "react-grid-layout";
import { getLocalStorageItem, isValidArray, showSuccessErrorToast } from "modules/utils";
import {
  Button,
  Card,
  CardBody,
  CardFooter,
  CardImg,
  CardText,
  Col,
  Container,
  Input,
  Label,
  Row,
  Modal,
  ModalBody,
  ModalHeader,
  Collapse,
} from "reactstrap";
import { fetchCatalogPlanner } from "redux/actions/manageCatalog/catalogPlanner";
import { fetchUpdateCatalogPlannerCategoryPosition } from "redux/actions/manageCatalog/updateCatalogPlannerCategoryPosition";
import Loader from "components/Common/Loader";
import { fetchMoveCategoryPages } from "redux/actions/blockBuilder/moveCategoryPages";
import { toast } from "react-toastify";
import { fetchCatalogTree } from "redux/actions/manageCatalog/catalogTree";
import { fetchGetPagePlannerByPage } from "redux/actions/blockBuilder/getPagePlannerByPage";
import { fetchCheckIfBlockSizeExist } from "redux/actions/manageCatalog/checkIfBlockSizeExist";
import { fetchGetPageOptions } from "redux/actions/blockBuilder/getPageOption";
import { getApi, postApi } from "redux/actions/api";
import { fetchGetDefaultBlockSizeOptions } from "redux/actions/blockBuilder/getDefaultBlockSizeOption";
import { CaretDownOutlined, CaretUpOutlined } from "@ant-design/icons";
import { fetchBuildSinglePage } from "redux/actions/manageCatalog/buildSinglePage";

const tempHTMLTable = `<table>
<tr>
  <th style="border:1px solid black">Company</th>
  <th style="border:1px solid black">Contact</th>
  <th style="border:1px solid black">Country</th>
</tr>
<tr>
  <td style="border:1px solid black">Alfreds Futterkiste</td>
  <td style="border:1px solid black">Maria Anders</td>
  <td style="border:1px solid black">Germany</td>
</tr>
<tr>
  <td style="border:1px solid black">Centro comercial Moctezuma</td>
  <td style="border:1px solid black">Francisco Chang</td>
  <td style="border:1px solid black">Mexico</td>
</tr>
</table>`;
const CatalogPlanner = ({
  catalogId,
  isRoot,
  slider,
  pagePlannerData,
  pagePlannerDataLoading,
  catalogDataList,
}) => {
  const [layout, setLayout] = useState([]);
  const [imageVisible, setImageVisible] = useState(true);
  const [productsVisible, setProductsVisible] = useState(false);
  const [productNameVisible, setProductsNameVisible] = useState(false);
  const [activeCategoryId, setActiveCategoryId] = useState();
  const [changeState, setChangeState] = useState();
  const [gridData, setGridData] = useState();
  const [isOpen, setIsOpen] = useState(false);
  const [gridPlannerData, setGridPlannerData] = useState(null);
  const [pageForCategoryId, setpageForCategoryId] = useState(null);
  const [collectionToAdd, setCollectionToAdd] = useState(null);
  const [isOpenCollapse, setIsOpenCollapse] = useState(true);

  const [blockSizeId, setBlockSizeId] = useState(null);
  const [loading, setLoading] = useState(null);
  const gridRef = useRef();

  const dispatch = useDispatch();

  const {
    catalogPlanner = null,
    catalogPlannerLoading = false,
    sidebarTreeLoading = false,
    catalogTree = null,
    getPagePlannerByPageLoading = false,
    blockExistLoading = false,
    getPageOption = null,
    getPageOptionLoading = false,
    getBlockSizeOption,
    isLoading,
  } = useSelector((state) => ({
    catalogTree: state.catalogTree.data?.data,
    catalogPlanner: state.catalogPlanner.data?.data,
    catalogPlannerLoading: state.catalogPlanner.loading,
    blockExistLoading: state.checkIfBlockSizeExist.loading,
    sidebarTreeLoading:
      state?.updateCatalogPlannerCategoryPosition?.data?.data?.treeRefresh ||
      false,
    getPagePlannerByPageLoading: state.getPagePlannerByPage?.loading,
    getPageOption: state?.getPageOption?.data?.data,
    getPageOptionLoading: state?.getPageOption?.loading,
    getBlockSizeOption: state.getDefaultBlockSizeOptions.data?.data,
    isLoading: state.catalogTree?.loading || false,
  }));

  const id = getLocalStorageItem("idForPagePlanner");

  useEffect(() => {
    // alert("09999999999999", 1);
    fetchCatalogPlan();
    const passPlannerData = isValidArray(pagePlannerData)
      ? pagePlannerData
      : catalogPlanner;
    setGridPlannerData(passPlannerData);
  }, [catalogId, pagePlannerData, pageForCategoryId]);

  useEffect(() => {
    getInitialData();
  }, [id]);

  const getInitialData = (passedId) => {
    const singleCatagory =
      catalogTree &&
      catalogTree?.filter((d) => {
        return d?.id === parseInt(id);
      });
    if (!isLoading) {
      dispatch(
        fetchGetPagePlannerByPage(
          passedId || singleCatagory?.[0]?.data?.PageNumber
        )
      );
      dispatch(fetchGetPageOptions());

      const passPlannerData = isValidArray(pagePlannerData)
        ? pagePlannerData
        : catalogPlanner;

      setGridPlannerData(passPlannerData);
      setpageForCategoryId();
      setBlockSizeId();
    }

    getApi(`/getPageForCategoryID/${id}`).then((res) => {
      if (res?.data?.data) {
        setpageForCategoryId(res?.data?.data?.PageNumber);
        setCollectionToAdd(res?.data?.data);
        // dispatch(fetchGetPagePlannerByPage(res?.data?.data?.PageNumber));
        // dispatch(fetchGetPageOptions());
        dispatch(fetchGetDefaultBlockSizeOptions()).then((data) => { });
        // const passPlannerData = isValidArray(pagePlannerData)
        //   ? pagePlannerData
        //   : catalogPlanner;
        // setGridPlannerData(passPlannerData);
        // setCollectionToAdd(res?.data?.data);
      }
      //  else {
      //     if (!isLoading) {
      //       dispatch(
      //         fetchGetPagePlannerByPage(
      //           passedId || singleCatagory?.[0]?.data?.PageNumber
      //         )
      //       );
      //       dispatch(fetchGetPageOptions());

      //       const passPlannerData = isValidArray(pagePlannerData)
      //         ? pagePlannerData
      //         : catalogPlanner;
      //       console.log(
      //         "🚀 ~ file: CatalogPlanner.js:160 ~ getApi ~ passPlannerData:",
      //         passPlannerData
      //       );

      //       setGridPlannerData(passPlannerData);
      //       setpageForCategoryId();
      //       setBlockSizeId();
      //     }
      //   }
    });
  };

  const fetchCatalogPlan = () => {
    if (!slider) {
      dispatch(fetchCatalogPlanner(catalogId)).then((data) => {
        if (data?.flag) {
          getLayout(data?.data);
        }
      });
    }
  };

  const getLayout = (data = []) => {
    const single = data?.map((item) => {
      return {
        i: item.CategoryID,
        x: item.xPosition,
        y: item.yPosition,
        w: item.GridWidth,
        h: item.GridHeight,
      };
    });
    setLayout(single);
  };

  const onLayoutChange = (a, change) => {
    const updatedData = a.filter((d) => d.i === change.i);
    const apiData = {
      CategoryID: updatedData[0]?.i,
      positionX: String(updatedData[0]?.x),
      positionY: String(updatedData[0]?.y),
      width: String(updatedData[0]?.w),
      height: String(updatedData[0]?.h),
    };
    setGridData(a);
    setChangeState(change);
    const singleCatagory =
      catalogTree &&
      catalogTree?.filter((d) => {
        return d?.id === parseInt(change.i);
      });
    const passData = {
      BlockWidth: String(updatedData[0]?.w),
      BlockHeight: String(updatedData[0]?.h),
    };
    dispatch(fetchCheckIfBlockSizeExist(passData)).then((res) => {
      if (res?.data?.BlockExists) {
        dispatch(fetchUpdateCatalogPlannerCategoryPosition(apiData)).then(
          (data) => {
            if (data?.data?.treeRefresh) {
              dispatch(fetchCatalogTree());
              getPageGridDataHandle(singleCatagory?.[0]?.data?.PageNumber);
            }
          }
        );
      } else {
        setIsOpen(true);
      }
    });
  };

  const handleCreate = (flag) => {
    if (flag) {
      const updatedData = gridData?.filter((d) => d.i === changeState.i);
      const apiData = {
        CategoryID: updatedData[0]?.i,
        positionX: String(updatedData[0]?.x),
        positionY: String(updatedData[0]?.y),
        width: String(updatedData[0]?.w),
        height: String(updatedData[0]?.h),
      };
      const singleCatagory =
        catalogTree &&
        catalogTree?.filter((d) => {
          return d?.id === parseInt(changeState.i);
        });
      dispatch(fetchUpdateCatalogPlannerCategoryPosition(apiData)).then(
        (data) => {
          if (data?.data?.treeRefresh) {
            dispatch(fetchCatalogTree());
            getPageGridDataHandle(singleCatagory?.[0]?.data?.PageNumber);
          }
          setIsOpen(false);
        }
      );
    } else {
      getInitialData();
      setIsOpen(false);
    }
  };

  const getPageGridDataHandle = (id) => {
    if (getPagePlannerByPageLoading === false) {
      dispatch(fetchGetPagePlannerByPage(id));
    }
  };

  const handleCategoryPageMovement = (position, id) => {
    setActiveCategoryId(id);
    const passData = { CategoryID: id, position };
    dispatch(fetchMoveCategoryPages(passData)).then((data) => {
      if (data?.flag) {
        toast.success(data?.message);
        // window.location.reload();
        const singleCatagory =
          catalogTree &&
          catalogTree?.filter((d) => {
            return d?.id === id;
          });

        dispatch(
          fetchGetPagePlannerByPage(singleCatagory?.[0]?.data?.PageNumber)
        );
        dispatch(fetchCatalogTree());
      } else {
        toast.error(data?.message);
      }
    });
  };

  const submitCategory = (CategoryID, pageNumber, index) => {
    setLoading(true);
    const passData = {
      CategoryID: CategoryID || catalogId,
      BlockSizeID: blockSizeId,
      PageNumber: pageNumber || pageForCategoryId,
    };

    postApi(`/addCategoryToPlanner`, passData).then((res) => {
      if (res) {
        getInitialData(pageNumber || pageForCategoryId);
        setpageForCategoryId();
        setBlockSizeId();
        // catalogDataList();
        dispatch(fetchCatalogTree());
        setLoading(false);
        const removeAddedCollection = collectionToAdd.splice(index, 1);

        setCollectionToAdd(removeAddedCollection);
      }
      setLoading(false);
    });
  };

  const toggleCollapse = () => {
    setIsOpenCollapse(!isOpenCollapse);
  };

  if (catalogPlannerLoading || pagePlannerDataLoading || getPageOptionLoading) {
    return <Loader />;
  }
  const divHeight = window.innerHeight - 152;
  const divWidth =
    (parseInt(getPageOption?.pageSizeWidth) * divHeight) /
    parseInt(getPageOption?.pageSizeHeight);
  const rowNewHeight = divHeight / parseInt(getPageOption?.gridHeight) - 11; //10px margin + 1px border.

  const maxH = parseInt(getPageOption?.gridHeight);
  const singleCatagory =
    catalogTree &&
    catalogTree?.filter((d) => {
      return d?.id === parseInt(catalogId);
    });

  const buildSinglePage = () => {
    dispatch(fetchBuildSinglePage(singleCatagory?.[0]?.data?.PageNumber)).then(
      (res) => {
        console.log("🚀 ~ file: CatalogPlanner.js:373 ~ dispatch ~ res:", res);
        showSuccessErrorToast(true, res?.message);
        dispatch(fetchGetPagePlannerByPage(singleCatagory?.[0]?.data?.PageNumber));
      }
    );
  };

  if (!isValidArray(gridPlannerData) && !isValidArray(collectionToAdd)) {
    return (
      <>
        <div className="p-3 text-center w-100">
          No blocks configured for this category.
        </div>
      </>
    );
  } else if (pageForCategoryId) {
    return (
      <>
        <div
          className="catalogPlanner-section newSec"
          style={{ height: divHeight + "px", width: divWidth + "px" }}
        >
          <div className="row">
            <div className="col-6">
              <Container
                className="cat-log mt-5"
                style={{ position: "absolute", marginLeft: "600px" }}
              >
                <Row
                  className="mb-4"
                  style={{ textAlign: "right", display: "flex" }}
                >
                  <Col sm="4" style={{ flex: "1" }}>
                    <h6 className="text-end">Images </h6>
                  </Col>
                  <Col
                    sm="2"
                    onClick={(e) => {
                      setImageVisible(!imageVisible);
                    }}
                  >
                    <Input
                      type="checkbox"
                      name="flow"
                      checked={imageVisible ? true : false}
                    />
                  </Col>
                </Row>
                <Row
                  className="mb-4"
                  style={{ textAlign: "right", display: "flex" }}
                >
                  <Col sm="4" style={{ flex: "1" }}>
                    <h6 className="text-end">Products </h6>
                  </Col>
                  <Col
                    sm="2"
                    onClick={(e) => {
                      setProductsVisible(!productsVisible);
                    }}
                  >
                    <Input
                      type="checkbox"
                      name="flow"
                      checked={productsVisible ? true : false}
                    />
                  </Col>
                </Row>
              </Container>
            </div>

            {/* ///new collection page setup */}
          </div>
          <div className="row">
            <div className="col-6">
              <Container
                className="cat-log mt-5"
                style={{ position: "absolute", right: "500px" }}
              >
                <Row className="mb-4" style={{ display: "flex" }}>
                  <Col sm="10">
                    <h6 style={{ textAlign: "left !important" }} className="">
                      Collection not on page{" "}
                    </h6>
                  </Col>
                </Row>
                <Row className="mb-4" style={{ flex: "1" }}>
                  <Col sm="2" style={{ wordWrap: "break-word" }}>
                    <h6 className="text-center" style={{ textAlign: "center" }}>
                      {singleCatagory?.[0]?.text}{" "}
                    </h6>
                  </Col>
                  <Col
                    sm="5"
                    onClick={(e) => {
                      setProductsVisible(!productsVisible);
                    }}
                  >
                    <Input
                      type="select"
                      name="sections"
                      isFirstOption={true}
                      isLower={true}
                      isSearchable={true}
                      options={getBlockSizeOption}
                      // selected={blockSizes?.[d?.catName]?.blockSizeID}
                      // value={blockSizes?.[d?.catName]?.blockSizeID}
                      onChange={(e) => {
                        setBlockSizeId(parseInt(e.target.value));
                      }}
                    >
                      {
                        <option disabled={false} value={0}>
                          N/A
                        </option>
                      }
                      {isValidArray(getBlockSizeOption) &&
                        getBlockSizeOption.map((item, i) => {
                          return (
                            <option key={i} value={item?.BlockSizeID}>
                              {item?.BlockSizeName}
                            </option>
                          );
                        })}
                    </Input>
                  </Col>
                  <Col sm="4">
                    <Button disabled={loading} onClick={() => submitCategory()}>
                      Add
                    </Button>
                  </Col>
                </Row>
              </Container>
            </div>

            {/* ///page setup */}
          </div>
          <GridLayout
            ref={gridRef}
            className="layout-section"
            layout={layout}
            width={divWidth}
            isDraggable
            isResizable
            isBounded={true}
            rowHeight={rowNewHeight}
            preventCollision={false}
            allowOverlap={true}
            onDragStop={onLayoutChange}
            onResizeStop={onLayoutChange}
            cols={parseInt(getPageOption?.gridWidth)}
            maxRows={parseInt(getPageOption?.gridHeight)}
          >
            {isValidArray(gridPlannerData) &&
              gridPlannerData.map((item) => {
                return (
                  <div
                    className={`${item.customClass} myXXX card shadow-none rounded-0"`}
                    key={item.CategoryID}
                    data-grid={{
                      i: item.CategoryID || 0,
                      x: item?.xPosition || 0,
                      y: item?.yPosition || 0,
                      w: item?.GridWidth || 0,
                      h: item?.GridHeight || 0,
                      minW: 1,
                      minH: 1,
                      maxH: maxH,
                    }}
                    style={{ minHeight: 10, alignItems: "center" }}
                  >
                    <CardBody style={{ padding: 0 }} className="text-center">
                      <CardText className="h3 py-1 m-0">
                        {item.CategoryName}
                      </CardText>
                      {isValidArray(item.Images) &&
                        item.Images.map((d, i) => (
                          <CardImg
                            key={i}
                            style={{ width: 30, height: 30 }}
                            src={d}
                            className={`${!imageVisible && "d-none"
                              } me-1 rounded-0`}
                          />
                        ))}

                      <CardText className="p-0 m-0">
                        {"[" + item.GridWidth + "w x " + item.GridHeight + "h]"}
                      </CardText>
                      <div
                        dangerouslySetInnerHTML={{
                          __html: item.Products,
                        }}
                        className={`${!productsVisible && "d-none"}`}
                      ></div>
                      {/* {isValidArray(item.Products) &&
                        item.Products.map((d, i) => (
                          <CardText
                            key={i}
                            src={d}
                            className={`${
                              !productsVisible && "d-none"
                            } p-0 m-0`}
                          >
                            <div
                              dangerouslySetInnerHTML={{
                                __html: tempHTMLTable,
                              }}
                            ></div>
                          </CardText>
                        ))} */}
                    </CardBody>
                    {item.showPreviousButtons ? (
                      <div className="col-12 text-center">
                        <button
                          onClick={() => {
                            handleCategoryPageMovement(
                              "previousNew",
                              item.CategoryID
                            );
                          }}
                          type="button"
                          title="Move to new page"
                          className="btn btn-secondary next-btn rounded-0 me-1"
                          style={{ height: "20px", width: "35px" }}
                        >
                          <i className="fa fa-plus me-1"></i>
                          <i className="fa fa-angle-left"></i>
                        </button>
                        <button
                          onClick={() => {
                            handleCategoryPageMovement(
                              "previous",
                              item.CategoryID
                            );
                          }}
                          type="button"
                          title="Move to previous page"
                          className="btn btn-secondary next-btn rounded-0"
                          style={{ height: "20px", width: "35px" }}
                        >
                          <i className="fa fa-angle-left"></i>
                        </button>
                      </div>
                    ) : null}
                    {item.showNextButtons ? (
                      <div className="col-12 text-center">
                        <button
                          onClick={() => {
                            handleCategoryPageMovement("next", item.CategoryID);
                          }}
                          type="button"
                          title="Move to next page"
                          className="btn btn-secondary next-btn rounded-0 me-1"
                          style={{ height: "20px", width: "35px" }}
                        >
                          <i className="fa fa-angle-right"></i>
                        </button>
                        <button
                          onClick={() => {
                            handleCategoryPageMovement(
                              "nextNew",
                              item.CategoryID
                            );
                          }}
                          type="button"
                          title="Move to new page"
                          className="btn btn-secondary next-btn rounded-0"
                          style={{ height: "20px", width: "35px" }}
                        >
                          <i className="fa fa-angle-right me-1"></i>
                          <i className="fa fa-plus"></i>
                        </button>
                      </div>
                    ) : null}
                  </div>
                );
              })}
          </GridLayout>
        </div>
      </>
    );
  } else {
    return (
      <>
        <div className="category-display-template m-0">
          <Collapse isOpen={isOpenCollapse}>
            <div
              className="p-3"
              style={{ backgroundColor: "#c9e9ca" }}
            >
              <div className="row">
                <div className="col-2 text-start">
                  <b>BUILD</b>
                  <br />
                  <input
                    type="button"
                    className="btn btn-secondary"
                    value="Build"
                    onClick={() => {
                      buildSinglePage();
                    }}
                  />
                </div>
                <div className="col-8 ps-5">
                  {isValidArray(collectionToAdd) ? <b>ADD</b> : <></>}
                  <br />
                  {collectionToAdd?.map((d, i) => {
                    return (
                      <>
                        <div className="row">
                          <div className="col-2">
                            <p style={{ marginTop: "5px" }}>
                              {d.CategoryName}
                            </p>
                          </div>
                          <div className="col-8">
                            <Input
                              style={{
                                padding: "5px 10px",
                                borderRadius: "5px",
                              }}
                              type="select"
                              name="sections"
                              isFirstOption={true}
                              isLower={true}
                              isSearchable={true}
                              options={getBlockSizeOption}
                              // selected={blockSizes?.[d?.catName]?.blockSizeID}
                              // value={blockSizes?.[d?.catName]?.blockSizeID}
                              onChange={(e) => {
                                setBlockSizeId(parseInt(e.target.value));
                              }}
                            >
                              {
                                <option disabled={false} value={0}>
                                  N/A
                                </option>
                              }
                              {isValidArray(getBlockSizeOption) &&
                                getBlockSizeOption.map((item, i) => {
                                  return (
                                    <option key={i} value={item?.BlockSizeID}>
                                      {item?.BlockSizeName}
                                    </option>
                                  );
                                })}
                            </Input>
                          </div>
                          <div className="col-2">
                            <Button
                              disabled={loading}
                              onClick={() =>
                                submitCategory(d?.CategoryID, d?.PageNumber, i)
                              }
                            >
                              Add
                            </Button>
                          </div>
                        </div>
                      </>
                    );
                  })}
                </div>
                <div className="col-2 text-start">
                  <b>DISPLAY</b>
                  <br />
                  <div
                    onClick={(e) => {
                      setImageVisible(!imageVisible);
                    }}
                  >
                    <Input
                      type="checkbox"
                      name="flow"
                      checked={imageVisible ? true : false}
                    />
                    Images
                  </div>
                  <div
                    onClick={(e) => {
                      setProductsVisible(!productsVisible);
                    }}
                  >
                    <Input
                      type="checkbox"
                      name="flow"
                      checked={productsVisible ? true : false}
                    />
                    Products
                  </div>
                </div>
              </div>
            </div>
          </Collapse>
        </div>
        <div className="toggle-header" onClick={toggleCollapse}>
          {/* <span>Toggle Content</span> */}
          {isOpenCollapse ? <CaretUpOutlined /> : <CaretDownOutlined />}
        </div>
        <div
          className="catalogPlanner-section newSec"
          style={{ height: divHeight + "px", width: divWidth + "px" }}
        >
          <GridLayout
            ref={gridRef}
            className="layout-section"
            layout={layout}
            width={divWidth}
            isDraggable
            isResizable
            isBounded={true}
            rowHeight={rowNewHeight}
            preventCollision={false}
            allowOverlap={true}
            onDragStop={onLayoutChange}
            onResizeStop={onLayoutChange}
            cols={parseInt(getPageOption?.gridWidth)}
            maxRows={parseInt(getPageOption?.gridHeight)}
          >
            {isValidArray(gridPlannerData) &&
              gridPlannerData.map((item) => {
                return (
                  <div
                    className={`${item.customClass} myYYY card shadow-none rounded-0"`}
                    key={item.CategoryID}
                    data-grid={{
                      i: item.CategoryID || 0,
                      x: item?.xPosition || 0,
                      y: item?.yPosition || 0,
                      w: item?.GridWidth || 0,
                      h: item?.GridHeight || 0,
                      minW: 1,
                      minH: 1,
                      maxH: maxH,
                    }}
                    style={{ minHeight: 10, alignItems: "center" }}
                  >
                    <CardBody style={{ padding: 0 }} className="text-center">
                      <CardText className="h3 py-1 m-0">
                        {item.CategoryName} {item.showOrangeTriangle ? (
                          <i className="fas fa-exclamation-triangle text-orange" title="Incorrect SortOrder"></i>
                        ) : ''}
                      </CardText>
                      {isValidArray(item.Images) &&
                        item.Images.map((d, i) => (
                          <CardImg
                            key={i}
                            style={{ width: 30, height: 30 }}
                            src={d}
                            className={`${!imageVisible && "d-none"
                              } me-1 rounded-0`}
                          />
                        ))}

                      <CardText className="p-0 m-0">
                        {"[" + item.GridWidth + "w x " + item.GridHeight + "h]"}
                      </CardText>
                      <div
                        dangerouslySetInnerHTML={{
                          __html: item.Products,
                        }}
                        className={`${!productsVisible && "d-none"}`}
                      ></div>
                      {/* {isValidArray(item.Products) &&
                        item.Products.map((d, i) => (
                          <CardText
                            key={i}
                            src={d}
                            className={`${
                              !productsVisible && "d-none"
                            } p-0 m-0`}
                          >
                            <div
                              dangerouslySetInnerHTML={{
                                __html: tempHTMLTable,
                              }}
                            ></div>
                          </CardText>
                        ))} */}
                    </CardBody>
                    {item.showPreviousButtons ? (
                      <div className="col-12 text-center">
                        <button
                          onClick={() => {
                            handleCategoryPageMovement(
                              "previousNew",
                              item.CategoryID
                            );
                          }}
                          type="button"
                          title="Move to new page"
                          className="btn btn-secondary next-btn rounded-0 me-1"
                          style={{ height: "20px", width: "35px" }}
                        >
                          <i className="fa fa-plus me-1"></i>
                          <i className="fa fa-angle-left"></i>
                        </button>
                        <button
                          onClick={() => {
                            handleCategoryPageMovement(
                              "previous",
                              item.CategoryID
                            );
                          }}
                          type="button"
                          title="Move to previous page"
                          className="btn btn-secondary next-btn rounded-0"
                          style={{ height: "20px", width: "35px" }}
                        >
                          <i className="fa fa-angle-left"></i>
                        </button>
                      </div>
                    ) : null}
                    {item.showNextButtons ? (
                      <div className="col-12 text-center">
                        <button
                          onClick={() => {
                            handleCategoryPageMovement("next", item.CategoryID);
                          }}
                          type="button"
                          title="Move to next page"
                          className="btn btn-secondary next-btn rounded-0 me-1"
                          style={{ height: "20px", width: "35px" }}
                        >
                          <i className="fa fa-angle-right"></i>
                        </button>
                        <button
                          onClick={() => {
                            handleCategoryPageMovement(
                              "nextNew",
                              item.CategoryID
                            );
                          }}
                          type="button"
                          title="Move to new page"
                          className="btn btn-secondary next-btn rounded-0"
                          style={{ height: "20px", width: "35px" }}
                        >
                          <i className="fa fa-angle-right me-1"></i>
                          <i className="fa fa-plus"></i>
                        </button>
                      </div>
                    ) : null}
                  </div>
                );
              })}
          </GridLayout>
        </div>
        <Modal
          className=""
          isOpen={isOpen}
          toggle={() => setIsOpen(!isOpen)}
          size={"lg"}
          style={{ width: "100%" }}
        >
          <ModalHeader toggle={() => setIsOpen(!isOpen)}>
            Please Confirm
          </ModalHeader>
          <ModalBody>
            <div className="model-label-input imagesize-delete-model ">
              <div className="row align-center">
                <div className="col-12">
                  <Label>
                    The selected block size does not exist. Would you like to
                    create it?
                  </Label>
                </div>
              </div>
            </div>
            <div className="model-bottom-btn-section">
              <Button
                color="primary save-btn confirm-y"
                onClick={() => handleCreate(true)}
              >
                {" "}
                Yes
              </Button>
              <Button
                color="primary cancel-btn confirm-n"
                onClick={() => handleCreate(false)}
              >
                {" "}
                No
              </Button>
            </div>
          </ModalBody>
        </Modal>
        {/* <div className="page-planner-footer">{slider}</div> */}
      </>
    );
  }
};

export default CatalogPlanner;
