import React, { useState } from "react";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import AttributeSetup from "./tabs/AttributeSetup";
import DisplaySetup from "./tabs/DisplaySetup";
import TextSetup from "./tabs/TextSetup";

const CategorySetup = ({ catalogId, isRoot, setCatalogPlanner }) => {
  const initialActiveTab = {
    displaySetup: "active",
    textSetup: "",
    attributeSetup: "",
    activeTab: "displaySetup",
  };
  const [activeTab, setActivetab] = useState(initialActiveTab);
  const handleTab = (tabName) => {
    if (tabName == "textSetup") {
      setActivetab({
        textSetup: "active",
        attributeSetup: "",
        displaySetup: "",
        activeTab: "textSetup",
      });
    } else if (tabName == "attributeSetup") {
      setActivetab({
        textSetup: "",
        attributeSetup: "active",
        displaySetup: "",
        activeTab: "attributeSetup",
      });
    } else if (tabName == "displaySetup") {
      setActivetab({
        textSetup: "",
        attributeSetup: "",
        displaySetup: "active",
        activeTab: "displaySetup",
      });
    }
  };
  return (
    <div
      className="catalog-body-full"
      style={{ width: "100%" }}
      id="nav nav-tabs"
    >
      <Nav tabs>
        <NavItem>
          <NavLink
            className={activeTab.displaySetup}
            onClick={() => handleTab("displaySetup")}
          >
            Category Display Setup
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.textSetup}
            onClick={() => handleTab("textSetup")}
          >
            Category Text Schema
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.attributeSetup}
            onClick={() => handleTab("attributeSetup")}
          >
            Attribute Schema
          </NavLink>
        </NavItem>
      </Nav>
      <TabContent activeTab={activeTab.activeTab}>
        <TabPane tabId="displaySetup">
          {activeTab.activeTab === "displaySetup" && (
            <DisplaySetup
              catalogId={catalogId}
              isRoot={isRoot}
              activeTab={activeTab.activeTab}
              changeCatalogPlanner={setCatalogPlanner}
            />
          )}
        </TabPane>
        <TabPane tabId="textSetup">
          {activeTab.activeTab === "textSetup" && (
            <TextSetup
              catalogId={catalogId}
              isRoot={isRoot}
              activeTab={activeTab.activeTab}
            />
          )}
        </TabPane>
        <TabPane tabId="attributeSetup">
          {activeTab.activeTab === "attributeSetup" && (
            <AttributeSetup
              catalogId={catalogId}
              isRoot={isRoot}
              activeTab={activeTab.activeTab}
            />
          )}
        </TabPane>
      </TabContent>
    </div>
  );
};

export default CategorySetup;
