import InputField from "components/Common/InputField";
import SelectField from "components/Common/SelectField";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Button } from "reactstrap";
import UnLinkModal from "./UnLinkModal";
import { fetchCategoryDisplaySetup } from "../../../../../redux/actions/manageCatalog/categoryDisplaySetup";
import { fetchUpdateDisplaySetup } from "redux/actions/manageCatalog/updateDisplaySetup";
import { fetchUnlinkTemplate } from "redux/actions/manageCatalog/unlinkTemplate";
import { fetchLinkTemplate } from "redux/actions/manageCatalog/linkTemplate";
import { fetchGetCategoryDetails } from "redux/actions/manageCatalog/getCategoryDetails";
import { fetchCatalogTree } from "redux/actions/manageCatalog/catalogTree";
import { fetchLinkParentColor } from "redux/actions/manageCatalog/linkParentColor";
import { fetchUnlinkParentColor } from "redux/actions/manageCatalog/unLinkParentColor";
import Loader from "components/Common/Loader";
import { fetchGetBlocksListForCategory } from "redux/actions/manageCatalog/getBlockListForCategory";
import { isValidArray } from "modules/utils";
import {
  fetchCopyBlockIdForCategory,
  fetchCopyBlockIdForCategoryRequest,
} from "redux/actions/manageCatalog/copyBlockIdForCategory";
import { fetcGetBlockSizes } from "redux/actions/manageCatalog/getBlockSizes";
import { fetchUpdateCategoryTextBlockSchema } from "redux/actions/manageCatalog/updateCategoryTextBlockSchema";
import { fetchTextSetupData } from "redux/actions/manageCatalog/textSetupData";
import { fetchGetAllCategoryTextSchemaList } from "redux/actions/masterSetup/textBlockSchema/getAllCategoryTextSchemaList";
import { fetchLinkParentTextBlock } from "redux/actions/manageCatalog/linkParentTextBlock";
import { fetchUnlinkParentTextBlock } from "redux/actions/manageCatalog/unlinkParentTextBlock";
import { fetchAttributeSetupData } from "redux/actions/manageCatalog/attributeSetupData";
import { fetchGetAllAttributeSchemaList } from "redux/actions/output/getAllAttributeSchemaList";
import { fetchUpdateCategoryAttributeSchema } from "redux/actions/manageCatalog/updateCategoryAttributeSchema";
import { fetchLinkAttribute } from "redux/actions/manageCatalog/linkAttribute";
import { fetchUnlinkParentAttribute } from "redux/actions/manageCatalog/unlinkParentAttribute";
import { plannerOption, productSortOption } from "data/strings";

const DisplaySetup = ({ catalogId, isRoot, changeCatalogPlanner }) => {
  console.log("🚀 ~ catalogId:", catalogId);
  const dispatch = useDispatch();
  const [unlinkModal, setUnlinkModal] = useState(false);
  const [isEdit, setIsEdit] = useState(false);
  const [categoryName, setCategoryName] = useState("");
  const [catalogPlanner, setCatalogPlanner] = useState("");
  const [productCollectionSort, setProductCollectionSort] = useState("");
  const [blockListCategory, setBlockListForCategory] = useState("");
  const [blockID, setBlockID] = useState("");
  const [template, setTemplate] = useState("");
  const [templateOptions, setTemplateOptions] = useState("");
  const [isRootButtonShow, setIsRootButtonShow] = useState(false);
  const [isRootCategory, setIsRootCategory] = useState(false);
  const [colorCode, setColorCode] = useState(false);
  const [unlinkColorModal, setUnlinkColorModal] = useState(false);
  const [linkColorModal, setLinkColorModal] = useState(false);
  const [blockSizes, setBlockSize] = useState(false);
  const [categoryTextSchemaOptions, setCategoryTextSchemaOptions] = useState(
    []
  );
  const [selectedCategoryTextSchema, setSelectedCategoryTextSchema] =
    useState("");
  const [isCategoryTextEditable, setIsCategoryTextEditable] = useState(false);
  const [unlinkTextSetupModal, setUnlinkTextSetupModal] = useState(false);
  const [linkTextSetupModal, setLinkTextSetupModal] = useState(false);
  const [selectedCategorySchema, setSelectedCategorySchema] = useState("");
  const [isRootShow, setIsRootShow] = useState(false);
  const [categorySchemaOptions, setCategorySchema] = useState([]);
  const [unlinkAttributeSetupModal, setUnlinkAttributeSetupModal] =
    useState(false);
  const [linkAttributeSetupModal, setLinkAttributeSetupModal] = useState(false);
  const [isAttributeSetupEditable, setIsAttributeSetupEditable] =
    useState(false);

  const {
    isLoading = false,
    displaySetupData = null,
    categoryDetails = null,
    unLinkColorLoading = false,
    linkColorLoading = false,
    isDetailsLoading = false,
    blockListForCategory = null,
    blockListForCategoryLoading = false,
    blockSizeOptions = null,
    isLoadingTextSetup = false,
    isLoadinggetAllCategoryTextSchemaList = false,
    textSetupData = null,
    isLoadingAttributeSetupData = false,
    getAllAttributeSchemaLoading = false,
    attributeSetupData = null,
  } = useSelector((state) => ({
    displaySetupData: state.categoryDisplaySetup?.data?.data || null,
    isLoading: state.categoryDisplaySetup?.loading || false,
    categoryDetails: state.getCategoryDetails?.data?.data || null,
    isDetailsLoading: state.getCategoryDetails?.loading || false,
    unLinkColorLoading: state.unlinkParentColor?.loading || false,
    linkColorLoading: state.linkParentColor?.loading || false,
    blockListForCategory: state.getBlockListForCategory?.data?.data || false,
    blockListForCategoryLoading:
      state.getBlockListForCategory?.loading || false,
    blockSizeOptions: state?.getBlockSizes?.data?.data,
    isLoadingTextSetup: state.textSetupData?.loading || false,
    isLoadinggetAllCategoryTextSchemaList:
      state.getAllCategoryTextSchemaList?.loading || false,
    textSetupData: state.textSetupData?.data?.data || null,
    isLoadingAttributeSetupData: state.attributeSetupData?.loading || false,
    getAllAttributeSchemaLoading: state.getAllAttributeSchemaList?.loading,
    attributeSetupData: state.attributeSetupData?.data?.data || null,
  }));

  const handleUnlinkModal = () => {
    setUnlinkModal(!unlinkModal);
  };

  const handleLink = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchLinkTemplate(formData));
  };

  const getInitTextSetup = () => {
    dispatch(fetchTextSetupData(catalogId)).then((data) => {
      dispatch(fetchGetAllCategoryTextSchemaList()).then((res) => {
        const single = res?.data?.map((item) => {
          return {
            label: item.CategoryTextSchemaName,
            value: item.CategoryTextSchemaID,
          };
        });
        const options = [
          { label: "Select Text Block Schema", value: "" },
          ...single,
        ];
        setCategoryTextSchemaOptions(options);
        const selectedSchema = res?.data?.filter(
          (d) => d?.CategoryTextSchemaID === data?.data?.CategoryTextSchemaID
        );
        console.log(
          "🚀 ~ file: TextSetup.js:93 ~ dispatch ~ selectedSchema:",
          selectedSchema,
          selectedSchema?.[0]?.CategoryTextSchemaName
        );
        setSelectedCategoryTextSchema(
          selectedSchema?.[0]?.CategoryTextSchemaID
        );
        dispatch(fetchGetCategoryDetails(catalogId)).then((response) => {
          if (response) {
            console.log(
              "🚀 ~ dispatch ~ response:",
              response,
              response.data?.InheritCatTextID,
              catalogId
            );
            if (catalogId === response.data?.InheritCatTextID)
              setIsCategoryTextEditable(true);
          }
        });
      });
    });
  };
  const getInitAttributeSetup = () => {
    dispatch(fetchAttributeSetupData(catalogId)).then((data) => {
      console.log(
        "🚀 ~ file: AttributeSetup.js:66 ~ dispatch ~ data:",
        data,
        data?.InheritCatAttrID
      );
      if (data) {
        if (data?.data?.InheritCatAttrID === catalogId) {
          setIsAttributeSetupEditable(true);
        }
      }
      dispatch(fetchGetAllAttributeSchemaList()).then((res) => {
        getAllCategorySchema(res?.data);
        const schemaName = res?.data.filter((d) => {
          return d?.CatalogAttributeSchemaID === data?.data?.SchemaID;
        });

        setSelectedCategorySchema(data?.data?.SchemaID);
      });
      setIsRootShow(data?.data?.IsRoot === 1 ? true : false);
    });
  };
  const getAllCategorySchema = (data, preSelectedId) => {
    const single = data.map((item) => {
      return {
        value: item?.CatalogAttributeSchemaID,
        label: item?.CatalogAttributeSchemaName,
      };
    });
    const options = [{ label: "Select Schema", value: "" }, ...single];
    setCategorySchema(options);
  };

  const getCategoryDisplaySetup = () => {
    dispatch(fetchCategoryDisplaySetup(catalogId)).then((data) => {
      if (data?.flag) {
        setCategoryName(data?.data?.CategoryName);
        setCatalogPlanner(data?.data?.CatalogPlanner);
        setProductCollectionSort(data?.data?.SortBy);
        setTemplate(data?.data?.SelectedTemplate);
        setIsRootCategory(data?.data?.IsRoot === 0 ? false : true);
        let tempOption = data?.data?.TemplateList.map((item) => {
          return {
            label: item[Object.keys(item)],
            value: Object.keys(item),
          };
        });
        const finalTemplateOption = [
          { label: "Select Template", value: "" },
          ...tempOption,
        ];
        setTemplateOptions(finalTemplateOption);
      }
    });
  };

  const getIntialData = () => {
    dispatch(fetcGetBlockSizes());
    dispatch(fetchGetBlocksListForCategory(catalogId));
    getCategoryListDetails();
    getCategoryDisplaySetup();
    getInitTextSetup();
    getInitAttributeSetup();
  };
  useEffect(() => {
    getIntialData();
  }, [catalogId]);

  const getCategoryListDetails = () => {
    dispatch(fetchGetCategoryDetails(catalogId)).then((data) => {
      setBlockID(data?.data?.InheritCatBlockID);
      setIsRootButtonShow(data?.data?.IsRoot);
      setColorCode(data?.data?.ColourCMYK);
      setBlockSize(data?.data?.BlockSizeID);
    });
  };

  let blockSizesOptions = null;
  blockSizesOptions =
    blockSizeOptions &&
    blockSizeOptions?.map((d) => {
      return { label: d?.BlockSizeName, value: d?.BlockSizeID };
    });
  const selectorOption = { label: "Select Block Size", value: "" };
  blockSizesOptions && blockSizesOptions.unshift(selectorOption);
  let blockListOption = null;
  blockListOption =
    isValidArray(blockListForCategory) &&
    !blockListForCategoryLoading &&
    blockListForCategory.map((d) => {
      return { label: d.BlockName, value: d.BlockID };
    });

  const staticOption = { label: "Select Block for category", value: "" };
  blockListOption && blockListOption.unshift(staticOption);

  const handleSave = () => {
    const formData = {
      CategoryID: String(catalogId),
      CategoryName: categoryName,
      SortBy: productCollectionSort,
      blockID: blockID,
      isPage: String(catalogPlanner),
      template: template,
      colorCode: colorCode,
      blockSize: blockSizes,
    };

    dispatch(fetchUpdateDisplaySetup(formData)).then((data) => {
      setIsEdit(false);
      dispatch(fetchCatalogTree()).then((data) => {
        if (catalogPlanner) {
          changeCatalogPlanner(catalogPlanner);
        }
      });
    });
  };

  const handleCancle = () => {
    setIsEdit(false);
  };

  const handleUnlinkTemplate = () => {
    const formData = {
      CategoryID: String(catalogId),
    };

    dispatch(fetchUnlinkTemplate(formData)).then((data) => {
      handleUnlinkModal();
    });
  };

  const handleUnlinkColorModal = () => {
    setUnlinkColorModal(!unlinkColorModal);
  };
  const handleLinkColorModal = () => {
    setLinkColorModal(!linkColorModal);
  };

  const handleLinkColor = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchLinkParentColor(formData)).then((data) => {
      getCategoryListDetails();
      handleLinkColorModal();
    });
  };

  const handleUnlinkColor = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchUnlinkParentColor(formData)).then((data) => {
      handleUnlinkColorModal();
      getCategoryListDetails();
    });
  };

  const handleCopyCategory = () => {
    dispatch(fetchCopyBlockIdForCategory(blockListCategory)).then((d) => { });
  };

  const updateCategoryTextSchema = (id) => {
    const formData = {
      CategoryID: parseInt(catalogId),
      CategoryTextSchemaID: id,
    };
    dispatch(fetchUpdateCategoryTextBlockSchema(formData)).then((res) => {
      if (res) {
        getInitTextSetup();
      }
      console.log("🚀 ~ file: AttributeSetup.js:312 ~ dispatch ~ res:", res);
    });
  };

  const handleUnlinkTextSetupModal = () => {
    setUnlinkTextSetupModal(!unlinkTextSetupModal);
  };
  const handleLinkTextSetupModal = () => {
    setLinkTextSetupModal(!linkTextSetupModal);
  };
  const handleUnlinkAttributeSetupModal = () => {
    setUnlinkAttributeSetupModal(!unlinkAttributeSetupModal);
  };
  const handleLinkAttributeSetupModal = () => {
    setLinkAttributeSetupModal(!linkAttributeSetupModal);
  };

  const handleLinkTextSetup = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchLinkParentTextBlock(formData)).then((data) => {
      getInitTextSetup();
      handleLinkTextSetupModal();
    });
  };

  const handleUnlinkTextSetup = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchUnlinkParentTextBlock(formData)).then((data) => {
      handleUnlinkTextSetupModal();
      getInitTextSetup();
    });
  };
  const handleLinkAttributeSetup = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchLinkAttribute(formData)).then((data) => {
      getInitAttributeSetup();
      handleLinkAttributeSetupModal();
    });
  };

  const handleUnlinkAttributeSetup = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchUnlinkParentAttribute(formData)).then((data) => {
      handleUnlinkAttributeSetupModal();
      getInitAttributeSetup();
    });
  };
  const updateCategorySchema = (id) => {
    const formData = {
      CategoryID: parseInt(catalogId),
      AttributeSchemaID: id,
    };
    dispatch(fetchUpdateCategoryAttributeSchema(formData)).then((res) => {
      if (res) {
        getInitAttributeSetup();
      }
    });
  };

  if (
    isLoading ||
    unLinkColorLoading ||
    linkColorLoading ||
    isDetailsLoading ||
    isLoadingTextSetup ||
    isLoadinggetAllCategoryTextSchemaList ||
    isLoadingAttributeSetupData ||
    getAllAttributeSchemaLoading
  ) {
    return (
      <div className="category-display-template m-4">
        <div className="tableorganisation category-table table-drag-drop center-text-tbl product-tableBorder">
          <Loader />
        </div>
      </div>
    );
  }

  const isRootCategoryFromDetails = categoryDetails?.IsRoot;

  return (
    <div className="display-setup category-display-template">
      <div className="category-btn">
        <div className="row">
          <div className="col-lg-12">
            {isEdit ? (
              <>
                <Button onClick={handleSave}>Save</Button>
                <Button
                  onClick={() => handleCancle()}
                  className="cancel-btn-red"
                >
                  Cancel
                </Button>
              </>
            ) : (
              <Button onClick={() => setIsEdit(true)}>Edit</Button>
            )}
          </div>
        </div>
      </div>

      <div className="">
        <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Category ID</p>
            </div>
            <div className="col-md-9">
              <p>{displaySetupData && displaySetupData?.CategoryID}</p>
            </div>
          </div>
        </div>
        <br></br>

        <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Category Name</p>
            </div>
            <div className="col-md-9">
              <InputField
                type="text"
                name="categoryName"
                placeholder="Category Name"
                isDisabled={isRootCategory ? true : !isEdit}
                onChange={(e) => setCategoryName(e.target.value)}
                value={categoryName}
              />
            </div>
          </div>
        </div>
        <br></br>

        {/* <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Catalog Planner</p>
            </div>
            <div className="col-md-9">
              <SelectField
                type="select"
                name="catalogPlanner"
                id="catalogPlanner"
                placeholder="catalogPlanner"
                options={plannerOption}
                isDisabled={!isEdit}
                onChange={setCatalogPlanner}
                value={catalogPlanner}
              />
            </div>
          </div>
        </div>
        <br></br> */}

        {/* <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Product Collection Sort</p>
            </div>
            <div className="col-md-9">
              <SelectField
                type="select"
                name="productCollectionSort"
                id="productCollectionSort"
                placeholder="Select Organization"
                options={productSortOption}
                isDisabled={!isEdit}
                onChange={setProductCollectionSort}
                value={productCollectionSort}
              />
            </div>
          </div>
        </div>
        <br></br> */}

        <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Block Sizes</p>
            </div>
            <div className="col-md-9">
              {/* <p> */}
              <SelectField
                type="select"
                name="productCollectionSort"
                id="productCollectionSort"
                placeholder="Select Block Sizes"
                options={blockSizesOptions}
                isDisabled={!isEdit}
                onChange={setBlockSize}
                value={blockSizes}
              />
              {/* </p> */}
            </div>
          </div>
        </div>
        <br></br>

        <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Block</p>
            </div>
            <div className="col-md-9">
              <SelectField
                type="select"
                name="productCollectionSort"
                id="productCollectionSort"
                placeholder="Select Block for category"
                options={blockListOption}
                onChange={setBlockID}
                value={blockID}
                isDisabled={!isEdit}
              />
            </div>
          </div>
        </div>
        <div className="category-setup-section mt-2">
          <div className="row">
            <div className="col-md-3"></div>
            <div className="col-md-9">
              <p className="mb-0">
                <b>Copy Block ID for all same level categories</b>
              </p>
              <Button
                className="unlink-model-btn"
                onClick={handleCopyCategory}
                disabled={!blockListCategory}
              >
                Copy
              </Button>
            </div>
          </div>
        </div>

        <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Color</p>
            </div>
            <div className="col-md-9">
              <InputField
                id="bgColor"
                isDisabled={categoryDetails?.InheritColor !== "0" || !isEdit}
                className="details-single-element"
                name="color"
                type="color"
                isLabelRequired={false}
                onChange={(e) => {
                  setColorCode(e?.target?.value);
                }}
                value={colorCode ? colorCode : 0}
              />
            </div>
          </div>
        </div>

        {!isRoot &&
          parseInt(categoryDetails?.InheritColor) === 1 &&
          isRootButtonShow !== 1 ? (
          <>
            <div className="category-setup-section mt-2">
              <div className="row">
                <div className="col-md-3"></div>
                <div className="col-md-9">
                  <p className="mb-0">
                    <b>
                      Color shown in this category is linked from level above
                    </b>
                  </p>
                  <Button
                    className="unlink-model-btn"
                    onClick={handleUnlinkColorModal}
                  >
                    Un-Link
                  </Button>
                </div>
              </div>
            </div>
            {unlinkColorModal && (
              <UnLinkModal
                isOpen={unlinkColorModal}
                toggle={handleUnlinkColorModal}
                unLinkFunction={handleUnlinkColor}
                modalText="Do you want to unlink color for this category?"
              />
            )}
          </>
        ) : (
          <>
            <div>
              {isRoot ? (
                <p className="mt-4"></p>
              ) : (
                <>
                  {" "}
                  <div className="category-setup-section mt-2">
                    <div className="row">
                      <div className="col-md-3"></div>
                      <div className="col-md-9">
                        <p className="mb-0">
                          <b>
                            Color shown in this category is not linked from
                            level above
                          </b>
                        </p>
                        <Button onClick={handleLinkColorModal}>Link</Button>
                      </div>
                    </div>
                  </div>
                </>
              )}
            </div>
          </>
        )}

        <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Template</p>
            </div>
            <div className="col-md-9">
              {/* <p> */}
              <SelectField
                type="select"
                name="template"
                id="template"
                placeholder="Select template"
                options={templateOptions}
                isDisabled={!isEdit}
                onChange={setTemplate}
                value={template}
              />
              {/* </p> */}
            </div>
          </div>
        </div>
        {isRootButtonShow !== 1 && (
          <>
            {" "}
            {displaySetupData?.TemplateInheritance == 1 ? (
              <div className="category-setup-section mt-2">
                <div className="row">
                  <div className="col-md-3"></div>
                  <div className="col-md-9">
                    <p className="mb-0">
                      Template in this category is linked from level above.
                    </p>
                    <p className="mb-0">Any changes made will not be saved.</p>
                    <Button onClick={handleUnlinkModal}>Un-link</Button>
                  </div>
                </div>
              </div>
            ) : (
              <div className="category-setup-section mt-2">
                <div className="row">
                  <div className="col-md-3"></div>
                  <div className="col-md-9">
                    <p className="mb-0">
                      Template in this category is not linked from level above.
                    </p>
                    <Button onClick={handleLink}>Link</Button>
                  </div>
                </div>
              </div>
            )}
          </>
        )}

        {/* CATEGORY TEXT BLOCK SCHEMA */}
        <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Category Text Block </p>
            </div>
            <div className="col-md-9">
              <SelectField
                name="textBlockSchema"
                options={categoryTextSchemaOptions}
                onChange={(e) => {
                  setSelectedCategoryTextSchema(e);
                  updateCategoryTextSchema(e);
                }}
                value={selectedCategoryTextSchema}
                isDisabled={!isCategoryTextEditable || !isEdit}
              />
            </div>
          </div>
        </div>
        {!isRootCategoryFromDetails &&
          parseInt(textSetupData?.inheritTextBlock) === 1 ? (
          <>
            <div className="category-setup-section mt-2">
              <div className="row">
                <div className="col-md-3"></div>
                <div className="col-md-9">
                  <p>
                    {" "}
                    Text Blocks shown on this category are linked from level
                    above
                  </p>
                  <Button
                    className="unlink-model-btn"
                    onClick={handleUnlinkTextSetupModal}
                  >
                    Un-link
                  </Button>
                </div>
              </div>
            </div>
            {unlinkTextSetupModal && (
              <UnLinkModal
                isOpen={unlinkTextSetupModal}
                toggle={handleUnlinkTextSetupModal}
                unLinkFunction={handleUnlinkTextSetup}
                modalText="Do you want to unlink text blocks for this category?"
              />
            )}
          </>
        ) : (
          <>
            <div>
              {isRootCategoryFromDetails ? (
                <p className="mt-4"></p>
              ) : (
                <div className="category-setup-section mt-2">
                  <div className="row">
                    <div className="col-md-3"></div>
                    <div className="col-md-9">
                      <p>
                        Text Blocks shown on this category are not linked from
                        level above
                      </p>
                      <Button onClick={handleLinkTextSetup}>Link</Button>
                    </div>
                  </div>
                </div>
              )}
            </div>
          </>
        )}
        {linkTextSetupModal && (
          <UnLinkModal
            isOpen={linkTextSetupModal}
            toggle={handleLinkTextSetup}
            unLinkFunction={handleLink}
            modalText="Do you want to link text block for this category?"
          />
        )}

        {/* PRODUCT ATTRIBUTE SETUP */}
        <div className="category-setup-section">
          <div className="row">
            <div className="col-md-3">
              <p>Product Attribute Setup</p>
            </div>
            <div className="col-md-9">
              {/* <p> */}
              <SelectField
                name="categorySchema"
                options={categorySchemaOptions}
                onChange={(e) => {
                  setSelectedCategorySchema(e);
                  updateCategorySchema(e);
                }}
                value={selectedCategorySchema}
                isDisabled={!isAttributeSetupEditable || !isEdit}
              />
              {/* </p> */}
            </div>
          </div>
        </div>
        {!isRootShow && attributeSetupData?.inheritAttribute == 1 ? (
          <>
            <div className="category-setup-section mt-2">
              <div className="row">
                <div className="col-md-3"></div>
                <div className="col-md-9">
                  <p>
                    Attributes shown on products in this category are linked
                    from level above
                  </p>
                  <Button
                    className="unlink-model-btn"
                    onClick={handleUnlinkAttributeSetupModal}
                  >
                    Un-link
                  </Button>
                </div>
              </div>
            </div>
            {unlinkAttributeSetupModal && (
              <UnLinkModal
                isOpen={unlinkAttributeSetupModal}
                toggle={handleUnlinkAttributeSetupModal}
                unLinkFunction={handleUnlinkAttributeSetup}
                modalText="Do you want to unlink product attributes for this category?"
              />
            )}
          </>
        ) : (
          <>
            <div>
              {isRootShow ? (
                <p className="mt-4"></p>
              ) : (
                <div className="category-setup-section mt-2">
                  <div className="row">
                    <div className="col-md-3"></div>
                    <div className="col-md-9">
                      <p>
                        Attributes shown on products in this category are not
                        linked from level above
                      </p>
                      <Button onClick={handleLinkAttributeSetupModal}>
                        Link
                      </Button>
                    </div>
                  </div>
                </div>
              )}
            </div>
          </>
        )}
        {linkAttributeSetupModal && (
          <UnLinkModal
            isOpen={linkAttributeSetupModal}
            toggle={handleLinkAttributeSetupModal}
            unLinkFunction={handleLinkAttributeSetup}
            modalText="Do you want to link product attributes for this category?"
          />
        )}
        {linkColorModal && (
          <UnLinkModal
            isOpen={linkColorModal}
            toggle={handleLinkColorModal}
            unLinkFunction={handleLinkColor}
            modalText="Do you want to link color for this category?"
          />
        )}

        {unlinkModal && (
          <UnLinkModal
            isOpen={unlinkModal}
            toggle={handleUnlinkModal}
            unLinkFunction={() => handleUnlinkTemplate()}
            modalText="Do you want to unlink template for this category?"
          />
        )}
      </div>
    </div>
  );
};

export default DisplaySetup;
