import { Component, useEffect } from "react";
import React, { useState } from "react";
// import './App.css';
import { DragDropContext, Droppable, Draggable } from "react-beautiful-dnd";
import { Button, Input } from "reactstrap";
import Table from "components/Common/Table";
import ReactTable from "react-table-6";
import strings from "data/strings";
import SelectField from "components/Common/SelectField";
import { fetchCategoryTextData } from "redux/actions/manageCatalog/categoryTextData";
import { fetchGetAllCategoryTextSchemaList } from "redux/actions/masterSetup/textBlockSchema/getAllCategoryTextSchemaList";
import { useDispatch, useSelector } from "react-redux";
import { isValidArray, filterFieldData } from "modules/utils";
import { fetchTextSetupData } from "redux/actions/manageCatalog/textSetupData";
import { fetchDeleteTextSetup } from "redux/actions/manageCatalog/deleteTextSetup";
import DeleteModalWithoutHeader from "components/Common/Modal/DeleteModalWithoutHeader";
import { fetchUpdateTextSetupSortOrder } from "redux/actions/manageCatalog/updateTextSetupSortOrder";
import InputField from "components/Common/InputField";
import { fetchAddTextBlockToCategory } from "redux/actions/manageCatalog/addTextBlockToCategory";
import { fetchDeleteCategoryTextBlock } from "redux/actions/manageCatalog/deleteCategoryTextBlock";
import Loader from "components/Common/Loader";
import UnLinkModal from "./UnLinkModal";
import { fetchUnlinkParentTextBlock } from "redux/actions/manageCatalog/unlinkParentTextBlock";
import { fetchLinkParentTextBlock } from "redux/actions/manageCatalog/linkParentTextBlock";
import { fetchGetCategoryDetails } from "redux/actions/manageCatalog/getCategoryDetails";
import { fetchUpdateCategoryTextBlockSchema } from "redux/actions/manageCatalog/updateCategoryTextBlockSchema";

const TextSetup = ({ catalogId, activeTab }) => {
  const dispatch = useDispatch();

  const [unlinkModal, setUnlinkModal] = useState(false);
  const [linkModal, setLinkModal] = useState(false);
  const [categoryTextSchemaOptions, setCategoryTextSchemaOptions] = useState(
    []
  );
  console.log(
    "🚀 ~ file: TextSetup.js:47 ~ TextSetup ~ categoryTextSchemaOptions:",
    categoryTextSchemaOptions
  );
  const [selectedCategoryTextSchema, setSelectedCategoryTextSchema] =
    useState("");

  const {
    isLoading = false,
    textSetupData = null,
    categoryDetails = null,
    isDetailsLoading = false,
  } = useSelector((state) => ({
    textSetupData: state.textSetupData?.data?.data || null,
    isLoading: state.textSetupData?.loading || false,
    categoryDetails: state.getCategoryDetails?.data?.data || null,
    isDetailsLoading: state.getCategoryDetails?.loading || false,
  }));
  console.log(
    "🚀 ~ file: TextSetup.js:55 ~ TextSetup ~ categoryDetails:",
    categoryDetails,
    textSetupData
  );

  useEffect(() => {
    if (activeTab == "textSetup") {
      getInitTextSetup();
    }
  }, [catalogId]);

  const getInitTextSetup = () => {
    dispatch(fetchTextSetupData(catalogId)).then((data) => {
      console.log("🚀 ~ file: TextSetup.js:78 ~ dispatch ~ data:", data);
      dispatch(fetchGetAllCategoryTextSchemaList()).then((res) => {
        console.log("🚀 ~ file: TextSetup.js:77 ~ dispatch ~ res:", res);
        const single = res?.data?.map((item) => {
          return {
            label: item.CategoryTextSchemaName,
            value: item.CategoryTextSchemaID,
          };
        });
        const options = [
          { label: "Select Text Block Schema", value: "" },
          ...single,
        ];
        setCategoryTextSchemaOptions(options);
        const selectedSchema = res?.data?.filter(
          (d) => d?.CategoryTextSchemaID === data?.data?.CategoryTextSchemaID
        );
        console.log(
          "🚀 ~ file: TextSetup.js:93 ~ dispatch ~ selectedSchema:",
          selectedSchema,
          selectedSchema?.[0]?.CategoryTextSchemaName
        );
        setSelectedCategoryTextSchema(
          selectedSchema?.[0]?.CategoryTextSchemaID
        );
      });
      dispatch(fetchGetCategoryDetails(catalogId));
    });
  };

  const getCategoryList = (data) => {
    const value = data?.categoryTextBlocks?.map((item) => {
      return {
        textBlockId: item.TextBlockID,
        textBlockName: item.TextBlockName,
        sort: item.SortOrder,
      };
    });
    return value;
  };

  const getMissingTextBlockOption = (data) => {
    const value = data?.missingTextBlocks?.map((item) => {
      return {
        label: item.TextBlockName,
        value: item.TextBlockID,
      };
    });

    return [{ label: "Add text block", value: "" }, ...value];
  };

  const handleUnlinkModal = () => {
    setUnlinkModal(!unlinkModal);
  };
  const handleLinkModal = () => {
    setLinkModal(!linkModal);
  };

  const handleLink = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchLinkParentTextBlock(formData)).then((data) => {
      getInitTextSetup();
      handleLinkModal();
    });
  };

  const handleUnlink = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchUnlinkParentTextBlock(formData)).then((data) => {
      handleUnlinkModal();
      getInitTextSetup();
    });
  };

  const updateCategoryTextSchema = (id) => {
    const formData = {
      CategoryID: parseInt(catalogId),
      CategoryTextSchemaID: id,
    };
    dispatch(fetchUpdateCategoryTextBlockSchema(formData)).then((res) => {
      if (res) {
        getInitTextSetup();
      }
      console.log("🚀 ~ file: AttributeSetup.js:312 ~ dispatch ~ res:", res);
    });
  };

  if (isLoading || isDetailsLoading) {
    return (
      <div className="category-display-template m-4">
        <div className="tableorganisation category-table table-drag-drop center-text-tbl product-tableBorder">
          <Loader />
        </div>
      </div>
    );
  }

  const isRoot = categoryDetails?.IsRoot;

  return (
    <div className="category-display-template m-4">
      <div className="category-display-template m-4 product-attribute-drop">
        <div className="w-100 text-center h5">
          Category Text Schema are now managed via Setup &gt; Text Blocks &gt;
          Text Block Schema.
        </div>
      </div>
      <div className="tableorganisation  category-table attribute-table-setup center-text-tbl product-tableBorder">
        <div className="d-flex justify-content-between align-center mb-2">
          <div className="tabcontent w-25" style={{ paddingLeft: 0 }}>
            <SelectField
              className="w-100"
              name="categorySchema"
              options={categoryTextSchemaOptions}
              onChange={(e) => {
                setSelectedCategoryTextSchema(e);
                updateCategoryTextSchema(e);
              }}
              value={selectedCategoryTextSchema}
            />
          </div>
        </div>
      </div>

      {!isRoot && parseInt(textSetupData?.inheritTextBlock) === 1 ? (
        <>
          <div>
            <p className="mt-4">
              <b>
                Text Blocks shown on this category are linked from level above
              </b>
            </p>
            <Button className="unlink-model-btn" onClick={handleUnlinkModal}>
              Un-link
            </Button>
          </div>
          {unlinkModal && (
            <UnLinkModal
              isOpen={unlinkModal}
              toggle={handleUnlinkModal}
              unLinkFunction={handleUnlink}
              modalText="Do you want to unlink text blocks for this category?"
            />
          )}
        </>
      ) : (
        <>
          <div>
            {isRoot ? (
              <p className="mt-4"></p>
            ) : (
              <>
                {" "}
                <p className="mt-4">
                  <b>
                    Text Blocks shown on this category are not linked from level
                    above
                  </b>
                </p>
                <Button onClick={handleLinkModal}>Link</Button>
              </>
            )}
          </div>
        </>
      )}
      {linkModal && (
        <UnLinkModal
          isOpen={linkModal}
          toggle={handleLinkModal}
          unLinkFunction={handleLink}
          modalText="Do you want to link text block for this category?"
        />
      )}
    </div>
  );
};

export default TextSetup;
