import React, { useState, useEffect } from "react";
import { useDispatch } from "react-redux";
import Pagination from "react-js-pagination";
import SweetAlert from "react-bootstrap-sweetalert";
import { Button, Modal, ModalBody, ModalHeader } from "reactstrap";
import informationIcon from "../../../../assets/images/informationIcon.png";

import { fetchGetCategoryMedia } from "redux/actions/manageCatalog/getCategoryMedia";
import { isValidArray } from "modules/utils";
import InputNormal from "components/Common/InputNormal";
import Loader from "components/Common/Loader";
import { useSelector } from "react-redux";
const CatalogMedia = ({ catalogId }) => {
  const [catId, setCatId] = useState(null);
  const [search, setSearch] = useState("");
  const [deleteModal, setDeleteModal] = useState(false);
  const [notDeleteModal, setNotDeleteModal] = useState(false);
  const [deleteId, setDeleteId] = useState(null);
  const [activePage, setActivePage] = useState(1);
  const [activeCatPage, setActiveCatPage] = useState(1);
  const [perPage, setPerPage] = useState(50);
  const [perPageCat, setPerPageCat] = useState(50);
  const [imageData, setImageData] = useState([]);

  const dispatch = useDispatch();

  const {
    productImages = null,
    categoryImages = null,
    allImages = null,
    imagesLoading = false,
  } = useSelector((state) => ({
    productImages: state.categoryMedia?.data?.data?.productImages,
    categoryImages: state.categoryMedia?.data?.data?.categoryImages,
    allImages: state.categoryMedia?.data?.data,
    imagesLoading: state.categoryMedia?.loading,
  }));

  useEffect(() => {
    dispatch(fetchGetCategoryMedia(catalogId)).then((data) => {
      if (data && data?.flag) setImageData(data?.data);
    });
  }, [catalogId]);

  const handleDeleteModal = () => {
    setDeleteModal(!deleteModal);
  };

  const handleNotDeleteModal = () => {
    setNotDeleteModal(!notDeleteModal);
  };

  const handleDelete = () => {
    setDeleteModal(false);
    // dispatch(fetchDeleteImage(deleteId)).then(() => {
    //   //   handleDeleteModal();
    //   getAllImages();
    // });
  };

  const handlePageChange = (data) => {
    setActivePage(data);
    // getAllImages(data);
  };

  const getPagination = () => {
    return (
      <div className="">
        {isValidArray(productImages) && (
          <Pagination
            activePage={activePage}
            itemsCountPerPage={perPage}
            pageRangeDisplayed={5}
            totalItemsCount={productImages?.length || 0}
            // nextPageText={"Last"}
            // prevPageText={"First"}
            lastPageText={"Last"}
            firstPageText={"First"}
            hideNavigation={true}
            onChange={(e) => {
              handlePageChange(e);
            }}
            innerClass="pagination pagination-custom"
          />
        )}
      </div>
    );
  };

  return (
    <div className="catalog-media">
      <h3>Product Images</h3>
      <>
        {!imagesLoading && !isValidArray(productImages) && (
          <p>No Product Images Found for this category</p>
        )}
        <div>
          <div className="bg-white common-space img-box-section media-image-view">
            <div className="d-flex justify-content-end">
              {/* <InputNormal
                type="text"
                name="Attribute"
                placeholder="Search Images..."
                value={search}
                // onChange={handleSearch}
              /> */}
            </div>
            <div className="row">
              {imagesLoading ? ( //temp var
                <Loader />
              ) : (
                isValidArray(productImages) &&
                productImages.map((d, i) => {
                  return (
                    <div className="col-2 my-2" key={d?.ImageID}>
                      <div className="common-space text-center img-listing-box">
                        {/* <i
                          className="fa fa-times fa-lg"
                          onClick={() => {
                            setDeleteId(d?.ImageID);
                            handleDeleteModal();
                          }}
                        ></i> */}
                        <img
                          style={{
                            height: d?.ImageHeight,
                            width: d?.ImageWidth,
                          }}
                          src={d?.ImagePath}
                          alt="Producty"
                        />
                        <div className="img-box-title">{d?.ImageName}</div>
                      </div>
                    </div>
                  );
                })
              )}
            </div>
            {isValidArray(productImages) && productImages && (
              <>
                {/* <p>
                  Showing {productImages?.length - productImages?.length - 1} to{" "}
                  {productImages?.length} of {productImages?.length} entries
                </p>
                {productImages?.length && getPagination()} */}
              </>
            )}
          </div>

          {notDeleteModal && (
            <Modal
              className="conformation-popup delete-warning-popup invite-seller-popup"
              isOpen={notDeleteModal}
              toggle={handleNotDeleteModal}
              size={"lg"}
            >
              <ModalBody>
                <div className="alert-img">
                  <img src={informationIcon} alt="cancel" />
                </div>
                <h3 className="warning-popup-title">Image Not Deleted!</h3>
                <p className="lead text-muted ">Image has not been deleted!</p>
                <div className="popup-btn-section">
                  <Button
                    color="primary save-btn confirm-y"
                    onClick={handleNotDeleteModal}
                  >
                    Ok
                  </Button>
                </div>
              </ModalBody>
            </Modal>
          )}
          {deleteModal && (
            <SweetAlert
              show={deleteModal}
              danger
              showCancel
              confirmBtnText="Yes"
              confirmBtnBsStyle="success"
              allowEscape={false}
              closeOnClickOutside={false}
              cancelBtnText="No"
              cancelBtnBsStyle="success"
              title="Are you sure you want to delete this image?"
              onConfirm={handleDelete}
              onCancel={() => {
                handleDeleteModal();
                handleNotDeleteModal();
              }}
              focusConfirmBtn
            >
              <p className="lead text-muted ">
                You will not be able to recover this file!
              </p>
            </SweetAlert>
          )}
        </div>
      </>
      <h3>Category Images</h3>
      <>
        {!imagesLoading && !isValidArray(categoryImages) && (
          <p>No Category Images Found for this category</p>
        )}
        <div>
          <div className="bg-white common-space img-box-section media-image-view">
            <div className="d-flex justify-content-end">
              {/* <InputNormal
                type="text"
                name="Attribute"
                placeholder="Search Images..."
                value={search}
                // onChange={handleSearch}
              /> */}
            </div>
            <div className="row">
              {imagesLoading ? ( //temp var
                <Loader />
              ) : (
                isValidArray(categoryImages) &&
                categoryImages.map((d, i) => {
                  return (
                    <div className="col-2 my-2" key={d?.ImageID}>
                      <div className="common-space text-center img-listing-box">
                        {/* <i
                          className="fa fa-times fa-lg"
                          onClick={() => {
                            setDeleteId(d?.ImageID);
                            handleDeleteModal();
                          }}
                        ></i> */}
                        <img
                          style={{
                            height: d?.ImageHeight,
                            width: d?.ImageWidth,
                          }}
                          src={d?.ImagePath}
                          alt="Producty"
                        />
                        <div className="img-box-title">{d?.ImageName}</div>
                      </div>
                    </div>
                  );
                })
              )}
            </div>
            {isValidArray(categoryImages) && categoryImages && (
              <>
                {/* <p>
                  Showing {categoryImages?.length - categoryImages?.length - 1}{" "}
                  to {categoryImages?.length} of {categoryImages?.length}{" "}
                  entries
                </p>
                {categoryImages?.length && getPagination()} */}
              </>
            )}
          </div>

          {notDeleteModal && (
            <Modal
              className="conformation-popup delete-warning-popup invite-seller-popup"
              isOpen={notDeleteModal}
              toggle={handleNotDeleteModal}
              size={"lg"}
            >
              <ModalBody>
                <div className="alert-img">
                  <img src={informationIcon} alt="cancel" />
                </div>
                <h3 className="warning-popup-title">Image Not Deleted!</h3>
                <p className="lead text-muted ">Image has not been deleted!</p>
                <div className="popup-btn-section">
                  <Button
                    color="primary save-btn confirm-y"
                    onClick={handleNotDeleteModal}
                  >
                    Ok
                  </Button>
                </div>
              </ModalBody>
            </Modal>
          )}
          {deleteModal && (
            <SweetAlert
              show={deleteModal}
              danger
              showCancel
              confirmBtnText="Yes"
              confirmBtnBsStyle="success"
              allowEscape={false}
              closeOnClickOutside={false}
              cancelBtnText="No"
              cancelBtnBsStyle="success"
              title="Are you sure you want to delete this image?"
              onConfirm={handleDelete}
              onCancel={() => {
                handleDeleteModal();
                handleNotDeleteModal();
              }}
              focusConfirmBtn
            >
              <p className="lead text-muted ">
                You will not be able to recover this file!
              </p>
            </SweetAlert>
          )}
        </div>
      </>
    </div>
  );
};

export default CatalogMedia;
