import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import CatalogPlanner from "../catalogPlanner/CatalogPlanner";
import BlockPages from "./tabs/BlockPages";
import BlockSetup from "./tabs/BlockSetup";
import BuildPages from "./tabs/BuildPages";
import CatalogOptions from "./tabs/CatalogOptions";
import Split from "react-split";
import { fetchGetUserCatalogDetail } from "redux/actions/output/getUserCatalogDetail";

export default function Planner({
  catalogId,
  setCatalogPlanner,
  catalogDataList,
  // pagePlannerEnabled,
}) {
  // console.log("🚀 ~ file: Planner.js:18 ~ catalogId:", catalogId);
  // console.log(
  //   "🚀 ~ file: Planner.js:14 ~ pagePlannerEnabled:",
  //   pagePlannerEnabled
  // );
  const dispatch = useDispatch();

  const initialActiveTab = {
    catalogOptions: "active",
    buildPages: "",
    blockSizeSetup: "",
    blockSetup: "",
    activeTab: "catalogOptions",
  };

  // useEffect(() => {
  //   dispatch(fetchGetUserCatalogDetail());
  // }, []);

  const [activeTab, setActivetab] = useState(initialActiveTab);
  const handleTab = (tabName) => {
    if (tabName == "catalogOptions") {
      setActivetab({
        catalogOptions: "active",
        buildPages: "",
        blockSizeSetup: "",
        blockSetup: "",
        activeTab: "catalogOptions",
      });
    } else if (tabName == "buildPages") {
      setActivetab({
        catalogOptions: "",
        buildPages: "active",
        blockSizeSetup: "",
        blockSetup: "",
        activeTab: "buildPages",
      });
    } else if (tabName == "blockSizeSetup") {
      setActivetab({
        catalogOptions: "",
        buildPages: "",
        blockSizeSetup: "active",
        blockSetup: "",
        activeTab: "blockSizeSetup",
      });
    } else if (tabName == "blockSetup") {
      setActivetab({
        catalogOptions: "",
        buildPages: "",
        blockSizeSetup: "",
        blockSetup: "active",
        activeTab: "blockSetup",
      });
    }
  };
  const {
    getUserCatalogDetailsPages = null,
    getUserCatalogDetailsPagesLoading = false,
    getPagePlannerByPageData = null,
    getPagePlannerByPageLoading = false,
    pagePlannerEnabled = null,
    catalogTree = null,
    blockListing,
  } = useSelector((state) => ({
    catalogTree: state.catalogTree?.data?.data || null,
    getUserCatalogDetailsPages: state.getUserCatalogDetail.data?.data?.Pages,
    getUserCatalogDetailsPagesLoading: state.getUserCatalogDetail?.loading,
    getPagePlannerByPageData: state.getPagePlannerByPage.data?.data,
    getPagePlannerByPageLoading: state.getPagePlannerByPage?.loading,
    pagePlannerEnabled: state.getUserCatalogDetail?.data?.data || null,
    blockListing: state.blockListing?.data?.data,
  }));
  const isRoot = catalogTree[0]?.id == parseInt(catalogId) ? true : false;

  // console.log("isroot: " + isRoot);
  return (
    <>
      {isRoot ? (
        <div
          className="catalog-body-full"
          style={{ width: "100%" }}
          id="nav nav-tabs"
        >
          <Nav tabs>
            <NavItem>
              <NavLink
                className={activeTab.catalogOptions}
                onClick={() => handleTab("catalogOptions")}
              >
                Catalog Options
              </NavLink>
            </NavItem>
            <NavItem>
              <NavLink
                className={activeTab.buildPages}
                onClick={() => handleTab("buildPages")}
              >
                Build Pages
              </NavLink>
            </NavItem>
            <NavItem>
              <NavLink
                className={activeTab.blockSizeSetup}
                onClick={() => handleTab("blockSizeSetup")}
              >
                Block Size Setup
              </NavLink>
            </NavItem>
            <NavItem>
              <NavLink
                className={activeTab.blockSetup}
                onClick={() => handleTab("blockSetup")}
              >
                Block Setup
              </NavLink>
            </NavItem>
          </Nav>
          <TabContent activeTab={activeTab.activeTab}>
            <TabPane tabId="catalogOptions">
              {activeTab.activeTab === "catalogOptions" && (
                <CatalogOptions
                  catalogId={catalogId}
                  isRoot={isRoot}
                  activeTab={activeTab.activeTab}
                />
              )}
            </TabPane>
            <TabPane tabId="buildPages">
              {activeTab.activeTab === "buildPages" && (
                <BuildPages
                  catalogId={catalogId}
                  isRoot={isRoot}
                  activeTab={activeTab.activeTab}
                />
              )}
            </TabPane>
            <TabPane tabId="blockSizeSetup">
              {activeTab.activeTab === "blockSizeSetup" && (
                //   <BlockSetup
                //   catalogId={catalogId}
                //   isRoot={isRoot}
                //   activeTab={activeTab.activeTab}
                // />
                <BlockSetup
                  catalogId={catalogId}
                  isRoot={isRoot}
                  activeTab={activeTab.activeTab}
                />
              )}
            </TabPane>
            <TabPane tabId="blockSetup">
              {activeTab.activeTab === "blockSetup" && (
                <BlockSetup
                  catalogId={catalogId}
                  isRoot={isRoot}
                  activeTab={activeTab.activeTab}
                />
              )}
            </TabPane>
          </TabContent>
        </div>
      ) : (
        <>
          {pagePlannerEnabled?.VisualDesigner ? (
            <>
              <Split
                sizes={[0, 100]}
                minSize={260}
                direction="horizontal"
                cursor="col-resize"
                className="split-flex1"
              >
                <CatalogPlanner
                  catalogId={catalogId}
                  // slider={pageSlider()}
                  pagePlannerDataLoading={getPagePlannerByPageLoading}
                  pagePlannerData={getPagePlannerByPageData}
                  catalogDataList={catalogDataList}
                />
              </Split>
            </>
          ) : (
            <div className="mt-3 container text-center">
              {" "}
              You need to enable Planner for this catalog.{" "}
            </div>
          )}
        </>
      )}
    </>
  );
}
