import React, { useEffect, useState } from "react";
import { useHistory } from "react-router-dom/cjs/react-router-dom.min";
import { useDispatch, useSelector } from "react-redux";
import { Button, Modal, ModalBody, ModalFooter, ModalHeader } from "reactstrap";
import { fetchBlockList } from "redux/actions/blockBuilder/blockListing";
import { fetchBlockDelete } from "redux/actions/blockBuilder/blockDelete";
import { fetchBlockAdd } from "redux/actions/blockBuilder/blockAdd";
import InputField from "components/Common/InputField";
import Headings from "components/ManageCatalog/Headings";
import SelectField from "components/Common/SelectField";
import Loader from "components/Common/Loader";
import { handleDecimalsOnValue, oneTrailingZeroes } from "modules/utils";
import { fetchGetCategoryMergeLevels } from "redux/actions/blockBuilder/getCategoryMergeLevels";
import Table from "components/Common/Table";
import NewCanvas from "components/BlockBuilder/tabs/catalogPages/NewCanvas";

const Block = ({ setActivetab, activeTab, handleTab }) => {
  const [isAddBlockModalOpen, setIsAddBlockModalOpen] = useState(false);
  const [blockEditMode, setBlockEditMode] = useState(false);
  const [editId, setEditId] = useState(null);
  const [addBlockData, setAddBlockData] = useState({
    BlockName: "",
    Height: "",
    Width: "",
    Unit: "mm",
    MergeLevel: "",
  });
  console.log(
    "🚀 ~ file: Block.js ~ line 25 ~ Block ~ addBlockData",
    addBlockData
  );
  const history = useHistory();

  const {
    isLoading = true,
    blockListing,
    isCategoryLoading = true,
    getCategoryMergeLevels,
    blockSizeOptions,
  } = useSelector((state) => ({
    isLoading: state.blockListing?.loading || false,
    blockListing: state.blockListing?.data?.data,
    isCategoryLoading: state.getCategoryMergeLevels?.loading || false,
    getCategoryMergeLevels: state.getCategoryMergeLevels?.data?.data,
    blockSizeOptions: state?.getDefaultBlockSizeOptions?.data?.data,
  }));

  const dispatch = useDispatch();

  const getBlockList = () => {
    dispatch(fetchBlockList());
  };

  useEffect(() => {
    getBlockList();
    dispatch(fetchGetCategoryMergeLevels()).then((data) => {
      setAddBlockData({ ...addBlockData, MergeLevel: data?.data?.[0] });
    });
  }, []);

  const onSubmitBlockData = () => {
    dispatch(fetchBlockAdd(addBlockData)).then((d) => {
      toggleAddBlockModal();
      getBlockList();
      setAddBlockData({
        ...addBlockData,
        BlockName: "",
        Height: "",
        Width: "",
      });
    });
  };

  const getCategoryOptions = () => {
    const options = getCategoryMergeLevels.map((d) => {
      return {
        label: d,
        value: d,
      };
    });
    return options; //onsole.log("🚀 ~ file: Block.js ~ line 73 ~ options ~ options", options);
  };
  const toggleAddBlockModal = () => {
    setIsAddBlockModalOpen(!isAddBlockModalOpen);
    // getCategoryOptions();
  };

  const handleBlockEdit = (block) => {
    setBlockEditMode(true);
    setEditId(block);
    // insertParam("blockId", block?.original?.BlockID);
    // history.push({
    //   pathname: "/Layout",
    //   search: `?blockId=${block?.original?.BlockID}`,
    //   state: { blockId: block?.original?.BlockID },
    // });
    // handleTab("catalogPages");
  };

  const handleBlockDelete = (block) => {
    dispatch(fetchBlockDelete({ BlockID: block?.original?.BlockID })).then(
      () => {
        dispatch(fetchBlockList());
      }
    );
  };

  const columns = [
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          Block Name
        </div>
      ),
      id: "BlockName",
      accessor: "BlockName",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          Block Created Date
        </div>
      ),
      id: "BlockCreatedAt",
      accessor: "BlockCreatedAt",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          Width
        </div>
      ),
      id: "BlockWidth",
      accessor: "BlockWidth",
      Cell: (d) => {
        return <>{oneTrailingZeroes(d?.original?.BlockWidth)}</>;
      },
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          Height
        </div>
      ),
      id: "BlockHeight",
      accessor: "BlockHeight",
      Cell: (d) => {
        return <>{oneTrailingZeroes(d?.original?.BlockHeight)}</>;
      },
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          Merge Level
        </div>
      ),
      id: "MergeLevel",
      accessor: "BlockMergeLevel",
    },
    {
      minWidth: 300,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          Edit
        </div>
      ),
      accessor: "DashboardItemIsVisible",
      Cell: (d) => {
        return (
          <>
            <Button onClick={() => handleBlockEdit(d)} id="block-edit">
              Edit
            </Button>
            {" | "}
            <Button onClick={() => handleBlockDelete(d)}>Delete</Button>
          </>
        );
      },
    },
  ];

  if (isLoading) {
    return <Loader />;
  }
  if (blockEditMode && editId) {
    return <NewCanvas editId={editId?.original?.BlockID} />;
  }

  const blockColumns = [
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          BlockSizeFraction
        </div>
      ),
      id: "BlockSizeFraction",
      accessor: "BlockSizeFraction",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          BlockSizeName
        </div>
      ),
      id: "BlockSizeName",
      accessor: "BlockSizeName",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          BlockSizeOrientation
        </div>
      ),
      id: "BlockSizeOrientation",
      accessor: "BlockSizeOrientation",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          BlockGridWidth
        </div>
      ),
      id: "BlockGridWidth",
      accessor: "BlockGridWidth",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          BlockWidth
        </div>
      ),
      id: "BlockWidth",
      accessor: "BlockWidth",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          BlockHeight
        </div>
      ),
      id: "BlockHeight",
      accessor: "BlockHeight",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          BlockArea
        </div>
      ),
      id: "BlockArea",
      accessor: "BlockArea",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          ItemsPerPage
        </div>
      ),
      id: "ItemsPerPage",
      accessor: "ItemsPerPage",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          BlockSizeCreateDateTime
        </div>
      ),
      id: "BlockSizeCreateDateTime",
      accessor: "BlockSizeCreateDateTime",
    },
  ];
  if (activeTab === "blockSizeSetup") {
    return (
      <div className="tableorganisation bg-white manage-user-tbl-section center-text-tbl product-tableBorder">
        <Table
          columns={blockColumns}
          isSearchRequired={false}
          Data={blockSizeOptions}
          getFilterData={() => blockSizeOptions}
          isLoading={isLoading}
          isDataPerPage={false}
          totalRecordVisible={false}
          showPagination={false}
        />
      </div>
    );
  }

  return (
    <>
      <div className="tableorganisation bg-white manage-user-tbl-section center-text-tbl product-tableBorder">
        <Button
          className="mb-3"
          onClick={() => toggleAddBlockModal()}
          id="add-block-modal-btn"
        >
          Add Block
        </Button>
        {isAddBlockModalOpen && (
          <Modal
            className="conformation-popup"
            isOpen={isAddBlockModalOpen}
            toggle={toggleAddBlockModal}
            size="lg"
          >
            <ModalHeader>Add Block</ModalHeader>
            <ModalBody>
              <div className="d-flex">
                <div className="m-2">
                  <InputField
                    id="tableRows"
                    className="details-single-element"
                    name="tableRows"
                    type="text"
                    label={<Headings mr={5}>Block Name</Headings>}
                    isLabelRequired={true}
                    onChange={(e) =>
                      setAddBlockData({
                        ...addBlockData,
                        BlockName: e.target.value,
                      })
                    }
                    value={`${addBlockData?.BlockName}`}
                  />
                </div>
              </div>

              <div className="d-flex">
                <div className="m-2">
                  <InputField
                    id="tableColumns"
                    className="details-single-element"
                    name="tableColumns"
                    type="text"
                    label={<Headings mr={5}>Width</Headings>}
                    isLabelRequired={true}
                    onChange={(e) =>
                      setAddBlockData({
                        ...addBlockData,
                        Width: handleDecimalsOnValue(e.target.value),
                      })
                    }
                    value={`${addBlockData?.Width}`}
                  />
                </div>
                <div className="m-2">
                  <InputField
                    id="tableColumns"
                    className="details-single-element"
                    name="tableColumns"
                    type="text"
                    label={<Headings mr={5}>Height</Headings>}
                    isLabelRequired={true}
                    onChange={(e) =>
                      setAddBlockData({
                        ...addBlockData,
                        Height: handleDecimalsOnValue(e.target.value),
                      })
                    }
                    value={`${addBlockData?.Height}`}
                  />
                </div>

                <div className="m-2">
                  <SelectField
                    id="blockSettingUnit"
                    name="blockSettingUnit"
                    className="details-single-element-dropdown pe-4"
                    label={<Headings>Unit Type</Headings>}
                    placeholder=""
                    isLabelRequired={true}
                    onChange={(value) =>
                      setAddBlockData({
                        ...addBlockData,
                        Unit: value,
                      })
                    }
                    options={[{ label: "mm", value: "mm" }]}
                    value={addBlockData?.Unit}
                  />
                </div>
              </div>
              <div className="d-flex">
                <div className="m-2">
                  <SelectField
                    id="MergeLevel"
                    name="MergeLevel"
                    className="details-single-element-dropdown pe-4"
                    label={<Headings>Merge Level</Headings>}
                    placeholder=""
                    isLabelRequired={true}
                    onChange={(value) =>
                      setAddBlockData({
                        ...addBlockData,
                        MergeLevel: value,
                      })
                    }
                    options={getCategoryOptions()}
                    value={addBlockData?.MergeLevel}
                  />
                </div>
              </div>
            </ModalBody>
            <ModalFooter>
              <Button color="primary" onClick={onSubmitBlockData}>
                Add Block
              </Button>
              <Button color="primary" onClick={toggleAddBlockModal}>
                Cancel
              </Button>
            </ModalFooter>
          </Modal>
        )}
        <Table
          columns={columns}
          isSearchRequired={false}
          Data={blockListing}
          getFilterData={() => blockListing}
          isLoading={isLoading}
          isDataPerPage={false}
          totalRecordVisible={false}
          showPagination={false}
        />
      </div>
    </>
  );
};

export default Block;
