import React, { useEffect, useState } from "react";
import { Input, Label } from "reactstrap";
import { useDispatch, useSelector } from "react-redux";
import { Container, Row, Col } from "reactstrap";
import InputField from "components/Common/InputField";
import { fetchGetUserCatalogDetail } from "redux/actions/output/getUserCatalogDetail";
import { fetchSaveLayoutOptions } from "redux/actions/blockBuilder/saveLayoutOptions";
import { fetchSavePageOptions } from "redux/actions/blockBuilder/savePageOptions";
import {
  isValidArray,
  isValidObject,
  showSuccessErrorToast,
} from "modules/utils";
import { fetchGetPageOptions } from "redux/actions/blockBuilder/getPageOption";
import { fetchGetLayoutOptions } from "redux/actions/blockBuilder/getLayoutOptions";
import Loader from "components/Common/Loader";
import { fetchGetCategoryMergeLevels } from "redux/actions/blockBuilder/getCategoryMergeLevels";
import { fetchGetDefaultBlockSizeOptions } from "redux/actions/blockBuilder/getDefaultBlockSizeOption";
import { fetchGetBuildPagesOptions } from "redux/actions/blockBuilder/getBuildPagesOptions";
import { fetchSaveBuildPagesOptions } from "redux/actions/blockBuilder/saveBuildPageOptions";
import { fetchGetBuildPagesDetails } from "redux/actions/blockBuilder/getBuildPagesDetails";
import { useCustomHook } from "components/BlockBuilder/tabs/catalogPages/NewCatalogPagesTab.js/CustomHook";

const orientationOptions = [
  { label: "Landscape", value: "landscape" },
  { label: "Portrait", value: "portrait" },
];

export default function BuildPages() {
  const dispatch = useDispatch();

  useEffect(() => {
    loadMergeLevelAndBlockSize();
    loadPageInitData();
    loadLayoutInitData();
    dispatch(fetchGetUserCatalogDetail());
  }, []);

  const {
    getPageOptionsLoading = false,
    getLayoutOptionsLoading = false,
    getBlockSizeOptionLoading = false,
    getBuildPagesOptionLoading = false,
    saveBuildPagesOptionsLoading = false,
    getCategoryMergeLevelLoading = false,
    getBlockSizeOption = null,
    getLayoutOptions = null,
    getCategoryMergeLevel = null,
    getBuildPageDetailsLoading = false,
  } = useSelector((state) => ({
    getPageOptionsLoading: state.getUserCatalogDetail.loading,
    getLayoutOptionsLoading: state.getUserCatalogDetail.loading,
    getLayoutOptions: state.getLayoutOptions.data?.data,
    getCategoryMergeLevel: state.getCategoryMergeLevels.data?.data,
    getCategoryMergeLevelLoading: state.getCategoryMergeLevels.loading,
    getBlockSizeOptionLoading: state.getDefaultBlockSizeOptions.loading,
    getBuildPagesOptionLoading: state.getBuildPageOptions.loading,
    saveBuildPagesOptionsLoading: state.saveBuildPagesOptions.loading,
    getBuildPageDetailsLoading: state.getBuildPageDetails.loading,
    getBlockSizeOption: state.getDefaultBlockSizeOptions.data?.data,
  }));

  console.log(
    "🚀 ~ BuildPages ~ getCategoryMergeLevel:",
    getCategoryMergeLevel
  );
  const {
    layoutVariant,
    columnLayoutVariant,
    assembly,
    categoryValue,
    pageNumberValue,
    pageSizeWidth,
    pageSizeHeight,
    orientation,
    marginTop,
    marginBottom,
    marginLeft,
    marginRight,
    verticalGutter,
    horizontalGutter,
    layoutError,
    columnError,
    assemblyError,
    sectionsError,
    pageSizeWidthError,
    pageSizeHeightError,
    orientationError,
    marginLeftError,
    marginRightError,
    marginTopError,
    marginBottomError,
    gutterVerticalError,
    gutterHorizontalError,
    blockSizes,
    setLayoutVariant,
    setColumnLayoutVariant,
    setAssembly,
    setCategoryValue,
    setPageNumberValue,
    setPageSizeWidth,
    setPageSizeHeight,
    setOrientation,
    setMarginTop,
    setMarginBottom,
    setMarginLeft,
    setMarginRight,
    setVerticalGutter,
    setHorizontalGutter,
    setBlockSize,
  } = useCustomHook();

  const loadMergeLevelAndBlockSize = () => {
    dispatch(fetchGetCategoryMergeLevels()).then((levels) => {
      dispatch(fetchGetDefaultBlockSizeOptions()).then((data) => {
        if (data?.data) {
          getBuildPage();
        }
      });
    });
  };

  const loadPageInitData = () => {
    dispatch(fetchGetPageOptions()).then((data) => {
      if (data?.data) {
        setMarginTop(data?.data?.topMargin);
        setMarginBottom(data?.data?.bottomMargin);
        setMarginLeft(data?.data?.leftMargin);
        setMarginRight(data?.data?.rightMargin);
        setVerticalGutter(data?.data?.verticalGutter);
        setHorizontalGutter(data?.data?.horizontalGutter);
        setOrientation(data?.data?.orientation);
        setPageSizeWidth(data?.data?.pageSizeWidth);
        setPageSizeHeight(data?.data?.pageSizeHeight);
      }
    });
  };

  const loadLayoutInitData = () => {
    dispatch(fetchGetLayoutOptions()).then((data) => {
      if (data?.data) {
        setLayoutVariant(data?.data?.layout);
        setColumnLayoutVariant(data?.data?.columnLayout);
        setAssembly(data?.data?.assembly);
        setCategoryValue(data?.data?.section);
        setPageNumberValue(data?.data?.pageNumber);
      }
    });
  };

  const [isSubmitLayout, setSubmitLayout] = useState("");
  const [isSubmitPage, setSubmitPage] = useState("");

  const submitLayoutOption = () => {
    setSubmitLayout(isSubmitLayout + 1);
    if (!(layoutError || columnError || assemblyError || sectionsError)) {
      const passData = {
        layout: layoutVariant,
        columnLayout: columnLayoutVariant,
        assembly: assembly,
        section: categoryValue,
        pageNumber: pageNumberValue,
      };

      dispatch(fetchSaveLayoutOptions(passData));
    }
  };
  const submitPageOption = () => {
    setSubmitPage(isSubmitPage + 1);
    if (
      !(
        pageSizeWidthError ||
        pageSizeHeightError ||
        orientationError ||
        marginLeftError ||
        marginRightError ||
        marginTopError ||
        marginBottomError ||
        gutterVerticalError ||
        gutterHorizontalError
      )
    ) {
      const passData = {
        pageSizeWidth: pageSizeWidth,
        pageSizeHeight: pageSizeHeight,
        orientation: orientation,
        topMargin: marginTop,
        bottomMargin: marginBottom,
        leftMargin: marginLeft,
        rightMargin: marginRight,
        verticalGutter,
        horizontalGutter,
      };

      dispatch(fetchSavePageOptions(passData)).then((d) => {
        loadPageInitData();
      });
    }
  };

  const submitBuildPagesOption = () => {
    const newData = categoryLevelBlockSize.map((d) => {
      return {
        [d?.catName]: isValidObject(blockSizes[d?.catName])
          ? blockSizes[d?.catName]
          : {
            blockSizeID: 0,
            useExistingBlock: 0,
            useExistingBlockPositions: 0,
            newPage: 0,
            level: d?.catName,
          },
      };
    });
    const passNewData = [
      ...newData,
      {
        Panel: {
          blockSizeID: blockSizes["Panel"].blockSizeID,
          useExistingBlock: blockSizes["Panel"]?.useExistingBlock,
          useExistingBlockPositions: blockSizes["Panel"]?.useExistingBlockPositions,
        },
      },
    ];
    const passData = {
      data: passNewData,
    };

    dispatch(fetchSaveBuildPagesOptions(passData)).then(() => {
      getBuildPage();
    });
  };

  const getBuildPages = () => {
    dispatch(fetchGetBuildPagesDetails()).then((data) => {
      showSuccessErrorToast(true, data?.message);
      getBuildPage();
    });
  };

  const getBuildPage = () => {
    dispatch(fetchGetBuildPagesOptions()).then((data) => {
      if (data) {
        let newData = {};

        data?.data.map((d) => {
          Object.values(d).map((p) => {
            newData = {
              ...newData,
              [p.level]: {
                blockSizeID: p.blockSizeID ? p.blockSizeID : 0,
                useExistingBlock: p.useExistingBlock || 0,
                useExistingBlockPositions: p.useExistingBlockPositions || 0,
                newPage: p.newPage || 0,
                level: p.level,
              },
            };
          });
        });

        // // setBlockSize(newData);
        setBlockSize(newData);
      }
    });
  };

  const getErrorFlag = (error) => !!error && !!isSubmitLayout;
  const getErrorFlagPage = (error) => !!error && !!isSubmitPage;

  const showError = (error) => {
    if (getErrorFlag(error)) {
      return (
        <div className="text-danger input-feedback font12 mt-2">{error}</div>
      );
    }
    return null;
  };
  const showErrorPage = (error) => {
    if (getErrorFlagPage(error)) {
      return (
        <div className="text-danger input-feedback font12 mt-2">{error}</div>
      );
    }
    return null;
  };

  if (
    getPageOptionsLoading ||
    getLayoutOptionsLoading ||
    getBuildPagesOptionLoading ||
    saveBuildPagesOptionsLoading ||
    getCategoryMergeLevelLoading ||
    getBuildPageDetailsLoading
  ) {
    return <Loader />;
  }

  const categoryLevelBlockSize =
    getCategoryMergeLevel &&
    getBlockSizeOption &&
    getCategoryMergeLevel.map((d) => {
      return {
        catName: d,
        defaultBlockSizeOption: getBlockSizeOption || [],
        startOnNewPage: false,
      };
    });

  const handleBlockSize = (catName, sizeId) => {
    const saveData = {
      ...blockSizes,
      [catName]: {
        ...blockSizes?.[catName],
        blockSizeID: sizeId,
      },
    };
    console.log("🚀 ~ handleBlockSize ~ saveData:", saveData);
    setBlockSize({
      ...blockSizes,
      [catName]: {
        ...blockSizes?.[catName],
        blockSizeID: sizeId,
      },
    });
  };

  const handleUseExistingBlocks = (catName, check) => {
    const newData = {
      ...blockSizes,
      [catName]: {
        ...blockSizes?.[catName],
        useExistingBlock: check ? 1 : 0,
      },
    };
    setBlockSize({
      ...blockSizes,
      [catName]: {
        ...blockSizes?.[catName],
        useExistingBlock: check ? 1 : 0,
      },
    });
  };

  const handleUseExistingBlockPositions = (catName, check) => {
    const newData = {
      ...blockSizes,
      [catName]: {
        ...blockSizes?.[catName],
        useExistingBlockPositions: check ? 1 : 0,
      },
    };
    setBlockSize({
      ...blockSizes,
      [catName]: {
        ...blockSizes?.[catName],
        useExistingBlockPositions: check ? 1 : 0,
      },
    });
  };

  console.log(blockSizes);
  const handleNewPage = (catName, check) => {
    setBlockSize({
      ...blockSizes,
      [catName]: {
        ...blockSizes?.[catName],
        newPage: check ? 1 : 0,
      },
    });
  };
  console.log("🚀 ~ BuildPages ~ getBlockSizeOption:", getBlockSizeOption);

  return (
    <div className="bg-white common-space output-create-file-section">
      <div className="row">
        <div className="col-12">
          <Container className="mt-3">
            <p className="mb-5">
              {`Catalog pages have not yet been built for your catalog. Clicking the
            "Check setup" button below will check that you catalog/categories
            have been setup correctly prior to building wireframes. Clicking the
            "Build" button below will build wireframe catalog pages for all of
            your content. Depending on the number of products and your selected
            page layouts this process may take up to a minute.`}
            </p>
            <Row className="mb-4" key="first">
              <Col sm="3">
                <h6 className="text-left">Category Level</h6>
              </Col>
              <Col sm="3">
                <Label check className="mr-3 ml-3">
                  <h6 className="text-left">Default Block Size</h6>
                </Label>
              </Col>
              <Col sm="2">
                <Label check className="mr-3 ml-3">
                  <h6 className="text-left">Use Existing Block Sizes</h6>
                </Label>
              </Col>
              <Col sm="2">
                <Label check className="mr-3 ml-3">
                  <h6 className="text-left">Use Existing Block Positions</h6>
                </Label>
              </Col>
              <Col sm="2">
                <Label check className="mr-3 ml-3">
                  <h6 className="text-left">Start on new page</h6>
                </Label>
              </Col>
            </Row>
            {categoryLevelBlockSize &&
              categoryLevelBlockSize.map((d, i) => {
                return (
                  <>
                    <Row className="mb-4" key={`${d?.catName}${i}`}>
                      <Col sm="3" className="pt-2">
                        <h6 className="text-left">{d?.catName} </h6>
                      </Col>
                      <Col sm="3">
                        <Input
                          type="select"
                          name="sections"
                          isFirstOption={true}
                          isLower={true}
                          isSearchable={true}
                          options={d?.defaultBlockSizeOption}
                          selected={blockSizes?.[d?.catName]?.blockSizeID}
                          value={blockSizes?.[d?.catName]?.blockSizeID}
                          onChange={(e) => {
                            handleBlockSize(
                              d?.catName,
                              parseInt(e.target.value)
                            );
                          }}
                        >
                          {
                            <option disabled={false} value={0}>
                              N/A
                            </option>
                          }
                          {isValidArray(d?.defaultBlockSizeOption) &&
                            d?.defaultBlockSizeOption.map((item, i) => {
                              return (
                                <option key={i} value={item?.BlockSizeID}>
                                  {item?.BlockSizeName}
                                </option>
                              );
                            })}
                        </Input>
                      </Col>
                      <Col sm="2">
                        <Input
                          type="checkbox"
                          name={blockSizes?.[d?.catName]}
                          checked={
                            blockSizes?.[d?.catName]?.useExistingBlock === 1
                              ? true
                              : false
                          }
                          onChange={() => {
                            handleUseExistingBlocks(
                              d?.catName,
                              blockSizes?.[d?.catName]?.useExistingBlock === 1
                                ? 0
                                : 1
                            );
                          }}
                          style={{ marginLeft: "20%" }}
                        />
                      </Col>
                      <Col sm="2">
                        <Input
                          type="checkbox"
                          name={blockSizes?.[d?.catName]}
                          checked={
                            blockSizes?.[d?.catName]?.useExistingBlockPositions === 1
                              ? true
                              : false
                          }
                          onChange={() => {
                            handleUseExistingBlockPositions(
                              d?.catName,
                              blockSizes?.[d?.catName]?.useExistingBlockPositions === 1
                                ? 0
                                : 1
                            );
                          }}
                          style={{ marginLeft: "20%" }}
                        />
                      </Col>
                      <Col sm="2">
                        <Input
                          type="checkbox"
                          name={blockSizes?.[d?.catName]}
                          checked={
                            blockSizes?.[d?.catName]?.newPage === 1
                              ? true
                              : false
                          }
                          onChange={() => {
                            handleNewPage(
                              d?.catName,
                              blockSizes?.[d?.catName]?.newPage === 1 ? 0 : 1
                            );
                          }}
                          style={{ marginLeft: "20%" }}
                        />
                      </Col>
                    </Row>
                  </>
                );
              })}
            <Row className="mb-4">
              <Col sm="3" className="pt-2">
                <h6 className="text-left">Panel </h6>
              </Col>
              <Col sm="3">
                <Input
                  type="select"
                  name="sections"
                  isFirstOption={true}
                  isLower={true}
                  isSearchable={true}
                  options={getBlockSizeOption}
                  selected={blockSizes?.["Panel"]?.blockSizeID}
                  value={blockSizes?.["Panel"]?.blockSizeID}
                  onChange={(e) => {
                    handleBlockSize("Panel", parseInt(e.target.value));
                  }}
                >
                  {
                    <option disabled={false} value={0}>
                      N/A
                    </option>
                  }
                  {isValidArray(getBlockSizeOption) &&
                    getBlockSizeOption.map((item, i) => {
                      return (
                        <option key={i} value={item?.BlockSizeID}>
                          {item?.BlockSizeName}
                        </option>
                      );
                    })}
                </Input>
              </Col>
              <Col sm="2">
                <Input
                  type="checkbox"
                  name={"useExistingBlock"}
                  checked={
                    blockSizes?.["Panel"]?.useExistingBlock === 1 ? true : false
                  }
                  onChange={() => {
                    handleUseExistingBlocks(
                      "Panel",
                      blockSizes?.["Panel"]?.useExistingBlock === 1 ? 0 : 1
                    );
                  }}
                  style={{ marginLeft: "20%" }}
                />
              </Col>
              <Col sm="2">
                <Input
                  type="checkbox"
                  name={"useExistingBlockPositions"}
                  checked={
                    blockSizes?.["Panel"]?.useExistingBlockPositions === 1 ? true : false
                  }
                  onChange={() => {
                    handleUseExistingBlockPositions(
                      "Panel",
                      blockSizes?.["Panel"]?.useExistingBlockPositions === 1 ? 0 : 1
                    );
                  }}
                  style={{ marginLeft: "20%" }}
                />
              </Col>
            </Row>
            <Row className="mb-4">
              {/* <Col sm="4">
                <div className="mt-4" style={{ alignContent: "center" }}>
                  <button
                    type="button"
                    className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                    value="submit_export"
                    name="submit_export"
                    // onClick={() => {
                    //   submitBuildPagesOption();
                    // }}
                    disabled
                  >
                    Check setup
                  </button>
                </div>
              </Col> */}
              <Col sm="4">
                <Label check className="mr-3 ml-3">
                  <div className="mt-4" style={{ alignContent: "center" }}>
                    <button
                      type="button"
                      className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                      value="submit_export"
                      name="submit_export"
                      onClick={() => {
                        getBuildPages();
                      }}
                    // disabled
                    >
                      Build pages
                    </button>
                  </div>
                </Label>
              </Col>
              <Col sm="4">
                <Label check className="mr-3 ml-3">
                  <div className="mt-4" style={{ alignContent: "center" }}>
                    <button
                      type="button"
                      className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                      value="submit_export"
                      name="submit_export"
                      onClick={() => {
                        submitBuildPagesOption();
                      }}
                    >
                      Save
                    </button>
                  </div>
                </Label>
              </Col>
            </Row>
          </Container>
        </div>
      </div>
    </div>
  );
}
