import React, { useEffect, useState } from "react";
import { Input, Label } from "reactstrap";
import { useDispatch, useSelector } from "react-redux";
import { Container, Row, Col } from "reactstrap";
import InputField from "components/Common/InputField";
import { fetchGetUserCatalogDetail } from "redux/actions/output/getUserCatalogDetail";
import { fetchSaveLayoutOptions } from "redux/actions/blockBuilder/saveLayoutOptions";
import { fetchSavePageOptions } from "redux/actions/blockBuilder/savePageOptions";
import { isValidArray, showSuccessErrorToast } from "modules/utils";
import { fetchGetPageOptions } from "redux/actions/blockBuilder/getPageOption";
import { fetchGetLayoutOptions } from "redux/actions/blockBuilder/getLayoutOptions";
import Loader from "components/Common/Loader";
import { fetchGetCategoryMergeLevels } from "redux/actions/blockBuilder/getCategoryMergeLevels";
import { fetchGetDefaultBlockSizeOptions } from "redux/actions/blockBuilder/getDefaultBlockSizeOption";
import { fetchGetBuildPagesOptions } from "redux/actions/blockBuilder/getBuildPagesOptions";
import { fetchSaveBuildPagesOptions } from "redux/actions/blockBuilder/saveBuildPageOptions";
import { fetchGetBuildPagesDetails } from "redux/actions/blockBuilder/getBuildPagesDetails";
import { useCustomHook } from "components/BlockBuilder/tabs/catalogPages/NewCatalogPagesTab.js/CustomHook";
import ReactSwitch from "react-switch";
import { fetchEnablePagePlannerForCatalog } from "redux/actions/manageCatalog/enablePagePlannerForCatalog";
import { fetchDisablePagePlannerForCatalog } from "redux/actions/manageCatalog/disablePagePlannerForCatalog";
import classNames from "classnames";
import { fetchGetAllAttributeSchemaList } from "redux/actions/output/getAllAttributeSchemaList";

const gridOptions = [
  { label: "12", value: "12" },
  { label: "11", value: "11" },
  { label: "10", value: "10" },
  { label: "9", value: "9" },
  { label: "8", value: "8" },
  { label: "7", value: "7" },
  { label: "6", value: "6" },
  { label: "5", value: "5" },
  { label: "4", value: "4" },
  { label: "3", value: "3" },
  { label: "2", value: "2" },
  { label: "1", value: "1" },
];

export default function CatalogOptions() {
  const dispatch = useDispatch();

  useEffect(() => {
    loadMergeLevelAndBlockSize();
    loadPageInitData();
    loadLayoutInitData();
    dispatch(fetchGetUserCatalogDetail());
    loadPageBuilderData();
    dispatch(fetchGetAllAttributeSchemaList());
  }, []);

  const {
    getPageOptionsLoading = false,
    getLayoutOptionsLoading = false,
    getBlockSizeOptionLoading = false,
    getBuildPagesOptionLoading = false,
    saveBuildPagesOptionsLoading = false,
    getCategoryMergeLevelLoading = false,
    enablePlannerLoading = false,
    disablePlannerLoading = false,
    getBlockSizeOption = null,
    getLayoutOptions = null,
    getCategoryMergeLevel = null,
    getAllAttributeSchemaList = null,
  } = useSelector((state) => ({
    getPageOptionsLoading: state.getUserCatalogDetail.loading,
    getAllAttributeSchemaList: state.getAllAttributeSchemaList?.data?.data,
    getLayoutOptionsLoading: state.getUserCatalogDetail.loading,
    getLayoutOptions: state.getLayoutOptions.data?.data,
    getCategoryMergeLevel: state.getCategoryMergeLevels.data?.data,
    getCategoryMergeLevelLoading: state.getCategoryMergeLevels.loading,
    getBlockSizeOptionLoading: state.getDefaultBlockSizeOptions.loading,
    getBuildPagesOptionLoading: state.getBuildPageOptions.loading,
    saveBuildPagesOptionsLoading: state.saveBuildPagesOptions.loading,
    enablePlannerLoading: state.enablePagePlannerForCatalog.loading,
    disablePlannerLoading: state.disablePagePlannerForCatalog.loading,
    getBlockSizeOption: state.getDefaultBlockSizeOptions.data?.data,
  }));
  console.log(
    "🚀 ~ file: CatalogOptions.js:70 ~ CatalogOptions ~ getAllAttributeSchemaList:",
    getAllAttributeSchemaList
  );

  const {
    layoutVariant,
    columnLayoutVariant,
    assembly,
    pageBreak,
    categoryValue,
    pageSizeWidth,
    pageSizeHeight,
    orientation,
    gridWidth,
    gridHeight,
    marginTop,
    marginBottom,
    marginLeft,
    marginRight,
    verticalGutter,
    horizontalGutter,
    layoutError,
    columnError,
    assemblyError,
    pageBreakError,
    pageSizeWidthError,
    pageSizeHeightError,
    orientationError,
    gridWidthError,
    gridHeightError,
    marginLeftError,
    marginRightError,
    marginTopError,
    marginBottomError,
    gutterVerticalError,
    gutterHorizontalError,
    blockSizes,
    setLayoutVariant,
    setColumnLayoutVariant,
    setAssembly,
    setPageBreak,
    setCategoryValue,
    setPageSizeWidth,
    setPageSizeHeight,
    setOrientation,
    setGridWidth,
    setGridHeight,
    setMarginTop,
    setMarginBottom,
    setMarginLeft,
    setMarginRight,
    setVerticalGutter,
    setHorizontalGutter,
    setBlockSize,
  } = useCustomHook();

  const [pageNumberValue, setPageNumberValue] = useState("NotSpecified");
  const [startNumberingValue, setStartNumberingValue] = useState("1");

  const [marginLeftLabel, setMarginLeftLabel] = useState("");
  const [marginRightLabel, setMarginRightLabel] = useState("");

  const [hideCategoryDiv, setHideCategoryDiv] = useState("");
  const [hidePageNumberDiv, setHidePageNumberDiv] = useState("");

  // console.log(
  //   "🚀 ~ file: CatalogOptions.js:133 ~ CatalogOptions ~ gridWidth:",
  //   gridWidth
  // );

  const loadMergeLevelAndBlockSize = () => {
    dispatch(fetchGetCategoryMergeLevels()).then((levels) => {
      dispatch(fetchGetDefaultBlockSizeOptions()).then((data) => {
        if (data?.data) {
          getBuildPage();
          // let newData = {};
          // const blockData =
          //   levels?.data &&
          //   levels?.data.map((d) => {
          //     newData = { ...newData, [d]: { blockSizeID: 0, newPage: 0 } };
          //   });

          // setBlockSize(newData);
        }
      });
    });
  };
  const getBuildPage = () => {
    dispatch(fetchGetBuildPagesOptions()).then((data) => {
      if (data) {
        let newData = {};
        Object.keys(data?.data).map((d) => {
          newData = {
            ...newData,
            [d]: {
              blockSizeID: data?.data?.[d]?.blockSizeID
                ? data?.data?.[d]?.blockSizeID
                : 0,
              newPage: data?.data?.[d]?.newPage || 0,
              level: d,
            },
          };
        });

        // // setBlockSize(newData);
        setBlockSize(newData);
      }
    });
  };

  const loadPageBuilderData = () => {
    dispatch(fetchGetUserCatalogDetail()).then((data) => {
      if (data?.data) {
        setEnablePlanner(data?.data?.VisualDesigner);
      }
    });
  };

  const loadPageInitData = () => {
    dispatch(fetchGetPageOptions()).then((data) => {
      console.log("🚀 ~ file: CatalogOptions.js:188 ~ dispatch ~ data:", data);
      if (data?.data) {
        setMarginTop(data?.data?.topMargin);
        setMarginBottom(data?.data?.bottomMargin);
        setMarginLeft(data?.data?.leftMargin);
        setMarginRight(data?.data?.rightMargin);
        setVerticalGutter(data?.data?.verticalGutter);
        setHorizontalGutter(data?.data?.horizontalGutter);
        setOrientation(data?.data?.schemaID);
        setGridWidth(data?.data?.gridWidth || { label: "12", value: "12" });
        setGridHeight(data?.data?.gridHeight || { label: "12", value: "12" });
        setPageSizeWidth(data?.data?.pageSizeWidth);
        setPageSizeHeight(data?.data?.pageSizeHeight);
      }
    });
  };

  const loadLayoutInitData = () => {
    dispatch(fetchGetLayoutOptions()).then((data) => {
      if (data?.data) {
        setLayoutVariant(data?.data?.layout);
        setColumnLayoutVariant(data?.data?.columnLayout);
        setAssembly(data?.data?.assembly);
        if (data?.data?.assembly == 'Spreads') {
          setMarginLeftLabel("Inner");
          setMarginRightLabel("Outer");
        }
        else {
          setMarginLeftLabel("Left");
          setMarginRightLabel("Right");
        }

        if (data?.data?.pageBreak == 'Category') {
          setHideCategoryDiv("");
          setHidePageNumberDiv("d-none");
        }

        if (data?.data?.pageBreak == 'PageNumber') {
          setHideCategoryDiv("d-none");
          setHidePageNumberDiv("");
        }
        setPageBreak(data?.data?.pageBreak);
        setCategoryValue(data?.data?.section);
        setPageNumberValue(data?.data?.pageNumber);
        setStartNumberingValue(data?.data?.startNumbering);
      }
    });
  };

  const changeLabels = (data) => {
    setAssembly(data);
    if (data == "Spreads") {
      setMarginLeftLabel("Inner");
      setMarginRightLabel("Outer");
    }
    else {
      setMarginLeftLabel("Left");
      setMarginRightLabel("Right");
    }
  };

  const [isSubmitLayout, setSubmitLayout] = useState("");
  const [isSubmitPage, setSubmitPage] = useState("");
  const [enablePlanner, setEnablePlanner] = useState(false);

  const submitLayoutOption = () => {
    setSubmitLayout(isSubmitLayout + 1);
    if (!(layoutError || columnError || assemblyError || pageBreakError)) {
      const passData = {
        layout: layoutVariant,
        columnLayout: columnLayoutVariant,
        assembly: assembly,
        pageBreak: pageBreak,
        category: categoryValue,
        pageNumber: pageNumberValue,
        startNumbering: startNumberingValue
      };
      console.log(passData);

      dispatch(fetchSaveLayoutOptions(passData));
    }
  };
  const submitPageOption = () => {
    setSubmitPage(isSubmitPage + 1);
    if (
      !(
        pageSizeWidthError ||
        pageSizeHeightError ||
        // orientationError ||
        gridWidthError ||
        gridHeightError ||
        marginLeftError ||
        marginRightError ||
        marginTopError ||
        marginBottomError ||
        gutterVerticalError ||
        gutterHorizontalError
      )
    ) {
      const passData = {
        pageSizeWidth: pageSizeWidth,
        pageSizeHeight: pageSizeHeight,
        schemaID: orientation,
        gridWidth: gridWidth,
        gridHeight: gridHeight,
        topMargin: marginTop,
        bottomMargin: marginBottom,
        leftMargin: marginLeft,
        rightMargin: marginRight,
        verticalGutter,
        horizontalGutter,
      };
      console.log(
        "🚀 ~ file: CatalogOptions.js:263 ~ submitPageOption ~ passData:",
        passData
      );

      dispatch(fetchSavePageOptions(passData)).then((d) => {
        loadPageInitData();
      });
    }
  };

  const getErrorFlag = (error) => !!error && !!isSubmitLayout;
  const getErrorFlagPage = (error) => !!error && !!isSubmitPage;

  const showError = (error) => {
    if (getErrorFlag(error)) {
      return (
        <div className="text-danger input-feedback font12 mt-2">{error}</div>
      );
    }
    return null;
  };
  const showErrorPage = (error) => {
    if (getErrorFlagPage(error)) {
      return (
        <div className="text-danger input-feedback font12 mt-2">{error}</div>
      );
    }
    return null;
  };

  const toggleCatalogPlanner = (val) => {
    if (val === true) {
      setEnablePlanner(val);
      dispatch(fetchEnablePagePlannerForCatalog()).then(() => {
        dispatch(fetchGetUserCatalogDetail());
      });
    } else {
      setEnablePlanner(val);
      dispatch(fetchDisablePagePlannerForCatalog()).then(() => {
        dispatch(fetchGetUserCatalogDetail());
      });
    }
  };

  if (
    getPageOptionsLoading ||
    getLayoutOptionsLoading ||
    getBuildPagesOptionLoading ||
    saveBuildPagesOptionsLoading ||
    getCategoryMergeLevelLoading
    // enablePlannerLoading ||
    // disablePlannerLoading
  ) {
    return <Loader />;
  }

  return (
    <div className="bg-white common-space output-create-file-section">
      <div className="row">
        <div className="col-6">
          <Container className=" mt-5">
            <Row className="mb-4">
              <Col sm="6">
                <h6 className="text-left">Enable planner for this catalog </h6>
              </Col>
              <Col
                sm="4"
                onClick={(e) => {
                  setLayoutVariant("Flow");
                }}
              >
                <div className="d-flex align-center">
                  <ReactSwitch
                    className="switch-btn"
                    uncheckedIcon={false}
                    name="displayValue"
                    checkedIcon={false}
                    width={44}
                    height={20}
                    onChange={(e) => toggleCatalogPlanner(e)}
                    checked={enablePlanner}
                  />
                </div>
              </Col>
            </Row>
          </Container>
        </div>
      </div>
      <div
        className={classNames("row", { isDisabled: !enablePlanner })}
        aria-disabled={true}
      >
        <div className="col-6">
          <Container className="cat-log">
            <div className="export-name">
              <h4 className="output-tab-title mb-5 mt-0">
                <strong>Layout Option</strong>
              </h4>
            </div>
            <Row className="mb-4">
              <Col sm="4">
                <h6 className="text-left">Layout </h6>
              </Col>
              <Col
                sm="4"
                onClick={(e) => {
                  setLayoutVariant("Flow");
                }}
              >
                <Input
                  type="radio"
                  name="flow"
                  checked={layoutVariant === "Flow"}
                />
                <Label check className="mr-3 ml-3">
                  Flow
                </Label>
              </Col>
              <Col
                sm="4"
                onClick={(e) => {
                  setLayoutVariant("Grid");
                }}
              >
                <Input
                  type="radio"
                  name="grid"
                  checked={layoutVariant === "Grid"}
                />
                <Label check className="mr-3 ml-3">
                  Grid
                </Label>
              </Col>
              {showError(layoutError)}
            </Row>
            <Row className="mb-4">
              <Col sm="4">
                <h6 className="text-left">Column Layout </h6>
              </Col>
              <Col sm="4" onClick={() => setColumnLayoutVariant("Across")}>
                <Input
                  type="radio"
                  name="across"
                  checked={columnLayoutVariant === "Across"}
                />
                <Label check className="mr-3 ml-3">
                  Across, Down
                </Label>
              </Col>
              <Col sm="4" onClick={() => setColumnLayoutVariant("Down")}>
                <Input
                  type="radio"
                  name="down"
                  checked={columnLayoutVariant === "Down"}
                />
                <Label check className="mr-3 ml-3">
                  Down, Across
                </Label>
              </Col>
              {showError(columnError)}
            </Row>
            <Row className="mb-4">
              <Col sm="4">
                <h6 className="text-left">Assembly </h6>
              </Col>

              <Col sm="4" onClick={() => changeLabels("Spreads")}>
                <Input
                  type="radio"
                  name="spreads"
                  checked={assembly === "Spreads"}
                />
                <Label check className="mr-3 ml-3">
                  Spreads
                </Label>
              </Col>
              <Col sm="4" onClick={() => { setAssembly("SinglePages"); setMarginLeftLabel("Left"); setMarginRightLabel("Right"); }}>
                <Input
                  type="radio"
                  name="singlePages"
                  checked={assembly === "SinglePages"}
                />
                <Label check className="mr-3 ml-3">
                  Single Pages
                </Label>
              </Col>
              {showError(assemblyError)}
            </Row>
            <Row className="mb-4">
              <Col sm="4">
                <h6 className="text-left">Page Breaks </h6>
              </Col>

              <Col sm="4" onClick={() => { setPageBreak("Category"); setHidePageNumberDiv("d-none"); setHideCategoryDiv(""); }}>
                <Input
                  type="radio"
                  name="Category"
                  checked={pageBreak === "Category"}
                />
                <Label check className="mr-3 ml-3">
                  By Category
                </Label>
              </Col>
              <Col sm="4" onClick={() => { setPageBreak("PageNumber"); setHidePageNumberDiv(""); setHideCategoryDiv("d-none"); }}>
                <Input
                  type="radio"
                  name="PageNumber"
                  checked={pageBreak === "PageNumber"}
                />
                <Label check className="mr-3 ml-3">
                  By Page Number
                </Label>
              </Col>
              {showError(pageBreakError)}
            </Row>
            <Row className={"mb-4 " + (hideCategoryDiv)}>
              <Col sm="4">
                <h6 className="text-left">Category </h6>
              </Col>
              <Col sm="6">
                <Input
                  type="select"
                  name="sections"
                  isFirstOption={true}
                  isLower={true}
                  isSearchable={true}
                  options={getCategoryMergeLevel}
                  selected={categoryValue}
                  value={categoryValue}
                  onChange={(e) => {
                    setCategoryValue(e.target.value);
                  }}
                >
                  {<option disabled={true}>Select Option</option>}
                  {isValidArray(getCategoryMergeLevel) &&
                    getCategoryMergeLevel.map((item, i) => {
                      return (
                        <option key={i} value={item}>
                          {item}
                        </option>
                      );
                    })}
                </Input>
              </Col>
            </Row>
            <Row className={"mb-4 " + (hidePageNumberDiv)}>
              <Col sm="4">
                <h6 className="text-left">Page Numbers </h6>
              </Col>
              <Col sm="6">
                <Input
                  type="select"
                  name="pageNumbers"
                  isFirstOption={true}
                  isLower={true}
                  isSearchable={true}
                  options={getCategoryMergeLevel}
                  selected={pageNumberValue}
                  value={pageNumberValue}
                  onChange={(e) => {
                    setPageNumberValue(e.target.value);
                  }}
                >
                  {<option value="NotSpecified">Not Specified</option>}
                  {isValidArray(getCategoryMergeLevel) &&
                    getCategoryMergeLevel.map((item, i) => {
                      return (
                        <option key={i} value={item}>
                          {item}
                        </option>
                      );
                    })}
                </Input>
              </Col>
            </Row>
            <Row className={"mb-4 " + (hideCategoryDiv)}>
              <Col sm="4">
                <h6 className="text-left">Start Numbering </h6>
              </Col>
              <Col sm="6">
                <InputField
                  id="startNumbering"
                  className="layout-single-element"
                  name="startNumbering"
                  type="text"
                  value={startNumberingValue}
                  onChange={(e) => {
                    setStartNumberingValue(e.target.value);
                  }}
                />
              </Col>
            </Row>
            <Row>
              <div
                className="create-file-btn-section"
                style={{ float: "right" }}
              >
                <button
                  type="button"
                  className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                  value="submit_export"
                  name="submit_export"
                  onClick={() => {
                    submitLayoutOption();
                  }}
                >
                  Save
                </button>
              </div>
            </Row>
          </Container>
        </div>

        {/* ///page setup */}

        <div className="col-6">
          <div className="export-name">
            <h4 className="output-tab-title mb-5 mt-0">
              <strong>Page Setup</strong>
            </h4>
          </div>
          <Container className="cat-log">
            <Row>
              <Col sm="6">
                <div className="catalog-layout-setup-box">
                  <div className="catalog-layout-setup-label">Page Size</div>
                  <div
                    className="px-1"
                    style={{
                      display: "flex",
                      flexDirection: "row",
                      marginTop: 10,
                    }}
                  >
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingTop"
                        className="layout-single-element"
                        name="paddingTop"
                        type="text"
                        label={<>Width</>}
                        isLabelRequired={true}
                        value={pageSizeWidth}
                        onChange={(e) => {
                          setPageSizeWidth(e.target.value);
                        }}
                      />
                      {showErrorPage(pageSizeWidthError)}
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingTop"
                        className="layout-single-element"
                        name="paddingTop"
                        type="text"
                        label={<>Height</>}
                        isLabelRequired={true}
                        value={pageSizeHeight}
                        onChange={(e) => {
                          setPageSizeHeight(e.target.value);
                        }}
                      />
                    </div>
                  </div>
                </div>
                <div className="catalog-layout-setup-box">
                  <div className="catalog-layout-setup-label">Grid Size</div>
                  <div
                    className="px-1 row"
                    style={{
                      marginTop: 10,
                    }}
                  >
                    <div className="pr-1 custom-text-light col-6">
                      <Label for="gridWidth" className="form-label">
                        Horizontal
                      </Label>
                      <Input
                        type="select"
                        name="sections"
                        id="gridWidth"
                        isFirstOption={true}
                        isLower={true}
                        isSearchable={true}
                        value={gridWidth}
                        defaultValue={gridWidth}
                        selected={gridWidth}
                        onChange={(e) => {
                          setGridWidth(e.target.value);
                        }}
                      >
                        {isValidArray(gridOptions) &&
                          gridOptions.map((item, i) => {
                            return (
                              <option key={i} value={item.value}>
                                {item.label}
                              </option>
                            );
                          })}
                      </Input>
                      {showErrorPage(gridWidthError)}
                    </div>

                    <div className="pr-1 custom-text-light col-6">
                      <Label for="gridHeight" className="form-label">
                        Vertical
                      </Label>
                      <Input
                        type="select"
                        name="sections"
                        id="gridHeight"
                        isFirstOption={true}
                        isLower={true}
                        isSearchable={true}
                        value={gridHeight}
                        defaultValue={gridHeight}
                        selected={gridHeight}
                        onChange={(e) => {
                          setGridHeight(e.target.value);
                        }}
                      >
                        {isValidArray(gridOptions) &&
                          gridOptions.map((item, i) => {
                            return (
                              <option key={i} value={item.value}>
                                {item.label}
                              </option>
                            );
                          })}
                      </Input>
                      {showErrorPage(gridHeightError)}
                    </div>
                  </div>
                </div>
                <div className="catalog-layout-setup-box">
                  <div className="catalog-layout-setup-label">Schema</div>

                  <Input
                    type="select"
                    name="sections"
                    // isFirstOption={false}
                    isLower={true}
                    isSearchable={true}
                    options={getAllAttributeSchemaList}
                    value={orientation}
                    defaultValue={null}
                    // selected={orientation}
                    onChange={(e) => {
                      setOrientation(e.target.value);
                    }}
                  >
                    <option>Select Schema</option>
                    {isValidArray(getAllAttributeSchemaList) &&
                      getAllAttributeSchemaList.map((item, i) => {
                        return (
                          <option key={i} value={item.CatalogAttributeSchemaID}>
                            {item.CatalogAttributeSchemaName}
                          </option>
                        );
                      })}
                  </Input>

                  {/* {showErrorPage(orientationError)} */}
                </div>
                <div className="catalog-layout-setup-box">
                  <div className="catalog-layout-setup-label">Margins</div>
                  <div
                    className="px-1"
                    style={{
                      display: "flex",
                      flexDirection: "row",
                      marginTop: 10,
                    }}
                  >
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingTop"
                        className="layout-single-element"
                        name="paddingTop"
                        type="text"
                        label={<>Top</>}
                        isLabelRequired={true}
                        value={marginTop}
                        onChange={(e) => {
                          setMarginTop(e.target.value);
                        }}
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingRight"
                        className="layout-single-element"
                        name="paddingRight"
                        type="text"
                        label={marginRightLabel}
                        isLabelRequired={true}
                        value={marginRight}
                        onChange={(e) => {
                          setMarginRight(e.target.value);
                        }}
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingBottom"
                        className="layout-single-element"
                        name="paddingBottom"
                        type="text"
                        label={<>Bottom</>}
                        isLabelRequired={true}
                        value={marginBottom}
                        onChange={(e) => {
                          setMarginBottom(e.target.value);
                        }}
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingLeft"
                        className="layout-single-element"
                        name="paddingLeft"
                        type="text"
                        label={<div className="mr=5">{marginLeftLabel}</div>}
                        isLabelRequired={true}
                        value={marginLeft}
                        onChange={(e) => {
                          setMarginLeft(e.target.value);
                        }}
                      />
                    </div>
                  </div>
                  {showErrorPage(
                    marginTopError ||
                    marginRightError ||
                    marginBottomError ||
                    marginLeftError
                  )}
                </div>
                <div className="catalog-layout-setup-box">
                  <div className="catalog-layout-setup-label">Gutter</div>
                  <div
                    className="px-1"
                    style={{
                      display: "flex",
                      flexDirection: "row",
                      marginTop: 10,
                    }}
                  >
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingTop"
                        className="layout-single-element"
                        name="paddingTop"
                        type="text"
                        label={<>Vertical</>}
                        isLabelRequired={true}
                        value={verticalGutter}
                        onChange={(e) => {
                          setVerticalGutter(e.target.value);
                        }}
                      />
                    </div>
                    <div className="pr-1 custom-text-light">
                      <InputField
                        id="paddingRight"
                        className="layout-single-element"
                        name="paddingRight"
                        type="text"
                        label={<>Horizontal</>}
                        isLabelRequired={true}
                        value={horizontalGutter}
                        onChange={(e) => {
                          setHorizontalGutter(e.target.value);
                        }}
                      />
                    </div>
                  </div>
                  {showErrorPage(gutterVerticalError || gutterHorizontalError)}
                </div>
                <div className="create-file-btn-section">
                  <button
                    type="button"
                    className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                    value="submit_export"
                    name="submit_export"
                    onClick={() => submitPageOption()}
                  >
                    Save
                  </button>
                </div>
              </Col>
            </Row>
          </Container>
        </div>
      </div>
    </div>
  );
}
