import React, { Component } from "react";
import AsyncSelect from "react-select/async";
import { fetchProductNotInCollection } from "redux/actions/manageCatalog/productNotInCollection";
import { connect } from "react-redux";

class ProductSearch extends Component {
  constructor(props) {
    super(props);

    this.state = {
      inputValue: "",
      defaultOptions: [],
      searchValue: "",
      dataIsLoading: false,
    };

    this.getProductNotInCollection = this.getProductNotInCollection.bind(this);
    this.loadOptions = this.loadOptions.bind(this);
    this.handleInputChange = this.handleInputChange.bind(this);
  }

  componentDidMount() {
    if (this.props.catalogId) {
      this.props
        .fetchProductNotInCollection(this.props.catalogId, "")
        .then((data) => {
          this.setState({
            defaultOptions: this.getProductNotInCollection(data?.data),
          });
        });
    }
  }

  getProductNotInCollection(data) {
    return data?.map((item) => ({
      label: item.text,
      value: item.id,
    }));
  }

  loadOptions(inputValue) {
    const { setProductOptionSearchValue } = this.props;
    setProductOptionSearchValue(inputValue);
    return this.props
      .fetchProductNotInCollection(this.props.catalogId, inputValue)
      .then((data) => {
        return this.getProductNotInCollection(data?.data);
      });
  }

  componentDidUpdate = async (prevProps) => {
    if (prevProps.selectedProduct !== this.props.selectedProduct) {
      this.setState({ dataIsLoading: true });
      this.props
        .fetchProductNotInCollection(
          this.props.catalogId,
          this.props.productOptionSearchValue
        )
        .then((data) => {
          this.setState({
            dataIsLoading: false,
            defaultOptions: this.getProductNotInCollection(data?.data),
          });
          this.props.setProductOptionSearchValue(
            this.props.productOptionSearchValue
          );
        });
    }
  };

  handleInputChange(newValue) {
    const { setProductOptionSearchValue } = this.props;
    const inputValue = newValue.replace(/\W/g, "");
    this.setState({ inputValue: newValue, searchValue: newValue });
    setProductOptionSearchValue(newValue);
    return newValue;
  }

  render() {
    const {
      setSelectedProduct,
      selectedProduct,
      productOptionSearchValue,
      setProductOptionSearchValue,
    } = this.props;

    const { inputValue, searchValue, defaultOptions, dataIsLoading } =
      this.state;

    return (
      <AsyncSelect
        cacheOptions
        isLoading={dataIsLoading}
        value={selectedProduct}
        inputValue={productOptionSearchValue}
        defaultOptions={this.state.defaultOptions}
        loadOptions={this.loadOptions}
        onInputChange={this.handleInputChange}
        onChange={(d) => setSelectedProduct(d, productOptionSearchValue)}
        closeMenuOnSelect={false}
        isMulti
      />
    );
  }
}

const mapStateToProps = (state) => {
  return {};
};

const mapDispatchToProps = {
  fetchProductNotInCollection,
};

export default connect(mapStateToProps, mapDispatchToProps)(ProductSearch);
