import SelectDropdownSearchable from "components/Common/SelectDropdownSearchable";
import { isValidArray, isValidUrl, setLocalStorageItem } from "modules/utils";
import React, { useEffect, useRef, useState } from "react";
import { DragDropContext, Draggable, Droppable } from "react-beautiful-dnd";
import { useDispatch, useSelector } from "react-redux";
import { Link } from "react-router-dom";
import ReactTable from "react-table-6";
import {
  Button,
  Card,
  CardBody,
  Col,
  Form,
  Input,
  Label,
  Row,
} from "reactstrap";
import { fetchAddAttributeToCategory } from "redux/actions/manageCatalog/addAttributeToCategory";
import { fetchAddProductToCollection } from "redux/actions/manageCatalog/addProductToCollection";
import { fetchAttributeSetupData } from "redux/actions/manageCatalog/attributeSetupData";
import { fetchCategoryTextData } from "redux/actions/manageCatalog/categoryTextData";
import { fetchGetAttributesNotInCategory } from "redux/actions/manageCatalog/getAttributesNotInCategory";
import { fetchGetCategoryDetails } from "redux/actions/manageCatalog/getCategoryDetails";
import { fetchLinkAttribute } from "redux/actions/manageCatalog/linkAttribute";
import { fetchProductNotInCollection } from "redux/actions/manageCatalog/productNotInCollection";
import { fetchUnlinkParentAttribute } from "redux/actions/manageCatalog/unlinkParentAttribute";
import { fetchUpdateAttributeWidthForCategory } from "redux/actions/manageCatalog/updateAttributeWidthForCategory";
import { fetchAttributeListForSchema } from "redux/actions/output/attributeListForSchema";
import { fetchUpdateCategoryText } from "redux/actions/manageCatalog/updateCategoryText";
import { fetchUpdateProductAttribute } from "redux/actions/manageCatalog/updateProductAttribute";
import ChainIcon2 from "../../../../assets/images/chainIcon.png";
import ChainIcon from "../../../../assets/images/chainicon2.png";
import editIcon from "../../../../assets/images/editicon.png";
import { fetchCategoryProduct } from "../../../../redux/actions/manageCatalog/categoryProducts";
import UnLinkModal from "../categorySetup/tabs/UnLinkModal";
import ShowImageModal from "./ShowImageModal";
import TypeWiseField from "./TypeWiseField";
import ProductSearch from "./ProductSearch";
import { fetchUpdateProductCollectionSortOrder } from "redux/actions/manageCatalog/updateProductCollectionSortOrder";
import CatalogChangeModal from "./CatalogChangeModal";
import { fetchCheckCategoryCatalog } from "redux/actions/manageCatalog/checkCategoryCatalog";
import ProductTextModal from "./ProductTextModal";
import { fetchAddProductFromTextToCollection } from "redux/actions/manageCatalog/addProductFromTextToCollection";
import deleteSelected from "assets/images/delete-selected.png";
import classNames from "classnames";
import Loader from "components/Common/Loader";
import getCategoryStatistics from "redux/reducers/manageCatalog/getCategoryStatistics";
import { fetchGetCategoryStatistics } from "redux/actions/manageCatalog/getCategoryStatistics";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import { Steps } from "intro.js-react";
import "intro.js/introjs.css";
import TextArea from "components/Common/TextArea";
import { Editor } from "@tinymce/tinymce-react";
import { fetchImageLabelList } from "redux/actions/media/imageLabelList";
import InputField from "components/Common/InputField";
import SelectField from "components/Common/SelectField";
import { fetchGetAllAttributeSchemaList } from "redux/actions/output/getAllAttributeSchemaList";
import { fetchUpdateCategoryAttributeSchema } from "redux/actions/manageCatalog/updateCategoryAttributeSchema";
import AddNewAttributeInGridModal from "./AddNewAttributeInGridModal";
import { fetchAddAttributeToSchema } from "redux/actions/output/addAttributeToSchema";
import { Formik } from "formik";
import {
  attributeSchemaListForm,
  displayFormErrors,
} from "modules/validations";
import { fetchAddAttributeSchema } from "redux/actions/masterSetup/addAttributeSchema";
import { fetchUpdateSchemaAttributes } from "redux/actions/output/updateSchemaAttributes";
import { fetchCloneAttributeSchema } from "redux/actions/manageCatalog/cloneAttributeSchema";
import ConfirmationModal from "./ConfirmationModal";
import { fetchDeleteAttributeSchema } from "redux/actions/manageCatalog/deleteAttributeSchema";
import { showSuccessErrorToast } from "modules/utils";

const Products = ({
  catalogId,
  isAddHighlightClass,
  setIsAddHighlightClass,
  loadInitDataTree,
}) => {
  const editorRef = useRef(null);
  const refContainer = useRef(null);
  const [dimensions, setDimensions] = useState({ width: 0, height: 0, schemaToolBarWidth: 0 });
  const [schemaToolBarWidth, setSchemaToolBarWidth] = useState(0);
  const [unlinkModal, setUnlinkModal] = useState(false);
  const [linkModal, setLinkModal] = useState(false);
  const [isDisabled, setDisabled] = useState(false);
  const [items, setItems] = useState([]);
  const [tempItems, setTempItems] = useState([]);
  const [categoryTextItems, setCategoryTextItems] = useState([]);
  const [isEdit, setIsEdit] = useState(false);
  const [productNotInCollection, setProductNotInCollection] = useState([]);
  const [selectedProduct, setSelectedProduct] = useState([]);
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);
  const [productTableHeader, setProductTableHeader] = useState([]);
  const [tableWidth, setTableWidth] = useState([]);
  const [isCollectionButtonShow, setIsCollectionButtonShow] = useState(false);
  const [isRootButtonShow, setIsRootButtonShow] = useState(false);
  const [inheritAttribute, setInheritAttribute] = useState(false);

  const [deleteProductData, setDeleteProductData] = useState([]);
  const [showImageModal, setShowImageModal] = useState(false);
  const [imagePath, setImagePath] = useState("");
  const [missingAttributeData, setMissingAttributeData] = useState([]);
  const [missingAttributeValue, setMissingAttributeValue] = useState([]);
  const [searchProductValue, setSearchProductValue] = useState("");
  const [productWidthArray, setProductWidthArray] = useState({});
  const [showProductTextModal, setShowProductTextModal] = useState(false);
  const [checkBoxVal, setSetCheckBoxVal] = useState(true);
  const [categorySchemaOptions, setCategorySchema] = useState([]);
  const [selectedCategorySchema, setSelectedCategorySchema] = useState("");
  const [showAddAttributeModal, setShowAddAttributeModal] = useState(false);
  const [missingAttribute, setMissingAttribute] = useState([]);
  const [editAttributeWidths, setEditAttributeWidth] = useState();
  const [showConfirmModal, setConfirmModal] = useState();
  const [confirmText, setConfirmText] = useState("");
  const [newAddedAttributeWidth, setNewAddedAttributeWidth] = useState();
  const [newAddedAttributeValue, setNewAddedAttributeValue] = useState();
  const [textAreaVal, setTextAreaVal] = useState(null);

  const [productOptionSearchValue, setProductOptionSearchValue] = useState();
  const dispatch = useDispatch();

  const {
    categoryTextData = null,
    categoryTextLoading = false,
    categoryProductList = false,
    categoryProductLoading = false,
    categoryStatisticsData = null,
    imageLabelList = null,
    categoryProductData,
  } = useSelector((state) => ({
    categoryProductList: state.categoryProducts?.data?.data || null,
    isLoading: state.categoryProducts?.loading || null,
    categoryTextData: state.categoryTextData?.data?.data || null,
    categoryTextLoading: state.categoryTextData?.loading || null,
    attributeSetupData: state.attributeSetupData?.data?.data || null,
    categoryStatisticsData: state.getCategoryStatistics?.data?.data,
    categoryProductLoading: state.categoryProducts?.loading,
    categoryProductData: state.categoryProducts?.data?.data,
    imageLabelList: state.imageLabelList?.data?.data || null,
  }));

  for (var key in categoryProductList) {
    var checkIsCollection = categoryProductList["IsCollection"];
  }

  const getAllCategorySchema = (data, preSelectedId) => {
    const single = data.map((item) => {
      return {
        value: item?.CatalogAttributeSchemaID,
        label: item?.CatalogAttributeSchemaName,
      };
    });
    const options = [{ label: "Select Schema", value: "" }, ...single];
    setCategorySchema(options);
  };

  const handleAddAttributeModal = () => {
    setShowAddAttributeModal(!showAddAttributeModal);
  };

  const handleUnlinkModal = () => {
    setIsAddHighlightClass(!isAddHighlightClass);
    setUnlinkModal(!unlinkModal);
    getCategoryListDetails();
  };

  const handleLinkModal = () => {
    setIsAddHighlightClass(!isAddHighlightClass);

    setLinkModal(!linkModal);
    getCategoryListDetails();
  };

  const handleConfirmModal = () => {
    setConfirmModal(!showConfirmModal);
  };

  const handleAddNewAttribute = () => {
    const formData = {
      CatalogAttributeSchemaID: selectedCategorySchema,
      data: [
        {
          name: parseInt(newAddedAttributeValue),
          value: newAddedAttributeWidth,
        },
      ],
    };
    dispatch(fetchAddAttributeToSchema(formData)).then((res) => {
      handleAddAttributeModal();
      loadInitData();
    });
  };

  const handleUnlink = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchUnlinkParentAttribute(formData)).then(() => {
      setIsAddHighlightClass(false);
      handleUnlinkModal();
    });
  };

  const handleLink = () => {
    const formData = {
      CategoryID: String(catalogId),
    };
    dispatch(fetchLinkAttribute(formData)).then(() => {
      handleLinkModal();
      setIsAddHighlightClass(false);
    });
  };
  const handleShowImageModal = () => {
    setIsAddHighlightClass(!isAddHighlightClass);
    setShowImageModal(!showImageModal);
  };

  const handleAddProductData = () => {
    const productArray = textAreaVal.split("\n");

    const passData = {
      Products: productArray,
      CategoryID: catalogId,
      insertProductIfNotExisting: checkBoxVal,
    };
    dispatch(fetchAddProductFromTextToCollection(passData)).then((data) => {
      if (data?.data) {
        setTextAreaVal(null);
        handleProductTextModal();
        // loadInitDataTree();
        loadInitData();
      }
    });
  };

  const onExit = () => {
    setStepsEnabled(false);
  };

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = d.elementIDName;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  const loadInitData = () => {
    // alert(1);
    dispatch(fetchImageLabelList());
    dispatch(fetchCategoryProduct(catalogId)).then((data) => {
      const result = getProductList(data?.data);
      if (result) {
        setItems(result);
        setTableWidth(data?.data?.columnAttributesTotal);
        dispatch(fetchAttributeSetupData(catalogId)).then((setupData) => {
          dispatch(fetchGetAllAttributeSchemaList()).then((res) => {
            getAllCategorySchema(res?.data);
            // const schemaName = res?.data.filter((d) => {
            //   return d?.CatalogAttributeSchemaID === setupData?.data?.SchemaID;
            // });

            setSelectedCategorySchema(setupData?.data?.SchemaID);
          });
          // dispatch(fetchAttributeListForSchema(setupData?.data?.SchemaID)).then(
          //   (data) => {
          //     const options = data?.data?.map((item) => {
          //       return {
          //         label: item.AttributeName,
          //         value: item.AttributeID,
          //       };
          //     });
          //     const single = [
          //       { label: "Add attribute", value: "" },
          //       ...options,
          //     ];
          //     setMissingAttribute(single);
          //   }
          // );
          dispatch(fetchCategoryTextData(catalogId)).then((data) => {
            const result = data?.data?.map((item) => {
              return {
                Id: item.CategoryTextID,
                TextBlockName: item.TextBlockName,
                Value: item.Value,
                AllowHTML: item?.AllowHTML,
              };
            });
            setCategoryTextItems(result);
            dispatch(fetchProductNotInCollection(catalogId, "")).then(
              (data) => {
                getProductNotInCollection(data?.data);
              }
            );
          });
        });


        if (refContainer.current) {
          setDimensions({
            width: refContainer.current.offsetWidth,
            height: refContainer.current.offsetHeight
          });
          setSchemaToolBarWidth(refContainer.current.offsetWidth - 175)
        }
        
      } else {
        setItems(null);
        dispatch(fetchGetCategoryStatistics(catalogId)).then((data) => {
          dispatch(fetchCategoryTextData(catalogId)).then((data) => {
            const result = data?.data?.map((item) => {
              return {
                Id: item.CategoryTextID,
                TextBlockName: item.TextBlockName,
                Value: item.Value,
              };
            });
            setCategoryTextItems(result);
            dispatch(fetchProductNotInCollection(catalogId, "")).then(
              (data) => {
                getProductNotInCollection(data?.data);
              }
            );
          });
        });
      }
    });
    sleep(1000);
    getCategoryListDetails();
    dispatch(fetchGetAttributesNotInCategory(catalogId)).then((data) => {
      const single = data?.data?.map((item) => {
        return {
          label: item.AttributeDisplayName,
          value: item.AttributeID,
        };
      });
      setMissingAttributeData(single);
    });
  };
  useEffect(() => {
    loadInitData();
  }, [catalogId]);

  // useEffect(() => {
  //   const handleResize = () => {
  //     // Step 5: Update the width state variable
  //     if (refContainer.current) {
  //       setDimensions({
  //         width: refContainer.current.clientWidth,
  //         height: refContainer.current.clientHeight,
  //       });
  //     }
  //   };

  //   // Attach the event listener when the component mounts
  //   window.addEventListener("resize", handleResize);

  //   // Clean up the event listener when the component unmounts
  //   return () => {
  //     window.removeEventListener("resize", handleResize);
  //   };
  // }, []);

  useEffect(() => {
    if (searchProductValue) {
      dispatch(fetchProductNotInCollection(catalogId, searchProductValue)).then(
        (data) => {
          getProductNotInCollection(data?.data);
        }
      );
    }
  }, [searchProductValue]);
  const updateCategorySchema = (id) => {
    const formData = {
      CategoryID: parseInt(catalogId),
      AttributeSchemaID: id,
    };
    dispatch(fetchUpdateCategoryAttributeSchema(formData)).then((res) => {
      if (res) {
        loadInitData();
      }
    });
  };
  const getCategoryListDetails = () => {
    dispatch(fetchGetCategoryDetails(catalogId)).then((data) => {
      setIsCollectionButtonShow(data?.data?.IsCollection ? true : false);
      setIsRootButtonShow(data?.data?.IsRoot ? false : true);
      setInheritAttribute(Number(data?.data?.InheritAttribute) ? true : false);
    });
  };
  const updateCategoryWidth = (attributeId, width, columnName) => {
    const formData = new FormData();
    formData.append("CategoryID", catalogId);
    formData.append("AttributeID", attributeId);
    formData.append("Width", width);

    dispatch(fetchUpdateAttributeWidthForCategory(formData)).then(() => {
      editHeaderWidth(columnName);
    });
  };
  const editHeaderWidth = (columnName) => {
    const updateHeader = productTableHeader?.map((item) => {
      if (item.FullColumnName === columnName) {
        return {
          ...item,
          isEdit: item?.isEdit ? false : true,
        };
      }
      return item;
    });
    setProductTableHeader(updateHeader);
  };

  const getProductList = (data) => {
    let uniqueProductHeader = [
      ...new Map(
        data?.header?.map((item) => {
          return [item["Name"], { ...item, isEdit: false }];
        })
      ).values(),
    ];

    setTableWidth(data?.columnAttributesTotal);
    setProductTableHeader(uniqueProductHeader);
    if (isValidArray(uniqueProductHeader)) {
      let widthObject = {};
      uniqueProductHeader.map((header) => {
        widthObject = {
          ...widthObject,
          [header.FullColumnName]: header.ColumnWidth,
        };
      });
      setProductWidthArray(widthObject);
    }
    let rowData = data?.rowData;

    if (isValidArray(rowData)) {
      const value = Object.values(rowData).map((key) => {
        let data = {
          ProductId: key?.ProductID,
          Sort: key?.Sort,
          ProductCode: key?.ProductyProductCode,
        };

        let updatedObj = key;
        delete updatedObj.ProductID;
        delete updatedObj.Sort;
        delete updatedObj.ProductyProductCode;

        let categoryProduct = Object.values(updatedObj);
        return {
          ...data,
          categoryProduct: categoryProduct,
        };
      });
      return value;
    }
  };

  const getProductNotInCollection = (data) => {
    const value = data?.map((item) => {
      return {
        label: item.text,
        value: item.id,
      };
    });
    setProductNotInCollection(value);
  };

  const onDragEnd = (e) => {
    if (!e.destination) {
      return;
    }
    const sorted = reorder(items, e.source.index, e.destination.index);
    setItems(sorted);
    var formData = new FormData();
    let arrItems = [];

    sorted.map((d) => {
      arrItems = [...arrItems, String(d.ProductId)];
    });

    formData.append("CategoryID", catalogId);
    formData.append(`productsArray`, arrItems);

    dispatch(fetchUpdateProductCollectionSortOrder(formData)).then(() => {
      dispatch(fetchCategoryProduct(catalogId)).then((data) => {
        console.log("🚀 ~ file: Products.js:468 ~ dispatch ~ data:", data);
        const result = getProductList(data?.data);
        setItems(result);
      });
    });
  };

  const reorder = (list, startIndex, endIndex) => {
    const result = Array.from(list);
    const [removed] = result.splice(startIndex, 1);
    result.splice(endIndex, 0, removed);

    return result;
  };
  let selectedLabelId = [];
  const selectedLabels = items?.map((item) => {
    return item?.categoryProduct?.map((categoryData) => {
      return categoryData?.fieldData?.map((d) => {
        return d?.multiImages?.map((label) => {
          return (selectedLabelId = [...selectedLabelId, label?.ImageLabel]);
        });
      });
    });
  });

  const handleChange = (id, columnname, value, fieldName = "", singleImage) => {
    const updated = items.map((d) => {
      if (d.ProductId == id) {
        if (columnname === "sortId") {
          return {
            ...d,
            Sort: {
              ...d.Sort,
              fieldData: d.Sort.fieldData.map((fieldSort) => {
                return {
                  ...fieldSort,
                  value: value,
                };
              }),
            },
          };
        }
        if (columnname === "a_multiimage") {
          return {
            ...d,
            categoryProduct: d?.categoryProduct.map((j) => {
              if (j.FullColumnName === columnname) {
                return {
                  ...j,
                  fieldData: j.fieldData.map((fieldArr) => {
                    // const images =

                    if (fieldArr.name == fieldName) {
                      return {
                        ...fieldArr,
                        multiImages: fieldArr.multiImages.map((image) => {
                          return {
                            ...image,
                            ImageLabel:
                              image?.ImagePath === singleImage
                                ? parseInt(value)
                                : image?.ImageLabel,
                          };
                        }),
                        value: fieldArr.multiImages.map((image) => {
                          return {
                            ...image,
                            ImageLabel:
                              image?.ImagePath === singleImage
                                ? parseInt(value)
                                : image?.ImageLabel,
                          };
                        }),
                      };
                    }
                    return fieldArr;
                  }),
                };
              }
              return j;
            }),
          };
        }
        return {
          ...d,
          categoryProduct: d?.categoryProduct.map((j) => {
            if (j.FullColumnName === columnname) {
              return {
                ...j,
                fieldData: j.fieldData.map((fieldArr) => {
                  if (fieldArr.name == fieldName) {
                    return {
                      ...fieldArr,
                      value: value,
                    };
                  }
                  return fieldArr;
                }),
              };
            }
            return j;
          }),
        };
      }
      return d;
    });

    setItems(updated);
  };

  // handleDropDown

  const handleSave = () => {
    let categoryArr = [];
    let saveCategoryProduct = items.map((item) => {
      item.Sort.fieldData.map((fieldData) => {
        categoryArr = [
          ...categoryArr,
          {
            name: fieldData?.name,
            value: fieldData?.value,
          },
        ];
      });
      item.categoryProduct.map((categoryData) => {
        categoryData?.fieldData?.map((fieldData) => {
          if (isValidArray(fieldData?.value)) {
            if (categoryData?.IsMultiImage) {
              categoryArr = [
                ...categoryArr,
                {
                  name: fieldData?.name,
                  value: fieldData?.value,
                },
              ];
            } else {
              let fieldDataValue = [];
              fieldData?.value?.map((fieldDataVal) => {
                fieldDataValue = [...fieldDataValue, fieldDataVal?.value];
              });
              categoryArr = [
                ...categoryArr,
                {
                  name: fieldData?.name,
                  value: isValidArray(fieldDataValue)
                    ? fieldDataValue.toString()
                    : [],
                },
              ];
            }
          } else {
            categoryArr = [
              ...categoryArr,
              {
                name: fieldData?.name,
                value: fieldData?.value,
              },
            ];
          }
        });
      });
    });
    let formData = {
      data: categoryArr,
      CategoryID: catalogId,
      productInstanceIdArray: deleteProductData,
    };

    dispatch(fetchUpdateProductAttribute(formData)).then(() => {
      dispatch(fetchCategoryProduct(catalogId)).then((data) => {
        console.log("🚀 ~ file: Products.js:638 ~ dispatch ~ data:", data);
        const result = getProductList(data?.data);
        setItems(result);
        setIsEdit(false);
      });
    });
  };

  const handleSaveCategoryText = () => {
    var formData = new FormData();
    categoryTextItems.map((d, i) => {
      formData.append(`data[${i}][name]`, d.Id);
      formData.append(`data[${i}][value]`, d.Value);
    });
    dispatch(fetchUpdateCategoryText(formData)).then(() => {
      setDisabled(false);
    });
  };
  const deleteCategory = (productId) => {
    let deleteCategoryProduct = deleteProductData.find(
      (d1) => d1 === productId
    );
    let updateArray = deleteProductData;
    if (deleteCategoryProduct) {
      updateArray = updateArray.filter((d) => d != productId);

      setDeleteProductData(updateArray);
    } else {
      updateArray = [...updateArray, productId];

      setDeleteProductData(updateArray);
    }
  };
  const textAttr = (id) => {
    return categoryTextData.find((d) => {
      return d?.CategoryTextID === id;
    });
  };

  const ReactTableColumns = [
    {
      Header: "Text Block Name",
      id: "TextBlockName",
      accessor: "TextBlockName",
      style: { height: "auto" },
    },
    {
      Header: "Content",
      id: "Value",
      accessor: (d) => {
        const htmlString = d?.Value;
        var sanitizedString = "";
        if (htmlString !== null) {
          sanitizedString = htmlString.replace(/<[^>]*>/g, ""); // Remove all HTML tags
        }

        // return <div>{sanitizedString}</div>;
        return isDisabled
          ? renderEditable(d?.Value || "", d.Id, d)
          : sanitizedString;
      },
      style: { height: "auto" },
    },
  ];

  const TypeBaseField = ({ value, id, handleChange }) => {
    const attrData = textAttr(id);

    return (
      <>
        {attrData?.AllowHTML ? (
          <>
            <Editor
              key={id}
              onEditorChange={(e) => {
                handleChange(e, id);
              }}
              onInit={(evt, editor) => (editorRef.current = editor)}
              value={value}
              init={{
                height: 500,
                browser_spellcheck: true,
                contextmenu: false,
                plugins: [
                  "advlist autolink lists link image charmap print preview anchor",
                  "searchreplace visualblocks code fullscreen",
                  "insertdatetime media table paste code help wordcount",
                ],
                toolbar:
                  "undo redo | formatselect | " +
                  "bold italic backcolor | alignleft aligncenter " +
                  "alignright alignjustify | bullist numlist outdent indent | " +
                  "removeformat | help",
                content_style:
                  "body { font-family:Helvetica,Arial,sans-serif; font-size:14px }",
                menubar: "file edit view insert format tools table",
              }}
            />
          </>
        ) : (
          <>
            {attrData?.MultiLine ? (
              <>
                <TextArea
                  onChange={(e) => {
                    handleChange(e.target.value, id);
                  }}
                  value={value}
                />
              </>
            ) : (
              <>
                <InputField
                  type="text"
                  name="userEmail"
                  onChange={(e) => {
                    handleChange(e.target.value, id);
                  }}
                  value={value}
                />
              </>
            )}
          </>
        )}
      </>
    );
  };
  const renderEditable = (value, id, data) => {
    return TypeBaseField({
      value: value,
      id: id,
      handleChange: getAttributeData,
    });
  };

  const getAttributeData = (value, id) => {
    const updated = categoryTextItems.map((d) => ({
      ...d,
      Value: d.Id === id ? value : d.Value,
    }));
    setCategoryTextItems(updated);
  };

  const showImageInModal = (imagePath) => {
    setImagePath(imagePath);
    handleShowImageModal();
  };

  const sleep = (ms) =>
    new Promise((resolve) => {
      setTimeout(() => {
        resolve();
      }, ms);
    });

  const addProductToCollection = () => {
    var formData = new FormData();
    let productArr = [];
    selectedProduct.map((d) => {
      productArr = [...productArr, d.value];
    });
    formData.append("CategoryID", catalogId);
    formData.append("Products", productArr);
    dispatch(fetchAddProductToCollection(formData)).then(() => {
      setSelectedProduct([]);
      dispatch(fetchCategoryProduct(catalogId)).then((data) => {
        const result = getProductList(data?.data);
        setItems(result);
        dispatch(fetchAttributeSetupData(catalogId));
      });
      // handleLinkModal();
    });
  };

  const handleProductTextModal = () => {
    setShowProductTextModal(!showProductTextModal);
  };

  const addAttributeToCategory = () => {
    var formData = new FormData();
    formData.append("CategoryID", catalogId);
    missingAttributeValue.map((d, i) => {
      formData.append(`data[${i}][name]`, d.value);
      // formData.append(`data[${i}][value]`, d.value);
    });
    dispatch(fetchAddAttributeToCategory(formData)).then(() => {
      setSelectedProduct([]);
      dispatch(fetchCategoryProduct(catalogId)).then(() => {
        setMissingAttributeValue([]);
      });
      // handleLinkModal();
    });
  };

  const updateWidthValue = (value, columnName) => {
    const updatedHeader = productTableHeader.map((item) => {
      if (item.FullColumnName === columnName) {
        return {
          ...item,
          Width: value,
        };
      }
      return item;
    });
    setProductTableHeader(updatedHeader);
  };

  const setSelectedProductOption = (option, searchValue) => {
    setSelectedProduct(option);
    setProductOptionSearchValue(searchValue);
  };

  const handleSubmit = (values) => {
    const result = { CatalogAttributeSchemaName: values.label };

    dispatch(fetchAddAttributeSchema(result)).then(() => {});
  };

  const handleSaveAttributeWidths = () => {
    const schemaName = categorySchemaOptions.find(
      (d) => parseInt(d.value) === selectedCategorySchema
    );
    const formData = new FormData();
    formData.append("schemaID", selectedCategorySchema);
    formData.append("schemaName", schemaName?.label);
    const attributeList = productTableHeader.filter((d) => d?.AttributeID);

    attributeList?.map((item, i) => {
      formData.append(`data[${i}][name]`, String(item.AttributeID));
      formData.append(`data[${i}][value]`, String(item.Width));
    });
    dispatch(fetchUpdateSchemaAttributes(formData)).then((data) => {
      // getAttributeSchemaList();
      setEditAttributeWidth(false);
      loadInitData();
    });
  };

  const handleCloneAttributeSchema = () => {
    dispatch(fetchCloneAttributeSchema(selectedCategorySchema)).then((data) => {
      // handleConfirmModal();
      showSuccessErrorToast(true, data?.message);
    });
  };

  const handleDeleteAttributeSchema = () => {
    dispatch(fetchDeleteAttributeSchema(selectedCategorySchema)).then(
      (data) => {
        handleConfirmModal();
        showSuccessErrorToast(data?.flag, data?.message);
      }
    );
  };

  // const handleSchemaActions = (type) => {
  //   if (type === "delete") {
  //     return handleDeleteAttributeSchema();
  //   } else {
  //     return handleCloneAttributeSchema();
  //   }
  // };
  const cardsArray = [
    {
      name: "Total Categories",
      icon: "fa fa-cube",
      color: "",
      string: "totalCategories",
    },
    {
      name: "Unique Products",
      icon: "fa fa-user",
      color: "",
      string: "uniqueProducts",
    },
    {
      name: "Total Collections",
      icon: "fa fa-book",
      color: "",
      string: "totalCollections",
    },
    {
      name: "Total Products",
      icon: "fa fa-th-list",
      color: "#39b54a",
      string: "totalProducts",
    },
    {
      name: "Products Not in a Collection",
      icon: "fa fa-cube",
      color: "#ffa726",
      string: "productsNotInCollection",
    },
    {
      name: "Empty Collections",
      icon: "fa fa-th-list",
      color: "#ffa726",
      string: "emptyCollections",
    },
  ];

  if (!checkIsCollection) {
    return (
      <>
        {categoryStatisticsData?.importProducts &&
        categoryStatisticsData?.setupCatalogLayoutInfo &&
        categoryStatisticsData?.setupProductAttributes ? (
          <> </>
        ) : (
          <></>
        )}
        <div className="state-card-wrapper">
          <Card id="keyStaticsHome">
            <CardBody>
              <div className="panel-body">
                <div className="row card-row">
                  {/* <div className="col-12" style={{ paddingLeft: "10px" }}>
                    <b>Key Statistics</b>
                  </div> */}
                  {cardsArray.map((d) => {
                    return (
                      <>
                        <div
                          className="col-lg-4 col-md-4 col-sm-4"
                          key={d?.name}
                        >
                          <div className="card card-stats" id="card1">
                            <div className="card-header card-header-success card-header-icon">
                              <div
                                className="card-icon card-grey"
                                style={
                                  d?.color ? { backgroundColor: d?.color } : {}
                                }
                              >
                                <i className={d?.icon}></i>
                              </div>
                              <h3 className="text-secondary">
                                <b>{d?.name}</b>
                              </h3>
                              <h3 className="card-title">
                                {
                                  categoryStatisticsData?.keyStatistics?.[
                                    d?.string
                                  ]
                                }
                              </h3>
                            </div>
                          </div>
                        </div>
                      </>
                    );
                  })}
                </div>
              </div>
            </CardBody>
          </Card>
          {isValidArray(categoryTextData) && (
            <>
              <div
                className="manage-catalog-tbl-section product-tableBorder mt-5"
                id="table-two"
              >
                <div className="row">
                  <div className="col-6">
                    <label className="form-label category-table-title">
                      Category Text
                    </label>
                  </div>
                  <div className="col-6">
                    <div className="right-top-btn-section product-cnacelbtn mt-4">
                      {isDisabled ? (
                        <>
                          <Button onClick={handleSaveCategoryText}>Save</Button>
                          <Button
                            onClick={() => {
                              setDisabled(false);
                            }}
                            className="cancel-btn-red"
                          >
                            Cancel
                          </Button>
                        </>
                      ) : (
                        <Button onClick={() => setDisabled(true)}>Edit</Button>
                      )}
                    </div>
                  </div>
                </div>
                <ReactTable
                  columns={ReactTableColumns}
                  data={[...categoryTextItems]}
                  loading={categoryTextLoading}
                  minRows={0}
                  className="-striped -highlight"
                  showPagination={false}
                  sortable={false}
                  multiSort={false}
                  resizable={true}
                  filterable={false}
                />
              </div>
            </>
          )}
        </div>
      </>
    );
  }

  if (categoryProductLoading) {
    return <Loader />;
  }

  return (
    <>
      <Steps
        enabled={stepsEnabled}
        steps={steps}
        initialStep={initialStep}
        onExit={onExit}
        onComplete={() => setStepsEnabled(false)}
        options={{ doneLabel: "Done" }}
      />
      <div
        className="category-display-template m-4"
        ref={refContainer}
        width={dimensions.width}
      >
        {isCollectionButtonShow && (
          <div className="right-top-btn-section product-add-collection mr-0">
            <div className="row align-items-center">
              <div
                className="col-lg-4 catalog-select-box"
                id="add-product-to-collection"
              >
                <ProductSearch
                  catalogId={catalogId}
                  setSelectedProduct={setSelectedProductOption}
                  selectedProduct={selectedProduct}
                  productOptionSearchValue={productOptionSearchValue}
                  setProductOptionSearchValue={setProductOptionSearchValue}
                />
              </div>
              <div className="col-lg-4 text-align-initial d-flex align-items-flex-start">
                <Button
                  disabled={!isValidArray(selectedProduct)}
                  onClick={addProductToCollection}
                >
                  Add product(s) to collection
                </Button>
                <Button
                  // disabled={!isValidArray(selectedProduct)}
                  onClick={handleProductTextModal}
                >
                  Add product(s) from text
                </Button>
              </div>
              <div className="col-lg-4">
                {isEdit ? (
                  <>
                    <Button onClick={handleSave}>Save</Button>
                    <Button
                      onClick={() => {
                        setIsEdit(false);
                      }}
                      className="cancel-btn-red"
                    >
                      Cancel
                    </Button>
                  </>
                ) : (
                  <Button id="edit-collection" onClick={() => setIsEdit(true)}>
                    Edit Collection
                  </Button>
                )}
              </div>
            </div>
          </div>
        )}
        {/* <div>
          <div
            className="border p-1 float-end mt-1"
            style={{background: "#e5e5e5",
              width: 
                editAttributeWidths ? schemaToolBarWidth + 25 + "px" : schemaToolBarWidth + "px"
            }}
          >
            <div className="align-items-center text-start">
              <div className="d-inline-block mx-1">
                {editAttributeWidths ? (
                  <></>
                ) : (
                  <Button
                    className="primary btn-small confirm-y mb-0"
                    onClick={() => {
                      // getAttributeSchemaList();
                      setEditAttributeWidth(true);
                    }}
                  >
                    Edit{"    "}
                  </Button>
                )}
              </div>
              <div className="d-inline-block mx-1">
                <Label style={{ fontSize: 14 }}>Choose Existing</Label>
              </div>
              <div className="d-inline-block mx-1">
                <SelectField
                  type="select"
                  name="attributeSchemaId"
                  id="attributeSchemaId"
                  //placeholder="Select Organization"
                  options={categorySchemaOptions}
                  onChange={(e) => {
                    setSelectedCategorySchema(e);
                    updateCategorySchema(e);
                  }}
                  value={selectedCategorySchema}
                  isDisabled={editAttributeWidths ? false : true}
                />
              </div>
              <div className="d-inline-block mx-1">
                {editAttributeWidths ? (
                  <>
                    <Button
                      onClick={handleSaveAttributeWidths}
                      className="primary btn-small confirm-y mr-2"
                      style={{ marginRight: "5px" }}
                    >
                      Save
                    </Button>
                    <Button
                      onClick={() => {
                        setEditAttributeWidth(false);
                      }}
                      className="bg-danger border-danger btn-small"
                    >
                      Cancel
                    </Button>
                  </>
                ) : (
                  <></>
                )}
              </div>
              <div className="d-inline-block mx-1">
                <Label style={{ fontSize: 14 }}>OR</Label>
              </div>
              <div className="d-inline-block mx-1">
                <Button
                  className="primary btn-small confirm-y"
                  onClick={() => {
                    // handleConfirmModal();
                    // setConfirmText(
                    //   "Are you sure you want to clone this schema"
                    // );
                    handleCloneAttributeSchema();
                    // getAttributeSchemaList();
                    // setIsEdit(true);
                  }}
                  disabled={editAttributeWidths ? false : true}
                >
                  Clone Existing
                </Button>
              </div>
              <div className="d-inline-block mx-1">
                <Label style={{ fontSize: 14 }}>OR</Label>
              </div>
              <div className="d-inline-block mx-1">
                <Formik
                  initialValues={{
                    label: "",
                  }}
                  validationSchema={attributeSchemaListForm}
                  onSubmit={handleSubmit}
                  enableReinitialize
                >
                  {({
                    values,
                    errors,
                    touched,
                    handleChange,
                    handleBlur,
                    handleSubmit,
                    submitCount,
                    setFieldValue,
                  }) => {
                    const showError = (key) =>
                      displayFormErrors(key, errors, touched, submitCount);

                    return (
                      <Form>
                        <Row className="align-items-center">
                          <Col xs="8">
                            <InputField
                              type="text"
                              name="label"
                              placeholder="Create New Schema"
                              onChange={handleChange}
                              value={values.label || ""}
                              isDisabled={editAttributeWidths ? false : true}
                            />
                            {showError("label")}
                          </Col>
                          <Col xs="4">
                            <Button
                              className="primary btn-small confirm-y"
                              // onClick={handleSubmit}
                              onClick={() => {
                                handleSubmit();
                              }}
                              disabled={editAttributeWidths ? false : true}
                            >
                              Create
                            </Button>
                          </Col>
                        </Row>
                      </Form>
                    );
                  }}
                </Formik>
              </div>
              {isRootButtonShow && inheritAttribute == 1 ? (
                <>
                  <div className="d-inline-block mx-1">
                    <Label style={{ fontSize: 14 }}>Attributes</Label>
                  </div>
                  <div className="d-inline-block mx-1">
                    <Button
                      className="btn-small"
                      onClick={() => {
                        handleUnlinkModal();
                        setIsAddHighlightClass(true);
                      }}
                      disabled={editAttributeWidths ? false : true}
                    >
                      <img src={ChainIcon} />
                    </Button>
                  </div>
                </>
              ) : (
                <>
                  <div className="d-inline-block mx-1">
                    <Label style={{ fontSize: 14 }}>Attributes</Label>
                  </div>
                  <div className="d-inline-block mx-1">
                    <Button
                      className="btn-small"
                      onClick={() => {
                        handleLinkModal();
                        setIsAddHighlightClass(true);
                      }}
                      disabled={editAttributeWidths ? false : true}
                    >
                      <img src={ChainIcon2} />
                    </Button>
                  </div>
                  </>
            )}
            </div>
          </div>
        </div> */}
        {/* <div className="tabcontent w-25" style={{ paddingLeft: 0 }}></div> */}
        {inheritAttribute == 0 && (
          <div className="d-flex align-items-center justify-content-right text-align-right w-100 product-plus-button">
            <div className="col-lg-2 ">
              <SelectDropdownSearchable
                name="selectOrganization"
                options={missingAttributeData}
                handleChange={(itemId) => {
                  setMissingAttributeValue(itemId);
                }}
                isMulti={true}
                value={missingAttributeValue}
              />
            </div>
            <Button
              className="ml-2"
              onClick={addAttributeToCategory}
              disabled={missingAttributeValue.length ? false : true}
            >
              <i className="fa fa-plus"></i>
            </Button>
          </div>
        )}

        <div
          className="tableorganisation2 category-table product-table-setup center-text-tbl table-responsive datatable_box mt-5"
          id="table-one"
          style={{
            minHeight: isValidArray(categoryTextData) ? "fit-content" : "460px",
            overflowX: "auto",
            maxWidth: "100%",
          }}
        >
          <DragDropContext onDragEnd={onDragEnd}>
            <Droppable droppableId="Table">
              {(provided) => (
                <table
                  className=""
                  {...provided.droppableProps}
                  ref={provided.innerRef}
                  border={tableWidth}
                  style={{ tableLayout: "fixed"}}
                >
                  <thead>
                    {isValidArray(productTableHeader) &&
                      productTableHeader.map((item, i) => {
                        let newContainerWidth = 0;
                        if(tableWidth > 100)
                        {
                          newContainerWidth = (dimensions.width * tableWidth) / 100;
                        }
                        else
                        {
                          newContainerWidth = dimensions.width;
                        }
                        //determine width of each item based on window width
                        var newWidth = (item?.Width * (newContainerWidth - 175)) / tableWidth;
                        newWidth = parseFloat(newWidth).toFixed(2);
                        return (
                          <>
                            <th
                              key={i}
                              style={{
                                backgroundColor: item.ColorCode || "#e5e5e5",
                                width: 
                                  item?.Name == "ProductID"
                                  ? "75px"
                                  : item?.Name == "Sort"
                                  ? "40px"
                                  : `${newWidth}px`,
                                wordWrap: "break-word",
                                position: "sticky",
                                top:"0",
                                zIndex: 
                                  item?.Name == "ProductID"
                                  ? "999"
                                  : item?.Name == "Sort"
                                  ? "999"
                                  : "998",
                                left: 
                                  item?.Name == "ProductID"
                                  ? "0"
                                  : item?.Name == "Sort"
                                  ? "75px"
                                  : "",
                              }}
                            >
                              {item?.Name}
                              <br></br>
                              {!(
                                item?.Name == "ProductID" ||
                                item?.Name == "Sort"
                              ) && (
                                <span
                                  className="widthSize"
                                  data-toggle="tooltip"
                                  data-placement="top"
                                  title="Width: 100"
                                >
                                  <input
                                    type="text"
                                    disabled={
                                      editAttributeWidths ? false : true
                                    }
                                    size="1"
                                    value={item?.Width}
                                    onChange={(e) =>
                                      updateWidthValue(
                                        e.target.value,
                                        item?.FullColumnName
                                      )
                                    }
                                  />
                                  {/* <Button
                                    className={`editicon-btn ${
                                      item?.isEdit
                                        ? "orange-edit-btn"
                                        : "green-edit-btn"
                                    }`}
                                    onClick={() =>
                                      item?.editAttributeWidths
                                        ? updateCategoryWidth(
                                            item?.AttributeID,
                                            item?.Width,
                                            item?.FullColumnName
                                          )
                                        : editHeaderWidth(item?.FullColumnName)
                                    }
                                  >
                                    <img src={editIcon} />
                                  </Button> */}
                                </span>
                              )}
                            </th>
                            {i === 1 && isValidArray(items?.[0]?.categoryProduct) && (
                              <th
                                style={{
                                  width: "60px",
                                  backgroundColor: "#FFF",
                                  wordWrap: "break-word",
                                  left: "115px",
                                  top: "0",
                                  zIndex: "999",
                                  position: "sticky"
                                }}
                              >
                                Actions
                              </th>
                            )}
                          </>
                        );
                      })}
                    {editAttributeWidths ? (
                      <th
                        style={{
                          width: "25px",
                          backgroundColor: "#e5e5e5"
                        }}
                        className="text-center"
                      >
                        <a
                          href="javascript:void(0)"
                          className="text-dark"
                          onClick={() => {
                            handleAddAttributeModal();
                          }}
                        >
                          <i className="fa-regular fa-plus"></i>
                        </a>
                      </th>
                    ) : (
                      <></>
                    )}
                  </thead>
                  <tbody>
                    {isValidArray(items) ? (
                      items.map((catItems, index) => {
                        return (
                          <>
                            <Draggable
                              key={catItems.ProductId}
                              draggableId={String(catItems.ProductId)}
                              index={index}
                              isDragDisabled={isEdit}
                            >
                              {(provided) => (
                                <tr
                                  key={index}
                                  ref={provided.innerRef}
                                  {...provided.draggableProps}
                                  {...provided.dragHandleProps}
                                >
                                  <td className="position-sticky" style={{left: 0, zIndex: 997, backgroundColor: "#FFF", border: "border: 1px solid #ddd"}}>{catItems.ProductId}</td>
                                  <td className="position-sticky" style={{left: 75, zIndex: 997, backgroundColor: "#FFF", border: "border: 1px solid #ddd"}}>
                                    {isEdit ? (
                                      <Input
                                        style={{
                                          width: "100%",
                                          borderColor: "black",
                                          borderWidth: 1,
                                          marginBottom: 20,
                                        }}
                                        type="text"
                                        value={
                                          catItems?.Sort?.fieldData[0].value
                                        }
                                        onChange={(e) => {
                                          handleChange(
                                            catItems?.ProductId,
                                            "sortId",
                                            e.target.value
                                          );
                                        }}
                                      />
                                    ) : (
                                      catItems?.Sort?.fieldData[0]?.value
                                    )}
                                  </td>

                                  {isValidArray(catItems?.categoryProduct) &&
                                    catItems?.categoryProduct.map(
                                      (categoryItems, i) => {
                                        return (
                                          <>
                                            {i === 0 && (
                                              <td className="position-sticky" style={{left: 115, zIndex: 997, backgroundColor: "#FFF", border: "border: 1px solid #ddd"}}>
                                                {
                                                  <>
                                                    <Button
                                                      className="editicon-btn"
                                                    >
                                                      <Link
                                                        to={{
                                                          pathname: `/Product/${catItems.ProductCode}`,
                                                          search: `?pid=${catItems?.ProductId}`,
                                                        }}
                                                        target="_blank"
                                                      >
                                                        <img src={editIcon} />
                                                      </Link>
                                                    </Button>
                                                    {isEdit && (
                                                      <Button
                                                        className={classNames(
                                                          "editicon-btn icon-center ",
                                                          {
                                                            "color-orange":
                                                              deleteProductData.includes(
                                                                catItems?.ProductId
                                                              ),
                                                          }
                                                        )}
                                                        style={{
                                                          marginLeft: "4px",
                                                          backgroundColor:
                                                            "red",
                                                        }}
                                                        onClick={() => {
                                                          deleteCategory(
                                                            catItems?.ProductId
                                                          );
                                                        }}
                                                      >
                                                        {deleteProductData.includes(
                                                          catItems?.ProductId
                                                        ) ? (
                                                          <>
                                                            <i
                                                              className="fa fa-undo cc undo-icon"
                                                              style={{
                                                                color: "black",
                                                              }}
                                                            ></i>
                                                          </>
                                                        ) : (
                                                          <>
                                                            <i
                                                              className="fa fa-times fa-lg dlt-icon"
                                                              style={{
                                                                color: "black",
                                                              }}
                                                            ></i>
                                                          </>
                                                        )}
                                                        {/* <img src={deleteSelected} /> */}
                                                      </Button>
                                                    )}
                                                  </>
                                                }
                                              </td>
                                            )}
                                            <td>
                                              {isValidArray(
                                                categoryItems?.fieldData
                                              ) &&
                                                categoryItems?.fieldData.map(
                                                  (valueItemArr) => {
                                                    return (
                                                      <>
                                                        {isEdit &&
                                                        valueItemArr?.editable !==
                                                          "0" ? (
                                                          <div
                                                            className={
                                                              valueItemArr?.divClass
                                                                ? valueItemArr?.divClass
                                                                : ""
                                                            }
                                                            // style={{
                                                            //   width: `${categoryItems?.ColumnWidth}px`,
                                                            // }}
                                                          >
                                                            <TypeWiseField
                                                              style={{
                                                                width: "100%",
                                                                borderColor:
                                                                  "black",
                                                                borderWidth: 1,
                                                                marginBottom: 20,
                                                                display:
                                                                  categoryItems?.IsMultiImage &&
                                                                  "none",
                                                              }}
                                                              readOnly={false}
                                                              fieldType={
                                                                categoryItems?.datatype
                                                              }
                                                              isTextArea={
                                                                categoryItems?.isTextArea
                                                              }
                                                              handleChange={
                                                                handleChange
                                                              }
                                                              categoryItems={
                                                                valueItemArr
                                                              }
                                                              columnName={
                                                                categoryItems?.FullColumnName
                                                              }
                                                              productId={
                                                                catItems?.ProductId
                                                              }
                                                              options={
                                                                categoryItems?.datatype ===
                                                                  "enum" ||
                                                                categoryItems?.datatype ===
                                                                  "set"
                                                                  ? categoryItems?.setvalues
                                                                  : []
                                                              }
                                                            />
                                                          </div>
                                                        ) : (
                                                          <div className="product-cat-input">
                                                            <TypeWiseField
                                                              style={{
                                                                width: "100%",
                                                                marginBottom: 20,
                                                                border: "none",
                                                                background:
                                                                  "none transparent",
                                                                display:
                                                                  categoryItems?.IsMultiImage &&
                                                                  "none",
                                                              }}
                                                              readOnly={true}
                                                              fieldType={
                                                                categoryItems?.datatype
                                                              }
                                                              isTextArea={
                                                                categoryItems?.isTextArea
                                                              }
                                                              handleChange={
                                                                handleChange
                                                              }
                                                              categoryItems={
                                                                valueItemArr
                                                              }
                                                              columnName={
                                                                categoryItems?.FullColumnName
                                                              }
                                                              productId={
                                                                catItems?.ProductId
                                                              }
                                                              options={
                                                                categoryItems?.datatype ===
                                                                  "enum" ||
                                                                categoryItems?.datatype ===
                                                                  "set"
                                                                  ? categoryItems?.setvalues
                                                                  : []
                                                              }
                                                            />
                                                          </div>
                                                        )}
                                                        {valueItemArr?.flagPath && (
                                                          <>
                                                            {isValidUrl(
                                                              valueItemArr?.flagPath
                                                            ) ? (
                                                              <img
                                                                src={
                                                                  valueItemArr?.flagPath
                                                                }
                                                                width={15}
                                                              />
                                                            ) : (
                                                              valueItemArr?.flagPath
                                                            )}
                                                          </>
                                                        )}

                                                        {categoryItems?.IsMultiImage ? (
                                                          <>
                                                            {valueItemArr.multiImages ? (
                                                              <>
                                                                <div className="myRow">
                                                                  {valueItemArr.multiImages.map(
                                                                    (
                                                                      img,
                                                                      i
                                                                    ) => {
                                                                      let alreadySelectedLabels =
                                                                        [
                                                                          img.ImageLabel,
                                                                        ];
                                                                      return (
                                                                        <div
                                                                          className="myCol"
                                                                          key={
                                                                            imagePath +
                                                                            i
                                                                          }
                                                                        >
                                                                          <>
                                                                            <img
                                                                              onClick={() =>
                                                                                showImageInModal(
                                                                                  img?.ImagePath
                                                                                )
                                                                              }
                                                                              src={
                                                                                img?.ImagePath
                                                                              }
                                                                              width={
                                                                                25
                                                                              }
                                                                              className="me-1"
                                                                            />
                                                                            <br />
                                                                            {!isEdit ? (
                                                                              <>
                                                                                <div
                                                                                  style={{
                                                                                    fontSize:
                                                                                      "10px",
                                                                                  }}
                                                                                >
                                                                                  {
                                                                                    img?.ImageLabelName
                                                                                  }
                                                                                </div>
                                                                              </>
                                                                            ) : null}
                                                                            {isEdit &&
                                                                            valueItemArr.multiImages &&
                                                                            categoryItems?.IsMultiImage ? (
                                                                              <select
                                                                                value={
                                                                                  img?.ImageLabel
                                                                                }
                                                                                onChange={(
                                                                                  e
                                                                                ) => {
                                                                                  handleChange(
                                                                                    catItems?.ProductId,
                                                                                    categoryItems?.FullColumnName,
                                                                                    e
                                                                                      .target
                                                                                      .value,
                                                                                    valueItemArr?.name,
                                                                                    img?.ImagePath
                                                                                  );
                                                                                }}
                                                                              >
                                                                                <option>
                                                                                  {
                                                                                    valueItemArr
                                                                                      .multiImages
                                                                                      ?.ImageLabel
                                                                                  }
                                                                                  {
                                                                                    valueItemArr
                                                                                      .multiImages
                                                                                      ?.ImageLabel
                                                                                  }
                                                                                </option>
                                                                                {isValidArray(
                                                                                  imageLabelList
                                                                                ) &&
                                                                                  imageLabelList.map(
                                                                                    (
                                                                                      imgLabel
                                                                                    ) => {
                                                                                      return (
                                                                                        <>
                                                                                          <option
                                                                                            key={
                                                                                              imgLabel?.ImageLabelID
                                                                                            }
                                                                                            value={
                                                                                              imgLabel?.ImageLabelID
                                                                                            }
                                                                                            disabled={
                                                                                              selectedLabelId.includes(
                                                                                                imgLabel?.ImageLabelID
                                                                                              ) &&
                                                                                              categoryProductData?.ImageCompilation ===
                                                                                                "Collection"
                                                                                            }
                                                                                          >
                                                                                            {
                                                                                              imgLabel?.ImageLabelName
                                                                                            }
                                                                                          </option>
                                                                                        </>
                                                                                      );
                                                                                    }
                                                                                  )}
                                                                              </select>
                                                                            ) : null}
                                                                          </>
                                                                        </div>
                                                                      );
                                                                    }
                                                                  )}
                                                                </div>
                                                              </>
                                                            ) : (
                                                              <></>
                                                            )}
                                                          </>
                                                        ) : (
                                                          <>
                                                            <div className="row">
                                                              <div className="col">
                                                                {valueItemArr.displayImages.map(
                                                                  (
                                                                    imagesPath
                                                                  ) => {
                                                                    return (
                                                                      <>
                                                                        {isValidUrl(
                                                                          imagesPath
                                                                        ) ? (
                                                                          <img
                                                                            onClick={() =>
                                                                              showImageInModal(
                                                                                imagesPath
                                                                              )
                                                                            }
                                                                            src={
                                                                              imagesPath
                                                                            }
                                                                            width={
                                                                              25
                                                                            }
                                                                            className="me-1"
                                                                          />
                                                                        ) : (
                                                                          imagesPath
                                                                        )}
                                                                      </>
                                                                    );
                                                                  }
                                                                )}
                                                              </div>
                                                            </div>
                                                          </>
                                                        )}
                                                      </>
                                                    );
                                                  }
                                                )}
                                            </td>
                                          </>
                                        );
                                      }
                                    )}
                                </tr>
                              )}
                            </Draggable>
                          </>
                        );
                      })
                    ) : (
                      <tr>
                        <td className="text-center" colSpan={9}>
                          No data available
                        </td>
                      </tr>
                    )}
                    {provided.placeholder}
                  </tbody>
                </table>
              )}
            </Droppable>
          </DragDropContext>
        </div>

        {isValidArray(categoryTextData) && (
          <>
            <div
              className="tableorganisation manage-catalog-tbl-section product-tableBorder mt-5"
              id="table-two"
            >
              <div className="row">
                <div className="col-6">
                  <label className="form-label category-table-title">
                    Category Text{" "}
                  </label>
                </div>
                <div className="col-6">
                  <div className="right-top-btn-section product-cnacelbtn mt-4">
                    {isDisabled ? (
                      <>
                        <Button onClick={handleSaveCategoryText}>Save</Button>
                        <Button
                          onClick={() => {
                            setDisabled(false);
                          }}
                          className="cancel-btn-red"
                        >
                          Cancel
                        </Button>
                      </>
                    ) : (
                      <Button onClick={() => setDisabled(true)}>Edit</Button>
                    )}
                  </div>
                </div>
              </div>
              <ReactTable
                columns={ReactTableColumns}
                data={[...categoryTextItems]}
                loading={categoryTextLoading}
                minRows={0}
                className="-striped -highlight"
                showPagination={false}
                sortable={false}
                multiSort={false}
                resizable={true}
                filterable={false}
              />
            </div>
          </>
        )}

        {showAddAttributeModal && (
          <AddNewAttributeInGridModal
            isOpen={showAddAttributeModal}
            toggle={handleAddAttributeModal}
            missingAttribute={missingAttribute}
            newAddedAttributeWidth={newAddedAttributeWidth}
            setNewAddedAttributeWidth={setNewAddedAttributeWidth}
            newAddedAttributeValue={newAddedAttributeValue}
            setNewAddedAttributeValue={setNewAddedAttributeValue}
            handleAddNewAttribute={handleAddNewAttribute}
          />
        )}

        {showConfirmModal && (
          <ConfirmationModal
            isOpen={showConfirmModal}
            toggle={handleConfirmModal}
            handleConfirm={handleDeleteAttributeSchema}
          />
        )}

        {unlinkModal && (
          <UnLinkModal
            isOpen={unlinkModal}
            toggle={handleUnlinkModal}
            unLinkFunction={() => handleUnlink()}
            modalText="Do you want to unlink product attributes for this category?"
          />
        )}

        {linkModal && (
          <UnLinkModal
            toggle={handleLinkModal}
            unLinkFunction={() => handleLink()}
            modalText="Do you want to link product attributes for this category to its parent category?"
          />
        )}
        {showImageModal && (
          <ShowImageModal
            toggle={handleShowImageModal}
            isOpen={showImageModal}
            imagesPath={imagePath}
          />
        )}
        {showProductTextModal && (
          <ProductTextModal
            isOpen={showProductTextModal}
            toggle={setShowProductTextModal}
            setTextAreaVal={setTextAreaVal}
            textAreaVal={textAreaVal}
            checkBoxVal={checkBoxVal}
            setSetCheckBoxVal={setSetCheckBoxVal}
            handleAddProductData={handleAddProductData}
          />
        )}
      </div>
    </>
  );
};

export default Products;
