import React, { useEffect, useState } from "react";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import { useDispatch, useSelector } from "react-redux";
import ProductAttHistory from "./productAttHistory/ProductAttHistory";
import ProductList from "./productList/ProductList";
import ProductAttGrid from "./productAttGrid/ProjectAttGrid";
import { isValidArray } from "modules/utils";
import { setLocalStorageItem } from "modules/utils";
import "intro.js/introjs.css";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";

function ManageProduct() {
  const initialActiveTab = {
    productList: "active",
    productAttHistory: "",
    productAttGrid: "",
    activeTab: "productList",
  };
  const dispatch = useDispatch();
  const [activeTab, setActivetab] = useState(initialActiveTab);
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [steps, setSteps] = useState([]);



  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = `#${d.elementIDName}`;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  useEffect(() => {
    document.title = "Manage Products | Producty®";
    dispatch(getIntroJs("products")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  const handleTab = (tabName) => {
    if (tabName == "productList") {
      setActivetab({
        productList: "active",
        productAttHistory: "",
        productAttGrid: "",
        activeTab: "productList",
      });
    } else if (tabName == "productAttHistory") {
      setActivetab({
        productList: "",
        productAttHistory: "active",
        productAttGrid: "",
        activeTab: "productAttHistory",
      });
    } else if (tabName == "productAttGrid") {
      setActivetab({
        productList: "",
        productAttHistory: "",
        productAttGrid: "active",
        activeTab: "productAttGrid",
      });
    }
  };

  return (
    <div>
      <Nav tabs>
        <NavItem>
          <NavLink
            className={activeTab.productList}
            onClick={() => {
              handleTab("productList");
              setLocalStorageItem("isAttributeGrid", false);
            }}
          >
            Product List
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.productAttHistory}
            onClick={() => {
              handleTab("productAttHistory");
              setLocalStorageItem("isAttributeGrid", false);
            }}
          >
            Product Attribute History
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.productAttGrid}
            onClick={() => {
              handleTab("productAttGrid");
              setLocalStorageItem("isAttributeGrid", true);
            }}
          >
            Product Attribute Grid
          </NavLink>
        </NavItem>
      </Nav>
      <TabContent activeTab={activeTab.activeTab}>
        <TabPane tabId="productList">
          {activeTab.activeTab === "productList" && <ProductList />}
        </TabPane>
        <TabPane tabId="productAttHistory">
          {activeTab.activeTab === "productAttHistory" && <ProductAttHistory />}
        </TabPane>
        <TabPane tabId="productAttGrid">
          {activeTab.activeTab === "productAttGrid" && <ProductAttGrid />}
        </TabPane>
      </TabContent>
    </div>
  );
}

export default ManageProduct;
