import InputField from "components/Common/InputField";
import SelectField from "components/Common/SelectField";
import Table from "components/Common/Table";
import React, { useEffect, useMemo, useState } from "react";
import { useDetectClickOutside } from "react-detect-click-outside";
import { useDispatch, useSelector } from "react-redux";
import { Button, Input, Label } from "reactstrap";
import Pagination from "react-js-pagination";
import { fetchProductAttrHistory } from "redux/actions/manageProduct/productAttrHistory";
import { fetchProductCategoryList } from "redux/actions/manageProduct/productCategoryList";
import { fetchProductAttrGrid } from "redux/actions/manageProduct/productAttrGrid";
import { debounce } from "lodash";
import {
  compare,
  filterFieldData,
  getRowPerPageArray,
  isValidArray,
  searchIncludes,
  setLocalStorageItem,
} from "modules/utils";
import { Link } from "react-router-dom/cjs/react-router-dom.min";
import editIcon from "../../../assets/images/editicon.png";
import Loader from "components/Common/Loader";
import Select from "react-select";
import { getActiveElement } from "formik";
import CustomTd from "./customTd";

function ProjectAttGrid() {
  const dispatch = useDispatch();
  //   let headerArray =[]
  //   let rowData =[]
  const [headerArray, setHeaderArray] = useState([]);
  const [rowData, setRowData] = useState([]);

  const [orderType, setOrderType] = useState("desc");
  const [selectSortHeader, setSelectSortHeader] = useState("");

  const [selectedCategoryId, setSelectedCategoryId] = useState("");
  const [columnSearch, setColumnSearch] = useState({});

  const {
    isLoading = false,
    productAttrHistory = null,
    productCategoryList = null,
    productCategoryLoading = false,
    productAttrGrid = null,
    productAttrGridLoading = false,
  } = useSelector((state) => ({
    productAttrHistory: state.productAttrHistory?.data?.data || null,
    isLoading: state.productAttrHistory?.loading || null,
    productCategoryList: state.productCategoryList?.data?.data || null,
    productCategoryLoading: state.productCategoryList?.loading || null,
    productAttrGrid: state.productAttrGrid?.data?.data || null,
    productAttrGridLoading: state.productAttrGrid?.loading || null,
  }));

  useEffect(() => {
    dispatch(fetchProductCategoryList()).then((data) => {
      if (data?.flag) {
        setSelectedCategoryId(data?.data[0]?.id);
        getAttributeGridList(data?.data[0]?.id);
      }
    });
  }, []);

  const productCategoryOptions = () => {
    let single = [{ label: "All Products", value: 0 }];
    return productCategoryList?.map((item) => {
      let spaces = 1;
      switch (Number(item.level)) {
        case 1:
          single = { label: item?.text, value: item?.id };
          break;
        case 2:
          single = {
            label: "\xA0\xA0" + item?.text,
            value: item?.id,
          };
          break;
        case 3:
          single = {
            label: "\xA0\xA0\xA0\xA0" + item?.text,
            value: item?.id,
          };
          break;

        default:
          single = { label: item?.text, value: item?.id };
          break;
      }
      console.log(
        "🚀 ~ file: ProjectAttGrid.js:97 ~ returnproductCategoryList?.map ~ single",
        single
      );
      return single;
    });
  };

  // const getFilterData = (searchTerm) => {
  //   if (searchTerm) {
  //     const value = searchTerm.toLowerCase();
  //     return filterFieldData(value, rowData, headerTitles);
  //   }
  //   return rowData;
  // };

  const [activePage, setActivePage] = useState(1);
  const [perPage, setPerPage] = useState(10);

  const handleOnChangeCategory = (itemId) => {
    setSelectedCategoryId(itemId);
    getAttributeGridList(itemId.value);
  };

  const getTableData = () => {
    const indexOfLastData = activePage * perPage;
    const indexOfFirstData = indexOfLastData - perPage;
    const currentData = isValidArray(rowData)
      ? rowData.slice(indexOfFirstData, indexOfLastData)
      : [];
    return currentData;
  };

  const tableData = getTableData();

  const getTotalRecordFromTo = () => {
    return (
      <div className="mr-3" style={{ marginLeft: "15px" }}>
        Showing{" "}
        {(activePage - 1) * perPage + tableData.length - tableData.length + 1}{" "}
        to {(activePage - 1) * perPage + tableData.length} of {rowData?.length}{" "}
        entries
      </div>
    );
  };

  const CustomPage = () => {
    return (
      <div className="d-flex align-center show-page-section justify-content-between table-footer">
        {getRowPerPage()}
        {isValidArray(rowData) && (
          <Pagination
            activePage={activePage}
            itemsCountPerPage={perPage}
            pageRangeDisplayed={10}
            totalItemsCount={rowData?.length || 0}
            nextPageText={"Next"}
            prevPageText={"Previous"}
            onChange={(e) => {
              setActivePage(e);
            }}
            innerClass="pagination"
          />
        )}
      </div>
    );
  };

  const handleSortingSet = (columnName) => {
    if (columnName) {
      const slicedData = rowData.slice();
      if (orderType === "desc") {
        const sortedData = slicedData.sort((a, b) => {
          if (a[columnName] < b[columnName]) {
            return -1;
          } else if (a[columnName] > b[columnName]) {
            return 1;
          } else {
            return 0;
          }
        });
        setOrderType("asc");
        columnName !== "Action" && setRowData(sortedData);
      } else if (orderType === "asc") {
        const sortedData = slicedData.sort((a, b) => {
          if (a[columnName] < b[columnName]) {
            return 1;
          } else if (a[columnName] > b[columnName]) {
            return -1;
          } else {
            return 0;
          }
        });
        setOrderType("desc");
        columnName !== "Action" && setRowData(sortedData);
      }
    }
  };

  const getRowPerPage = () => {
    return (
      <div className="d-flex justify-content-between align-center mb-2 table-header">
        <div className="d-flex justify-content-left filter-tab align-center">
          <Label>Show</Label>
          <div style={{ minWidth: "20px" }}>
            <Input
              type="select"
              onChange={(e) => {
                setPerPage(Number(e.target.value));
              }}
              value={perPage}
            >
              {isValidArray(getRowPerPageArray) &&
                getRowPerPageArray?.map((item, i) => {
                  return (
                    <option key={i} value={item.value}>
                      {item.label}
                    </option>
                  );
                })}
            </Input>
          </div>
          <Label style={{ marginLeft: "10px" }}>entries</Label>

          {isValidArray(rowData) && getTotalRecordFromTo()}
        </div>
      </div>
    );
  };

  const changeValue = (index, field, value) => {
    const result = rowData.map((d, i) => {
      if (i === index) {
        return {
          ...d,
          [field]: value,
        };
      }
      return d;
    });
    setRowData(result);
  };

  const getAttributeGridList = (itemId) => {
    dispatch(fetchProductAttrGrid(itemId)).then((data) => {
      console.log("fetchProductAttrGrid", data);
      let dataArray = [];
      let dataBackgroundArray = [];
      let headers = [];
      for (var key of Object.keys(data?.data?.headers)) {
        if (data?.data?.headers[key] === "Product ID") {
          dataBackgroundArray = [
            ...dataBackgroundArray,
            {
              Header: data?.data?.headers[key],
              id: key,
              accessor: (d) => (
                <>{/* <p style={{ color: "#fff" }}>{d.ProductID}</p> */}</>
              ),
              getProps: () => {
                return {
                  style: {
                    background: "#444444",
                  },
                };
              },
            },
          ];
        } else if (data?.data?.headers[key] === "Product Code") {
          dataBackgroundArray = [
            ...dataBackgroundArray,
            {
              Header: data?.data?.headers[key],
              id: key,
              accessor: (d) => <p style={{ color: "#fff" }}>{d.ProductCode}</p>,
              getProps: () => {
                return {
                  style: {
                    background: "#444444",
                  },
                };
              },
            },
          ];
        } else if (data?.data?.headers[key] === "Action") {
          dataBackgroundArray = [
            ...dataBackgroundArray,
            {
              Header: data?.data?.headers[key],
              id: key,
              accessor: (d) => (
                <>
                  <Button className="editicon-btn">
                    <Link
                      to={{ pathname: `/Product/${d.ProductCode}` }}
                      target="_blank"
                      onClick={() =>
                        setLocalStorageItem("ProductId", d.ProductID)
                      }
                    >
                      <img src={editIcon} />
                    </Link>
                  </Button>
                </>
              ),
            },
          ];
        } else {
          dataArray = [
            ...dataArray,
            {
              Header: data?.data?.headers[key],
              id: key,
              accessor: (d) => (
                <>
                  <p>{d}</p>
                </>
              ),
            },
          ];
        }
        headers = [...headers, key];
      }
      const finalArray = [...dataBackgroundArray, ...dataArray.sort(compare)];
      setHeaderArray(finalArray);
      setRowData(data?.data?.rowData);
    });
  };

  const updateColumnSearch = (key, value) => {
    setColumnSearch({
      ...columnSearch,
      [key]: value || "",
    });
  };

  const renderSearchInput = (key) => (
    <Input
      name={key}
      type="search"
      onChange={(e) => updateColumnSearch(key, e?.target?.value)}
      value={columnSearch?.[key] || ""}
    />
  );

  const getFilteredListData = ({ columnSearch, data }) => {
    console.log(
      "🚀 ~ file: ProjectAttGrid.js:339 ~ getFilteredListData ~ data",
      data
    );
    const {
      ProductID = "",
      ProductCode = "",
      a_add = "",
      a_bladelength = "",
      a_capacity = "",
      a_capacityrangecool = "",
      a_capacityrangeheat = "",
      a_chainsizemm2leg = "",
      a_code = "",
      a_compressortype = "",
      a_condition = "",
      a_description = "",
      a_dietary = "",
      a_dimensionsindoor = "",
    } = columnSearch || {};

    return data
      .filter((d) =>
        ProductCode ? searchIncludes(d.ProductCode, ProductCode) : true
      )
      .filter((d) =>
        ProductID ? searchIncludes(d.ProductID.toString(), ProductID) : true
      )
      .filter((d) => (a_add ? searchIncludes(d?.a_add, a_add) : true))
      .filter((d) =>
        a_bladelength ? searchIncludes(d?.a_bladelength, a_bladelength) : true
      )
      .filter((d) =>
        a_capacity ? searchIncludes(d?.a_capacity, a_capacity) : true
      )
      .filter((d) =>
        a_capacityrangecool
          ? searchIncludes(d?.a_capacityrangecool, a_capacityrangecool)
          : true
      )
      .filter((d) =>
        a_capacityrangeheat
          ? searchIncludes(d?.a_capacityrangeheat, a_capacityrangeheat)
          : true
      )
      .filter((d) =>
        a_chainsizemm2leg
          ? searchIncludes(d?.a_chainsizemm2leg, a_chainsizemm2leg)
          : true
      )
      .filter((d) => (a_code ? searchIncludes(d?.a_code, a_code) : true))
      .filter((d) =>
        a_compressortype
          ? searchIncludes(d?.a_compressortype, a_compressortype)
          : true
      )
      .filter((d) =>
        a_condition ? searchIncludes(d?.a_condition, a_condition) : true
      )
      .filter((d) =>
        a_description ? searchIncludes(d?.a_description, a_description) : true
      )
      .filter((d) =>
        a_dietary ? searchIncludes(d?.a_dietary, a_dietary) : true
      )
      .filter((d) =>
        a_dimensionsindoor
          ? searchIncludes(d?.a_dimensionsindoor, a_dimensionsindoor)
          : true
      );
  };

  const filterData = getFilteredListData({
    columnSearch: columnSearch,
    data: tableData,
  });

  const filterOptionsCatalog = productCategoryOptions();
  const filterOptionsCatalogList = filterOptionsCatalog && [
    { label: "All Products", value: 0 },
    ...filterOptionsCatalog,
  ];

  return (
    <div className="bg-whiteColor productAttri-gird-section">
      {productAttrGridLoading ? (
        <Loader />
      ) : (
        <>
          <div className="tab-selectbox gird-filter-select">
            <div>Filter by catalog/category:</div>
            <Select
              name="Attribute"
              id="Attribute"
              className="custom-select-box"
              formatOptionLabel={function (data) {
                return (
                  <span
                    className={`level-${data.level}`}
                    dangerouslySetInnerHTML={{ __html: data.label }}
                  />
                );
              }}
              placeholder="Select category"
              options={filterOptionsCatalogList}
              onChange={handleOnChangeCategory}
              value={selectedCategoryId}
              isSearchable={true}
            />
            {/* <SelectField
              type="text"
              name="Attribute"
              placeholder="Attribute"
              onChange={handleOnChangeCategory}
              options={productCategoryOptions()}
              value={selectedCategoryId}
            /> */}
          </div>

          <div className="tableorganisation mt-5 catalog-tbl-section product-attHistory-page productHistory-scorll product-tableBorder center-text-tbl manage-catalog-tbl-section">
            {/* <Table
              columns={headerArray}
              Data={rowData}
              isLoading={productAttrGridLoading}
              getFilterData={getFilterData}
            /> */}

            <table className="table" border={"2px"}>
              <thead>
                <tr>
                  {isValidArray(headerArray) &&
                    headerArray.map((item, i) => {
                      return (
                        <th
                          key={i}
                          className={`${
                            item?.Header === selectSortHeader
                              ? `-sort-${orderType}`
                              : ""
                          }`}
                          onClick={() => {
                            setSelectSortHeader(item.Header);
                            handleSortingSet(item.id, orderType);
                          }}
                          style={{
                            backgroundColor: item.ColorCode,
                            // width: "200px",
                            // width: "100%",
                            // width: "50%",
                          }}
                        >
                          {item?.Header}
                          <br></br>
                          <span
                            className="widthSize"
                            data-toggle="tooltip"
                            data-placement="top"
                            title="Width: 100"
                          ></span>
                        </th>
                      );
                    })}
                </tr>
                <tr>
                  {isValidArray(headerArray) &&
                    headerArray.map((item, i) => {
                      if (item.Header === "Action") {
                        return <th key={i}></th>;
                      } else {
                        return <th key={i}>{renderSearchInput(item.id)}</th>;
                      }
                    })}
                </tr>
              </thead>
              <tbody>
                {isValidArray(rowData) ? (
                  filterData.map((items, index) => {
                    return (
                      <>
                        <tr>
                          {headerArray.map((header, innerIndex) => {
                            const { id: key } = header;

                            if (key === "ProductID") {
                              return <td key={key}>{items[key]}</td>;
                            }
                            if (key === "ProductCode") {
                              return <td key={key}>{items[key]}</td>;
                            }
                            if (key === "Action") {
                              return (
                                <td key={key}>
                                  <Button className="editicon-btn" key={key}>
                                    <Link
                                      to={{
                                        pathname: `/Product/${items.ProductCode}`,
                                      }}
                                      target="_blank"
                                      onClick={() =>
                                        setLocalStorageItem(
                                          "ProductId",
                                          items.ProductID
                                        )
                                      }
                                    >
                                      <img src={editIcon} />
                                    </Link>
                                  </Button>
                                </td>
                              );
                            }
                            if (
                              key !== ("ProductCode" && "ProductID" && "Action")
                            ) {
                              return (
                                <>
                                  <CustomTd
                                    key={headerArray.id}
                                    value={items[key]}
                                    data={items}
                                    index={index}
                                    innerIndex={innerIndex}
                                    field={key}
                                    changeValueFunction={changeValue}
                                  />
                                </>
                              );
                            }
                          })}
                        </tr>
                      </>
                    );
                  })
                ) : (
                  <tr>
                    {/* <td className="text-center" colSpan={17}>
                      No data available
                    </td> */}
                  </tr>
                )}
              </tbody>
              {!isValidArray(rowData) || !isValidArray(filterData) ? (
                <tr>
                  <td className="text-center" colSpan={17}>
                    {!isValidArray(rowData)
                      ? "No data available"
                      : !isValidArray(filterData) &&
                        "No data matching with search terms"}
                  </td>
                </tr>
              ) : (
                <></>
              )}
            </table>
          </div>

          <CustomPage />
        </>
      )}
    </div>
  );
}

export default ProjectAttGrid;
