import { debounce } from "lodash";
import React, { useState, useRef, useEffect, useMemo } from "react";
import { useDispatch } from "react-redux";
import { fetchUpdateProductAttrGridData } from "redux/actions/manageProduct/updateProductAttrGridData";
import { limitChar } from "../../../modules/utils";

function CustomTd({
  value,
  index,
  innerIndex,
  field,
  changeValueFunction,
  key,
  data,
}) {
  const dispatch = useDispatch();
  const [isActive, setIsActive] = useState(false);

  const node = useRef();

  function createMarkup() {
    const str = limitChar(value, 40);
    return { __html: str };
  }

  // * debounce code start
  const changeHandler = (field, value) => {
    const formData = {
      ProductID: data["ProductID"],
      AttributeID: field,
      AttributeName: field,
      Value: value,
    };
    dispatch(fetchUpdateProductAttrGridData(formData));
  };

  const debouncedChangeHandler = useMemo(
    () => debounce(changeHandler, 2000),
    []
  );

  useEffect(() => {
    return () => {
      debouncedChangeHandler.cancel();
    };
  }, []);
  // * debounce code end

  const handleChange = (index, field, value) => {
    changeValueFunction(index, field, value);
    debouncedChangeHandler(field, value);
  };

  useEffect(() => {
    const handleClickOutside = (e) => {
      if (
        node?.current?.contains(e.target) ||
        e?.target?.matches(
          `dropzone-img-box${innerIndex}, dropzone-img-box${innerIndex} *`
        )
      ) {
        if (!isActive) {
          setIsActive(true);
        }
      } else {
        if (isActive) {
          setIsActive(false);
        }
      }
    };

    document.addEventListener("mousedown", handleClickOutside);

    return () => {
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, [isActive]);

  return (
    <td key={key} ref={node} className={`dropzone-img-box${innerIndex}`}>
      {isActive &&
      (field === "a_productdescription" || field === "a_description") ? (
        <textarea
          style={{ width: "100%" }}
          value={value || ""}
          onChange={(e) => handleChange(index, field, e.target.value)}
        >
          {value}
        </textarea>
      ) : isActive ? (
        <input
          type="text"
          value={value || ""}
          onChange={(e) => handleChange(index, field, e.target.value)}
        />
      ) : (
        <div
          className="customTestArea"
          dangerouslySetInnerHTML={createMarkup()}
        ></div>
      )}
    </td>
  );
}

export default CustomTd;
