import Loader from "components/Common/Loader";
import Table from "components/Common/Table";
import { filterFieldData, setLocalStorageItem } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Link } from "react-router-dom/cjs/react-router-dom.min";
import { Button, Label, Modal, ModalBody } from "reactstrap";
import { fetchProductAttrHistory } from "redux/actions/manageProduct/productAttrHistory";
import { fetchRestoreOldValue } from "redux/actions/manageProduct/restoreOldValue";

function ProductAttHistory() {
  const dispatch = useDispatch();
  const [searchOrganization, setSearchOrganization] = useState("");

  const [addOrganizationModal, setAddOrganizationModal] = useState(false);
  const [selectedOrganizationId, setSelectedOrganizationId] = useState(0);

  const [restoreProductModal, setRestoreProductModal] = useState(false);
  const [newValue, setNewValue] = useState("");
  const [oldValue, setOldValue] = useState("");
  const [productId, setProductId] = useState("");
  const [attributeId, setAttributeId] = useState("");
  const [categoryId, setCategoryId] = useState("");
  const { isLoading = false, productAttrHistory = null } = useSelector(
    (state) => ({
      productAttrHistory: state.productAttrHistory?.data?.data || null,
      isLoading: state.productAttrHistory?.loading || null,
    })
  );

  useEffect(() => {
    dispatch(fetchProductAttrHistory());
  }, []);

  const handleAddOrganizationModal = () => {
    if (addOrganizationModal) {
      setSelectedOrganizationId(0);
    }
    setAddOrganizationModal(!addOrganizationModal);
  };

  const handleRestoreProductModal = (
    newValue,
    oldValue,
    productId,
    attributeId,
    categoryId
  ) => {
    setNewValue(newValue);
    setOldValue(oldValue);
    setProductId(productId);
    setAttributeId(attributeId);
    setCategoryId(categoryId);

    setRestoreProductModal(!restoreProductModal);
  };

  const handleSubmitRestore = () => {
    const formData = {
      ProductId: String(productId),
      AttributeId: String(attributeId),
      CategoryId: categoryId,
      newValue: newValue,
    };

    dispatch(fetchRestoreOldValue(formData)).then((data) => {
      dispatch(fetchProductAttrHistory());
      handleRestoreProductModal();
    });
  };

  const ReactTableColumns = [
    {
      minWidth: 200,
      Header: "Product Code",
      id: "ProductCode",
      accessor: "ProductCode",
      sortable: true,
    },

    {
      minWidth: 300,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Link
            to={{ pathname: `/Product/${d.ProductCode}` }}
            target="_blank"
            onClick={() => setLocalStorageItem("ProductId", d.ProductID)}
          >
            <Button>Edit Product</Button>
          </Link>{" "}
          <Button
            onClick={() => {
              handleRestoreProductModal(
                d.NewValue,
                d.OldValue,
                d.ProductID,
                d.AttributeID,
                d.CategoryID
              );
            }}
          >
            Restore
          </Button>
        </>
      ),
    },
    {
      minWidth: 250,
      Header: "Attribute Name",
      id: "AttributeName",
      accessor: "AttributeName",
      sortable: true,
    },
    {
      minWidth: 350,
      Header: "Old Value",
      id: "OldValue",
      accessor: "OldValue",
      sortable: true,
    },
    {
      minWidth: 350,
      Header: "New Value",
      id: "NewValue",
      accessor: "NewValue",
      sortable: true,
    },
    {
      minWidth: 200,
      Header: "Date / Time",
      id: "DateTime",
      accessor: "DateTime",
      sortable: true,
    },
    {
      minWidth: 200,
      Header: "User Name",
      id: "userName",
      sortable: true,
      accessor: (d) => d?.FirstName.concat(" ", d?.LastName),
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, productAttrHistory, [
        "ProductCode",
        "AttributeName",
        "OldValue",
        "NewValue",
        "DateTime",
        "userName",
      ]);
    }
    return productAttrHistory;
  };

  return (
    <div className="bg-whiteColor">
      {isLoading ? (
        <Loader />
      ) : (
        <div className="tableorganisation catalog-tbl-section product-attHistory-page ">
          <Table
            columns={ReactTableColumns}
            Data={productAttrHistory}
            isLoading={isLoading}
            getFilterData={getFilterData}
            sortColumn={{
              id: "ProductCode",
              desc: false,
            }}
          />
        </div>
      )}
      {restoreProductModal && (
        <Modal
          className="conformation-popup"
          isOpen={restoreProductModal}
          toggle={handleRestoreProductModal}
          size={"sm"}
        >
          {/* <ModalHeader toggle={handleRestoreProductModal}>Delete</ModalHeader> */}
          <ModalBody>
            <div className="model-label-input">
              <div className="row align-center">
                <div className="col-4"></div>
                <Label>
                  {" "}
                  Do you wish to revert the attribute value from {
                    newValue
                  } to {oldValue}
                </Label>
                {/* <div className="col-8">
                    <InputField
                      type="text"
                      name="userEmail"
                      placeholder="User email"
                      onChange={setInviteUser}
                      value={inviteUser}
                    />
                  </div> */}
              </div>
            </div>
            <div className="model-bottom-btn-section">
              <Button
                color="primary save-btn confirm-y"
                onClick={handleSubmitRestore}
              >
                {" "}
                Yes
              </Button>
              <Button
                color="primary save-btn confirm-n"
                onClick={handleRestoreProductModal}
              >
                {" "}
                No
              </Button>
            </div>
          </ModalBody>
        </Modal>
      )}
    </div>
  );
}

export default ProductAttHistory;
