import InputField from "components/Common/InputField";
import ServerSideTable from "components/Common/ServerSideTable";
import Table from "components/Common/Table";
import { Form, Formik } from "formik";
import { displayFormErrors, addProductForm } from "modules/validations";
import React, { useCallback, useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Link, useHistory } from "react-router-dom";
import { debounce } from "lodash";
import { Button } from "reactstrap";
import { fetchAddProduct } from "redux/actions/manageProduct/addProduct";
import {
  setLocalStorageItem,
  extractNumFromString,
  replaceNumFromString,
  isValidArray,
} from "../../../modules/utils";
import { fetchProductList } from "redux/actions/manageProduct/productList";
import { fetchAddProductValidation } from "redux/actions/manageProduct/addProductValidation";
import { fetchSearchProduct } from "redux/actions/manageProduct/searchProduct";
import { Steps } from "intro.js-react";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import "intro.js/introjs.css";

function ProductList() {
  const dispatch = useDispatch();
  const [finalProductData, setFinalProductData] = useState([]);
  const [searchTerm, setSearchTerm] = useState("");
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);

  const {
    isLoading = false,
    productListData = null,
    addProductValidation = null,
    productCountLoading = false,
  } = useSelector((state) => ({
    productListData: state.productListReducer?.data?.data || null,
    searchProductData: state.searchProduct?.data?.data || null,
    isLoading: state.productListReducer?.loading || null,
    addProductValidation: state.addProductValidation?.data?.data || null,
    productCountLoading: state.addProductValidation?.loading || null,
  }));

  const changeProductList = (item = 1, perPage = 50, search = "") => {
    if (search || searchTerm !== "") {
      const formData = {
        search: search || searchTerm,
        page: item,
        perPage: perPage,
      };
      dispatch(fetchSearchProduct(formData)).then((data) => {
        setFinalProductData(data?.data);
      });
    } else {
      dispatch(fetchProductList(item, perPage)).then((data) => {
        setFinalProductData(data?.data);
        dispatch(fetchAddProductValidation());
      });
    }
  };

  // const searchTermFunction = (search = "") => {
  //   if (search != "") {
  //     dispatch(fetchSearchProduct(search)).then((data) => {
  //       setFinalProductData(data);
  //     });
  //   } else {
  //     changeProductList();
  //   }
  // };

  const ReactTableColumns = [
    {
      minWidth: 300,
      Header: "Product ID",
      id: "ProductID",
      accessor: (d) => (
        <div
          style={{
            textAlign: "left",
          }}
        >
          {d.ProductID}
        </div>
      ),
    },
    {
      minWidth: 300,
      Header: "Product Code",
      id: "ProductCode",
      accessor: "ProductCode",
    },

    {
      minWidth: 300,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Link
            to={{
              pathname: `/Product/${d.ProductCode}`,
              search: `?pid=${d.ProductID}`,
            }}
            target="_blank"
            // onClick={() => setLocalStorageItem("ProductId", d.ProductID)}
          >
            <Button>Edit Product</Button>
          </Link>
        </>
      ),
    },
    {
      minWidth: 300,
      Header: "Created Date/Time",
      id: "CreatedAt",
      accessor: "CreatedAt",
    },
    {
      minWidth: 300,
      Header: "End Of Life Date",
      id: "EndOfLifeDate",
      accessor: "EndOfLifeDate",
    },
    {
      minWidth: 300,
      Header: "Created By",
      id: "CreatedBy",
      accessor: "CreatedBy",
    },
  ];

  const handleSubmit = (values, e) => {
    e.preventDefault;
    const formData = {
      ProductCode: values.searchProductCode,
    };
    // console.log(formData);
    dispatch(fetchAddProduct(formData)).then((data) => {
      changeProductList(1, 50);
    });
  };

  const debounceLoadData = useCallback(debounce(changeProductList, 1000), []);

  const onExit = () => {
    setStepsEnabled(false);
  };

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = d.elementIDName;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  useEffect(() => {
    dispatch(getIntroJs("products")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  return (
    <>
      <Steps
        enabled={stepsEnabled}
        steps={steps}
        initialStep={initialStep}
        onExit={onExit}
        onComplete={() => setStepsEnabled(false)}
        options={{ doneLabel: "Done" }}
      />
      <div className="bg-whiteColor productList-section">
        <div className="tabcontent ">
          <Formik
            initialValues={{ searchProductCode: "" }}
            validationSchema={addProductForm}
            onSubmit={handleSubmit}
            // onSubmit={e => {e.preventDefault()}} 
            enableReinitialize
          >
            {({
              values,
              errors,
              touched,
              handleChange,
              handleBlur,
              handleSubmit,
              submitCount,
              setFieldValue,
            }) => {
              const showError = (key) =>
                displayFormErrors(key, errors, touched, submitCount);
              return (
                <div className="full-width" style={{ width: "100%" }}>
                  <div
                    className="row align-items-center"
                    style={{ width: "100%" }}
                  >
                    <div className="col-2">
                      <InputField
                        type="text"
                        name="searchProductCode"
                        id="searchProductCode"
                        placeholder="Product Code"
                        onChange={(e) => {
                          handleChange(e);
                          setSearchTerm(e.target.value);
                          debounceLoadData(1, 50, e.target.value);
                        }}
                        onKeyPress={e => { e.which === 13 && e.preventDefault() }}
                        value={values.searchProductCode}
                      />
                      {showError("searchProductCode")}
                    </div>
                    <div className="col-2" style={{ marginLeft: "15px" }}>
                      <button className="btn btn-secondary" type="buttton" onClick={handleSubmit}>Add Product</button>
                    </div>

                    <div
                      className="col-6"
                    >
                      <p className="product-validation-alert" style={{ color: `${addProductValidation?.totalProductColor}` }}>
                        {addProductValidation && addProductValidation?.totalProductText}
                      </p>
                      <p className="product-validation-alert" style={{ color: `${addProductValidation?.packageProductColor}` }}>
                        {addProductValidation && addProductValidation?.packageProductText}
                      </p>
                      <p className="product-validation-alert" style={{ color: `${addProductValidation?.additionalChargeColor}` }}>
                        {addProductValidation && addProductValidation?.additionalChargeText}
                      </p>
                    </div>
                  </div>
                </div>
              );
            }}
          </Formik>
        </div>
        <div className="tableorganisation catalog-tbl-section product-tableBorder">
          <ServerSideTable
            columns={ReactTableColumns}
            Data={finalProductData}
            isLoading={isLoading}
            pageChangeFunction={changeProductList}
            searchTermFunction={changeProductList}
            searchTextVisible={false}
          />
        </div>
      </div>
    </>
  );
}

export default ProductList;
