import InputField from "components/Common/InputField";
import Table from "components/Common/Table";
import {
  filterFieldData,
  getLocalStorageItem,
  isValidArray,
} from "modules/utils";
import React, { useEffect, useRef, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useLocation } from "react-router-dom/cjs/react-router-dom.min";
import Switch from "react-switch";
import { Input, Label } from "reactstrap";
import { Button } from "reactstrap";
import { fetchManageAttributeList } from "redux/actions/manageProduct/editProduct/manageAttributeList";
import { fetchUpdateEditProductData } from "redux/actions/masterSetup/updateEditProductData";
import TypeWiseField from "./TypeWiseField";

function ManageAttribute() {
  const dispatch = useDispatch();
  const instanceRef = useRef(null);
  const catalogRef = useRef(null);
  const standardRef = useRef(null);

  const [displayEmptyValue, setDisplayEmptyValue] = useState(false);
  const [preferredValues, setPreferredValues] = useState(false);
  const [isDisabled, setDisabled] = useState(false);
  const [attributeValue, setAttributeValue] = useState("");
  const [manageAttributeData, setManageAttributeList] = useState([]);
  const [allInstanceAttributes, setAllInstanceAttributes] = useState([]);
  const [catalogAttributes, setCatalogAttributes] = useState([]);

  const [searchValue, setSearchValue] = useState("");
  const [orderType, setOrderType] = useState(true);
  const [orderColumnName, setOrderColumnName] = useState("");

  const executeScroll = (type) => {
    if (type === "instance") {
      instanceRef.current.scrollIntoView();
    } else if (type === "catalog") {
      catalogRef.current.scrollIntoView();
    } else if (type === "standard") {
      standardRef.current.scrollIntoView();
    }
  };

  // const ProductId = getLocalStorageItem("ProductId");
  const search = useLocation().search;
  const ProductId = new URLSearchParams(search).get("pid");

  const { isLoading = false, manageAttributeList = null } = useSelector(
    (state) => ({
      manageAttributeList: state.manageAttributeList?.data?.data || null,

      isLoading: state.manageAttributeList?.loading || null,
    })
  );

  useEffect(() => {
    listAttributeList();
  }, []);

  const listAttributeList = () => {
    const formData = {
      productID: ProductId,
      displayEmptyValues: displayEmptyValue ? "1" : "0",
      preferred: preferredValues ? "1" : "0",
    };
    handleFetchManageAttributeList(formData);
  };

  const handleFetchManageAttributeList = (formData) => {
    dispatch(fetchManageAttributeList(formData)).then((data) => {
      setManageAttributeList(data?.data?.allAttributes);
      setAllInstanceAttributes(data?.data?.allInstanceAttributes);
      setCatalogAttributes(data?.data?.catalogAttributes);
    });
  };

  const renderEditable = (value, id) => {
    return (
      <div className="table-edit-input">
        <div
          contentEditable
          suppressContentEditableWarning
          onBlur={(e) => getAttributeData(e.target.innerHTML, id)}
          dangerouslySetInnerHTML={{
            __html: value,
          }}
        />
      </div>
    );
  };
  const handleSearch = (val) => {
    setSearchValue(val);
    if (val) {
      const data = filterFieldData(val.toLowerCase(), manageAttributeData, [
        "AttributeName",
        "Value",
      ]);

      setManageAttributeList(data);

      if (isValidArray(allInstanceAttributes)) {
        let newArr = allInstanceAttributes.map((d) => {
          const isContainAttribute = d.AttributeName.search(val) !== -1;
          let isInstanceAttrCount = 0;

          d.rowData.map((row) => {
            if (
              (row.path && row.path.search(val) !== -1) ||
              (row.value && row.Value.search(val) !== -1)
            ) {
              isInstanceAttrCount = isInstanceAttrCount + 1;
            }
          });
          if (isInstanceAttrCount || isContainAttribute) {
            return d;
          }
          return null;
        });
        newArr = newArr.filter((d) => d);

        setAllInstanceAttributes(newArr);
      }
    } else {
      listAttributeList();
    }
  };
  const ReactTableColumns = [
    {
      minWidth: 300,
      Header: "Attribute Name",
      id: "AttributeName",
      accessor: (d) => {
        return (
          <div className="edit-manage-product-color">
            <div>{d.AttributeName}</div>
            {d.ColorCode && (
              <div
                className="attribute-id-bg"
                data-toggle="tooltip"
                data-placement="top"
                title="Catalog attribute"
                style={{ backgroundColor: `${d.ColorCode}` }}
              ></div>
            )}
          </div>
        );
      },
      sortable: true,
    },

    {
      minWidth: 300,
      Header: "Value",
      id: "Value",
      accessor: (d) => {
        return isDisabled
          ? renderEditable(d?.Value || "", d.AttributeID)
          : d?.Value;
      },
      sortable: true,
    },
  ];
  const getAttributeData = (value, id) => {
    const updated = manageAttributeData.map((d) => ({
      ...d,
      Value: d.AttributeID === id ? value : d.Value,
    }));

    setManageAttributeList(updated);
  };
  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, manageAttributeData, [
        "AttributeName",
        "Value",
      ]);
    }
    return manageAttributeData;
  };

  const handlePreferredToggleChange = (param = "") => {
    setPreferredValues(param === "preferred" ? true : false);

    const formData = {
      productID: ProductId,
      displayEmptyValues: displayEmptyValue ? "1" : "0",
      preferred: param === "preferred" ? "1" : "0",
    };
    handleFetchManageAttributeList(formData);
  };

  const handleToggleChange = (item) => {
    setDisplayEmptyValue(item);

    const formData = {
      productID: ProductId,
      displayEmptyValues: item ? "1" : "0",
      preferred: preferredValues ? "1" : "0",
    };
    handleFetchManageAttributeList(formData);
  };

  const handleEdit = () => {
    setDisabled(true);
  };
  const saveAttribute = () => {
    var formData = new FormData();
    let index;
    manageAttributeData.map((d, i) => {
      formData.append(`data[${i}][name]`, ProductId + "_" + d.AttributeID);
      formData.append(`data[${i}][value]`, d.Value);
      index = i;
    });
    allInstanceAttributes?.map((d, i) => {
      d?.rowData.map((row, i) => {
        index = index + 1;
        formData.append(`data[${index}][name]`, row?.Name);
        formData.append(`data[${index}][value]`, row?.Value);
      });
    });

    formData.append("productID", ProductId);

    dispatch(fetchUpdateEditProductData(formData)).then(() => {
      listAttributeList();
      setDisabled(false);
    });
  };
  const handleChange = (attributeId, val, isAttribute, path = "") => {
    if (!isAttribute) {
      if (isValidArray(manageAttributeData)) {
        const updatedData = manageAttributeData.map((d) => {
          if (d.AttributeID === attributeId) {
            return { ...d, Value: val };
          }
          return d;
        });

        setManageAttributeList(updatedData);
      }
    } else {
      if (isValidArray(allInstanceAttributes)) {
        const updatedData = allInstanceAttributes.map((d) => {
          if (d.AttributeID === attributeId) {
            return {
              ...d,
              rowData: d?.rowData.map((row) => {
                if (row.path === path) {
                  return {
                    ...row,
                    Value: val,
                  };
                }
                return row;
              }),
            };
          }
          return d;
        });

        setAllInstanceAttributes(updatedData);
      }
    }
  };
  const handleSortingSet = (columnName) => {
    setOrderType(!orderType);
    setOrderColumnName(columnName);
  };
  useEffect(() => {
    if (orderColumnName && isValidArray(manageAttributeData)) {
      const manageAttributeDataSort = manageAttributeData.slice();
      const result = manageAttributeDataSort?.sort(function (a, b) {
        if (orderType) {
          return a[orderColumnName].localeCompare(b[orderColumnName]);
        }
        return b[orderColumnName].localeCompare(a[orderColumnName]);
      });

      setManageAttributeList(result);
    }
  }, [orderType, orderColumnName]);

  const renderNewLineValue = (val) => {
    if (val) {
      return val.replace(/\n/g, "<br />");
    }
    return val;
  };

  return (
    <div>
      <div className="d-flex justify-content-between align-center manage-attribute-tab">
        <div className="d-flex">
          <div className="d-flex manage-attribute-left">
            <div
              className="d-flex align-center"
              onClick={() => handlePreferredToggleChange("all")}
            >
              <Input
                type="radio"
                name={`radioButton`}
                text="text"
                checked={!preferredValues}
                // onChange={(e) => handlePreferredToggleChange()}
              />
              <Label check disabled>
                All
              </Label>
            </div>
            <div
              className="d-flex align-center"
              onClick={() => handlePreferredToggleChange("preferred")}
            >
              <Input
                type="radio"
                name={`radioButton`}
                checked={preferredValues}
                // onChange={(e) => handlePreferredToggleChange()}
              />
              <Label check disabled>
                Preferred
              </Label>
            </div>
            <div className="d-flex align-center">
              <Label check>Display Empty Values </Label>{" "}
              <Switch
                className="switch-btn"
                uncheckedIcon={false}
                name="displayValue"
                checkedIcon={false}
                width={44}
                height={20}
                onChange={(e) => handleToggleChange(e)}
                checked={displayEmptyValue}
              />
            </div>
          </div>
          <div className="d-flex justify-content-between">
            <Label check>Go to: </Label>{" "}
            <Label
              check
              className="anchor-look"
              onClick={() => executeScroll("instance")}
            >
              Instance{" "}
            </Label>{" "}
          </div>
          <Label
            check
            className="anchor-look"
            onClick={() => executeScroll("catalog")}
          >
            Catalog{" "}
          </Label>{" "}
          <Label
            check
            className="anchor-look"
            onClick={() => executeScroll("standard")}
          >
            Standard{" "}
          </Label>{" "}
        </div>
        <div>
          {isValidArray(manageAttributeData) && (
            <div className="right-top-btn-section">
              {isDisabled ? (
                <>
                  <Button onClick={() => saveAttribute()}>Save</Button>
                  <Button
                    onClick={() => setDisabled(false)}
                    className="cancel-btn-red"
                  >
                    Cancel
                  </Button>
                </>
              ) : (
                <Button onClick={handleEdit}>Edit</Button>
              )}
            </div>
          )}
        </div>
      </div>

      <div className="tableorganisation manage-catalog-tbl-section bg-white">
        {/* <Table
          columns={ReactTableColumns}
          Data={
            isValidArray(manageAttributeData) ? [...manageAttributeData] : []
          }
          isLoading={isLoading}
          getFilterData={getFilterData}
        /> */}
        <div className="tableorganisation  category-table attribute-table-setup center-text-tbl bg-white">
          <div className="d-flex justify-content-between align-center mb-2">
            <div className=""></div>
            <div className="tabcontent">
              <label className="form-label">Search: </label>
              <input
                name="search"
                type="text"
                className="form-control"
                value={searchValue}
                onChange={(e) => handleSearch(e.target.value)}
              />
            </div>
          </div>
          <table border={"2px"}>
            <thead>
              <tr>
                <th
                  className={`${
                    orderColumnName === "AttributeName" && orderType
                      ? "-sort-asc"
                      : "-sort-desc"
                  }`}
                  onClick={() => handleSortingSet("AttributeName", orderType)}
                >
                  Attribute Name
                </th>
                <th
                  className={`${
                    orderColumnName === "Value" && orderType
                      ? "-sort-asc"
                      : "-sort-desc"
                  }`}
                  onClick={() => handleSortingSet("Value", orderType)}
                >
                  Value
                </th>
              </tr>
            </thead>
            <tbody>
              {isValidArray(allInstanceAttributes) && (
                <tr ref={instanceRef}>
                  <td
                    colSpan={2}
                    style={{ textAlign: "left", verticalAlign: "middle" }}
                  >
                    <strong>Instance Attributes</strong>
                  </td>
                </tr>
              )}
              {isValidArray(allInstanceAttributes) &&
                allInstanceAttributes.map((instanceAttributes) => {
                  return (
                    <>
                      <tr>
                        <td style={{ width: "12%" }}>
                          <>
                            {instanceAttributes?.AttributeName}{" "}
                            {instanceAttributes.ColorCode && (
                              <div
                                className="attribute-id-bg"
                                data-toggle="tooltip"
                                data-placement="top"
                                title={instanceAttributes.TooltipText}
                                style={{
                                  backgroundColor: `${instanceAttributes.ColorCode}`,
                                }}
                              ></div>
                            )}
                          </>
                        </td>
                        {isValidArray(instanceAttributes?.rowData) && (
                          <td style={{ width: "88%" }}>
                            <table border={"2px"}>
                              <tr>
                                <td style={{ width: "50%" }}>
                                  Collection Name{" "}
                                </td>
                                <td style={{ width: "50%" }}>Value </td>
                              </tr>

                              {instanceAttributes?.rowData.map(
                                (instanceRow) => {
                                  return (
                                    <>
                                      <tr>
                                        <td>{instanceRow?.path}</td>
                                        <td>
                                          {isDisabled &&
                                          Number(
                                            instanceAttributes?.Editable
                                          ) ? (
                                            <TypeWiseField
                                              isInstanceAttribute={true}
                                              value={instanceRow?.Value}
                                              allowHTML={
                                                instanceAttributes?.AllowHTML
                                              }
                                              isTextArea={
                                                instanceAttributes?.isTextArea
                                              }
                                              handleChange={handleChange}
                                              attributeId={
                                                instanceAttributes?.AttributeID
                                              }
                                              path={instanceRow?.path}
                                              isDisabled={
                                                parseInt(
                                                  instanceRow?.CanEdit
                                                ) === 1
                                                  ? true
                                                  : false
                                              }
                                            />
                                          ) : (
                                            <div
                                              dangerouslySetInnerHTML={{
                                                __html:
                                                  instanceAttributes?.isTextArea
                                                    ? renderNewLineValue(
                                                        instanceRow?.Value
                                                      )
                                                    : instanceRow?.Value,
                                              }}
                                            >
                                              {/* {instanceRow?.Value} */}
                                            </div>
                                          )}
                                        </td>
                                      </tr>
                                    </>
                                  );
                                }
                              )}
                            </table>

                            {/* {" "}
                            {isDisabled && instanceAttributes?.Editable ? (
                              <TypeWiseField
                                value={instanceRow?.Value}
                                allowHTML={instanceAttributes?.AllowHTML}
                                isTextArea={instanceAttributes?.isTextArea}
                                handleChange={handleChange}
                                attributeId={instanceAttributes?.AttributeID}
                              />
                            ) : (
                              instanceRow?.Value
                            )}{" "} */}
                          </td>
                        )}
                      </tr>
                    </>
                  );
                })}
              {isValidArray(catalogAttributes) && (
                <tr ref={catalogRef}>
                  <td
                    colSpan={2}
                    style={{
                      textAlign: "left",
                      verticalAlign: "middle",
                    }}
                  >
                    <strong>Catalog Attributes</strong>
                  </td>
                </tr>
              )}
              {isValidArray(catalogAttributes) &&
                catalogAttributes.map((manageAttribute, k1) => {
                  return (
                    <tr
                      className={manageAttribute?.AttributeName}
                      key={`tr-${k1}`}
                    >
                      <td>
                        <>
                          {manageAttribute?.AttributeName}{" "}
                          {manageAttribute.ColorCode && (
                            <div
                              className="attribute-id-bg"
                              data-toggle="tooltip"
                              data-placement="top"
                              title={manageAttribute?.TooltipText}
                              style={{
                                backgroundColor: `${manageAttribute.ColorCode}`,
                              }}
                            ></div>
                          )}
                        </>
                      </td>

                      <td>
                        {" "}
                        {isDisabled && manageAttribute?.CanEdit ? (
                          <TypeWiseField
                            value={manageAttribute?.Value}
                            allowHTML={manageAttribute?.AllowHTML}
                            isTextArea={manageAttribute?.isTextArea}
                            handleChange={handleChange}
                            attributeId={manageAttribute?.AttributeID}
                            isDisabled={
                              parseInt(manageAttribute?.CanEdit) === 0
                                ? true
                                : false
                            }
                          />
                        ) : (
                          <div
                            dangerouslySetInnerHTML={{
                              __html: manageAttribute?.isTextArea
                                ? renderNewLineValue(manageAttribute?.Value)
                                : manageAttribute?.Value,
                            }}
                          />
                        )}{" "}
                      </td>
                    </tr>
                  );
                })}
              {isValidArray(manageAttributeData) && (
                <tr ref={standardRef}>
                  <td
                    colSpan={2}
                    style={{ textAlign: "left", verticalAlign: "middle" }}
                  >
                    <strong>Standard Attributes</strong>
                  </td>
                </tr>
              )}
              {isValidArray(manageAttributeData) &&
                manageAttributeData.map((manageAttribute, k1) => {
                  return (
                    <tr
                      className={manageAttribute?.AttributeName}
                      key={`tr-${k1}`}
                    >
                      <td>
                        <>
                          {manageAttribute?.AttributeName}{" "}
                          {manageAttribute.ColorCode && (
                            <div
                              className="attribute-id-bg"
                              data-toggle="tooltip"
                              data-placement="top"
                              title={manageAttribute.TooltipText}
                              style={{
                                backgroundColor: `${manageAttribute.ColorCode}`,
                              }}
                            ></div>
                          )}
                        </>
                      </td>

                      <td>
                        {" "}
                        {isDisabled && manageAttribute?.CanEdit ? (
                          <>
                            <TypeWiseField
                              value={manageAttribute?.Value}
                              allowHTML={manageAttribute?.AllowHTML}
                              isTextArea={manageAttribute?.isTextArea}
                              handleChange={handleChange}
                              attributeId={manageAttribute?.AttributeID}
                              isDisabled={
                                parseInt(manageAttribute?.CanEdit) === 0
                                  ? true
                                  : false
                              }
                            />
                          </>
                        ) : (
                          <div
                            dangerouslySetInnerHTML={{
                              __html: manageAttribute?.isTextArea
                                ? renderNewLineValue(manageAttribute?.Value)
                                : manageAttribute?.Value,
                            }}
                          />
                        )}{" "}
                      </td>
                    </tr>
                  );
                })}
            </tbody>
          </table>
        </div>
        <div className="d-flex align-center show-page-section justify-content-between">
          <div className="">
            Showing {isValidArray(manageAttributeData) ? "1" : "0"} to{" "}
            {isValidArray(manageAttributeData)
              ? manageAttributeData.length
              : "0"}{" "}
            of{" "}
            {isValidArray(manageAttributeData)
              ? manageAttributeData.length
              : "0"}{" "}
            entries
          </div>
        </div>
      </div>
    </div>
  );
}

export default ManageAttribute;
