import React, { useEffect, useState } from "react";

import { useDispatch, useSelector } from "react-redux";
import { Button, Input } from "reactstrap";
import "react-table-6/react-table.css";
import Table from "components/Common/Table";
import { fetchEditProductAttHistoryList } from "redux/actions/manageProduct/editProduct/editProductAttHistory";
import {
  filterFieldData,
  getLocalStorageItem,
  setLocalStorageItem,
} from "modules/utils";
import { Link } from "react-router-dom";
import { useLocation } from "react-router-dom/cjs/react-router-dom.min";
import { Label, Modal, ModalBody } from "reactstrap";
import { fetchRestoreOldValue } from "redux/actions/manageProduct/restoreOldValue";
import { fetchProductAttrHistory } from "redux/actions/manageProduct/productAttrHistory";

function ProductAttHistory() {
  const dispatch = useDispatch();
  // const ProductId = getLocalStorageItem("ProductId");
  const search = useLocation().search;
  const ProductId = new URLSearchParams(search).get("pid");
  const [restoreProductModal, setRestoreProductModal] = useState(false);
  const [newValue, setNewValue] = useState("");
  const [oldValue, setOldValue] = useState("");
  const [productId, setProductId] = useState("");
  const [attributeId, setAttributeId] = useState("");
  const [categoryId, setCategoryId] = useState("");
  const { isLoading = false, editProductAttHistory = null } = useSelector(
    (state) => ({
      editProductAttHistory: state.editProductAttHistory?.data?.data || null,
      isLoading: state.editProductAttHistory?.loading || null,
    })
  );

  useEffect(() => {
    dispatch(fetchEditProductAttHistoryList(ProductId));
  }, []);

  const handleRestoreProductModal = (
    newValue,
    oldValue,
    productId,
    attributeId,
    categoryId
  ) => {
    setNewValue(newValue);
    setOldValue(oldValue);
    setProductId(productId);
    setAttributeId(attributeId);
    setCategoryId(categoryId);

    setRestoreProductModal(!restoreProductModal);
  };
  const handleSubmitRestore = () => {
    const formData = {
      ProductId: String(productId),
      AttributeId: String(attributeId),
      CategoryId: categoryId,
      newValue: oldValue,
    };

    dispatch(fetchRestoreOldValue(formData)).then((data) => {
      dispatch(fetchEditProductAttHistoryList(ProductId));
      dispatch(fetchProductAttrHistory());
      handleRestoreProductModal();
    });
  };

  const ReactTableColumns = [
    {
      minWidth: 70,
      Header: "Product Code",
      id: "ProductCode",
      accessor: "ProductCode",
      sortable: true,
    },
    {
      minWidth: 80,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Link
            to={{ pathname: `/Product/${d.ProductCode}?pid=${ProductId}` }}
            target="_blank"
            onClick={() => setLocalStorageItem("ProductId", d.ProductID)}
          >
            <Button>Edit Product</Button>
            {console.log("999", d)}
          </Link>
          {" | "}
          <Button
            onClick={() => {
              handleRestoreProductModal(
                d.NewValue,
                d.OldValue,
                d.ProductID,
                d.AttributeID,
                d.CategoryID
              );
            }}
          >
            Restore
          </Button>
        </>
      ),
    },
    {
      minWidth: 100,
      Header: "Attribute Name",
      id: "AttributeName",
      accessor: "AttributeName",
      sortable: true,
    },
    {
      minWidth: 200,
      Header: "Old Value",
      id: "OldValue",
      accessor: "OldValue",
      sortable: true,
    },
    {
      minWidth: 70,
      Header: "New Value",
      id: "NewValue",
      accessor: "NewValue",
      sortable: true,
    },
    {
      minWidth: 60,
      Header: "Date Time",
      id: "DateTime",
      accessor: "DateTime",
      sortable: true,
    },
    {
      minWidth: 70,
      Header: "User Name",
      id: "userName",
      accessor: (d) => d?.FirstName.concat(" ", d?.LastName),
      sortable: true,
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, editProductAttHistory, [
        "ProductCode",
        "AttributeName",
        "OldValue",
        "NewValue",
        "DateTime",
        "userName",
      ]);
    }
    return editProductAttHistory;
  };

  return (
    <div className="tableorganisation bg-white product-edit-catagory">
      <Table
        columns={ReactTableColumns}
        Data={editProductAttHistory}
        isLoading={isLoading}
        getFilterData={getFilterData}
        sortColumn={{
          id: "ProductCode",
          desc: false,
        }}
      />
      {restoreProductModal && (
        <Modal
          className="conformation-popup"
          isOpen={restoreProductModal}
          toggle={handleRestoreProductModal}
          size={"sm"}
        >
          {/* <ModalHeader toggle={handleRestoreProductModal}>Delete</ModalHeader> */}
          <ModalBody>
            <div className="model-label-input">
              <div className="row align-center">
                <div className="col-4"></div>
                <Label>
                  {" "}
                  Do you wish to revert the attribute value from {
                    newValue
                  } to {oldValue}
                </Label>
                {/* <div className="col-8">
                    <InputField
                      type="text"
                      name="userEmail"
                      placeholder="User email"
                      onChange={setInviteUser}
                      value={inviteUser}
                    />
                  </div> */}
              </div>
            </div>
            <div className="model-bottom-btn-section">
              <Button
                color="primary save-btn confirm-y"
                onClick={handleSubmitRestore}
              >
                {" "}
                Yes
              </Button>
              <Button
                color="primary save-btn confirm-n"
                onClick={handleRestoreProductModal}
              >
                {" "}
                No
              </Button>
            </div>
          </ModalBody>
        </Modal>
      )}
    </div>
  );
}

export default ProductAttHistory;
