import React, { useEffect } from "react";

import { useDispatch, useSelector } from "react-redux";
import "react-table-6/react-table.css";
import Table from "components/Common/Table";
import { filterFieldData, getLocalStorageItem } from "modules/utils";
import { fetchProductCollectionList } from "redux/actions/manageProduct/editProduct/productCollectionList";
import { useLocation } from "react-router-dom/cjs/react-router-dom.min";

function ProductCollection() {
  const dispatch = useDispatch();
  // const ProductId = getLocalStorageItem("ProductId");
  const search = useLocation().search;
  const ProductId = new URLSearchParams(search).get("pid");

  const { isLoading = false, productCollectionList = null } = useSelector(
    (state) => ({
      productCollectionList: state.productCollectionList?.data?.data || null,
      isLoading: state.productCollectionList?.loading || null,
    })
  );

  useEffect(() => {
    dispatch(fetchProductCollectionList(ProductId));
  }, []);

  const ReactTableColumns = [
    {
      Header: "Category Name",
      id: "CategoryName",
      accessor: "CategoryName",
      sortable: true,
    },

    {
      Header: "Path",
      id: "path",
      accessor: (d) => {
        return <div dangerouslySetInnerHTML={createMarkup(d)}></div>;
      },
      sortable: true,
    },
  ];
  function createMarkup(d) {
    return { __html: d?.path };
  }

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, productCollectionList, [
        "CategoryName",
        "Path",
      ]);
    }
    return productCollectionList;
  };

  return (
    <div className="tableorganisation bg-white product-edit-catagory">
      <Table
        columns={ReactTableColumns}
        Data={productCollectionList}
        isLoading={isLoading}
        getFilterData={getFilterData}
        sortColumn={{
          id: "CategoryName",
          desc: false,
        }}
      />
    </div>
  );
}

export default ProductCollection;
