import { Editor } from "@tinymce/tinymce-react";
import MultiSelectCheckboxMenu from "components/Common/MultiSelectCheckboxMenu";
import TextArea from "components/Common/TextArea";
import { isValidArray } from "modules/utils";
import React, { useRef } from "react";
import { Input, Label } from "reactstrap";

const TypeWiseField = ({
  fieldType,
  //   categoryItems,
  handleChange,
  attributeId,
  isTextArea,
  columnName,
  value,
  allowHTML,
  isInstanceAttribute = false,
  path = "",
  //   options = [],
  isDisabled = false,
}) => {
  let multiSelectOptions = [];
  let multiSelectOptionsValue = [];
  const editorRef = useRef(null);
  // alert(isDisabled ? "true" : "false");
  if (isTextArea) {
    return (
      <TextArea
        onChange={(e) => {
          handleChange(attributeId, e.target.value, isInstanceAttribute, path);
        }}
        value={value}
        disabled={isDisabled}
      />
    );
  }
  if (allowHTML) {
    return (
      <Editor
        onEditorChange={(e) => {
          handleChange(attributeId, e, isInstanceAttribute, path);
        }}
        onInit={(evt, editor) => (editorRef.current = editor)}
        value={value}
        init={{
          height: 500,
          plugins: [
            "advlist autolink lists link image charmap print preview anchor",
            "searchreplace visualblocks code fullscreen",
            "insertdatetime media table paste code help wordcount",
          ],
          toolbar:
            "undo redo | formatselect | " +
            "bold italic backcolor | alignleft aligncenter " +
            "alignright alignjustify | bullist numlist outdent indent | " +
            "removeformat | help",
          content_style:
            "body { font-family:Helvetica,Arial,sans-serif; font-size:14px }",
          menubar: "file edit view insert format tools table",
        }}
        disabled={isDisabled}
      />
    );
  }
  return (
    <Input
      type="text"
      value={value}
      onChange={(e) => {
        handleChange(attributeId, e.target.value, isInstanceAttribute, path);
      }}
      disabled={isDisabled}
    />
  );
};

export default TypeWiseField;
