import React, { useEffect, useState } from "react";
import { Input, Label, Button } from "reactstrap";
import SelectField from "components/Common/SelectField";
import { useDispatch, useSelector } from "react-redux";
import { fetchBlobList } from "redux/actions/manageProduct/editProduct/blobList";
import { getLocalStorageItem } from "modules/utils";
import { fetchPreviewBlob } from "redux/actions/manageProduct/previewBlob";
import SelectDropdownSearchable from "components/Common/SelectDropdownSearchable";
import { useLocation } from "react-router-dom/cjs/react-router-dom.min";

function PreviewBlob() {
  const dispatch = useDispatch();
  // const ProductId = getLocalStorageItem("ProductId");
  const search = useLocation().search;
  const ProductId = new URLSearchParams(search).get("pid");

  const [blob, setBlob] = useState("");
  const [blobLabel, setBlobLabel] = useState();
  const [blobOP, setBlobOP] = useState([]);
  const [blobType, setBlobType] = useState("htmlcode");
  const {
    isLoading = false,
    blobList = null,
    previewBlob = null,
    previewBlobLoading = false,
  } = useSelector((state) => ({
    blobList: state.blobList?.data?.data || null,
    isLoading: state.blobList?.loading || null,
    previewBlob: state.previewBlob?.data?.data || null,
    previewBlobLoading: state.previewBlob?.loading || null,
  }));

  const renderNewLineValue = (val) => {
    if (val) {
      return val.replace(/\n/g, "<br />");
    }
    return val;
  };

  function createMarkup() {
    return {
      __html: renderNewLineValue(previewBlob),
    };
  }

  useEffect(() => {
    dispatch(fetchBlobList()).then((data) => {
      if (data?.data) {
        setBlob(String(data?.data[0]?.ProductBlobID));
      }
    });
  }, []);

  const blobOptions = () => {
    return blobList?.map((item) => {
      return {
        label: item.ProductBlobName,
        value: item.ProductBlobID,
      };
    });
  };

  const blobOption = blobOptions();

  const submitPreview = () => {
    const formData = {
      blobID: blob,
      productID: ProductId,
      outputType: blobType,
    };
    dispatch(fetchPreviewBlob(formData));
  };

  const handleBlobChange = (itemId) => {
    setBlob(itemId);
  };

  return (
    <div className="bg-white common-space preview-blog-tab">
      <div>
        <div className="preview-blog-select">
          <div className="preview-blog-label">Select Blob</div>
          <div className="col-lg-10">
            {/* <SelectField options={[]} /> */}
            <SelectDropdownSearchable
              name="selectBlob"
              options={blobOption}
              handleChange={(itemId) => {
                setBlob(itemId.value);
                setBlobLabel(itemId);
              }}
              value={blobLabel}
            />
          </div>
          {/* <SelectField
            type="select"
            name="selectOrganization"
            placeholder="Select Organization"
            options={blobOptions()}
            onChange={handleBlobChange}
            value={blob}
          /> */}
        </div>
      </div>
      <div>
        <div className="preview-blog-label">Select Option:</div>
        <div className="d-flex align-center">
          <div className="d-flex align-center custom-radio-btn">
            <Input
              type="radio"
              name="blobType"
              value="html"
              onChange={(e) => {
                setBlobType(e.currentTarget.value);
              }}
              checked={blobType === "html"}
            />
            <Label check>HTML (Preview)</Label>{" "}
          </div>
          <div className="d-flex align-center custom-radio-btn">
            <Input
              type="radio"
              name="blobType"
              value="htmlcode"
              onChange={(e) => setBlobType(e.currentTarget.value)}
              checked={blobType === "htmlcode"}
            />
            <Label check>HTML (Code)</Label>{" "}
          </div>
          <div className="d-flex align-center custom-radio-btn">
            <Input
              type="radio"
              name="blobType"
              value="raw"
              checked={blobType === "raw"}
              onChange={(e) => setBlobType(e.currentTarget.value)}
            />
            <Label check>Raw</Label>{" "}
          </div>
        </div>
      </div>
      <div className="create-file-btn-section mt-3">
        <Button
          className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
          onClick={submitPreview}
        >
          Submit
        </Button>
      </div>
      {previewBlob && (
        <div className="create-file-btn-section mt-3">
          <p>Result </p>
          {blobType === "html" ? (
            <div dangerouslySetInnerHTML={createMarkup()}></div>
          ) : (
            <div className="result-create-section">
              <pre dangerouslySetInnerHTML={createMarkup()}></pre>
            </div>
          )}
        </div>
      )}
    </div>
  );
}

export default PreviewBlob;
