/* eslint-disable react/react-in-jsx-scope */
import { useEffect, useState } from "react";
import { useHistory } from "react-router-dom";
import { useParams } from "react-router-dom/cjs/react-router-dom.min";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import AttributeSetupTabHandler from "./attributes/MasterAttributeSetupTabs/AttributeSetupTabHandler";
import Dashboard from "./dashboardItems/Dashboard";
import Languages from "./languages/Languages";
import ProductBlobs from "./productBlobs/ProductBlobs";
import SelectCatalog from "./selectCatalog/SelectCatalog";
import Templates from "./templates/Templates";
import TextBlockTabs from "./textBlocks/TextBlockTabs";

function MasterSetup(props) {
  const { type, subtype } = useParams();
  console.log("🚀 ~ MasterSetup ~ subtype:", subtype);

  const tabName = type;
  console.log("🚀 ~ MasterSetup ~ tabName:", tabName);
  const initialActiveTab = {
    attributes: tabName == "Attributes" ? "active" : "",
    units: tabName == "Units" ? "active" : "",
    textBlocks: tabName == "TextBlocks" ? "active" : "",
    templates: tabName == "Templates" ? "active" : "",
    languages: tabName == "Languages" ? "active" : "",
    productBlobs: tabName == "ProductBlobs" ? "active" : "",
    selectCatalog: tabName == "SelectCatalog" ? "active" : "",
    dashBoard: tabName == "Dashboard" ? "active" : "",
    // block: tabName == "Block" ? "active" : "",
    activeTab: tabName,
  };
  const [activeTab, setActivetab] = useState(initialActiveTab);
  console.log("🚀 ~ MasterSetup ~ type:", type);
  const history = useHistory();

  useEffect(() => {
    document.title = "Manage Set Up | Producty®";
  }, []);

  useEffect(() => {
    const masterSetupArr = [
      "Attributes",
      "Units",
      "TextBlocks",
      "Templates",
      "Languages",
      "ProductBlobs",
      "SelectCatalog",
      "Dashboard",
      // "Block",
    ];

    if (!masterSetupArr.includes(type || subtype)) {
      // alert(1);
      history.push(`/home`);
    }
    setActivetab({
      attributes: tabName == "Attributes" ? "active" : "",
      units: tabName == "Units" ? "active" : "",
      textBlocks: tabName == "TextBlocks" ? "active" : "",
      templates: tabName == "Templates" ? "active" : "",
      languages: tabName == "Languages" ? "active" : "",
      productBlobs: tabName == "ProductBlobs" ? "active" : "",
      selectCatalog: tabName == "SelectCatalog" ? "active" : "",
      dashBoard: tabName == "Dashboard" ? "active" : "",
      // block: tabName == "Block" ? "active" : "",
      activeTab: type,
    });
  }, [type]);

  const handleTab = (tabName) => {
    history.push(`/Setup/${tabName}`);
  };

  return (
    <div>
      <Nav tabs>
        <NavItem>
          <NavLink
            className={activeTab.attributes}
            onClick={() => handleTab("Attributes")}
          >
            Attributes
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.textBlocks}
            onClick={() => handleTab("TextBlocks")}
          >
            Category Text
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.templates}
            onClick={() => handleTab("Templates")}
          >
            Templates
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.languages}
            onClick={() => handleTab("Languages")}
          >
            Languages
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.productBlobs}
            onClick={() => handleTab("ProductBlobs")}
          >
            Product Blobs
          </NavLink>
        </NavItem>
        <NavItem>
          <NavLink
            className={activeTab.dashBoard}
            onClick={() => handleTab("Dashboard")}
          >
            Dashboard
          </NavLink>
        </NavItem>
        {/* <NavItem>
          <NavLink
            className={activeTab.selectCatalog}
            onClick={() => handleTab("SelectCatalog")}
          >
            Select Catalog
          </NavLink>
        </NavItem> */}
        {/* <NavItem>
          <NavLink
            className={activeTab.block}
            onClick={() => handleTab("Block")}
          >
            Block
          </NavLink>
        </NavItem> */}
      </Nav>
      <TabContent activeTab={activeTab.activeTab}>
        <TabPane tabId="Attributes">
          {activeTab.activeTab === "Attributes" && <AttributeSetupTabHandler />}
        </TabPane>

        <TabPane tabId="TextBlocks">
          {activeTab.activeTab === "TextBlocks" && <TextBlockTabs />}
        </TabPane>
        <TabPane tabId="Templates">
          {activeTab.activeTab === "Templates" && <Templates />}
        </TabPane>
        <TabPane tabId="Languages">
          {activeTab.activeTab === "Languages" && <Languages />}
        </TabPane>
        <TabPane tabId="ProductBlobs">
          {activeTab.activeTab === "ProductBlobs" && <ProductBlobs />}
        </TabPane>
        <TabPane tabId="SelectCatalog">
          {activeTab.activeTab === "SelectCatalog" && <SelectCatalog />}
        </TabPane>
        <TabPane tabId="Dashboard">
          {activeTab.activeTab === "Dashboard" && <Dashboard />}
        </TabPane>
        {/* <TabPane tabId="Block">
          {activeTab.activeTab === "Block" && <Block />}
        </TabPane> */}
      </TabContent>
    </div>
  );
}

export default MasterSetup;
