import InputField from "components/Common/InputField";
import { Form, Formik } from "formik";
import {
  displayFormErrors,
  unitForm,
} from "modules/validations";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import {
  Button,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import { fetchUnitList } from "redux/actions/masterSetup/unitList";
import { fetchGetUnit } from "redux/actions/masterSetup/getUnitDetails";
import { fetchAddUnit } from "redux/actions/masterSetup/addUnit";
import { fetchUpdateUnit } from "redux/actions/masterSetup/updateUnit";

function UnitModal({ isOpen, toggle, saveFunction, searchUnit, editId, setSearchUnit }) {
  const dispatch = useDispatch();

  const [unitOption, setUnitOption] = useState([]);

  const { unitList = null, getUnitDetails = null } = useSelector((state) => ({
    unitList: state.unitList?.data?.data,
    getUnitDetails: state.getUnitDetails?.data?.data || null,
  }));

  useEffect(() => {
    if (editId) {
      dispatch(fetchGetUnit(editId));
    }
  }, []);

  const handleSubmit = (values) => {
    const result = values;
    if (editId) {
      dispatch(fetchUpdateUnit(result)).then(() => {
        dispatch(fetchUnitList());
        setSearchUnit("")
        toggle();
      });
    } else {
      dispatch(fetchAddUnit(result)).then(() => {
        dispatch(fetchUnitList());
        setSearchUnit("")
        toggle();
      });
    }
  };

  const getInitialValues = () => {

    if (editId) {
      return {
        UnitAbbreviation: getUnitDetails?.UnitAbbreviation || searchUnit || "",
        UnitID: getUnitDetails?.UnitID ? String(getUnitDetails?.UnitID) : "",
        UnitDescription: getUnitDetails?.UnitDescription || "",
      };
    }
    return {
      UnitAbbreviation: searchUnit || "",
      UnitDescription: "",
    };
  };

  return (
    <div>
      {isOpen && (
        <Modal
          className="conformation-popup catalog-popup"
          isOpen={isOpen}
          toggle={() => toggle()}
          size={"lg"}
        >
          <ModalHeader toggle={() => toggle()}>
            Add / Edit Units
          </ModalHeader>
          <ModalBody>
            <Formik
              initialValues={getInitialValues()}
              validationSchema={unitForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <>
                    <Form inline="true">
                      <div className="model-label-input">
                        <div className="row">
                          <div className="col-4">
                            <Label>Abbreviation : </Label>
                          </div>
                          <div className="col-8">
                            <InputField
                              type="text"
                              name="UnitAbbreviation"
                              placeholder="Abbreviation"
                              onChange={handleChange}
                              value={values.UnitAbbreviation || ""}
                            />
                            {showError("UnitAbbreviation")}
                          </div>
                        </div>
                      </div>
                      <div className="model-label-input">
                        <div className="row">
                          <div className="col-4">
                            <Label>Description : </Label>
                          </div>
                          <div className="col-8">
                            <InputField
                              type="text"
                              name="UnitDescription"
                              placeholder="Description"
                              onChange={handleChange}
                              value={values.UnitDescription || ""}
                            />
                            {showError("UnitDescription")}
                          </div>
                        </div>
                      </div>
                      <div className="model-bottom-btn-section">
                        <Button
                          color="primary cancel-btn confirm-n"
                          onClick={() => toggle()}
                        >
                          {" "}
                          Cancel
                        </Button>
                        <Button
                          color="primary save-btn confirm-y"
                          onClick={handleSubmit}
                        >
                          {" "}
                          Save changes
                        </Button>
                      </div>
                    </Form>
                  </>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}
    </div>
  );
}

export default UnitModal;
