import InputNormal from "components/Common/InputNormal";
import DeleteModal from "components/Common/Modal/DeleteModal";
import RestrictUserType from "components/Common/RestrictUserType";
import Table from "components/Common/Table";
import { Form, Formik } from "formik";
import { filterFieldData, getStatusArray, isValidArray } from "modules/utils";
import {
  displayFormErrors,
  inviteSellerForm,
  inviteAccountManagerForm,
  inviteUserForm,
  unitForm,
} from "modules/validations";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Button } from "reactstrap";
import { fetchUnitList } from "redux/actions/masterSetup/unitList";
import strings from "../../../data/strings";
import UnitModal from "./UnitModal";
import { fetchDeleteUnit } from "redux/actions/masterSetup/deleteUnit";

function Units() {
  const dispatch = useDispatch();

  const [searchUnit, setSearchUnit] = useState("");

  const [deleteUserModal, setDeleteUserModal] = useState(false);
  const [selectedIdDelete, setSelectedIdDelete] = useState(0);
  const [addUnitModal, setAddUnitModal] = useState(false);
  const [editId, setEditId] = useState(null);

  const {
    isLoading = false,
    unitList = null,
    getUnitDetails = null,
  } = useSelector((state) => ({
    unitList: state.unitList?.data?.data || null,
    isLoading: state.unitList?.loading || null,
    getUnitDetails: state.getUnitDetails?.data?.data || null,
    //isLoading: state.unitList?.loading || null,
  }));

  useEffect(() => {
    dispatch(fetchUnitList());
  }, []);

  const handleAddUnitModal = (id = null) => {
    setEditId(id);
    setAddUnitModal(!addUnitModal);
  };

  const ReactTableColumns = [
    {
      minWidth: 150,
      Header: "Unit ID",
      id: "UnitID",
      accessor: "UnitID",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Unit Abbreviation",
      id: "UnitAbbreviation",
      accessor: "UnitAbbreviation",
      sortable: true,
    },
    {
      minWidth: 200,
      Header: "Unit Description",
      id: "UnitDescription",
      accessor: "UnitDescription",
      sortable: true,
    },
    {
      minWidth: 220,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Button
            onClick={() => {
              handleAddUnitModal(d.UnitID);
            }}
          >
            Edit
          </Button>
          {" | "}
          <Button
            onClick={() => {
              handleDeleteUserModal(d?.UnitID);
            }}
          >
            Delete
          </Button>
        </>
      ),
    },
  ];

  const handleDeleteUserModal = (id = null) => {
    setSelectedIdDelete(id);
    setDeleteUserModal(!deleteUserModal);
  };

  const handleDelete = () => {
    dispatch(fetchDeleteUnit(selectedIdDelete)).then(() => {
      dispatch(fetchUnitList());
      handleDeleteUserModal();
    });
  };

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, unitList, [
        "UnitID",
        "UnitAbbreviation",
        "UnitDescription",
      ]);
    }
    return unitList;
  };

  return (
    <div>
      <div className="tabcontent">
        <InputNormal
          type="text"
          name="Attribute"
          placeholder="Unit"
          value={searchUnit}
          onChange={setSearchUnit}
        />
        <Button onClick={() => handleAddUnitModal()}>Add Unit</Button>
      </div>
      <div className="tableorganisation bg-white manage-user-tbl-section center-text-tbl product-tableBorder">
        <Table
          columns={ReactTableColumns}
          Data={unitList}
          isLoading={isLoading}
          getFilterData={getFilterData}
          searchField={searchUnit}
          sortColumn={{
            id: "UnitID",
            desc: false,
          }}
        />
      </div>

      {addUnitModal && (
        <UnitModal
          isOpen={addUnitModal}
          toggle={handleAddUnitModal}
          searchUnit={searchUnit}
          editId={editId}
          setEditId={setEditId}
          setSearchUnit={setSearchUnit}
        />
      )}
      {deleteUserModal && (
        <DeleteModal
          toggle={handleDeleteUserModal}
          isOpen={deleteUserModal}
          deleteFunction={handleDelete}
        />
      )}
    </div>
  );
}

export default Units;
