import CheckBox from "components/Common/CheckBox";
import InputField from "components/Common/InputField";
import SelectFieldFormik from "components/Common/SelectFieldFormik";
import TextArea from "components/Common/TextArea";
import { Form, Formik } from "formik";
import {
  commonYesNoArray,
  dataTypeArray,
  preferredAttributeArray,
  isMultiImageOptions
} from "modules/utils";
import { displayFormErrors, addAttributeForm } from "modules/validations";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import { fetchAddAttribute } from "redux/actions/masterSetup/addAttribute";
import { fetchAttributeDetail } from "redux/actions/masterSetup/attributeDetails";
import { fetchAttributeList } from "redux/actions/masterSetup/attributeList";
import { fetchUnitList } from "redux/actions/masterSetup/unitList";
import { fetchUpdateAttribute } from "redux/actions/masterSetup/updateAttribute";
import { fetchImageSizeList } from "redux/actions/media/imageSizeList";

function AttributeModal({
  isOpen,
  toggle,
  saveFunction,
  searchResellerEmail,
  editId,
  setSearchResellerEmail,
}) {
  const dispatch = useDispatch();

  const [unitOption, setUnitOption] = useState([]);
  const [imageSize, setImageSize] = useState([]);

  const [multiImage, setMultiImage] = useState(0);
  const [message, setMessage] = useState("");

  const { unitList = null, attributeDetail = null } = useSelector((state) => ({
    unitList: state.unitList?.data?.data,
    attributeDetail: state.attributeDetail?.data?.data,
  }));

  useEffect(() => {
    if (editId) {
      dispatch(fetchAttributeDetail(editId));
    }
    dispatch(fetchUnitList()).then((data) => {
      const updated = data?.data.map((d) => {
        return {
          value: d?.UnitID,
          label: d?.UnitAbbreviation,
        };
      });
      setUnitOption(updated);
    });
    dispatch(fetchImageSizeList()).then((data) => {
      const result = data?.data.map((d) => {
        return {
          value: d?.ImageSizeID,
          label: d?.ImageSizeID,
        };
      });
      setImageSize(result);
    });
  }, []);

  const handleSubmit = (values) => {
    let result = {
      ...values,
      ProductSearch: values?.ProductSearch === true ? "1" : "0",
      AllowMultiLanguage: values?.AllowMultiLanguage === true ? "1" : "0",
      isCatalogAttribute: values?.isCatalogAttribute === true ? "1" : "0",
      InstanceAttribute: values?.InstanceAttribute === true ? "1" : "0",
      isVirtualAttribute: values?.isVirtualAttribute === true ? "1" : "0",
      AllowHTML: values?.AllowHTML === true ? "1" : "0",
      OutputAsImage: values?.OutputAsImage === true ? "1" : "0",
    };

    if (editId) {
      result = {
        ...result,
        AttributeID: attributeDetail?.AttributeID,
      };
      dispatch(fetchUpdateAttribute(result)).then((data) => {
        if (data?.flag) {
          dispatch(fetchAttributeList());
          setSearchResellerEmail("");
          toggle();
        } else {
          setMessage(data?.message);
        }
      });
    } else {
      dispatch(fetchAddAttribute(result)).then((data) => {
        if (data?.flag) {
          dispatch(fetchAttributeList());
          setSearchResellerEmail("");
          toggle();
        } else {
          setMessage(data?.message);
        }
      });
    }
  };

  const getInitialValues = () => {
    if (editId) {
      console.log(attributeDetail?.IsMultiImage);
      return {
        AttributeName:
          attributeDetail?.AttributeName || searchResellerEmail || "",
        UnitID: attributeDetail?.UnitID ? String(attributeDetail?.UnitID) : "",
        PreferredAttribute: attributeDetail?.PreferredAttribute === 1 ? "Yes" : "No",
        ProductSearch: attributeDetail?.ProductSearch === 1 ? true : false,
        OutputAsImage: attributeDetail?.OutputAsImage === 1 ? true : false,
        AllowMultiLanguage: attributeDetail?.AllowMultiLanguage === 1 ? true : false,
        datatype: attributeDetail?.datatype || "varchar(255)",
        AttributePrefix: attributeDetail?.AttributePrefix || "",
        AttributeSuffix: attributeDetail?.AttributeSuffix || "",
        AttributeCleansingText: attributeDetail?.AttributeCleansingText || "",
        InstanceAttribute: attributeDetail?.InstanceAttribute === 1 ? true : false,
        isCatalogAttribute: attributeDetail?.isCatalogAttribute === 1 ? true : false,
        isVirtualAttribute: attributeDetail?.isVirtualAttribute === 1 ? true : false,
        isTextArea: attributeDetail?.isTextArea === 1 ? true : false,
        AllowHTML: attributeDetail?.AllowHTML === 1 ? true : false,
        ImageSizeID: attributeDetail?.ImageSizeID || "",
        IsMultiImage: attributeDetail?.IsMultiImage || 0,
        IsImageURL: attributeDetail?.IsImageURL || 0,
        setValues: attributeDetail?.setValues || "",
        AttributeConcatText: attributeDetail?.AttributeConcatText || "",
      };
    }
    return {
      AttributeName: searchResellerEmail || "",
      UnitID: "",
      PreferredAttribute: "",
      ProductSearch: false,
      OutputAsImage: false,
      AllowMultiLanguage: false,
      datatype: "varchar(255)",
      AttributePrefix: "",
      AttributeSuffix: "",
      AttributeCleansingText: "",
      InstanceAttribute: false,
      isCatalogAttribute: false,
      isVirtualAttribute: false,
      isTextArea: "",
      AllowHTML: false,
      ImageSizeID: "",
      IsMultiImage: 0,
      IsImageURL: 0,
      setValues: "",
      AttributeConcatText: "",
    };
  };

  return (
    <div>
      {isOpen && (
        <Modal
          className="conformation-popup"
          isOpen={isOpen}
          toggle={() => toggle()}
          size={"lg"}
        >
          <ModalHeader toggle={() => toggle()}>
            Add / Edit Attribute
          </ModalHeader>
          <ModalBody>
            <Formik
              initialValues={getInitialValues()}
              validationSchema={addAttributeForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <Form className="model-atttibute-box">
                    <div className="model-label-input">
                      <div className="row align-center">
                        <div className="col-4">
                          <Label>Attribute name :</Label>
                        </div>
                        <div className="col-8">
                          <InputField
                            type="text"
                            name="AttributeName"
                            placeholder="Attribute Name"
                            onChange={handleChange}
                            value={values.AttributeName || ""}
                          />
                        </div>
                        {showError("AttributeName")}
                      </div>
                    </div>
                    <div className="model-label-input">
                      <div className="row align-center">
                        <div className="col-4">
                          <Label>Unit :</Label>
                        </div>
                        <div className="col-8">
                          <SelectFieldFormik
                            type="select"
                            name="UnitID"
                            id="UnitID"
                            placeholder="Select Unit"
                            options={unitOption}
                            onChange={handleChange}
                            value={values.UnitID}
                            isFirstOption={true}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-label-input">
                      <div className="row align-center">
                        <div className="col-4">
                          <Label>Preferred Attribute :</Label>
                        </div>
                        <div className="col-8">
                          <SelectFieldFormik
                            type="select"
                            name="PreferredAttribute"
                            id="PreferredAttribute"
                            placeholder="Select Preferred Attribute"
                            options={preferredAttributeArray}
                            onChange={handleChange}
                            value={values.PreferredAttribute}
                            isFirstOption={true}
                            isLower={true}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-label-input">
                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>Product Search : </Label>{" "}
                        </div>
                        <div className="col-8">
                          <CheckBox
                            type="checkbox"
                            name="ProductSearch"
                            onChange={handleChange}
                            value={values.ProductSearch || ""}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-label-input">
                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>Output As Image : </Label>{" "}
                        </div>
                        <div className="col-8">
                          <CheckBox
                            type="checkbox"
                            name="OutputAsImage"
                            onChange={handleChange}
                            value={values.OutputAsImage || ""}
                          />
                        </div>
                      </div>
                    </div>
                    {values.OutputAsImage && (
                      <div className="model-label-input">
                        <div className="row align-center">
                          <div className="col-4">
                            <Label>Multi-Image :</Label>
                          </div>
                          <div className="col-8">
                            <SelectFieldFormik
                              type="select"
                              name="IsMultiImage"
                              id="IsMultiImage"
                              placeholder="Choose an Option"
                              options={isMultiImageOptions}
                              onChange={handleChange}
                              value={values.IsMultiImage}
                              isFirstOption={true}
                            />
                          </div>
                        </div>
                      </div>
                    )}
                    {values.OutputAsImage && (
                      <div className="model-label-input">
                        <div className="row align-center">
                          <div className="col-4">
                            <Label>Is Image URL :</Label>
                          </div>
                          <div className="col-8">
                            <SelectFieldFormik
                              type="select"
                              name="IsImageURL"
                              id="IsImageURL"
                              placeholder="Choose an Option"
                              options={isMultiImageOptions}
                              onChange={handleChange}
                              value={values.IsImageURL}
                              isFirstOption={true}
                            />
                          </div>
                        </div>
                      </div>
                    )}
                    {values.OutputAsImage && (
                      <div className="model-label-input">
                        <div className="row align-center">
                          <div className="col-4">
                            <Label>Image size Id :</Label>
                          </div>
                          <div className="col-8">
                            <SelectFieldFormik
                              type="select"
                              name="ImageSizeID"
                              id="ImageSizeID"
                              placeholder="Choose an Option"
                              options={imageSize}
                              onChange={handleChange}
                              value={values.ImageSizeID || ""}
                              isFirstOption={true}
                            />
                          </div>
                        </div>
                      </div>
                    )}

                    <div className="model-label-input">
                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>Multi Language : </Label>{" "}
                        </div>
                        <div className="col-8">
                          <CheckBox
                            type="checkbox"
                            name="AllowMultiLanguage"
                            onChange={handleChange}
                            value={values.AllowMultiLanguage || ""}
                          />
                        </div>
                      </div>
                    </div>
                    {!values.AllowMultiLanguage && (
                      <>
                        <div className="model-label-input">
                          <div className="row align-center">
                            <div className="col-4">
                              <Label>Data Type :</Label>
                            </div>
                            <div className="col-8">
                              <SelectFieldFormik
                                type="select"
                                name="datatype"
                                id="datatype"
                                placeholder="Select Data Type"
                                options={dataTypeArray}
                                onChange={handleChange}
                                value={values.datatype}
                                isFirstOption={true}
                              />
                            </div>
                          </div>
                        </div>
                        {values.datatype == "enum" ||
                          values.datatype == "set" ? (
                          <div className="model-label-input">
                            <div className="row align-center">
                              <div className="col-4">
                                <Label>Setup/Enum Values :</Label>
                              </div>
                              <div className="col-8">
                                <TextArea
                                  name="setValues"
                                  placeholder="Setup/Enum Values"
                                  onChange={handleChange}
                                  value={values.setValues || ""}
                                />
                              </div>
                            </div>
                          </div>
                        ) : (
                          ""
                        )}

                        <div className="model-label-input">
                          <div className="row align-center">
                            <div className="col-4">
                              <Label>Attribute Prefix :</Label>
                            </div>
                            <div className="col-8">
                              <InputField
                                type="text"
                                name="AttributePrefix"
                                placeholder="Attribute Prefix"
                                onChange={handleChange}
                                value={values.AttributePrefix || ""}
                              />
                            </div>
                          </div>
                        </div>
                        <div className="model-label-input">
                          <div className="row align-center">
                            <div className="col-4">
                              <Label>Attribute Suffix :</Label>
                            </div>
                            <div className="col-8">
                              <InputField
                                type="text"
                                name="AttributeSuffix"
                                placeholder="Attribute Suffix"
                                onChange={handleChange}
                                value={values.AttributeSuffix || ""}
                              />
                            </div>
                          </div>
                        </div>
                        <div className="model-label-input">
                          <div className="row align-center">
                            <div className="col-4">
                              <Label>Cleanup Options :</Label>
                            </div>
                            <div className="col-8">
                              <TextArea
                                name="AttributeCleansingText"
                                placeholder="Cleanup Options"
                                onChange={handleChange}
                                value={values.AttributeCleansingText || ""}
                              />
                            </div>
                          </div>
                        </div>
                        <div className="model-label-input">
                          <div className="row align-center mb-3">
                            <div className="col-4">
                              <Label check>Instance Attribute : </Label>{" "}
                            </div>
                            <div className="col-8">
                              <CheckBox
                                type="checkbox"
                                name="InstanceAttribute"
                                onChange={handleChange}
                                value={values.InstanceAttribute || ""}
                              />
                            </div>
                          </div>
                        </div>
                        <div className="model-label-input">
                          <div className="row align-center mb-3">
                            <div className="col-4">
                              <Label check>Catalog Attribute : </Label>{" "}
                            </div>
                            <div className="col-8">
                              <CheckBox
                                type="checkbox"
                                name="isCatalogAttribute"
                                onChange={handleChange}
                                value={values.isCatalogAttribute || ""}
                              />
                            </div>
                          </div>
                        </div>
                        <div className="model-label-input">
                          <div className="row align-center mb-3">
                            <div className="col-4">
                              <Label check>Virtual Attribute : </Label>{" "}
                            </div>
                            <div className="col-8">
                              <CheckBox
                                type="checkbox"
                                name="isVirtualAttribute"
                                onChange={handleChange}
                                value={values.isVirtualAttribute || ""}
                              />
                            </div>
                          </div>
                        </div>
                        {values.isVirtualAttribute && (
                          <div className="model-label-input">
                            <div className="row align-center">
                              <div className="col-4">
                                <Label>Virtual Attribute Setup :</Label>
                              </div>
                              <div className="col-8">
                                <TextArea
                                  name="AttributeConcatText"
                                  placeholder="Attribute Statement"
                                  onChange={handleChange}
                                  value={values.AttributeConcatText || ""}
                                />
                              </div>
                            </div>
                          </div>
                        )}
                        {!values.isVirtualAttribute && (
                          <>
                            <div className="model-label-input">
                              <div className="row align-center mb-3">
                                <div className="col-4">
                                  <Label check>Text Area : </Label>{" "}
                                </div>
                                <div className="col-8">
                                  <CheckBox
                                    type="checkbox"
                                    name="isTextArea"
                                    onChange={handleChange}
                                    value={values.isTextArea || ""}
                                  />
                                </div>
                              </div>
                            </div>
                            <div className="model-label-input">
                              <div className="row align-center mb-3">
                                <div className="col-4">
                                  <Label check>Allow HTML : </Label>{" "}
                                </div>
                                <div className="col-8">
                                  <CheckBox
                                    type="checkbox"
                                    name="AllowHTML"
                                    onChange={handleChange}
                                    value={values.AllowHTML || ""}
                                  />
                                </div>
                              </div>
                            </div>
                          </>
                        )}
                      </>
                    )}
                    {message.length > 0 && (
                      <p style={{ color: "red" }}>{message}</p>
                    )}

                    <div className="model-bottom-btn-section">
                      <Button
                        color="primary save-btn confirm-y"
                        onClick={handleSubmit}
                      >
                        {" "}
                        Save changes
                      </Button>
                    </div>
                  </Form>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}
    </div>
  );
}

export default AttributeModal;
