import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Button, Input } from "reactstrap";
import { Steps } from "intro.js-react";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import { fetchAttributeList } from "redux/actions/masterSetup/attributeList";
import { fetchDeleteAttribute } from "redux/actions/masterSetup/deleteAttribute";
import { isValidArray, filterFieldData } from "modules/utils";
import AttributeModal from "./AttributeModal";
import DeleteModal from "components/Common/Modal/DeleteModal";
import "intro.js/introjs.css";
import Table from "components/Common/Table";

function Attributes() {
  const dispatch = useDispatch();

  const [searchResellerEmail, setSearchResellerEmail] = useState("");
  const [editId, setEditId] = useState(null);
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);
  const [addAttributeModal, setAddAttributeModal] = useState(false);
  const [deleteUserModal, setDeleteUserModal] = useState(false);
  const [selectedIdDelete, setSelectedIdDelete] = useState(0);

  const { isLoading = false, attributeList = null } = useSelector((state) => ({
    attributeList: state.attributeList?.data?.data || null,
    isLoading: state.attributeList?.loading || null,
  }));

  useEffect(() => {
    dispatch(fetchAttributeList());

    dispatch(getIntroJs("setup")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = d.elementIDName;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  // const handleRowExpand = (row) => {
  //   // Toggle the row's expanded state
  //   row.toggleRowExpanded();
  // };

  const ReactTableColumns = [
    {
      minWidth: 150,
      Header: "Attribute ID",
      id: "AttributeID",
      // expander: true,
      accessor: (d, row) => {
        return (
          <div className="attribute-bg-icon-text">
            <div>{d.AttributeID}</div>
            <div>{JSON.stringify(d)}</div>
            {d.ColorCode && (
              <div
                className="attribute-id-bg"
                data-toggle="tooltip"
                data-placement="top"
                title={d.TooltipText}
                style={{ backgroundColor: `${d.ColorCode}` }}
              ></div>
            )}
            <div className="custom-expanded-content">
              {d.isExpanded && (
                <div className="custom-expanded-d">
                  <h4>Details for Attribute ID: {d.original.AttributeID}</h4>
                  <div className="custom-form-group">
                    <label htmlFor="customAttributeName">Attribute Name:</label>
                    <input
                      type="text"
                      id="customAttributeName"
                      className="custom-form-control"
                      value={d.original.AttributeName}
                      readOnly
                    />
                  </div>
                  <div className="custom-form-group">
                    <label htmlFor="customDataType">Data Type:</label>
                    <input
                      type="text"
                      id="customDataType"
                      className="custom-form-control"
                      value={d.original.datatype}
                      readOnly
                    />
                  </div>
                  {/* Add more fields as needed */}
                </div>
              )}
            </div>
          </div>
        );
      },
      sortable: true,
      // cell: ({ row }) => (
      //   <div className="custom-expanded-content">
      //     <div className="attribute-bg-icon-text">
      //       <div>{row.AttributeID}</div>
      //       {row.ColorCode && (
      //         <div
      //           className="attribute-id-bg"
      //           data-toggle="tooltip"
      //           data-placement="top"
      //           title={row.TooltipText}
      //           style={{ backgroundColor: `${row.ColorCode}` }}
      //         ></div>
      //       )}
      //     </div>
      //     {row.isExpanded && (
      //       <div className="custom-expanded-row">
      //         <h4>Details for Attribute ID: {row.original.AttributeID}</h4>
      //         <div className="custom-form-group">
      //           <label htmlFor="customAttributeName">Attribute Name:</label>
      //           <input
      //             type="text"
      //             id="customAttributeName"
      //             className="custom-form-control"
      //             value={row.original.AttributeName}
      //             readOnly
      //           />
      //         </div>
      //         <div className="custom-form-group">
      //           <label htmlFor="customDataType">Data Type:</label>
      //           <input
      //             type="text"
      //             id="customDataType"
      //             className="custom-form-control"
      //             value={row.original.datatype}
      //             readOnly
      //           />
      //         </div>
      //         {/* Add more fields as needed */}
      //       </div>
      //     )}
      //   </div>
      // ),
      Cell: ({ row }) => (
        // Use the row.canExpand and row.getToggleRowExpandedProps prop getter
        // to build the toggle for expanding a row
        <>
          <div className="attribute-bg-icon-text">
            <div>{row?.AttributeID}</div>
            {row.ColorCode && (
              <div
                className="attribute-id-bg"
                data-toggle="tooltip"
                data-placement="top"
                title={row.TooltipText}
                style={{ backgroundColor: `${row.ColorCode}` }}
              ></div>
            )}
          </div>
          <div className="custom-expanded-content">
            {row.isExpanded && (
              <div className="custom-expanded-row">
                <h4>Details for Attribute ID: {row.original.AttributeID}</h4>
                <div className="custom-form-group">
                  <label htmlFor="customAttributeName">Attribute Name:</label>
                  <input
                    type="text"
                    id="customAttributeName"
                    className="custom-form-control"
                    value={row.original.AttributeName}
                    readOnly
                  />
                </div>
                <div className="custom-form-group">
                  <label htmlFor="customDataType">Data Type:</label>
                  <input
                    type="text"
                    id="customDataType"
                    className="custom-form-control"
                    value={row.original.datatype}
                    readOnly
                  />
                </div>
                {/* Add more fields as needed */}
              </div>
            )}
          </div>
        </>
      ),
    },
    {
      minWidth: 300,
      Header: "Attribute Name",
      id: "AttributeName",
      accessor: "AttributeName",
      sortable: true,
    },
    {
      minWidth: 200,
      Header: "Data Type",
      id: "datatype",
      accessor: "datatype",
      sortable: true,
    },
    {
      minWidth: 60,
      Header: "Unit",
      id: "UnitID",
      accessor: "UnitID",
      sortable: true,
    },
    {
      minWidth: 130,
      Header: "Product Search",
      id: "ProductSearch",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.ProductSearch ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 100,
      Header: "Preferred",
      id: "PreferredAttribute",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.PreferredAttribute ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 100,
      Header: "Catalog",
      id: "isCatalogAttribute",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.isCatalogAttribute ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 100,
      Header: "Virtual",
      id: "isVirtualAttribute",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.isVirtualAttribute ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 100,
      Header: "Instance",
      id: "InstanceAttribute",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.InstanceAttribute ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 130,
      Header: "Multi-language",
      id: "AllowMultiLanguage",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.AllowMultiLanguage ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 100,
      Header: "Text Area",
      id: "isTextArea",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.isTextArea ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 100,
      Header: "HTML",
      id: "AllowHTML",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.AllowHTML ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 220,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Button onClick={() => handleAddAttributeModal(d.AttributeID)}>
            Edit
          </Button>
          {" | "}
          <Button onClick={() => handleDelAttributeModal(d.AttributeID)}>
            Delete
          </Button>
        </>
      ),
    },
  ];

  const handleAddAttributeModal = (id = null) => {
    setEditId(id);
    setAddAttributeModal(!addAttributeModal);
  };

  const handleDelAttributeModal = (id) => {
    setSelectedIdDelete(id);
    setDeleteUserModal(!deleteUserModal);
  };

  const handleDelete = () => {
    dispatch(fetchDeleteAttribute(selectedIdDelete)).then(() => {
      dispatch(fetchAttributeList());
      setDeleteUserModal(false);
    });
  };

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm?.toLowerCase().replace(/[^a-zA-Z0-9 ]/g, "");
      return filterFieldData(value, attributeList, [
        "AttributeID",
        "AttributeName",
        "datatype",
        "UnitID",
      ]);
    }
    return attributeList;
  };

  const handleRowExpand = (row) => {
    console.log("🚀 ~ handleRowExpand ~ row:", row);
    // Toggle the row's expanded state
    row?.toggleRowExpanded();
  };

  return (
    <div>
      <Steps
        enabled={stepsEnabled}
        steps={steps}
        initialStep={initialStep}
        onExit={() => setStepsEnabled(false)}
        onComplete={() => setStepsEnabled(false)}
        options={{ doneLabel: "Done" }}
      />

      <div className="introjs-btns">
        <Button
          color="primary"
          onClick={() => setStepsEnabled(true)}
          className="introjs-btn"
        >
          Setup Intro
        </Button>
      </div>

      <AttributeModal
        isOpen={addAttributeModal}
        toggle={() => handleAddAttributeModal()}
        editId={editId}
      />

      <DeleteModal
        isOpen={deleteUserModal}
        toggle={() => setDeleteUserModal(!deleteUserModal)}
        handleDelete={() => handleDelete()}
        message="Are you sure you want to delete this attribute?"
      />

      <div>
        <div className="custom-content-body">
          <Table
            columns={ReactTableColumns}
            Data={attributeList}
            isLoading={isLoading}
            getFilterData={getFilterData}
            isSearchRequired={true}
            isDataPerPage={true}
            totalRecordVisible={true}
            showPagination={true}
            downloadName="Attributes"
            isDownloadExcel={false}
            className="asas"
            // getTrProps={(state, rowInfo) => ({
            //   onClick: () => {
            //     handleRowExpand(rowInfo);
            //   },
            // })}
            // getTrProps={(state, rowInfo, column, instance) => {
            //   return {
            //     onClick: (e, handleOriginal) => {
            //       handleRowExpand(rowInfo);
            //     },
            //   };
            // }}
            handleRowExpand={handleRowExpand}
          />
        </div>
      </div>
    </div>
  );
}

export default Attributes;
