import React, { useEffect, useState } from "react";
import Table from "components/Common/Table";
import { useDispatch, useSelector } from "react-redux";
import Switch from "react-switch";
import { fetchGetDashboardItemsList } from "redux/actions/masterSetup/getDashboardItemsList";
import { fetchUpdateDashboardListItem } from "redux/actions/masterSetup/updateDashboardListItem";

const Dashboard = () => {
  const { isLoading = false, dashboardItem = null } = useSelector((state) => ({
    dashboardItem: state.getDashboardItemsList.data?.data,
    isLoading: state.getDashboardItemsList?.loading || false,
  }));

  const dispatch = useDispatch();

  useEffect(() => {
    getDashboardItemsList();
  }, []);

  const getDashboardItemsList = () => {
    dispatch(fetchGetDashboardItemsList()).then((data) => {});
  };

  const updateDashboard = (id, isVisible) => {
    const formData = {
      DashboardItemID: String(id),
      IsVisible: String(isVisible ? 1 : 0),
    };
    dispatch(fetchUpdateDashboardListItem(formData)).then((data) => {
      getDashboardItemsList();
    });
  };

  const columns = [
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          Dashboard Item ID
        </div>
      ),
      id: "DashboardItemID",
      accessor: "DashboardItemID",
    },
    {
      minWidth: 150,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          Dashboard Header
        </div>
      ),
      id: "DashboardHeading",
      accessor: "DashboardHeading",
    },
    {
      minWidth: 300,
      Header: () => (
        <div
          style={{
            textAlign: "center",
          }}
        >
          Show / Hide
        </div>
      ),
      accessor: "DashboardItemIsVisible",
      Cell: (d) => {
        if (d?.original?.CanHide == 1) {
          return (
            <Switch
              onChange={() => {
                dashboardItem.map((item) => {
                  if (d.original.DashboardItemID === item.DashboardItemID) {
                    updateDashboard(
                      item.DashboardItemID,
                      !item.DashboardItemIsVisible
                    );
                  }
                });
              }}
              checked={d.original.DashboardItemIsVisible === 1 ? true : false}
              uncheckedIcon={false}
              checkedIcon={false}
            />
          );
        }
      },
    },
  ];

  return (
    <>
      <div className="tableorganisation bg-white manage-user-tbl-section center-text-tbl product-tableBorder">
        <Table
          columns={columns}
          isSearchRequired={false}
          Data={dashboardItem}
          getFilterData={() => dashboardItem}
          isLoading={isLoading}
          isDataPerPage={false}
          totalRecordVisible={false}
          showPagination={false}
        />
      </div>
    </>
  );
};

export default Dashboard;
