import CheckBox from "components/Common/CheckBox";
import SelectDropdownSearchable from "components/Common/SelectDropdownSearchable";
import { Form, Formik } from "formik";
import { isValidArray } from "modules/utils";
import { displayFormErrors, languageForm } from "modules/validations";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import AsyncSelect from "react-select/async";
import { Button, Label, Modal, ModalBody, ModalHeader } from "reactstrap";
import { fetchAddLanguage } from "redux/actions/masterSetup/addLanguage";
import { fetchCatalogLanguageList } from "redux/actions/masterSetup/catalogLanguageList";
import { fetchFlagList } from "redux/actions/masterSetup/flagList";
import { fetchGetLanguage } from "redux/actions/masterSetup/getLanguageDetails";
import { fetchLanguageList } from "redux/actions/masterSetup/languageList";
import { fetchRegionList } from "redux/actions/masterSetup/regionList";
import { fetchUpdateLanguage } from "redux/actions/masterSetup/updateLanguage";

function LanguageModal({ isOpen, toggle, saveFunction, editId }) {
  const dispatch = useDispatch();

  const [unitOption, setUnitOption] = useState([]);
  const [languageListOption, setLanguageListOption] = useState([]);
  const [regionListOption, setRegionListOption] = useState([]);
  const [flagListOption, setFlagListOption] = useState([]);

  const {
    isLanguageLoading = false,
    languageList = [],
    isRegionLoading = false,
    regionList = [],
    isFlagLoading = false,
    flagList = [],
    isGetLanguageDetailsLoading = false,
    getLanguageDetails = null,
  } = useSelector((state) => ({
    languageList: state.languageList?.data?.data,
    isLanguageLoading: state.languageList?.loading,
    regionList: state.regionList?.data?.data,
    isRegionLoading: state.regionList?.loading,
    isGetLanguageDetailsLoading: state.getLanguageDetails?.loading,
    getLanguageDetails: state.getLanguageDetails?.data?.data,
  }));

  useEffect(() => {
    dispatch(fetchLanguageList()).then((data) => {
      const result = data?.data.map((d) => {
        return {
          value: d?.LanguageID,
          label: d?.LanguageDescription,
        };
      });
      setLanguageListOption(result);
    });
  }, []);
  useEffect(() => {
    if (editId) {
      dispatch(fetchGetLanguage(editId));
      getRegionList();
      getFlagList();
    }
  }, []);

  const handleSubmit = (values) => {
    if (editId) {
      const result = {
        LanguageID: values?.language?.value || "",
        EnableRegion: values.EnableRegion ? 1 : 0,
        RegionID: values?.RegionID?.value || "",
        EnableFlag: values.EnableFlag ? 1 : 0,
        ShowFlagID: values?.ShowFlagID?.value || "",
        DisplayInCollections: values.DisplayInCollections ? 1 : 0,
        IsDefault: values.IsDefault ? 1 : 0,
        CatalogLanguageID: getLanguageDetails.CatalogLanguageID,
      };
      dispatch(fetchUpdateLanguage(result)).then(() => {
        dispatch(fetchCatalogLanguageList());
        toggle();
      });
    } else {
      const result = {
        LanguageID: values?.language?.value || "",
        EnableRegion: values.EnableRegion ? 1 : 0,
        RegionID: values?.RegionID?.value || "",
        EnableFlag: values.EnableFlag ? 1 : 0,
        ShowFlagID: values?.ShowFlagID?.value || "",
        DisplayInCollections: values.DisplayInCollections ? 1 : 0,
        IsDefault: values.IsDefault ? 1 : 0,
      };
      dispatch(fetchAddLanguage(result)).then(() => {
        dispatch(fetchCatalogLanguageList());
        toggle();
      });
    }
  };
  const getRegionList = () => {
    if (!isValidArray(regionList)) {
      dispatch(fetchRegionList()).then((data) => {
        const regionListData = data?.data.map((d) => {
          return {
            value: d?.LanguageID,
            label: d?.LanguageDescription,
          };
        });
        setRegionListOption(regionListData);
      });
    } else {
      const regionListData = regionList.map((d) => {
        return {
          value: d?.LanguageID,
          label: d?.LanguageDescription,
        };
      });
      setRegionListOption(regionListData);
    }
  };
  const getFlagList = () => {
    if (!isValidArray(flagList)) {
      dispatch(fetchFlagList()).then((data) => {
        const flagListData = data?.data.map((d) => {
          return {
            value: d?.FlagID,
            label: d?.FlagCountryName,
            image: d.FlagImagePath,
          };
        });
        setFlagListOption(flagListData);
      });
    } else {
      const flagListData = flagList.map((d) => {
        return {
          value: d?.FlagID,
          label: d?.FlagCountryName,
          image: d.FlagImagePath,
        };
      });
      setFlagListOption(flagListData);
    }
  };

  const getInitialValues = () => {
    if (editId) {
      let RegionIDObj = regionListOption.find(
        (o) => o.value === getLanguageDetails?.RegionID
      );
      let LanguageIDObj = languageListOption.find(
        (o) => o.value === getLanguageDetails?.LanguageID
      );
      let ShowFlagIDObj = flagListOption.find(
        (o) => o.value === getLanguageDetails?.ShowFlagID
      );

      return {
        EnableRegion: Number(getLanguageDetails?.EnableRegion) ? true : false,
        EnableFlag: Number(getLanguageDetails?.EnableFlag) ? true : false,
        language: LanguageIDObj,
        DisplayInCollections: Number(getLanguageDetails?.DisplayInCollections)
          ? true
          : false,
        IsDefault: Number(getLanguageDetails?.IsDefault) ? true : false,
        ShowFlagID: ShowFlagIDObj,
        RegionID: RegionIDObj,
      };
    }
    return {
      EnableRegion: false,
      EnableFlag: false,
      language: "",
      DisplayInCollections: false,
      IsDefault: false,
      ShowFlagID: "",
      RegionID: "",
    };
  };

  return (
    <div>
      {isOpen && (
        <Modal
          className="conformation-popup catalog-popup languageModel-add-edit"
          isOpen={isOpen}
          toggle={() => toggle()}
          size={"lg"}
        >
          <ModalHeader toggle={() => toggle()}>Add / Edit Language</ModalHeader>
          <ModalBody>
            <Formik
              initialValues={getInitialValues()}
              validationSchema={languageForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <>
                    <Form inline="true">
                      <div className="model-label-input add-edit-model-language">
                        <div className="row">
                          <div className="col-4">
                            <Label>Language : </Label>
                          </div>
                          <div className="col-8">
                            <SelectDropdownSearchable
                              name="language"
                              placeholder="Select Language"
                              options={
                                isValidArray(languageListOption) &&
                                languageListOption
                              }
                              isLoading={isLanguageLoading}
                              handleChange={(value) => {
                                setFieldValue("language", value);
                              }}
                              value={values?.language || ""}
                            />
                            {showError("language")}
                          </div>
                        </div>
                      </div>
                      <div className="model-label-input">
                        <div className="row align-center mb-3">
                          <div className="col-4">
                            <Label check>Enable Region : </Label>{" "}
                          </div>
                          <div className="col-8">
                            <CheckBox
                              type="checkbox"
                              name="EnableRegion"
                              onChange={(e) => {
                                setFieldValue("EnableRegion", e.target.checked);
                                getRegionList();
                                !e.target.checked &&
                                  setFieldValue("RegionID", "");
                              }}
                              value={values.EnableRegion || ""}
                            />
                          </div>
                        </div>
                      </div>
                      {values?.EnableRegion && (
                        <>
                          {" "}
                          <div className="model-label-input add-edit-model-language">
                            <div className="row">
                              <div className="col-4">
                                <Label>Region : </Label>
                              </div>
                              <div className="col-8">
                                <SelectDropdownSearchable
                                  name="RegionID"
                                  options={
                                    isValidArray(regionListOption) &&
                                    regionListOption
                                  }
                                  isLoading={isRegionLoading}
                                  handleChange={(value) => {
                                    setFieldValue("RegionID", value);
                                  }}
                                  value={values?.RegionID || ""}
                                />
                              </div>
                            </div>
                          </div>
                        </>
                      )}
                      <div className="model-label-input">
                        <div className="row align-center mb-3">
                          <div className="col-4">
                            <Label check>Show Flag: </Label>{" "}
                          </div>
                          <div className="col-8">
                            <CheckBox
                              type="checkbox"
                              name="EnableFlag"
                              onChange={(e) => {
                                setFieldValue("EnableFlag", e.target.checked);
                                getFlagList();
                                !e.target.checked &&
                                  setFieldValue("ShowFlagID", "");
                              }}
                              value={values.EnableFlag || ""}
                            />
                          </div>
                        </div>
                      </div>
                      {values?.EnableFlag && (
                        <>
                          {" "}
                          <div className="model-label-input add-edit-model-language">
                            <div className="row">
                              <div className="col-4">
                                <Label>Select Flag : </Label>
                              </div>
                              <div className="col-8">
                                <SelectDropdownSearchable
                                  name="ShowFlagID"
                                  options={
                                    isValidArray(flagListOption) &&
                                    flagListOption
                                  }
                                  isLoading={isFlagLoading}
                                  handleChange={(value) => {
                                    setFieldValue("ShowFlagID", value);
                                  }}
                                  value={values?.ShowFlagID || ""}
                                  menuIsOpenFlag={true}
                                />
                              </div>
                            </div>
                          </div>
                        </>
                      )}
                      <div className="model-label-input">
                        <div className="row align-center mb-3">
                          <div className="col-4">
                            <Label check>Display in Collection : </Label>{" "}
                          </div>
                          <div className="col-8">
                            <CheckBox
                              type="checkbox"
                              name="DisplayInCollections"
                              onChange={handleChange}
                              value={values.DisplayInCollections || ""}
                            />
                          </div>
                        </div>
                      </div>
                      <div className="model-label-input">
                        <div className="row align-center mb-3">
                          <div className="col-4">
                            <Label check>Default: </Label>{" "}
                          </div>
                          <div className="col-8">
                            <CheckBox
                              type="checkbox"
                              name="IsDefault"
                              onChange={handleChange}
                              value={values.IsDefault || ""}
                            />
                          </div>
                        </div>
                      </div>
                      <div className="model-bottom-btn-section">
                        <Button
                          color="primary cancel-btn confirm-n"
                          onClick={() => toggle()}
                        >
                          {" "}
                          Cancel
                        </Button>
                        <Button
                          color="primary save-btn confirm-y"
                          onClick={handleSubmit}
                        >
                          {" "}
                          Save changes
                        </Button>
                      </div>
                    </Form>
                  </>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}
    </div>
  );
}

export default LanguageModal;
