import Loader from "components/Common/Loader";
import DeleteModal from "components/Common/Modal/DeleteModal";
import SelectField from "components/Common/SelectField";
import Table from "components/Common/Table";
import { filterFieldData, isValidArray } from "modules/utils";
import React, { useEffect, useState } from "react";
import { DragDropContext, Draggable, Droppable } from "react-beautiful-dnd";
import { useDispatch, useSelector } from "react-redux";
import Switch from "react-switch";
import { Button, Input, Label } from "reactstrap";
import { fetchCatalogLanguageList } from "redux/actions/masterSetup/catalogLanguageList";
import { fetchDeleteLanguage } from "redux/actions/masterSetup/deleteLanguage";
import { fetchDeleteUnit } from "redux/actions/masterSetup/deleteUnit";
import { fetchDisableMultiLanguage } from "redux/actions/masterSetup/disableMultiLanguage";
import { fetchEnableMultiLanguage } from "redux/actions/masterSetup/enableMultiLangauge";
import { fetchLanguageList } from "redux/actions/masterSetup/languageList";
import { fetchUpdateLanguageSortOrder } from "redux/actions/masterSetup/updateLanguageSortOrder";
import { fetchGetUserCatalogDetail } from "redux/actions/output/getUserCatalogDetail";
import LanguageModal from "./LanguageModal";

function Languages() {
  const dispatch = useDispatch();
  const [displayEmptyValue, setDisplayEmptyValue] = useState(false);
  const [addLanguageModal, setaddLanguageModal] = useState(false);
  const [editId, setEditId] = useState(null);
  const [deleteLanguageModal, setDeleteLanguageModal] = useState(false);
  const [selectedIdDelete, setSelectedIdDelete] = useState(0);
  const [items, setItems] = useState([]);

  const {
    isLoading = false,
    languageList = null,
    catalogLanguageList = null,
  } = useSelector((state) => ({
    languageList: state.languageList?.data?.data || null,
    isLoading: state.catalogLanguageList?.loading || null,
    catalogLanguageList: state.catalogLanguageList?.data?.data || null,
    getUserCatalogDetail: state.getUserCatalogDetail.data?.data,
  }));

  useEffect(() => {
    getInitialData();
  }, []);

  const getInitialData = () => {
    dispatch(fetchCatalogLanguageList()).then((data) => {
      return setItems(data.data);
    });
    dispatch(fetchGetUserCatalogDetail()).then((data) => {
      data?.data?.enableMultiLanguage
        ? setDisplayEmptyValue(true)
        : setDisplayEmptyValue(false);
    });
  };
  const handleAddLanguageModal = (id = null) => {
    setEditId(id);
    setaddLanguageModal(!addLanguageModal);
  };
  const LanguageOptions = () => {
    let updated =
      isValidArray(languageList) &&
      languageList?.map((item) => {
        return {
          label: item.OrganisationName,
          value: item.OrganisationID,
        };
      });

    updated = isValidArray(updated)
      ? [{ label: "Select Organization", value: "" }, ...updated]
      : [{ label: "Select Organization", value: "" }];

    return updated;
  };
  const handleDeleteLanguageModal = (id = null) => {
    setSelectedIdDelete(id);
    setDeleteLanguageModal(!deleteLanguageModal);
  };

  const handleDelete = () => {
    dispatch(fetchDeleteLanguage(selectedIdDelete)).then(() => {
      dispatch(fetchCatalogLanguageList());
      handleDeleteLanguageModal();
    });
  };

  const handleToggleChange = (item) => {
    setDisplayEmptyValue(item);
    if (item) {
      dispatch(fetchEnableMultiLanguage());
    } else {
      dispatch(fetchDisableMultiLanguage());
    }
  };

  const reorder = (list, startIndex, endIndex) => {
    const result = Array.from(list);
    const [removed] = result.splice(startIndex, 1);
    result.splice(endIndex, 0, removed);

    return result;
  };

  const onDragEnd = (e) => {
    if (!e.destination) {
      return;
    }
    const sorted = reorder(items, e.source.index, e.destination.index);

    setItems(sorted);
    let attributeId = [];
    sorted.map((d, i) => {
      attributeId = [...attributeId, d.CatalogLanguageID];
    });

    let formData = new FormData();
    formData.append("languagesArray", attributeId);

    dispatch(fetchUpdateLanguageSortOrder(formData)).then((data) => {
      getInitialData();
    });
  };

  return (
    <div>
      <div className="d-flex justify-content-between manage-attribute-tab">
        <div className="manage-attribute-left language-add-model">
          <div className="d-flex align-center">
            <Label check>Enable multi-language for this catalog </Label>{" "}
            <Switch
              className="switch-btn"
              uncheckedIcon={false}
              name="displayValue"
              checkedIcon={false}
              width={44}
              height={20}
              onChange={(e) => handleToggleChange(e)}
              checked={displayEmptyValue}
            />
          </div>
          {displayEmptyValue ? (
            <Button onClick={() => handleAddLanguageModal()}>
              Add Language
            </Button>
          ) : (
            ""
          )}
        </div>
      </div>
      <div className="layout-template-section">
        <div className="tableorganisation category-table attributeschemaTable center-text-tbl">
          {isValidArray(catalogLanguageList) && (
            <DragDropContext onDragEnd={onDragEnd}>
              <Droppable droppableId="Table">
                {(provided) => (
                  <table
                    {...provided.droppableProps}
                    ref={provided.innerRef}
                    border={"2px"}
                  >
                    <thead className="text-center">
                      <th>Flag</th>
                      <th>Language Name</th>
                      <th>Region</th>
                      <th>Default</th>
                      <th>SortOrder</th>
                      <th>Display In Collections</th>
                      <th>Operations</th>
                    </thead>
                    <tbody>
                      {items.map((item, index) => (
                        <Draggable
                          key={item.CatalogLanguageID}
                          draggableId={String(item.CatalogLanguageID)}
                          index={index}
                          isDragDisabled={false}
                        >
                          {(provided) => (
                            <tr
                              ref={provided.innerRef}
                              {...provided.draggableProps}
                              {...provided.dragHandleProps}
                              className="text-center"
                            >
                              <td>
                                <img
                                  src={item.FlagImage}
                                  className="icon-flag"
                                />
                              </td>

                              <td>{item?.LanguageName}</td>
                              <td>{item?.RegionName}</td>
                              <td>{item?.IsDefault ? "Yes" : "No"}</td>
                              <td>{item?.SortOrder}</td>
                              <td>
                                <Input
                                  type="checkbox"
                                  name=""
                                  checked={
                                    item.DisplayInCollections ? "checked" : ""
                                  }
                                  disabled
                                />
                              </td>
                              <td>
                                <Button
                                  onClick={() => {
                                    handleAddLanguageModal(
                                      item.CatalogLanguageID
                                    );
                                  }}
                                >
                                  Edit
                                </Button>
                                {" | "}
                                <Button
                                  onClick={() => {
                                    handleDeleteLanguageModal(
                                      item?.CatalogLanguageID
                                    );
                                  }}
                                >
                                  Delete
                                </Button>
                              </td>
                            </tr>
                          )}
                        </Draggable>
                      ))}
                      {provided.placeholder}
                    </tbody>
                  </table>
                )}
              </Droppable>
            </DragDropContext>
          )}
        </div>
      </div>

      {addLanguageModal && (
        <LanguageModal
          isOpen={addLanguageModal}
          toggle={handleAddLanguageModal}
          editId={editId}
          setEditId={setEditId}
        />
      )}
      {deleteLanguageModal && (
        <DeleteModal
          toggle={handleDeleteLanguageModal}
          isOpen={deleteLanguageModal}
          deleteFunction={handleDelete}
        />
      )}
    </div>
  );
}

export default Languages;
