import React, { useEffect, useState } from "react";
import { Input, Label, Button } from "reactstrap";

import { useDispatch, useSelector } from "react-redux";

import { getLocalStorageItem } from "modules/utils";
import { fetchPreviewBlob } from "redux/actions/manageProduct/previewBlob";
import { useParams } from "react-router-dom/cjs/react-router-dom.min";

import ProductSearch from "./ProductSearch";

function PreviewBlob() {
  const dispatch = useDispatch();
  const ProductId = getLocalStorageItem("ProductId");
  const { productBlobId } = useParams();

  const [blob, setBlob] = useState("");
  const [blobType, setBlobType] = useState("htmlcode");
  const {
    isLoading = false,
    searchProductBlobList = null,
    previewBlob = null,
    previewBlobLoading = false,
  } = useSelector((state) => ({
    searchProductBlobList: state.searchProductBlob?.data?.data || null,
    isLoading: state.blobList?.loading || null,
    previewBlob: state.previewBlob?.data?.data || null,
    previewBlobLoading: state.previewBlob?.loading || null,
  }));

  useEffect(() => {
    document.title = "Preview Blob | Producty®";
  }, []);

  function createMarkup() {
    return { __html: previewBlob };
  }

  const submitPreview = () => {
    const formData = {
      blobID: productBlobId,
      productID: blob?.value,
      outputType: blobType,
    };
    dispatch(fetchPreviewBlob(formData));
  };

  const handleBlobChange = (itemId) => {
    setBlob(itemId);
  };

  return (
    <div className="bg-white common-space preview-blog-tab">
      <div>
        <div className="preview-blog-select">
          <h4>Preview Blob</h4>
          <div className="preview-blog-label">Select Product</div>
          <ProductSearch handleBlobChange={handleBlobChange} blob={blob} />
          {/* <SelectDropdownSearchable
            type="select"
            name="selectOrganization"
            placeholder="Select Product"
            options={blobOptions()}
            handleChange={handleBlobChange}
            value={blob}
          /> */}
        </div>
      </div>
      <div>
        <div className="preview-blog-label">Select Option:</div>
        <div className="d-flex align-center">
          <div className="d-flex align-center custom-radio-btn">
            <Input
              type="radio"
              name="blobType"
              value="html"
              onChange={(e) => {
                setBlobType(e.currentTarget.value);
              }}
              checked={blobType === "html"}
            />
            <Label check>HTML (Preview)</Label>{" "}
          </div>
          <div className="d-flex align-center custom-radio-btn">
            <Input
              type="radio"
              name="blobType"
              value="htmlcode"
              onChange={(e) => setBlobType(e.currentTarget.value)}
              checked={blobType === "htmlcode"}
            />
            <Label check>HTML (Code)</Label>{" "}
          </div>
          <div className="d-flex align-center custom-radio-btn">
            <Input
              type="radio"
              name="blobType"
              value="raw"
              checked={blobType === "raw"}
              onChange={(e) => setBlobType(e.currentTarget.value)}
            />
            <Label check>Raw</Label>{" "}
          </div>
        </div>
      </div>
      <div className="create-file-btn-section">
        <Button
          className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
          onClick={submitPreview}
        >
          Submit
        </Button>
      </div>
      {previewBlob && (
        <div className="create-file-btn-section">
          <p>Result </p>
          <div dangerouslySetInnerHTML={createMarkup()}></div>
        </div>
      )}
    </div>
  );
}

export default PreviewBlob;
