import InputField from "components/Common/InputField";
import DeleteModal from "components/Common/Modal/DeleteModal";
import RestrictUserType from "components/Common/RestrictUserType";
import Table from "components/Common/Table";
import CreatableSelect from "react-select/creatable";
import { Form, Formik } from "formik";
import {
  filterFieldData,
  getStatusArray,
  isValidArray,
  setLocalStorageItem,
} from "modules/utils";
import {
  displayFormErrors,
  addProductBlobForm,
  editProductBlobForm,
} from "modules/validations";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import { fetchProductBlobList } from "redux/actions/masterSetup/productBlobList";
import { fetchGetBlobDetail } from "redux/actions/masterSetup/getBlobDetail";
import { fetchUpdateProductBlob } from "redux/actions/masterSetup/updateProductBlob";
import { fetchAddProductBlob } from "redux/actions/masterSetup/addProductBlob";

import strings from "../../../data/strings";
import "react-accessible-accordion/dist/fancy-example.css";
import { Link } from "react-router-dom";
import TextArea from "components/Common/TextArea";
import CheckBox from "components/Common/CheckBox";
import { fetchDeleteProductBlob } from "redux/actions/masterSetup/deleteProductBlob";
import { Collapse } from "reactstrap";

function ProductBlobs() {
  const dispatch = useDispatch();
  const [editBlobModal, setEditBlobModal] = useState(false);
  const [addAttributeModal, setAddAttributeModal] = useState(false);
  const [deleteBlobModal, setDeleteBlobModal] = useState(false);
  const [selectedIdUpdate, setSelectedIdUpdate] = useState(0);
  const [selectedIdDelete, setSelectedIdDelete] = useState(0);
  const [isOpen, setIsOpen] = useState(false);

  const {
    isLoading = false,
    productBlobList = null,
    blobDetail = null,
  } = useSelector((state) => ({
    productBlobList: state.productBlobList?.data?.data || null,
    blobDetail: state.getBlobDetail?.data?.data || null,
    isLoading: state.productBlobList?.loading || null,
  }));

  useEffect(() => {
    dispatch(fetchProductBlobList());
  }, []);

  const handleEditBlobModal = (id = 0) => {
    setEditBlobModal(!editBlobModal);
    if (id) {
      dispatch(fetchGetBlobDetail(id)).then((data) => {});
    }
  };

  const handleAddAttributeModal = () => {
    setAddAttributeModal(!addAttributeModal);
    setIsOpen(!isOpen);
  };

  const handleDeleteBlobModal = () => {
    setDeleteBlobModal(!deleteBlobModal);
  };

  const handleDeleteBlob = () => {
    dispatch(fetchDeleteProductBlob(selectedIdDelete)).then((data) => {
      dispatch(fetchProductBlobList());
      handleDeleteBlobModal();
    });
  };

  const ReactTableColumns = [
    {
      minWidth: 70,
      Header: "Blob ID",
      id: "ProductBlobID",
      accessor: "ProductBlobID",
      sortable: true,
    },
    {
      minWidth: 120,
      Header: "Blob Name",
      id: "ProductBlobName",
      accessor: "ProductBlobName",
      sortable: true,
    },
    {
      minWidth: 150,
      Header: "Additional Headers",
      id: "ProductBlobHeaders",
      accessor: "ProductBlobHeaders",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Blob Data",
      id: "ProductBlobData",
      accessor: "ProductBlobData",
      sortable: true,
    },
    {
      minWidth: 100,
      Header: "Blob Cleansing",
      id: "BlobCleansing",
      accessor: "BlobCleansing",
      sortable: true,
    },
    {
      minWidth: 150,
      Header: "Remove Empty Lines ?",
      id: "RemoveEmptyLines",
      accessor: (d) => (d.RemoveEmptyLines ? "Yes" : "No"),
      sortable: true,
    },
    {
      minWidth: 140,
      Header: "Unique Category Values?",
      id: "UniqueCategoryValues",
      accessor: (d) => (d.UniqueCategoryValues ? "Yes" : "No"),
      sortable: true,
    },
    {
      minWidth: 110,
      Header: "Keyword Reformat?",
      id: "KeywordReformat",
      accessor: (d) => (d.KeywordReformat ? "Yes" : "No"),
      sortable: true,
    },
    {
      minWidth: 220,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Button
            onClick={() => {
              handleEditBlobModal(d.ProductBlobID);
              setSelectedIdUpdate(d.ProductBlobID);
            }}
          >
            Edit
          </Button>
          {" | "}
          <Button
            onClick={() => {
              setSelectedIdDelete(d.ProductBlobID);
              handleDeleteBlobModal();
            }}
          >
            Delete
          </Button>
          {" | "}
          <Link
            to={{ pathname: `/previewBlobByBlobID/${d.ProductBlobID}` }}
            target="_blank"
            onClick={() =>
              setLocalStorageItem("productBlobId", d.ProductBlobID)
            }
          >
            <Button>Preview</Button>
          </Link>
        </>
      ),
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, productBlobList, [
        "ProductBlobID",
        "ProductBlobName",
        "ProductBlobHeaders",
        "ProductBlobData",
        "BlobCleansing",
        "RemoveEmptyLines",
        "UniqueCategoryValues",
        "KeywordReformat",
      ]);
    }
    return productBlobList;
  };

  const getInitialValues = () => {
    // if (editId) {
    let tempArray = [];
    if (blobDetail?.ProductBlobHeaders) {
      const headerArray = JSON.parse(blobDetail?.ProductBlobHeaders);
      for (let item in headerArray) {
        tempArray.push({ label: headerArray[item], value: headerArray[item] });
      }
    }

    return {
      blobName: blobDetail?.ProductBlobName || "",
      additionalHeader: isValidArray(tempArray) ? tempArray : "",
      blobData: blobDetail?.ProductBlobData || "",
      removeEmptyLine: blobDetail?.RemoveEmptyLines == 1 ? true : false,
      uniqueCategoryValue: blobDetail?.UniqueCategoryValues == 1 ? true : false,
      keywordReformat: blobDetail?.KeywordReformat == 1 ? true : false,
    };
    // }
  };

  const handleSubmit = (values) => {
    const tempArray = [];
    for (let item in values.additionalHeader) {
      tempArray.push(values.additionalHeader[item].value);
    }

    const formData = {
      blobID: selectedIdUpdate,
      blobName: values.blobName,
      additionalHeader: tempArray,
      blobsData: values.blobData,
      removeEmptyLines: values.removeEmptyLine ? "1" : "0",
      replaceLineBreaks: "0",
      uniqueCategoryValues: values.uniqueCategoryValue ? "1" : "0",
      keywordReformat: values.keywordReformat ? "1" : "0",
    };

    dispatch(fetchUpdateProductBlob(formData)).then((data) => {
      if (data?.flag) {
        dispatch(fetchProductBlobList());
        handleEditBlobModal();
      }
    });
  };

  const handleAddFormSubmit = (values) => {
    const tempArray = [];
    for (let item in values.additionalHeader) {
      tempArray.push(values.additionalHeader[item].value);
    }

    const formData = {
      blobName: values.blobName,
      additionalHeader: tempArray,
      blobsData: values.addBlobData,
      removeEmptyLines: values.removeEmptyLine == true ? "1" : "0",
      replaceLineBreaks: "0",
      uniqueCategoryValues: "0",
      keywordReformat: "0",
    };

    dispatch(fetchAddProductBlob(formData)).then((data) => {
      if (data?.flag) {
        dispatch(fetchProductBlobList());
      }
    });
  };

  return (
    <div className="">
      <div className="product-add-blob-section">
        <Button onClick={handleAddAttributeModal}>Add Blob</Button>

        <Collapse isOpen={isOpen}>
          <div>
            <div className="tabbing-select-title">Add New Product Blob</div>
            <Formik
              initialValues={{
                blobName: "",
                additionalHeader: [],
                addBlobData: "",
                removeEmptyLine: false,
              }}
              validationSchema={addProductBlobForm}
              onSubmit={handleAddFormSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <Form>
                    <div className="">
                      <div className="row align-center mb-3">
                        <div className="col-3">
                          <Label>Blob Name </Label>
                        </div>
                        <div className="col-9">
                          <InputField
                            type="text"
                            name="blobName"
                            placeholder="Blob Name"
                            onChange={handleChange}
                            value={values.blobName || ""}
                          />
                          {showError("blobName")}
                        </div>
                      </div>
                      <div className="row align-center mb-3">
                        <div className="col-3">
                          <Label>Additional Headers </Label>
                        </div>
                        <div className="col-9 short-input">
                          <CreatableSelect
                            isMulti
                            name="additionalHeader"
                            onChange={(newValue, actionMeta) =>
                              setFieldValue("additionalHeader", newValue)
                            }
                            options={[{}]}
                            value={values.additionalHeader}
                          />

                          {showError("additionalHeader")}
                        </div>
                      </div>
                      <div className="row align-center mb-3">
                        <div className="col-3">
                          <Label>Add Blob Data</Label>
                        </div>
                        <div className="col-9">
                          <InputField
                            type="textarea"
                            name="addBlobData"
                            placeholder="Add Blob Data"
                            onChange={handleChange}
                            value={values.addBlobData || ""}
                          />
                          {showError("addBlobData")}
                        </div>
                      </div>
                      <div className="row align-center mb-3">
                        <div className="col-3">
                          <Label check>Remove Empty Lines?</Label>{" "}
                        </div>
                        <div className="col-9 d-flex align-center">
                          <Input
                            type="checkbox"
                            name="removeEmptyLine"
                            onChange={handleChange}
                            value={values.removeEmptyLine || ""}
                          />
                        </div>
                      </div>
                      <div className="row align-center">
                        <div className="col-3"></div>
                        <div className="col-9">
                          <div className="">
                            <Button
                              color="primary save-btn confirm-y"
                              onClick={handleSubmit}
                            >
                              {" "}
                              Submit
                            </Button>
                          </div>
                        </div>
                      </div>
                    </div>
                  </Form>
                );
              }}
            </Formik>
          </div>
        </Collapse>
      </div>

      <div className="tableorganisation bg-white manage-user-tbl-section center-text-tbl flag-table-header product-tableBorder preview-Tablebtn">
        <Table
          columns={ReactTableColumns}
          Data={productBlobList}
          isLoading={isLoading}
          getFilterData={getFilterData}
          isSearchRequired={false}
        />
      </div>

      {editBlobModal && (
        <Modal
          className="conformation-popup prod-blob-edit-model"
          isOpen={editBlobModal}
          toggle={handleEditBlobModal}
          size={"lg"}
        >
          <ModalHeader toggle={handleEditBlobModal}>Edit Blob</ModalHeader>
          <ModalBody>
            <Formik
              initialValues={getInitialValues()}
              validationSchema={editProductBlobForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <Form>
                    <div className="model-label-input">
                      <div className="row align-center">
                        <div className="col-4">
                          <Label>Blob Name </Label>
                        </div>
                        <div className="col-8">
                          <InputField
                            type="text"
                            name="blobName"
                            placeholder="Blob Name"
                            onChange={handleChange}
                            value={values.blobName || ""}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-label-input">
                      <div className="row align-center">
                        <div className="col-4">
                          <Label>Additional Headers Name </Label>
                        </div>
                        <div className="col-8">
                          <CreatableSelect
                            isMulti
                            name="additionalHeader"
                            onChange={(newValue, actionMeta) =>
                              setFieldValue("additionalHeader", newValue)
                            }
                            options={[{}]}
                            value={values.additionalHeader}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-label-input">
                      <div className="row align-center">
                        <div className="col-4">
                          <Label>Blob Data </Label>
                        </div>
                        <div className="col-8">
                          <TextArea
                            name="blobData"
                            placeholder="Blob Data"
                            onChange={handleChange}
                            value={values.blobData || ""}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-label-input">
                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>Remove Empty Lines? </Label>{" "}
                        </div>
                        <div className="col-8">
                          <CheckBox
                            type="checkbox"
                            name="removeEmptyLine"
                            onChange={handleChange}
                            value={values.removeEmptyLine || ""}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-label-input">
                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>Unique Category Values? </Label>{" "}
                        </div>
                        <div className="col-8">
                          <CheckBox
                            type="checkbox"
                            name="uniqueCategoryValue"
                            onChange={handleChange}
                            value={values.uniqueCategoryValue || ""}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-label-input">
                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>Keyword Reformat? </Label>{" "}
                        </div>
                        <div className="col-8">
                          <CheckBox
                            type="checkbox"
                            name="keywordReformat"
                            onChange={handleChange}
                            value={values.keywordReformat || ""}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-bottom-btn-section">
                      <Button
                        color="primary save-btn confirm-y"
                        onClick={handleSubmit}
                      >
                        {" "}
                        Submit
                      </Button>
                    </div>
                  </Form>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}

      {deleteBlobModal && (
        <DeleteModal
          toggle={handleDeleteBlobModal}
          deleteFunction={handleDeleteBlob}
          isOpen={deleteBlobModal}
        />
      )}
    </div>
  );
}

export default ProductBlobs;
