import React, { Component } from "react";
import AsyncSelect from "react-select/async";
import { fetchSearchProductBlob } from "redux/actions/masterSetup/searchProductBlob";
import { connect } from "react-redux";

class ProductSearch extends Component {
  constructor(props) {
    super(props);

    this.state = {
      inputValue: "",
      defaultOptions: [],
    };

    this.getProductNotInCollection = this.getProductNotInCollection.bind(this);
    this.loadOptions = this.loadOptions.bind(this);
    this.handleInputChange = this.handleInputChange.bind(this);
  }

  componentDidMount() {
    this.props.fetchSearchProductBlob("").then((data) => {
      const SetDefaultVal = {
        label: data?.data[0]?.ProductCode,
        value: String(data?.data[0]?.ProductID),
      };

      this.props.handleBlobChange(SetDefaultVal);
      this.setState({
        defaultOptions: this.getProductNotInCollection(data?.data),
      });
    });
  }

  getProductNotInCollection(data) {
    return data?.map((item) => ({
      label: item.ProductCode,
      value: item.ProductID,
    }));
  }

  loadOptions(inputValue) {
    return this.props
      .fetchSearchProductBlob(inputValue)
      .then((data) => this.getProductNotInCollection(data?.data));
  }

  handleInputChange(newValue) {
    const inputValue = newValue.replace(/\W/g, "");
    this.setState({ inputValue: newValue });
    return newValue;
  }

  render() {
    const { handleBlobChange, blob } = this.props;

    return (
      <AsyncSelect
        cacheOptions
        defaultOptions={this.state.defaultOptions}
        loadOptions={this.loadOptions}
        onInputChange={this.handleInputChange}
        onChange={handleBlobChange}
        value={blob}
        defaultValue={blob}
      />
    );
  }
}

const mapStateToProps = (state) => {
  return {};
};

const mapDispatchToProps = {
  fetchSearchProductBlob,
};

export default connect(mapStateToProps, mapDispatchToProps)(ProductSearch);
