import SelectField from "components/Common/SelectField";
import { isValidArray, removeLocalStorageItem } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { fetchOrganizationList } from "redux/actions/masterAdmin/organizationList";
import { fetchCatalogList } from "redux/actions/masterAdmin/catalogList";
import { Button, Label } from "reactstrap";
import { fetchUpdateUserCatalog } from "redux/actions/masterSetup/updateUserCatalog";
import { useHistory } from "react-router";
import { fetchUserDetail } from "redux/actions/auth/getUserDetail";

function SelectCatalog() {
  const dispatch = useDispatch();
  const history = useHistory();
  const [selectOrganization, setSelectOrganization] = useState("");
  const [selectCatalog, setSelectCatalog] = useState("");

  const {
    isLoading = false,
    organizationList = null,
    loginUserDetails = null,
    catalogList = null,
  } = useSelector((state) => ({
    organizationList: state.organizationList?.data?.data || null,
    isLoading: state.organizationList?.loading || null,
    loginUserDetails: state.getUserDetail?.data?.data || null,
    catalogList: state.catalogList?.data?.data || null,
  }));

  useEffect(() => {
    dispatch(fetchOrganizationList()).then((data) => {
      if (data?.flag) {
        setSelectOrganization(String(loginUserDetails.OrganisationID));
        dispatch(
          fetchCatalogList(Number(loginUserDetails.OrganisationID))
        ).then((d) => {
          setSelectCatalog(String(loginUserDetails.CatalogID));
        });
      }
    });
  }, []);

  const organizationOptions = () => {
    let updated =
      isValidArray(organizationList) &&
      organizationList?.map((item) => {
        return {
          label: item.OrganisationName,
          value: item.OrganisationID,
        };
      });
    return updated;
  };

  const catalogOptions = () => {
    let updated =
      isValidArray(catalogList) &&
      catalogList?.map((item) => {
        return {
          label: item.CatalogName,
          value: item.CatalogID,
        };
      });

    return updated;
  };

  const handleOnChangeOrg = (itemId) => {
    setSelectOrganization(itemId);
    dispatch(fetchCatalogList(Number(itemId))).then((data) => {
      if (data?.flag) {
        setSelectCatalog(String(data?.data[0]?.CatalogID));
      }
    });
  };

  const handleOnChangeCatalog = (itemId) => {
    setSelectCatalog(itemId);
  };

  const handleSubmit = () => {
    const formData = {
      organisationId: String(selectOrganization),
      catalogId: String(selectCatalog),
    };

    dispatch(fetchUpdateUserCatalog(formData)).then((data) => {
      dispatch(fetchUserDetail()).then((d) => {
        removeLocalStorageItem("parentID");
        history.push("/Catalog");
      });
    });
  };

  return (
    <div className="catalog-tab">
      <div className="selectcatalog-tab">
        <div className="tab-selectbox">
          <Label>Organisation</Label>
          <SelectField
            type="select"
            name="selectOrganization"
            id="selectOrganization"
            placeholder="Select Organization"
            options={organizationOptions()}
            onChange={handleOnChangeOrg}
            value={selectOrganization}
            //   isFirstOpDisable={true}
          />
        </div>
      </div>
      <div className="selectcatalog-tab">
        <div className="tab-selectbox">
          <Label>Catalog</Label>
          <SelectField
            type="select"
            name="selectCatalog"
            id="selectCatalog"
            placeholder="Select Catalog"
            options={catalogOptions()}
            onChange={handleOnChangeCatalog}
            value={selectCatalog}
            //   isFirstOpDisable={true}
          />
        </div>
      </div>

      <div className="selectcatalog-tab">
        <div className="tab-selectbox">
          <Button onClick={handleSubmit}>Submit</Button>
        </div>
      </div>
    </div>
  );
}

export default SelectCatalog;
