import InputField from "components/Common/InputField";
import { Form, Formik } from "formik";
import {
  addTemplateForm,
  displayFormErrors,
  unitForm,
} from "modules/validations";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import {
  Button,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import { fetchTemplateList } from "redux/actions/masterSetup/templateList";
import { fetchGetTemplate } from "redux/actions/masterSetup/getTemplateDetail";
import { fetchAddTemplate } from "redux/actions/masterSetup/addTemplate";
import { fetchUpdateTemplate } from "redux/actions/masterSetup/updateTemplate";

function TemplateModal({ isOpen, toggle, saveFunction, searchTemplate, editId,setSearchTemplate }) {
  const dispatch = useDispatch();

  const [unitOption, setUnitOption] = useState([]);

  const {  getTemplateDetails = null } = useSelector((state) => ({
    getTemplateDetails: state.getTemplateDetails?.data?.data || null,
  }));

  useEffect(() => {
    if (editId) {
      dispatch(fetchGetTemplate(editId));
    }
  }, []);

  const handleSubmit = (values) => {
    const result = values;
    if (editId) {
      dispatch(fetchUpdateTemplate(result)).then(() => {
        dispatch(fetchTemplateList());
        setSearchTemplate("")
        toggle();
      });
    } else {
      dispatch(fetchAddTemplate(result)).then(() => {
        dispatch(fetchTemplateList());
        setSearchTemplate("")
        toggle();
      });
    }
  };

  const getInitialValues = () => {

    if (editId) {
      return {
        templateName: getTemplateDetails?.TemplateName || searchTemplate || "",
        templateID: getTemplateDetails?.CategoryTemplateID ? String(getTemplateDetails?.CategoryTemplateID) : "",
      };
    }
    return {
      templateName: searchTemplate || "",
    };
  };

  return (
    <div>
      {isOpen && (
        <Modal
          className="conformation-popup catalog-popup"
          isOpen={isOpen}
          toggle={() => toggle()}
          size={"lg"}
        >
          <ModalHeader toggle={() => toggle()}>
            Add / Edit Template
          </ModalHeader>
          <ModalBody>
            <Formik
              initialValues={getInitialValues()}
              validationSchema={addTemplateForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <>
                   <Form inline="true">
                      <div className="model-label-input">
                        <div className="row">
                          <div className="col-4">
                            <Label>Template Name : </Label>
                          </div>
                          <div className="col-8">
                            <InputField
                              type="text"
                              name="templateName"
                              placeholder="Template Name"
                              onChange={handleChange}
                              value={values.templateName || ""}
                            />
                            {showError("templateName")}
                          </div>
                        </div>
                      </div>
                      <div className="model-bottom-btn-section">
                        <Button
                          color="primary cancel-btn confirm-n"
                          onClick={() => toggle()}
                        >
                          {" "}
                          Cancel
                        </Button>
                        <Button
                          color="primary save-btn confirm-y"
                          onClick={handleSubmit}
                        >
                          {" "}
                          Save changes
                        </Button>
                      </div>
                    </Form>
                  </>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}
    </div>
  );
}

export default TemplateModal;
