import InputField from "components/Common/InputField";
import InputNormal from "components/Common/InputNormal";
import DeleteModal from "components/Common/Modal/DeleteModal";
import RestrictUserType from "components/Common/RestrictUserType";
import SelectField from "components/Common/SelectField";
import Table from "components/Common/Table";
import { Form, Formik } from "formik";
import { filterFieldData, getStatusArray, isValidArray } from "modules/utils";
import { displayFormErrors, addTemplateForm } from "modules/validations";
import React, { useEffect, useState } from "react";
import DataTable from "react-data-table-component";
import { useDispatch, useSelector } from "react-redux";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import { fetchDeleteTemplate } from "redux/actions/masterSetup/deleteTemplate";
import { fetchTemplateList } from "redux/actions/masterSetup/templateList";
import { fetchTextBlockList } from "redux/actions/masterSetup/textBlocksList";
import { fetchUnitList } from "redux/actions/masterSetup/unitList";
import strings from "../../../data/strings";
import TemplateModal from "./TemplateModal";

function Templates() {
  const dispatch = useDispatch();

  const [searchTemplate, setSearchTemplate] = useState("");
  const [addTemplateModal, setAddTemplateModal] = useState(false);

  const [deleteUserModal, setDeleteUserModal] = useState(false);

  const [selectedIdDelete, setSelectedIdDelete] = useState(0);
  const [editId, setEditId] = useState(null);

  const { isLoading = false, templateList = null } = useSelector((state) => ({
    templateList: state.templateList?.data?.data || null,
    isLoading: state.templateList?.loading || null,
  }));

  useEffect(() => {
    dispatch(fetchTemplateList());
  }, []);

  const handleInviteUser = () => {
    const formData = {};
  };

  const handleAddTemplateModal = (id = null) => {
    setEditId(id);
    setAddTemplateModal(!addTemplateModal);
  };

  const handleDeleteUserModal = (id = null) => {
    setSelectedIdDelete(id);
    setDeleteUserModal(!deleteUserModal);
  };

  const handleDelete = () => {
    dispatch(fetchDeleteTemplate(selectedIdDelete)).then(() => {
      dispatch(fetchTemplateList());
      handleDeleteUserModal();
    });
  };
  const ReactTableColumns = [
    {
      minWidth: 150,
      Header: "Template ID",
      id: "CategoryTemplateID",
      accessor: "CategoryTemplateID",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Template Name",
      id: "TemplateName",
      accessor: "TemplateName",
      sortable: true,
    },
    {
      minWidth: 220,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Button
            onClick={() => {
              handleAddTemplateModal(d.CategoryTemplateID);
            }}
          >
            Edit
          </Button>
          {" | "}
          <Button
            onClick={() => {
              handleDeleteUserModal(d?.CategoryTemplateID);
            }}
          >
            Delete
          </Button>
        </>
      ),
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, templateList, [
        "CategoryTemplateID",
        "TemplateName",
      ]);
    }
    return templateList;
  };

  return (
    <div>
      <div className="tabcontent">
        <InputNormal
          type="text"
          name="Attribute"
          placeholder="Template"
          value={searchTemplate}
          onChange={setSearchTemplate}
        />
        <Button onClick={() => handleAddTemplateModal()}>Add Template</Button>
      </div>
      <div className="tableorganisation bg-white manage-user-tbl-section center-text-tbl product-tableBorder">
        <Table
          columns={ReactTableColumns}
          Data={templateList}
          isLoading={isLoading}
          getFilterData={getFilterData}
          sortColumn={{
            id: "CategoryTemplateID",
            desc: false,
          }}
        />
      </div>
      {addTemplateModal && (
        <TemplateModal
          isOpen={addTemplateModal}
          toggle={handleAddTemplateModal}
          searchTemplate={searchTemplate}
          editId={editId}
          setEditId={setEditId}
          setSearchTemplate={setSearchTemplate}
        />
      )}

      {deleteUserModal && (
        <DeleteModal
          toggle={handleDeleteUserModal}
          deleteFunction={handleDelete}
          isOpen={deleteUserModal}
        />
      )}
    </div>
  );
}

export default Templates;
