/* eslint-disable react/react-in-jsx-scope */
import InputField from "components/Common/InputField";
import Loader from "components/Common/Loader";
import DeleteModalWithoutHeader from "components/Common/Modal/DeleteModalWithoutHeader";
import SelectDropdownSearchable from "components/Common/SelectDropdownSearchable";
import SelectField from "components/Common/SelectField";
import { Form, Formik } from "formik";
import {
  filterFieldData,
  isValidArray,
  reorder,
  showSuccessErrorToast,
} from "modules/utils";
import {
  displayFormErrors,
  textBlockSchemaListForm,
} from "modules/validations";
import { useEffect, useState } from "react";
import { DragDropContext, Draggable, Droppable } from "react-beautiful-dnd";
import { useDispatch, useSelector } from "react-redux";
import { Button, Col, Input, Label, Row } from "reactstrap";
import { fetchGetCategoryMergeLevels } from "redux/actions/blockBuilder/getCategoryMergeLevels";
import { fetchAddCategoryTextSchema } from "redux/actions/masterSetup/textBlockSchema/addCategoryTextSchema";
import { fetchAddTextBlockToSchema } from "redux/actions/masterSetup/textBlockSchema/addTextBlockToSchema";
import { fetchCloneCategoryTextSchema } from "redux/actions/masterSetup/textBlockSchema/cloneCategoryTextSchema";
import { fetchDeleteCategoryTextSchema } from "redux/actions/masterSetup/textBlockSchema/deleteCategoryTextSchema";
import { fetchDeleteTextBlockForSchema } from "redux/actions/masterSetup/textBlockSchema/deleteTextBlockForSchema";
import { fetchGetAllCategoryTextSchemaList } from "redux/actions/masterSetup/textBlockSchema/getAllCategoryTextSchemaList";
import { fetchGetCategoryTextSchemaDetailsById } from "redux/actions/masterSetup/textBlockSchema/getCategoryTextSchemaDetailsById";
import { fetchGetTextBlockListForSchema } from "redux/actions/masterSetup/textBlockSchema/getTextBlockListForSchema";
import { fetchUpdateCategoryTextSchemaSortOrder } from "redux/actions/masterSetup/textBlockSchema/updateCategoryTextSchemaSortOrder";
import { fetchUpdateSchemaTextBlocks } from "redux/actions/masterSetup/textBlockSchema/updateSchemaTextBlocks";

export default function TextBlockSchema() {
  const [items, setItems] = useState([]);
  const [isEdit, setIsEdit] = useState(false);
  const [isAddTextBlock, setIsAddTextBlock] = useState(false);
  const [missingTextBlock, setMissingTextBlock] = useState([]);
  const [showConfirmModal, setConfirmModal] = useState();
  const [schemaNameEditable, setSchemaNameEditable] = useState(false);
  const [searchValue, setSearchValue] = useState("");
  const [selectedAddTextBlock, setSelectedAddTextBlock] = useState("");
  const [addNewTextBlockItems, setAddNewTextBlockItems] = useState([]);
  const [deleteTextBlockModal, setDeleteTextBlockModal] = useState(false);
  const [selectedTextBlockIdDelete, setSelectedTextBlockIdDelete] = useState(0);
  const [tempDeleteID, setTempDeleteID] = useState();
  const [selectedTextBlockSchemaId, setSelectedTextBlockSchemaId] =
    useState("");
  const [textBlockSchemaName, setTextBlockSchemaName] = useState("");
  const [textBlockSchemaListOption, setTextBlockSchemaListOption] = useState(
    []
  );

  const dispatch = useDispatch();

  const {
    getAttributeListForSchemaLoading = null,
    getAllCategoryTextSchemaList = null,
    getCategoryTextSchemaDetails = null,
    getCategoryMergeLevels = null,
  } = useSelector((state) => ({
    getAttributeListForSchemaLoading: state.attributeListForSchema?.loading,
    getAllCategoryTextSchemaList:
      state.getAllCategoryTextSchemaList?.data?.data,
    getCategoryTextSchemaDetails:
      state.getCategoryTextSchemaDetailsById?.data?.data,
    getCategoryMergeLevels: state.getCategoryMergeLevels?.data?.data,
  }));

  const categoryLevelOptions =
    isValidArray(getCategoryMergeLevels) &&
    getCategoryMergeLevels.map((d) => {
      return {
        label: d,
        value: d,
      };
    });

  const getInitialData = () => {
    dispatch(fetchGetAllCategoryTextSchemaList()).then((res) => {
      console.log("🚀 ~ file: TextBlockSchema.js:48 ~ dispatch ~ res:", res);
      const result = res?.data.map((d, i) => {
        let catlogObj = {
          value: d?.CategoryTextSchemaID,
          label: d?.CategoryTextSchemaName,
        };
        if (i === 0) {
          setTextBlockSchemaName(d?.CategoryTextSchemaName);
        }
        return catlogObj;
      });
      setTextBlockSchemaListOption([
        { label: "Please select one", value: "" },
        ...result,
      ]);
    });
  };

  useEffect(() => {
    getInitialData();
  }, []);

  const getTextBlockSchemaId = (itemId) => {
    let attributeObj = textBlockSchemaListOption.find(
      (o) => o.value === Number(itemId)
    );
    setSelectedTextBlockSchemaId(itemId);
    getTextBlockSchemaList(itemId);
  };

  const getTextBlockSchemaList = (itemId) => {
    if (itemId || selectedTextBlockSchemaId) {
      dispatch(
        fetchGetCategoryTextSchemaDetailsById(
          itemId || selectedTextBlockSchemaId
        )
      ).then((data) => {
        const name = getAllCategoryTextSchemaList.find(
          (d) => d?.CategoryTextSchemaID == itemId
        )?.CategoryTextSchemaName;
        setTextBlockSchemaName(name);
        setItems(data?.data);
        dispatch(fetchGetTextBlockListForSchema(itemId)).then((data) => {
          const options = data?.data?.map((item) => {
            return {
              label: item.TextBlockName,
              value: item.TextBlockID,
            };
          });
          const single = [{ label: "Add TextBlock", value: "" }, ...options];
          setMissingTextBlock(single);
          dispatch(fetchGetCategoryMergeLevels());
        });
      });
    } else {
      setTextBlockSchemaName();
      if (!selectedTextBlockSchemaId) {
        setItems([]);
      }
      setMissingTextBlock([]);
    }
  };

  const handleSubmit = (values) => {
    const result = { CategoryTextSchemaName: values.label };

    dispatch(fetchAddCategoryTextSchema(result)).then(() => {
      getInitialData();
    });
  };

  const handleConfirmModal = () => {
    setConfirmModal(!showConfirmModal);
  };

  const handleDeleteCategoryTextSchema = () => {
    dispatch(fetchDeleteCategoryTextSchema(selectedTextBlockSchemaId)).then(
      (data) => {
        handleConfirmModal();
        showSuccessErrorToast(data?.flag, data?.message);
        getInitialData();
      }
    );
  };

  const handleCloneAttributeSchema = () => {
    dispatch(fetchCloneCategoryTextSchema(selectedTextBlockSchemaId)).then(
      (data) => {
        handleConfirmModal();
        showSuccessErrorToast(true, data?.message);
        getInitialData();
      }
    );
  };

  const handleSearch = (searchText) => {
    setSearchValue(searchText);

    if (searchText) {
      const data = filterFieldData(searchText, items, [
        "AttributeID",
        "AttributeName",
        "ColumnWidth",
        "SortOrder",
      ]);
      setItems(data);
    } else {
      setItems(getCategoryTextSchemaDetails);
    }
  };

  const appendNewAttribute = (selectedAddAttribute1) => {
    if (selectedAddAttribute1) {
      var getItemData = missingTextBlock.find(
        (item) => item.value == selectedAddAttribute1
      );
      const restItemData = missingTextBlock.filter((d) => {
        return d.value != selectedAddAttribute1;
      });
      setMissingTextBlock(restItemData);

      let itemArr = {
        TextBlockId: getItemData.value,
        TextBlockName: getItemData.label,
        CategoryLevel: [],
      };
      var attributeData = [...addNewTextBlockItems, itemArr];

      setAddNewTextBlockItems(attributeData);
      setIsAddTextBlock(true);
    }
  };

  const onDragEnd = (e) => {
    if (!e.destination) {
      return;
    }
    const sorted = reorder(items, e.source.index, e.destination.index);

    setItems(sorted);
    let attributeId = [];
    sorted.map((d, i) => {
      attributeId = [...attributeId, d.SchemaAttributeID];
    });

    let formData = new FormData();
    formData.append("SchemaID", selectedTextBlockSchemaId);
    formData.append("textblocksArray", attributeId);

    const textblocksArray = sorted.map((d) => String(d?.TextBlockID));
    const passData = {
      textblocksArray,
      SchemaID: selectedTextBlockSchemaId,
    };

    dispatch(fetchUpdateCategoryTextSchemaSortOrder(passData)).then((data) => {
      getTextBlockSchemaList();
    });
  };

  const handleChange = (TextBlockID, levelValue) => {
    if (selectedAddTextBlock) {
      const textBlockData = addNewTextBlockItems?.map((item) => {
        if (item.TextBlockId === TextBlockID) {
          return {
            ...item,
            CategoryLevel: levelValue,
          };
        }
        return item;
      });

      setAddNewTextBlockItems(textBlockData);
    } else {
      const value = items?.map((item) => {
        if (item.TextBlockID === TextBlockID) {
          return {
            ...item,
            CategoryLevel: levelValue,
          };
        }
        return item;
      });
      console.log(
        "🚀 ~ file: TextBlockSchema.js:254 ~ value ~ value:",
        value,
        levelValue,
        TextBlockID
      );

      setItems(value);
    }
  };

  const handleDeleteTextBlockModal = () => {
    setDeleteTextBlockModal(!deleteTextBlockModal);
  };

  const handleDeleteTextBlock = () => {
    console.log(String(selectedTextBlockSchemaId));
    if (isAddTextBlock) {
      if (tempDeleteID > -1) {
        addNewTextBlockItems.splice(tempDeleteID, 1);
      }
      handleDeleteTextBlockModal();
    } else {
      dispatch(
        fetchDeleteTextBlockForSchema(
          String(selectedTextBlockSchemaId),
          String(selectedTextBlockIdDelete)
        )
      ).then((data) => {
        getTextBlockSchemaList();
        handleDeleteTextBlockModal();
      });
    }
    if (addNewTextBlockItems.length === 0) {
      setIsEdit(false);
      setIsAddTextBlock(false);
    }
  };

  const handleSave = () => {
    if (isAddTextBlock) {
      let formArray = [];

      addNewTextBlockItems?.map((item, i) => {
        formArray.push({
          id: String(item.TextBlockId),
          CategoryLevel: item?.CategoryLevel?.map((d) => d.value),
        });
      });

      const formData = {
        CategoryTextSchemaID: selectedTextBlockSchemaId,
        data: formArray,
      };
      dispatch(fetchAddTextBlockToSchema(formData)).then((data) => {
        getTextBlockSchemaList();
        setIsAddTextBlock(false);
        setIsEdit(false);
        setAddNewTextBlockItems([]);
        setSelectedAddTextBlock("");
      });
    } else {
      const data = items?.map((item, i) => {
        return {
          id: item?.TextBlockID,
          CategoryLevel: item?.CategoryLevel.map((d) => d?.value || d),
        };
      });
      const passData = {
        schemaID: selectedTextBlockSchemaId,
        schemaName: textBlockSchemaName,
        data,
      };

      dispatch(fetchUpdateSchemaTextBlocks(passData)).then((data) => {
        getTextBlockSchemaList();
        setIsEdit(false);
        getInitialData();
      });
    }
  };

  return (
    <div className="layout-template-section p-0 m-0">
      <div
        style={{
          alignItems: "center",
          paddingBottom: 20,
          background: "#e1e1e1",
          padding: 10,
        }}
      >
        <Row>
          <Col xs="6">
            <Row className="align-items-center">
              <Col xs="4">
                <Label>Edit Existing CategoryText Schema</Label>
              </Col>
              <Col xs="4">
                <SelectField
                  type="select"
                  name="attributeSchemaId"
                  id="attributeSchemaId"
                  placeholder="Select Organization"
                  options={textBlockSchemaListOption}
                  onChange={getTextBlockSchemaId}
                  value={selectedTextBlockSchemaId}
                />
              </Col>
              <Col xs="4">
                {isEdit || isAddTextBlock ? (
                  <>
                    <Button
                      onClick={handleSave}
                      className="primary save-btn confirm-y mr-2"
                      style={{ marginRight: "5px" }}
                    >
                      Save
                    </Button>
                    <Button
                      onClick={() => {
                        setIsEdit(false);
                        setIsAddTextBlock(false);
                        setAddNewTextBlockItems([]);
                      }}
                      className="cancel-btn-red"
                    >
                      Cancel
                    </Button>
                  </>
                ) : (
                  <>
                    <Button
                      className="primary save-btn confirm-y mb-1"
                      onClick={() => {
                        getTextBlockSchemaList();
                        setIsEdit(true);
                      }}
                      style={{ marginRight: 5 }}
                      disabled={!selectedTextBlockSchemaId}
                    >
                      Edit
                    </Button>
                    <Button
                      className="primary save-btn confirm-n mb-1"
                      onClick={() => {
                        handleDeleteCategoryTextSchema();
                        // getAttributeSchemaList();
                        // setIsEdit(true);
                      }}
                      style={{ marginRight: 5 }}
                      disabled={!selectedTextBlockSchemaId}
                    >
                      Delete
                    </Button>
                    <Button
                      className="primary save-btn confirm-y mb-1"
                      onClick={() => {
                        // handleConfirmModal();
                        // setConfirmText(
                        //   "Are you sure you want to clone this schema"
                        // );
                        handleCloneAttributeSchema();
                        getTextBlockSchemaList();
                        // setIsEdit(true);
                      }}
                      disabled={!selectedTextBlockSchemaId}
                    >
                      Clone
                    </Button>
                  </>
                )}
              </Col>{" "}
            </Row>
          </Col>
          <Col xs="6">
            <Formik
              initialValues={{
                label: "",
              }}
              validationSchema={textBlockSchemaListForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
                handleReset,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);

                return (
                  <Form>
                    <Row className="align-items-center">
                      <Col xs="4">
                        <Label>Create New CategoryText Schema </Label>
                      </Col>
                      <Col xs="4">
                        <InputField
                          type="text"
                          name="label"
                          placeholder="Create New Schema"
                          onChange={handleChange}
                          value={values.label || ""}
                        />
                        {showError("label")}
                      </Col>
                      <Col xs="4">
                        <Button
                          color="primary save-btn confirm-y"
                          onClick={handleSubmit}
                        // onClick={() => {
                        //   handleSubmit();
                        // }}
                        >
                          Create
                        </Button>
                      </Col>
                    </Row>
                  </Form>
                );
              }}
            </Formik>
          </Col>
        </Row>
      </div>
      {isValidArray(items) || isValidArray(missingTextBlock) ? (
        <>
          <div className="attributeSchema-table-text">
            <div className="col-lg-3">
              <div className="d-flex align-items-center">
                <Input
                  style={{ marginRight: "2px", width: "45%" }}
                  type="text"
                  value={textBlockSchemaName}
                  onChange={(e) => setTextBlockSchemaName(e.target.value)}
                  disabled={!schemaNameEditable}
                />
                <i
                  className={
                    schemaNameEditable
                      ? "fa fa-check cc undo-icon"
                      : "fa fa-pencil cc undo-icon"
                  }
                  style={{
                    color: "black",
                  }}
                  onClick={() => {
                    setSchemaNameEditable(!schemaNameEditable);
                  }}
                ></i>
              </div>
            </div>
          </div>

          <div className="tableorganisation category-table attributeschemaTable center-text-tbl">
            <div className="tabcontent bg-white">
              <label className="form-label">Search: </label>
              <input
                name="search"
                type="text"
                className="form-control"
                value={searchValue}
                onChange={(e) => handleSearch(e.target.value)}
              />
            </div>
            {/* </div> */}
            {getAttributeListForSchemaLoading ? (
              <Loader />
            ) : (
              <DragDropContext onDragEnd={onDragEnd}>
                <Droppable droppableId="Table">
                  {(provided) => (
                    <table
                      {...provided.droppableProps}
                      ref={provided.innerRef}
                      border={"2px"}
                    >
                      <thead>
                        <tr>
                          <th>TextBlock ID</th>
                          <th>TextBlock Name</th>
                          <th>Level</th>
                          <th>Sort</th>
                          <th>Delete</th>
                        </tr>
                      </thead>
                      <tbody>
                        {items.map((item, index) => (
                          <Draggable
                            key={item.TextBlockID}
                            draggableId={String(item.TextBlockID)}
                            index={index}
                            isDragDisabled={isEdit}
                          >
                            {(provided) => (
                              <tr
                                ref={provided.innerRef}
                                {...provided.draggableProps}
                                {...provided.dragHandleProps}
                              >
                                <td>{item.TextBlockID} </td>
                                <td>{item.textblock?.TextBlockName}</td>
                                <td style={{ maxWidth: "20%", width: "20%" }}>
                                  {isEdit ? (
                                    <SelectDropdownSearchable
                                      name="selectOrganization"
                                      options={categoryLevelOptions}
                                      handleChange={(value) => {
                                        handleChange(item.TextBlockID, value);
                                        // setMissingAttributeValue(item);
                                      }}
                                      isMulti={true}
                                      value={item.CategoryLevel.map((d) => {
                                        return {
                                          value: d?.value || d,
                                          label: d?.label || d,
                                        };
                                      })}
                                    />
                                  ) : (
                                    isValidArray(item.CategoryLevel) &&
                                    item.CategoryLevel.map(
                                      (d, i) =>
                                        `${d?.value || d}${i < item.CategoryLevel?.length - 1
                                          ? ", "
                                          : ""
                                        }`
                                    )
                                  )}
                                </td>
                                <td>{item.SortOrder}</td>
                                <td>
                                  <Button
                                    onClick={() => {
                                      handleDeleteTextBlockModal();
                                      setSelectedTextBlockIdDelete(
                                        item.TextBlockID
                                      );
                                    }}
                                  >
                                    Delete
                                  </Button>
                                </td>
                              </tr>
                            )}
                          </Draggable>
                        ))}
                        {provided.placeholder}

                        {addNewTextBlockItems.map((item, index) => (
                          <>
                            <tr key={item.TextBlockId}>
                              <td>{item.TextBlockId}</td>
                              <td>{item.TextBlockName}</td>
                              {isAddTextBlock ? (
                                <td style={{ maxWidth: "20%", width: "20%" }}>
                                  <SelectDropdownSearchable
                                    name="selectOrganization"
                                    options={categoryLevelOptions}
                                    handleChange={(value) => {
                                      handleChange(item.TextBlockId, value);
                                      // setMissingAttributeValue(item);
                                    }}
                                    isMulti={true}
                                  // value={missingAttributeValue}
                                  />
                                </td>
                              ) : (
                                <td>{item.width}</td>
                              )}

                              <td>{item.sort}</td>
                              <td>
                                <Button
                                  onClick={() => {
                                    handleDeleteTextBlockModal();
                                    setTempDeleteID(index);
                                  }}
                                >
                                  Delete
                                </Button>
                              </td>
                            </tr>
                          </>
                        ))}
                        {/*
                        <tr>
                          <td></td>
                          <td></td>
                          <td><b>{widthTotal}</b></td>
                          <td></td>
                          <td></td>
                        </tr>
                        */}
                      </tbody>
                    </table>
                  )}
                </Droppable>
              </DragDropContext>
            )}
          </div>

          <div className="col-lg-2 mt-5 pb-4">
            <SelectField
              isDisabled={!isEdit}
              type="select"
              name="attributeSchemaId"
              id="attributeSchemaId"
              options={missingTextBlock}
              //   onChange={getAttributeSchemaId}
              onChange={(e) => {
                setSelectedAddTextBlock(e);
                appendNewAttribute(e);
              }}
              value={selectedAddTextBlock}
            />
          </div>
        </>
      ) : (
        ""
      )}
      {deleteTextBlockModal && (
        <DeleteModalWithoutHeader
          toggle={handleDeleteTextBlockModal}
          deleteFunction={handleDeleteTextBlock}
          isOpen={deleteTextBlockModal}
        />
      )}
    </div>
  );
}

{
  /* {showConfirmModal && (
  <ConfirmationModal
    isOpen={showConfirmModal}
    toggle={handleConfirmModal}
    handleConfirm={handleDeleteCategoryTextSchema}
  />
)} */
}
