import InputField from "components/Common/InputField";
import InputNormal from "components/Common/InputNormal";
import DeleteModal from "components/Common/Modal/DeleteModal";
import RestrictUserType from "components/Common/RestrictUserType";
import SelectField from "components/Common/SelectField";
import SelectFieldFormik from "components/Common/SelectFieldFormik";
import Table from "components/Common/Table";
import { Form, Formik } from "formik";
import { filterFieldData, getStatusArray, isValidArray } from "modules/utils";
import { displayFormErrors, textBlockForm } from "modules/validations";
import React, { useEffect, useState } from "react";
import DataTable from "react-data-table-component";
import { useDispatch, useSelector } from "react-redux";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import { fetchAddTextBlock } from "redux/actions/masterSetup/addTextBlock";
import { fetchDeleteTextBlock } from "redux/actions/masterSetup/deleteTextBlock";
import { fetchTextBlockDetail } from "redux/actions/masterSetup/textBlockDetail";
import { fetchTextBlockList } from "redux/actions/masterSetup/textBlocksList";
import { fetchUnitList } from "redux/actions/masterSetup/unitList";
import { fetchUpdateTextBlock } from "redux/actions/masterSetup/updateTextBlock";
import { fetchImageSizeList } from "redux/actions/media/imageSizeList";
import strings from "../../../data/strings";

function TextBlocks() {
  const dispatch = useDispatch();

  const [searchTextBlock, setSearchTextBlock] = useState("");
  const [searchTextBlockModal, setSearchTextBlockModal] = useState(false);
  const [deleteUserModal, setDeleteUserModal] = useState(false);
  const [selectedIdDelete, setSelectedIdDelete] = useState(null);
  const [editId, setEditId] = useState(null);
  const [imageSize, setImageSize] = useState([]);

  const {
    isLoading = false,
    textBlocksList = null,
    textBlocksDetail = null,
    imageSizeList = null,
  } = useSelector((state) => ({
    textBlocksList: state.textBlocksList?.data?.data || null,
    isLoading: state.textBlocksList?.loading || null,
    textBlocksDetail: state.textBlocksDetail?.data?.data,
    imageSizeList: state.imageSizeList?.data?.data,
  }));

  console.log(
    "🚀 ~ file: TextBlocks.js ~ line 49 ~ TextBlocks ~ textBlocksList",
    textBlocksList
  );
  useEffect(() => {
    dispatch(fetchTextBlockList());
    dispatch(fetchImageSizeList()).then((data) => {
      const result = data?.data.map((d) => {
        return {
          value: d?.ImageSizeID,
          label: d?.ImageSizeID,
        };
      });
      setImageSize(result);
    });
  }, []);

  const ReactTableColumns = [
    {
      minWidth: 150,
      Header: "Text Block ID",
      id: "TextBlockID",
      accessor: "TextBlockID",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Text Block Name",
      id: "TextBlockName",
      accessor: "TextBlockName",
      sortable: true,
    },
    {
      minWidth: 130,
      Header: "Multiline",
      id: "MultiLine",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.MultiLine ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 100,
      Header: "Allow HTML",
      id: "AllowHTML",
      accessor: (d) => (
        <>
          <Input
            type="checkbox"
            name=""
            checked={d?.AllowHTML ? "checked" : ""}
            disabled
          />
        </>
      ),
      sortable: true,
    },
    {
      minWidth: 220,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Button
            onClick={() => {
              handleAddTextBlockModal(d?.TextBlockID);
            }}
          >
            Edit
          </Button>
          {" | "}
          <Button
            onClick={() => {
              handleDeleteUserModal(d?.TextBlockID);
            }}
          >
            Delete
          </Button>
        </>
      ),
    },
  ];

  const handleAddTextBlockModal = (id = null) => {
    setEditId(id);
    setSearchTextBlockModal(!searchTextBlockModal);
  };

  useEffect(() => {
    if (editId) {
      dispatch(fetchTextBlockDetail(editId));
    }
  }, [editId]);

  const handleDeleteUserModal = (id = null) => {
    setSelectedIdDelete(id);
    setDeleteUserModal(!deleteUserModal);
  };

  const handleDelete = () => {
    dispatch(fetchDeleteTextBlock(selectedIdDelete)).then(() => {
      setSelectedIdDelete(null);
      handleDeleteUserModal();
      dispatch(fetchTextBlockList());
    });
  };

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, textBlocksList, [
        "TextBlockID",
        "TextBlockName",
      ]);
    }
    return textBlocksList;
  };

  const handleSubmit = (values) => {
    let updated = {
      ...values,
      ImageSizeID: values?.ImageSizeID
        ? Number(values?.ImageSizeID)
        : values?.ImageSizeID,
      multiline: values?.multiline === true ? "1" : "0",
      allowHTML: values?.allowHTML === true ? "1" : "0",
      OutputAsImage: values?.OutputAsImage === true ? "1" : "0",
    };

    if (editId) {
      updated = { ...updated, textBlockID: textBlocksDetail?.TextBlockID };
      dispatch(fetchUpdateTextBlock(updated)).then(() => {
        dispatch(fetchTextBlockList());
        setSearchTextBlock("");
        handleAddTextBlockModal();
      });
    } else {
      dispatch(fetchAddTextBlock(updated)).then(() => {
        dispatch(fetchTextBlockList());
        setSearchTextBlock("");
        handleAddTextBlockModal();
      });
    }
  };

  const getInitialValues = () => {
    if (editId) {
      return {
        textBlockName: textBlocksDetail?.TextBlockName || searchTextBlock || "",
        OutputAsImage: textBlocksDetail?.OutputAsImage === 1 ? true : false,
        multiline: textBlocksDetail?.MultiLine === 1 ? true : false,
        allowHTML: textBlocksDetail?.AllowHTML === 1 ? true : false,
        ImageSizeID: textBlocksDetail?.ImageSizeID
          ? String(textBlocksDetail?.ImageSizeID)
          : null,
      };
    }
    return {
      textBlockName: searchTextBlock || "",
      OutputAsImage: "",
      multiline: "",
      allowHTML: "",
      ImageSizeID: null,
    };
  };

  return (
    <div>
      <div className="tabcontent">
        <InputNormal
          type="text"
          name="Attribute"
          placeholder="TextBlock"
          value={searchTextBlock}
          onChange={setSearchTextBlock}
        />
        <Button onClick={setSearchTextBlockModal}>Add TextBlock</Button>
      </div>
      <div className="tableorganisation bg-white manage-user-tbl-section center-text-tbl product-tableBorder">
        <Table
          columns={ReactTableColumns}
          Data={textBlocksList}
          isLoading={isLoading}
          getFilterData={getFilterData}
          searchField={searchTextBlock}
          sortColumn={{
            id: "TextBlockID",
            desc: false,
          }}
        />
      </div>

      {searchTextBlockModal && (
        <Modal
          className="conformation-popup catalog-popup"
          isOpen={searchTextBlockModal}
          toggle={() => handleAddTextBlockModal()}
          size={"lg"}
        >
          <ModalHeader toggle={() => handleAddTextBlockModal()}>
            Add / Edit Text Blocks
          </ModalHeader>
          <ModalBody>
            <Formik
              initialValues={getInitialValues()}
              validationSchema={textBlockForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <>
                    <Form inline="true">
                      <div className="model-label-input">
                        <div className="row mb-3">
                          <div className="col-4">
                            <Label>Text Block Name : </Label>
                          </div>
                          <div className="col-8">
                            <InputField
                              type="text"
                              name="textBlockName"
                              placeholder="Text Block Name"
                              onChange={handleChange}
                              value={values.textBlockName || ""}
                              checked={values.textBlockName}
                            />
                            {showError("textBlockName")}
                          </div>
                        </div>
                        <div className="row align-center mb-3">
                          <div className="col-4">
                            <Label check>Output as Image : </Label>{" "}
                          </div>
                          <div className="col-8">
                            <Input
                              type="checkbox"
                              name="OutputAsImage"
                              onChange={handleChange}
                              value={values.OutputAsImage || ""}
                              checked={values.OutputAsImage}
                            />
                          </div>
                        </div>
                        {values?.OutputAsImage === true && (
                          <div className="row align-center mb-3">
                            <div className="col-4">
                              <Label check> Image Size ID : </Label>{" "}
                            </div>
                            <div className="col-8">
                              <SelectFieldFormik
                                type="select"
                                name="ImageSizeID"
                                id="ImageSizeID"
                                placeholder="Choose an Option"
                                options={imageSize}
                                onChange={handleChange}
                                value={values.ImageSizeID || ""}
                                isFirstOption={true}
                              />
                            </div>
                          </div>
                        )}
                        <div className="row align-center mb-3">
                          <div className="col-4">
                            <Label check>Multiline : </Label>{" "}
                          </div>
                          <div className="col-8">
                            <Input
                              type="checkbox"
                              name="multiline"
                              onChange={handleChange}
                              value={values.multiline || ""}
                              checked={values.multiline}
                            />
                          </div>
                        </div>
                        <div className="row align-center mb-3">
                          <div className="col-4">
                            <Label check>Allow HTML : </Label>{" "}
                          </div>
                          <div className="col-8">
                            <Input
                              type="checkbox"
                              name="allowHTML"
                              onChange={handleChange}
                              value={values.allowHTML || ""}
                              checked={values.allowHTML}
                            />
                          </div>
                        </div>
                      </div>
                      <div className="model-bottom-btn-section">
                        <Button
                          color="primary cancel-btn confirm-n"
                          onClick={() => handleAddTextBlockModal()}
                        >
                          {" "}
                          Cancel
                        </Button>
                        <Button
                          color="primary save-btn confirm-y"
                          onClick={handleSubmit}
                        >
                          {" "}
                          Save changes
                        </Button>
                      </div>
                    </Form>
                  </>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}

      {deleteUserModal && (
        <DeleteModal
          toggle={handleDeleteUserModal}
          deleteFunction={handleDelete}
          isOpen={deleteUserModal}
        />
      )}
    </div>
  );
}

export default TextBlocks;
