import React, { useEffect, useState } from "react";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import { Steps } from "intro.js-react";
import "intro.js/introjs.css";
import ImportMedia from "./tabs/ImportMedia";
import MediaSetup from "./tabs/mediaSetup/MediaSetup";
import ViewMedia from "./tabs/ViewMedia";
import { isValidArray } from "modules/utils";
import { useDispatch, useSelector } from "react-redux";
import MediaIntegration from "./tabs/MediaIntegration";
import {
  useHistory,
  useParams,
} from "react-router-dom/cjs/react-router-dom.min";

const Media = (props) => {
  const dispatch = useDispatch();
  const history = useHistory();

  const tabName = props?.match?.params?.type;
  // console.log("🚀 ~ file: Media.js:19 ~ Media ~ tabName:", tabName);

  const initialActiveTab = {
    viewMedia: tabName === "ViewMedia" ? "active" : "",
    mediaSetup: tabName === "MediaSetup" ? "active" : "",
    importMedia: tabName === "ImportMedia" ? "active" : "",
    mediaIntegration: tabName === "MediaIntegration" ? "active" : "",
    activeTab: tabName,
  };
  // console.log(
  //   "🚀 ~ file: Media.js:28 ~ Media ~ initialActiveTab:",
  //   initialActiveTab
  // );
  const [activeTab, setActivetab] = useState(initialActiveTab);
  const [selectedProduct, setSelectedProduct] = useState([]);
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);
  const {
    loginUserDetails = null,
  } = useSelector((state) => ({
    loginUserDetails: state.getUserDetail?.data?.data || null,
  }));

  // console.log(loginUserDetails);

  const onExit = () => {
    setStepsEnabled(false);
  };

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = d.elementIDName;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };
  const { type } = useParams();

  useEffect(() => {
    document.title = "Manage Media | Producty®";
    dispatch(getIntroJs("media")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  useEffect(() => {
    setActivetab({
      viewMedia: tabName === "ViewMedia" ? "active" : "",
      mediaSetup: tabName === "MediaSetup" ? "active" : "",
      importMedia: tabName === "ImportMedia" ? "active" : "",
      mediaIntegration: tabName === "MediaIntegration" ? "active" : "",
      activeTab: type,
    });
  }, [type]);

  const handleTab = (name) => {
    // alert(1);
    history.push(`/Media/${name}`);
    // setActivetab(tabName);
  };

  return (
    <>
      <Steps
        enabled={stepsEnabled}
        steps={steps}
        initialStep={initialStep}
        onExit={onExit}
        onComplete={() => setStepsEnabled(false)}
        options={{ doneLabel: "Done" }}
      />
      <div>
        <Nav tabs>
          <NavItem>
            <NavLink
              className={activeTab.viewMedia}
              onClick={() => handleTab("ViewMedia")}
            >
              View Media
            </NavLink>
          </NavItem>
          <NavItem>
            <NavLink
              className={activeTab.importMedia}
              onClick={() => handleTab("ImportMedia")}
            >
              Import Media
            </NavLink>
          </NavItem>
            <NavItem>
              <NavLink
                className={activeTab.mediaSetup}
                onClick={() => handleTab("MediaSetup")}
              >
                Media Setup
              </NavLink>
            </NavItem>
          {loginUserDetails?.MediaIntegrationEnabled ? (
          <NavItem>
            <NavLink
              className={activeTab.mediaIntegration}
              onClick={() => handleTab("MediaIntegration")}
            >
              Media Integration
            </NavLink>
          </NavItem>
          ) : (
            <></>
          )}
    
        </Nav>
        <TabContent activeTab={activeTab.activeTab}>
          <TabPane tabId="ViewMedia">
            {activeTab.activeTab === "ViewMedia" && <ViewMedia />}
          </TabPane>
          <TabPane tabId="MediaSetup">
            {activeTab.activeTab === "MediaSetup" && <MediaSetup />}
          </TabPane>
          <TabPane tabId="ImportMedia">
            {activeTab.activeTab === "ImportMedia" && <ImportMedia />}
          </TabPane>
          <TabPane tabId="MediaIntegration">
            {activeTab.activeTab === "MediaIntegration" && <MediaIntegration />}
          </TabPane>
        </TabContent>
      </div>
    </>
  );
};

export default Media;
