import Loader from "components/Common/Loader";
import { bytesToSize, fileToBase64, isValidArray } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDropzone } from "react-dropzone";
import { useDispatch, useSelector } from "react-redux";
import { fetchAddImage } from "redux/actions/media/addImage";
import { fetchSetImage } from "redux/actions/media/storeImage";
import ImageComponent from "./ImageComponent";

const ImportMedia = () => {
  const { acceptedFiles, getRootProps, getInputProps } = useDropzone();

  const { storeImage = null, imageLoading = null } = useSelector((state) => ({
    storeImage: state.storeImage?.data,
    imageLoading: state?.addImage?.loading,
  }));

  const [imageProgress, setImageProgress] = useState([]);
  const [currentFile, setCurrentFile] = useState();
  const [storeImageData, setStoreImageData] = useState([]);
  const dispatch = useDispatch();

  useEffect(() => {
    if (isValidArray(acceptedFiles)) {
      const onUploadProgress = (progressEvent) => {
        let percentCompleted = Math.round(
          (progressEvent.loaded * 100) / progressEvent.total
        );
        setImageProgress(percentCompleted);
      };

      acceptedFiles.map((data, index) => {
        var formData = new FormData();
        formData.append("file", data);

        dispatch(fetchAddImage(formData, onUploadProgress)).then((image) => {
          setCurrentFile("");
          setImageProgress(0);
          // setStoreImageData([]);

          fileToBase64(data).then((res) => {
            dispatch(
              fetchSetImage({
                file: res?.file,
                size: bytesToSize(data.size),
                name: data?.name,
                src: image?.data?.ImagePath,
              })
            );
            setCurrentFile(res?.file + `${storeImage.length}`);
          });
        });
      });
    }
  }, [acceptedFiles]);

  useEffect(() => {
    setStoreImageData(storeImage);
  }, [storeImage]);

  const getLoading = (string, i) => {
    if (currentFile === string + `${i}`) {
      return true;
    }
    return false;
  };

  return (
    <div>
      <div className="bg-white common-space">
        <div className="alert-success">Add new images</div>
        {imageLoading && <Loader />}
        <div>
          <div
            {...getRootProps({
              className: "dropzone dropzone-area-section dz-started",
            })}
            style={{ minHeight: "400px", width: "100%" }}
          >
            <input {...getInputProps()} />
            {!isValidArray(storeImageData) && (
              <div className="dz-default dz-message"></div>
            )}
            <aside>
              {isValidArray(storeImageData) &&
                storeImageData.map((d, i) => {
                  return (
                    <ImageComponent
                      d={d}
                      i={i}
                      getLoading={getLoading}
                      imageProgress={imageProgress}
                      key={i}
                    />
                  );
                })}
            </aside>
          </div>
        </div>
      </div>
    </div>
  );
};

export default ImportMedia;
