/* eslint-disable no-undef */
import axios from "axios";
import {
  getLocalStorageItem,
  isValidArray,
  setLocalStorageItem,
} from "modules/utils";
import React, { useEffect, useState } from "react";
import { toast } from "react-toastify";
import { useDispatch, useSelector } from "react-redux";
import ReactTable from "react-table-6";
import { Button, Col, Container, Label, Row, Input, Table } from "reactstrap";
import { getApi } from "redux/actions/api";
import { fetchStoreMediaValetToken } from "redux/actions/media/storeMediaValetToken";
import { fetchGetMediaValetHistory } from "redux/actions/media/getMediaValetHistory";
import Loader from "components/Common/Loader";

const newUpdatedData = [
  {
    date: "2023-08-01 09:53:17 ",
    count: 42,
  },
  {
    date: "2023-08-01 09:53:17 ",
    count: 106,
  },
  {
    date: "2023-08-01 09:53:17 ",
    count: 120,
  },
];
const redirectUri = process.env.REACT_APP_MEDIA_VALET_REDIRECT_URI;
const clientId = process.env.REACT_APP_MEDIA_VALET_CLIENT_ID;
const clientSecret = process.env.REACT_APP_MEDIA_VALET_CLIENT_SECRET_ID;
const grantType = "authorization_code";
const apiUrl = "https://login.mediavalet.com/connect/token";

export default function MediaIntegration() {
  const dispatch = useDispatch();
  const [accessToken, setAccessToken] = useState("");

  const [lastNewRecord, setLastNewRecord] = useState("");
  const [lastUpdateRecord, setLastUpdateRecord] = useState("");
  const [lastSearchRecord, setLastSearchRecord] = useState("");

  const [newImageData, setNewImageData] = useState("");
  const [updateImageData, setUpdateImageData] = useState("");
  const [searchAssets, setSearchAssetsData] = useState("");
  const [searchVal, setSearchVal] = useState("");
  const setSearchType = (searchType) => {
    setLocalStorageItem("searchType", searchType);
  };

  // const {
  //   loginUserDetails = null,
  // } = useSelector((state) => ({
  //   loginUserDetails: state.getUserDetail?.data?.data || null,
  // }));

  const NewUpdatedColumn = [
    {
      Header: "Date/Time",
      id: "MediaValetImportHistoryDateTime",
      accessor: "MediaValetImportHistoryDateTime",
      style: { height: "auto" },
    },
    {
      Header: "Images Added or Updated",
      id: "ImageCount",
      accessor: "ImageCount",
    },
  ];

  const { isHistoryLoading = false, historyData = null } = useSelector(
    (state) => ({
      isHistoryLoading: state.getMediaValetHistory?.loading ?? false,
      historyData: state.getMediaValetHistory?.data?.data ?? null,
    })
  );

  useEffect(() => {
    dispatch(fetchGetMediaValetHistory()).then((res) => {
      if (res?.data) {
        setLastNewRecord(res?.data?.lastNewRecord);
        setLastUpdateRecord(res?.data?.lastUpdateRecord);
        setLastSearchRecord(res?.data?.lastSearchRecord);

        if (res?.data?.newImages && isValidArray(res?.data?.newImages)) {
          setNewImageData(res?.data?.newImages);
        }
        if (res?.data?.searchAssets && isValidArray(res?.data?.searchAssets)) {
          setSearchAssetsData(res?.data?.searchAssets);
        }
        if (res?.data?.updateImages && isValidArray(res?.data?.updateImages)) {
          setUpdateImageData(res?.data?.updateImages);
        }
      }
    });
    const handleAuthorizationCode = async (code) => {
      try {
        // Send a POST request to MediaValet's token endpoint to exchange the authorization code for an access token
        const formData = new URLSearchParams();
        formData.append("grant_type", grantType);
        formData.append("code", code);
        formData.append("redirect_uri", redirectUri);
        formData.append("client_id", clientId);
        formData.append("client_secret", clientSecret);
        const response = await axios.post(apiUrl, formData, {
          headers: {
            "Content-Type": "application/x-www-form-urlencoded",
          },
        });

        // Handle the response (e.g., save the refresh token to state or local storage)
        // // Extract the refresh token from the response and set it in the component state
        const { refresh_token } = response.data;

        const searchType = getLocalStorageItem("searchType");
        dispatch(
          fetchStoreMediaValetToken({
            token: refresh_token,
            searchType: searchType,
          })
        ).then((res) => {
          // console.log("🚀 ~ file: MediaIntegration.js:67 ~ ).then ~ res:", res);
          if (res && res.message) {
            toast.success(res?.message);
          } else {
            toast.error("Somthing went wrong!");
          }
        });
        setAccessToken(refresh_token);
      } catch (error) {
        console.error(
          "Error exchanging authorization code for access token:",
          error
        );
      }
    };

    // Check if the URL contains the authorization code (e.g., after the user is redirected back from the authentication page)
    const urlParams = new URLSearchParams(window.location.search);
    const code = urlParams.get("code");
    if (code) {
      handleAuthorizationCode(code);
    }
  }, []);

  const initializeMediaValet = () => {
    try {
      const authUrl = `https://login.mediavalet.com/connect/authorize?client_id=${clientId}&response_type=code&scope=openid%20api%20offline_access&redirect_uri=${redirectUri}&state=state-296bc9a0&refresh_token_uri=${apiUrl}?grantype=refresh_token`;
      window.location.href = authUrl;
    } catch (error) {
      console.log(
        "🚀 ~ file: MediaIntegration.js:54 ~ initializeMediaVa ~ error:",
        error
      );
    }
  };

  // if(!loginUserDetails?.MediaIntegrationEnabled)
  // {
  //   return(
  //     <div>
  //       <div className="row">
  //         <Container>
  //           <p className="h3 text-danger text-center mt-5">You are not authorised to view this page.</p>
  //         </Container>
  //       </div>
  //     </div>
  //   )
  // }

  if (isHistoryLoading) {
    return <Loader />;
  }

  return (
    <div>
      <div className="row">
        <Container>
          <div style={{ marginLeft: 40 }}>
            <p className="mt-4 align-items center">
              {`Modern Star has configured media integration with MediaValet`}
              <br />
              {`Producty® provides a number of separate methods for you to bring new/updated images from MediaValet into Producty®`}
              <br />
              {`Clicking the appropriate "Check for updates" or "Search" button will log you in to MediaValet (if required) and then run a background process to update the image records from MediaValet to Producty®. You will receive an email when this process is complete.`}
            </p>
          </div>
          <Row>
            <Col md={4} className="p-5" style={{}}>
              <h6 style={{ textTransform: "uppercase" }}>
                Newly Uploaded / Updated Images
              </h6>
              <p style={{ height: 150, maxHeight: 150 }}>
                Use this process to fetch images which have been recently added
                or updated within MediaValet.
                <br />
                Additions - New images recently added to MediaValet for existing
                products will be imported to Producty®.
                <br />
                Updates - Images which have been updated within MediaValet will
                be imported to Producty®.
              </p>
              <p className="mt-5">Last updated: {lastUpdateRecord}</p>
              <Button
                onClick={() => {
                  initializeMediaValet();
                  setSearchType("updateImages");
                }}
              >
                Check for updates
              </Button>
              <Table bordered striped className="mt-4 small">
                <thead>
                  <tr>
                    <th className="text-start">Date/Time</th>
                    <th className="text-end">Image Added or Updated</th>
                  </tr>
                </thead>
                <tbody>
                  {historyData?.updateImages.map((listValue, index) => {
                    return (
                      <tr key={index}>
                        <td className="text-start">
                          {listValue.MediaValetImportHistoryDateTime}
                        </td>
                        <td className="text-end">{listValue.ImageCount}</td>
                      </tr>
                    );
                  })}
                </tbody>
              </Table>
            </Col>
            <Col md={4} className="p-5" style={{}}>
              <h6>PRODUCTS RECENTLY ADDED TO PRODUCTY®</h6>
              <p style={{ height: 150, maxHeight: 150 }}>
                Use this process to check MediaValet for product records which
                have been recently added within Producty®.
              </p>
              <p className="mt-5">Last updated: {lastNewRecord}</p>
              <Button
                onClick={() => {
                  initializeMediaValet();
                  setSearchType("newImages");
                }}
              >
                Check for updates
              </Button>
              <Table bordered striped className="mt-4 small">
                <thead>
                  <tr>
                    <th className="text-start">Date/Time</th>
                    <th className="text-end">Image Added or Updated</th>
                  </tr>
                </thead>
                <tbody>
                  {historyData?.newImages.map((listValue, index) => {
                    return (
                      <tr key={index}>
                        <td className="text-start small">
                          {listValue.MediaValetImportHistoryDateTime}
                        </td>
                        <td className="text-end small">
                          {listValue.ImageCount}
                        </td>
                      </tr>
                    );
                  })}
                </tbody>
              </Table>
            </Col>
            <Col md={4} className="p-5" style={{}}>
              <h6>ONE-OFF IMAGE ASSET SEARCH</h6>
              <p style={{ height: 150, maxHeight: 150 }}>
                Use this process to search Mediavalet for a specific unique
                image reference which you would like to add/update within
                Producty®.
              </p>
              <p className="mt-5">Last updated: {lastSearchRecord}</p>
              <Input
                type="text"
                name="categoryName"
                className={"mb-2"}
                placeholder="Enter Asset ID"
                onChange={(e) => setSearchVal(e.target.value)}
                value={searchVal}
              />
              <Button
                onClick={() => {
                  initializeMediaValet();
                  setSearchType("searchAssets/" + searchVal);
                }}
              >
                Search
              </Button>

              <Table bordered striped className="mt-4 small">
                <thead>
                  <tr>
                    <th className="text-start">Date/Time</th>
                    <th className="text-end">Image Added or Updated</th>
                  </tr>
                </thead>
                <tbody>
                  {historyData?.searchAssets.map((listValue, index) => {
                    return (
                      <tr key={index}>
                        <td className="text-start small">
                          {listValue.MediaValetImportHistoryDateTime}
                        </td>
                        <td className="text-end small">
                          {listValue.ImageCount}
                        </td>
                      </tr>
                    );
                  })}
                </tbody>
              </Table>
            </Col>
          </Row>
        </Container>
      </div>
    </div>
  );
}
