import InputNormal from "components/Common/InputNormal";
import { isValidArray } from "modules/utils";
import React, { useCallback, useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Button, Modal, ModalBody, ModalHeader } from "reactstrap";
import Pagination from "react-js-pagination";
import SweetAlert from "react-bootstrap-sweetalert";
import { fetchDeleteImage } from "redux/actions/media/deleteImage";
import { fetchAllImages } from "redux/actions/media/getAllImages";
import Producty_rev from "../../../assets/images/Producty_rev.png";
import cancel from "../../../assets/images/cancel.png";
import informationIcon from "../../../assets/images/informationIcon.png";
import { fetchSearchImage } from "redux/actions/media/searchImage";
import Loader from "components/Common/Loader";
import { debounce } from "lodash";

const ViewMedia = () => {
  const [search, setSearch] = useState("");
  const [deleteModal, setDeleteModal] = useState(false);
  const [notDeleteModal, setNotDeleteModal] = useState(false);
  const [deleteId, setDeleteId] = useState(null);
  const [activePage, setActivePage] = useState(1);
  const [perPage, setPerPage] = useState(50);
  const [imageData, setImageData] = useState([]);

  const dispatch = useDispatch();

  const {
    allImages = null,
    allImagesLoading = false,
    findLoading = false,
    deleteImageLoading = false,
  } = useSelector((state) => ({
    allImages: state.allImages?.data?.data,
    allImagesLoading: state.allImages?.loading,
    findLoading: state.searchImage?.loading,
    deleteImageLoading: state.deleteImage?.loading,
  }));

  useEffect(() => {
    getAllImages();
  }, []);
  const handleDeleteModal = () => {
    setDeleteModal(!deleteModal);
  };

  const handleNotDeleteModal = () => {
    setNotDeleteModal(!notDeleteModal);
  };

  const handleDelete = () => {
    setDeleteModal(false);
    dispatch(fetchDeleteImage(deleteId)).then(() => {
      //   handleDeleteModal();
      getAllImages();
    });
  };

  const handlePageChange = (data) => {
    setActivePage(data);
    getAllImages(data);
  };

  const getPagination = () => {
    return (
      <div className="">
        {isValidArray(imageData?.data) && (
          <Pagination
            activePage={activePage}
            itemsCountPerPage={perPage}
            pageRangeDisplayed={5}
            totalItemsCount={imageData?.total || 0}
            // nextPageText={"Last"}
            // prevPageText={"First"}
            lastPageText={"Last"}
            firstPageText={"First"}
            hideNavigation={true}
            onChange={(e) => {
              handlePageChange(e);
            }}
            innerClass="pagination pagination-custom"
          />
        )}
      </div>
    );
  };

  const debouncedHandleSearch = (e) => {
    if (e) {
      dispatch(fetchSearchImage(e)).then((data) => {
        if (data?.flag) {
          setImageData(data);
        }
      });
    } else {
      getAllImages();
    }
  };

  const debounceLoadData = useCallback(
    debounce(debouncedHandleSearch, 1000),
    []
  );

  const handleSearch = (e) => {
    setSearch(e);
    debounceLoadData(e);
  };

  const getAllImages = (item = 1, perPage = 48) => {
    dispatch(fetchAllImages(item, perPage)).then((data) => {
      if (data?.flag) {
        setImageData(data?.data);
      }
    });
  };

  return (
    <>
      <div>
        <div className="bg-white common-space img-box-section media-image-view">
          <div className="d-flex justify-content-end">
            <InputNormal
              type="text"
              name="Attribute"
              placeholder="Search Images..."
              value={search}
              onChange={handleSearch}
            />
          </div>
          <div className="row">
            {findLoading || allImagesLoading || deleteImageLoading ? (
              <Loader />
            ) : (
              isValidArray(imageData?.data) &&
              imageData?.data.map((d, i) => {
                return (
                  <div className="col-2 my-2" key={d?.ImageID}>
                    <div className="common-space text-center img-listing-box">
                      <i
                        className="fa fa-times fa-lg"
                        onClick={() => {
                          setDeleteId(d?.ImageID);
                          handleDeleteModal();
                        }}
                      ></i>
                      <img
                        style={{ height: d?.ImageHeight, width: d?.ImageWidth }}
                        src={d?.ImagePath}
                        alt="Producty"
                      />
                      <div className="img-box-title">{d?.ImageName}</div>
                    </div>
                  </div>
                );
              })
            )}
          </div>
          {imageData?.from && (
            <>
              <p>
                Showing {imageData?.from} to {imageData?.to} of{" "}
                {imageData?.total} entries
              </p>
              {imageData?.data && getPagination()}
            </>
          )}
        </div>
        {/* {deleteModal && (
          <Modal
            className="conformation-popup delete-warning-popup invite-seller-popup"
            isOpen={deleteModal}
            toggle={handleDeleteModal}
            size={"lg"}
          >
            <ModalBody>
              <div className="delete-img">
                <img src={cancel} alt="cancel" />
              </div>
              <h3 className="warning-popup-title">
                Are you sure you want to delete this image?
              </h3>
              <p>You will not be able to recover this file!</p>
              <div className="popup-btn-section">
                <Button
                  color="primary save-btn confirm-y"
                  onClick={() => {
                    handleDeleteModal();
                    handleNotDeleteModal();
                  }}
                >
                  No
                </Button>
                <Button
                  color="primary save-btn confirm-y"
                  onClick={handleDelete}
                >
                  Yes
                </Button>
              </div>
            </ModalBody>
          </Modal>
        )} */}
        {notDeleteModal && (
          <Modal
            className="conformation-popup delete-warning-popup invite-seller-popup"
            isOpen={notDeleteModal}
            toggle={handleNotDeleteModal}
            size={"lg"}
          >
            <ModalBody>
              <div className="alert-img">
                <img src={informationIcon} alt="cancel" />
              </div>
              <h3 className="warning-popup-title">Image Not Deleted!</h3>
              <p className="lead text-muted ">Image has not been deleted!</p>
              <div className="popup-btn-section">
                <Button
                  color="primary save-btn confirm-y"
                  onClick={handleNotDeleteModal}
                >
                  Ok
                </Button>
              </div>
            </ModalBody>
          </Modal>
        )}
        {deleteModal && (
          <SweetAlert
            show={deleteModal}
            danger
            showCancel
            confirmBtnText="Yes"
            confirmBtnBsStyle="success"
            allowEscape={false}
            closeOnClickOutside={false}
            cancelBtnText="No"
            cancelBtnBsStyle="success"
            title="Are you sure you want to delete this image?"
            onConfirm={handleDelete}
            onCancel={() => {
              handleDeleteModal();
              handleNotDeleteModal();
            }}
            focusConfirmBtn
          >
            <p className="lead text-muted ">
              You will not be able to recover this file!
            </p>
          </SweetAlert>
        )}
      </div>
    </>
  );
};
export default ViewMedia;
