import InputField from "components/Common/InputField";
import Loader from "components/Common/Loader";
import DeleteModal from "components/Common/Modal/DeleteModal";
import Table from "components/Common/Table";
import { Form, Formik } from "formik";
import { filterFieldData } from "modules/utils";
import { addImageLabelForm, displayFormErrors } from "modules/validations";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Button, Label, Modal, ModalBody, ModalHeader } from "reactstrap";
import { fetchAddImageLabel } from "redux/actions/media/addImageLabel";
import { fetchDeleteImageLabel } from "redux/actions/media/deleteImageLabel";
import { fetchImageLabelList } from "redux/actions/media/imageLabelList";
import { fetchUpdateImageLabel } from "redux/actions/media/updateImageLabel";

const ImageLabel = () => {
  const dispatch = useDispatch();
  const [addLabelModal, setAddLabelModal] = useState(false);
  const [deleteLabelModal, setDeleteLabelModal] = useState(false);
  const [selectedIdDelete, setSelectedIdDelete] = useState(0);
  const [selectedIdEdit, setSelectedIdEdit] = useState(0);
  const [selectedLabelEdit, setSelectedLabelEdit] = useState(0);

  const {
    isLoading = false,
    imageLabelList = null,
    deleteImageLoading = false,
    addImageLoading = false,
    updateImageLabelLoading = false,
  } = useSelector((state) => ({
    imageLabelList: state.imageLabelList?.data?.data || null,
    isLoading: state.imageLabelList?.loading || null,
  }));

  useEffect(() => {
    dispatch(fetchImageLabelList());
  }, []);

  const ReactTableColumns = [
    {
      minWidth: 300,
      Header: "Image Label ID",
      id: "ImageLabelID",
      accessor: "ImageLabelID",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Image Label Name",
      id: "ImageLabelName",
      accessor: "ImageLabelName",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Button
            onClick={() => {
              setSelectedIdEdit(d.ImageLabelID);
              setSelectedLabelEdit(d.ImageLabelName);
              handleEditLabelModal();
            }}
          >
            Edit
          </Button>
          {" | "}
          <Button
            onClick={() => {
              setSelectedIdDelete(d.ImageLabelID);
              handleDeleteLabelModal();
            }}
          >
            Delete
          </Button>
        </>
      ),
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, imageLabelList, [
        "ImageLabelID",
        "ImageLabelName",
      ]);
    }
    return imageLabelList;
  };

  const handleAddLabelModal = () => {
    setSelectedLabelEdit("");
    setSelectedIdEdit(0);
    setAddLabelModal(!addLabelModal);
  };
  const handleEditLabelModal = () => {
    setAddLabelModal(!addLabelModal);
  };

  const handleDeleteLabelModal = () => {
    setDeleteLabelModal(!deleteLabelModal);
  };

  const handleDeleteLabel = () => {
    dispatch(fetchDeleteImageLabel(selectedIdDelete)).then((data) => {
      dispatch(fetchImageLabelList());
      handleDeleteLabelModal();
    });
  };

  const handleSubmit = (values) => {
    if (selectedIdEdit) {
      const formData = {
        imageLabelID: String(selectedIdEdit),
        imageLabelName: values.label,
      };
      dispatch(fetchUpdateImageLabel(formData)).then((data) => {
        dispatch(fetchImageLabelList());
        handleAddLabelModal();
      });
    } else {
      const formData = {
        imageLabelName: values.label,
      };
      dispatch(fetchAddImageLabel(formData)).then((data) => {
        dispatch(fetchImageLabelList());
        handleAddLabelModal();
      });
    }
  };

  return (
    <div>
      <div className="bg-white common-space media-setup-section">
        {isLoading ? (
          <Loader />
        ) : (
          <>
            <Button onClick={handleAddLabelModal}>Add Image Label</Button>
            <div className="tableorganisation catalog-tbl-section center-text-tbl product-tableBorder">
              <Table
                columns={ReactTableColumns}
                Data={imageLabelList}
                isLoading={isLoading}
                getFilterData={getFilterData}
                sortColumn={{
                  id: "ImageLabelID",
                  desc: false,
                }}
              />
            </div>
          </>
        )}

        {addLabelModal && (
          <Modal
            className="conformation-popup invite-seller-popup"
            isOpen={addLabelModal}
            toggle={handleAddLabelModal}
            size={"lg"}
          >
            <ModalHeader toggle={handleAddLabelModal}>
              Add / Edit Image Label
            </ModalHeader>
            <ModalBody>
              <Formik
                initialValues={{
                  label: selectedLabelEdit,
                }}
                validationSchema={addImageLabelForm}
                onSubmit={handleSubmit}
                enableReinitialize
              >
                {({
                  values,
                  errors,
                  touched,
                  handleChange,
                  handleBlur,
                  handleSubmit,
                  submitCount,
                  setFieldValue,
                }) => {
                  const showError = (key) =>
                    displayFormErrors(key, errors, touched, submitCount);

                  return (
                    <Form>
                      <div className="model-label-input imagesize-model">
                        <div className="row">
                          <div className="col-4">
                            <Label>Image Label Name: </Label>
                          </div>
                          <div className="col-8">
                            <InputField
                              type="text"
                              name="label"
                              placeholder="Add Label"
                              onChange={handleChange}
                              value={values.label || ""}
                            />
                            {showError("label")}
                          </div>
                        </div>
                      </div>
                      <div className="model-bottom-btn-section">
                        <Button
                          color="primary save-btn confirm-y"
                          onClick={handleSubmit}
                        >
                          Save changes
                        </Button>
                      </div>
                    </Form>
                  );
                }}
              </Formik>
            </ModalBody>
          </Modal>
        )}

        {deleteLabelModal && (
          <DeleteModal
            toggle={handleDeleteLabelModal}
            deleteFunction={handleDeleteLabel}
            isOpen={deleteLabelModal}
          />
        )}
      </div>
    </div>
  );
};

export default ImageLabel;
