import { addImageSizeForm, displayFormErrors } from "modules/validations";
import React, { useEffect, useState } from "react";
import { Form, Formik } from "formik";
import { Button, Label, Modal, ModalBody, ModalHeader } from "reactstrap";
import InputField from "components/Common/InputField";
import { useDispatch, useSelector } from "react-redux";
import { fetchImageSizeList } from "redux/actions/media/imageSizeList";
import { filterFieldData } from "modules/utils";
import Table from "components/Common/Table";
import DeleteModal from "components/Common/Modal/DeleteModal";
import { fetchAddImageSize } from "redux/actions/media/addImageSize";
import { fetchDeleteImageSize } from "redux/actions/media/deleteImageSize";
import Loader from "components/Common/Loader";

const ImageSize = () => {
  const dispatch = useDispatch();
  const [addSizeModal, setAddSizeModal] = useState(false);
  const [deleteSizeModal, setDeleteSizeModal] = useState(false);
  const [selectedIdDelete, setSelectedIdDelete] = useState(0);

  const {
    isLoading = false,
    imageSizeList = null,
    addImageSizeLoading = null,
  } = useSelector((state) => ({
    imageSizeList: state.imageSizeList?.data?.data || null,
    isLoading: state.imageSizeList?.loading || null,
    addImageSizeLoading: state.addImageSize?.loading || null,
  }));

  useEffect(() => {
    dispatch(fetchImageSizeList());
  }, []);

  const ReactTableColumns = [
    {
      minWidth: 300,
      Header: "ImageSize ID",
      id: "ImageSizeID",
      accessor: "ImageSizeID",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Width",
      id: "Width",
      accessor: "Width",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Height",
      id: "Height",
      accessor: "Height",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          {d?.ImageSizeIsDefault === 1 ? (
            <></>
          ) : (
            <Button
              onClick={() => {
                setSelectedIdDelete(d.ImageSizeID);
                handleDeleteSizeModal();
              }}
            >
              Delete
            </Button>
          )}
        </>
      ),
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, imageSizeList, [
        "ImageSizeID",
        "Width",
        "Height",
      ]);
    }
    return imageSizeList;
  };

  const handleAddSizeModal = () => {
    setAddSizeModal(!addSizeModal);
  };

  const handleDeleteSizeModal = () => {
    setDeleteSizeModal(!deleteSizeModal);
  };

  const handleDeleteSize = () => {
    dispatch(fetchDeleteImageSize(selectedIdDelete)).then((data) => {
      dispatch(fetchImageSizeList());
      handleDeleteSizeModal();
    });
  };

  const handleSubmit = (values) => {
    const formData = {
      width: values.width,
      height: values.height,
    };

    dispatch(fetchAddImageSize(formData)).then((data) => {
      dispatch(fetchImageSizeList());
      handleAddSizeModal();
    });
  };
  return (
    <div>
      <div className="bg-white common-space image-size-section">
        {isLoading || addImageSizeLoading ? (
          <Loader />
        ) : (
          <>
            <Button onClick={handleAddSizeModal}>Add Image Size</Button>

            <div className="tableorganisation catalog-tbl-section center-text-tbl media-setup-section product-tableBorder">
              <Table
                columns={ReactTableColumns}
                Data={imageSizeList}
                isLoading={isLoading}
                getFilterData={getFilterData}
                sortColumn={{
                  id: "ImageSizeID",
                  desc: false,
                }}
              />
            </div>
          </>
        )}

        {addSizeModal && (
          <Modal
            className="conformation-popup invite-seller-popup"
            isOpen={addSizeModal}
            toggle={handleAddSizeModal}
            size={"lg"}
          >
            <ModalHeader toggle={handleAddSizeModal}>
              Add / Edit Image Size
            </ModalHeader>
            <ModalBody>
              <Formik
                initialValues={{
                  width: "",
                  height: "",
                }}
                validationSchema={addImageSizeForm}
                onSubmit={handleSubmit}
                enableReinitialize
              >
                {({
                  values,
                  errors,
                  touched,
                  handleChange,
                  handleBlur,
                  handleSubmit,
                  submitCount,
                  setFieldValue,
                }) => {
                  const showError = (key) =>
                    displayFormErrors(key, errors, touched, submitCount);

                  return (
                    <Form>
                      <div className="model-label-input image-size-input-box">
                        <div className="row mb-3">
                          <div className="col-md-4">
                            <Label>Width: </Label>
                          </div>
                          <div className="col-md-8">
                            <InputField
                              type="number"
                              name="width"
                              placeholder="Add Width"
                              onChange={handleChange}
                              value={values.width || ""}
                            />
                            {showError("width")}
                          </div>
                        </div>
                        <div className="row">
                          <div className="col-md-4">
                            <Label>Height: </Label>
                          </div>
                          <div className="col-md-8">
                            <InputField
                              type="number"
                              name="height"
                              placeholder="Add Height"
                              onChange={handleChange}
                              value={values.height || ""}
                            />
                            {showError("height")}
                          </div>
                        </div>
                      </div>
                      <div className="model-bottom-btn-section">
                        <Button
                          color="primary save-btn confirm-y"
                          onClick={handleSubmit}
                        >
                          Save changes
                        </Button>
                      </div>
                    </Form>
                  );
                }}
              </Formik>
            </ModalBody>
          </Modal>
        )}

        {deleteSizeModal && (
          <DeleteModal
            toggle={setDeleteSizeModal}
            deleteFunction={handleDeleteSize}
            isOpen={deleteSizeModal}
          />
        )}
      </div>
    </div>
  );
};

export default ImageSize;
