import React, { useEffect, useState } from "react";
import Multiselect from "multiselect-react-dropdown";
import InputField from "components/Common/InputField";
import SelectField from "components/Common/SelectField";
import { isValidArray, getRowPerPageArray } from "modules/utils";
import Pagination from "react-js-pagination";
import { useDispatch, useSelector } from "react-redux";
import ReactTable from "react-table-6";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
  Tooltip,
} from "reactstrap";
import { fetchActiveCatalogList } from "redux/actions/masterAdmin/activeCatalogList";
import { fetchAddCatalog } from "redux/actions/masterAdmin/addCatalog";
import { fetchCatalogList } from "redux/actions/masterAdmin/catalogList";
import { fetchCatalogChildList } from "redux/actions/masterAdmin/catalogChildList";
import infoIconnew from "../../../assets/images/infoIconnew.png";
import Select from "react-select";
import { fetchLayoutList } from "redux/actions/output/layoutList";
import { createFiles } from "redux/actions/output/CreateFiles";
import { useHistory } from "react-router-dom/cjs/react-router-dom.min";
import { fetchGetAllAttributeSchemaList } from "redux/actions/output/getAllAttributeSchemaList";
import SelectDropdownSearchable from "components/Common/SelectDropdownSearchable";

function CreateLayout() {
  const dispatch = useDispatch();
  const history = useHistory();
  const [selectOrganization, setSelectOrganization] = useState("");
  const [selectLayout, setSelectLayout] = useState("");
  const [catalogDataList, setCatalogDataList] = useState([]);
  const [selectedValue, setSelectedValue] = useState([]);
  const [exportType, setExportType] = useState("");
  const [categoryID, setCategoryID] = useState([]);
  const [onBoardingCharge, setOnBoardingCharge] = useState(false);
  const [IndesignXml, setIndesignXml] = useState(false);
  const [abstractPdf, setabstractPdf] = useState(false);
  const [flatplanPdf, setflatplanPdf] = useState(false);
  const [layoutOption, setLayoutOption] = useState([]);
  const [isSubmit, setIsSubmit] = useState(false);
  const [attributeSchemaListOption, setAttributeSchemaListOption] = useState(
    []
  );

  const {
    isLoading = false,
    catalogList = null,
    categoryListLoading = false,
    categoryList = null,
    activeCatalogList = null,
  } = useSelector((state) => ({
    catalogList: state.catalogList?.data?.data || null,
    isLoading: state.catalogList?.loading || null,
    activeCatalogList: state.activeCatalogList?.data?.data || null,
    activeIsLoading: state.activeCatalogList?.loading || null,
    categoryListLoading: state.categoryList?.loading || null,
    categoryList: state.categoryList?.data?.data || null,
  }));

  useEffect(() => {
    dispatch(fetchCatalogChildList()).then((data) => {
      let updated = data?.data?.map((item) => {
        return {
          value: item.id,
          label: item.text,
          level: item.level,
          // name2: `<div dangerouslySetInnerHTML={{__html: '<p>First &middot; Second</p>'}}></div>`,
          // name1: `<div className="level-${item.level}" dangerouslySetInnerHTML={{__html: ${item.text}}}></div>`,
        };
      });
      setCatalogDataList(updated);
    });

    dispatch(fetchLayoutList()).then((data) => {
      const updated = data?.data.map((d, i) => {
        return {
          label: d?.LayoutName,
          value: d?.LayoutID,
        };
      });
      const single = [{ label: "No layout set" }, ...updated];
      setLayoutOption(single);
    });

    dispatch(fetchGetAllAttributeSchemaList()).then((data) => {
      const result = data?.data.map((d, i) => {
        return {
          value: d?.CatalogAttributeSchemaID,
          label: d?.CatalogAttributeSchemaName,
        };
      });
      const single = [{ label: "All Attributes", value: "0" }, ...result];
      setAttributeSchemaListOption(single);
    });
  }, []);

  const onSelect = (selectedList, selectedItem) => { };

  const onRemove = (selectedList, removedItem) => { };

  const handleChange = (value) => {
    const categoryIds = value.map((e) => e.value);

    setCategoryID(categoryIds);
  };

  const catalogOptions = () => {
    let updated = catalogDataList?.map((item) => {
      return {
        id: item.id,
        // name: `<snap className="level-${item.level}">${item.text}</snap>`,
        name: item.text,
      };
    });
    return updated;
  };

  const showLayoutOption = () => {
    return layoutOption?.map((item) => {
      return {
        label: item.label,
        value: item.value,
      };
    });
  };
  const showAttributeSchemaListOption = () => {
    return attributeSchemaListOption?.map((item) => {
      return {
        label: item.label,
        value: item.value,
      };
    });
  };

  const handleSubmitExport = () => {
    setIsSubmit(true);
    if (exportType && isValidArray(categoryID)) {
      const formData = {
        categoryID: categoryID,
        format: null,
        languageOption: null,
        exportType: exportType,
        ProductBlobID: null,
        attributeSchemaID: selectOrganization,
        LayoutID: selectLayout,
      };

      dispatch(createFiles(formData)).then((data) => {
        if (data?.flag === true) {
          history.push("/success");
        }
      });
    }
  };

  return (
    <>
      <div className="bg-white common-space output-create-file-section">
        <div className="row">
          <div className="col-6">
            <div className="export-name">
              <h4 className="output-tab-title">Data & Layout Options</h4>
            </div>
            <div className="create-box">
              <div className="create-box-label">Select Catalog/Category</div>
              <Select
                isMulti
                className="custom-select-box"
                options={catalogDataList}
                // menuIsOpen={true}

                categoryIDs={categoryID}
                placeholder="Select an option"
                formatOptionLabel={function (data) {
                  return (
                    <span
                      className={`level-${data.level}`}
                      dangerouslySetInnerHTML={{ __html: data.label }}
                    />
                  );
                }}
                onChange={(value) => handleChange(value)}
                isSearchable={true}
              />
              {isSubmit && !isValidArray(categoryID) ? (
                <p style={{ color: "red" }}>
                  Catalog/Category is a required field.
                </p>
              ) : (
                ""
              )}
            </div>
            <div className="create-box">
              <div className="create-box-label">Select Attribute Schema</div>
              <SelectDropdownSearchable
                type="select"
                name="selectOrganization"
                id="selectOrganization"
                placeholder="All Attributes"
                options={showAttributeSchemaListOption()}
                handleChange={(val) => setSelectOrganization(val)}
                value={selectOrganization}
              />
            </div>
            <div className="create-box">
              <div className="create-box-label">Select Layout</div>
              <SelectDropdownSearchable
                type="select"
                name="selectOrganization"
                id="selectOrganization"
                placeholder="No layout set"
                options={showLayoutOption()}
                handleChange={(val) => setSelectLayout(val)}
                value={selectLayout}
              />
            </div>
            <div className="create-box">
              <div className="custom-checkbox-right">
                <div className="create-box-label">Select Export Type:</div>
                <div className="custom-radio-btn">
                  <Label className="radio-inline xlsx_radio"></Label>
                  <Input
                    type="radio"
                    name="format"
                    value="Indesign XML"
                    onChange={(e) => setExportType("Indesign XML")}
                  />
                  Indesign XML
                  <div className="info-btn tooltip-contain">
                    <img
                      src={infoIconnew}
                      alt="IndesignXml"
                      data-toggle="tooltip"
                      id="IndesignXmlExample"
                      title=""
                    />
                    <Tooltip
                      flip
                      target="IndesignXmlExample"
                      placement="bottom-start"
                      toggle={() => setIndesignXml(!IndesignXml)}
                      isOpen={IndesignXml}
                      autohide={false}
                    >
                      Indesign friendly XML Export
                    </Tooltip>
                  </div>
                </div>
                <div className="custom-radio-btn">
                  <Label className="radio-inline json_radio"></Label>
                  <Input
                    type="radio"
                    name="format"
                    onChange={(e) => setExportType("AbstractPDF")}
                    value="AbstractPDF"
                  />
                  Abstract PDF
                  <div className="info-btn">
                    <img
                      src={infoIconnew}
                      alt="abstractPdf"
                      data-toggle="tooltip"
                      id="abstractPdfExample"
                      title=""
                    />
                    <Tooltip
                      flip
                      target="abstractPdfExample"
                      placement="bottom-start"
                      toggle={() => setabstractPdf(!abstractPdf)}
                      isOpen={abstractPdf}
                      autohide={false}
                    >
                      Export your catalog into print ready PDF.
                    </Tooltip>
                  </div>
                </div>

                <div className="custom-radio-btn">
                  <Label className="radio-inline json_radio"></Label>
                  <Input
                    type="radio"
                    name="format"
                    onChange={(e) => setExportType("FlatplanPDF")}
                    value="FlatplanPDF"
                  />
                  Flat Plan PDF
                  <div className="info-btn">
                    <img
                      src={infoIconnew}
                      alt="flatplanPdf"
                      data-toggle="tooltip"
                      id="flatplanPdfExample"
                      title=""
                    />
                    <Tooltip
                      flip
                      target="flatplanPdfExample"
                      placement="bottom-start"
                      toggle={() => setflatplanPdf(!flatplanPdf)}
                      isOpen={flatplanPdf}
                      autohide={false}
                    >
                      Export your catalog into print ready FlatPlan PDF.
                    </Tooltip>
                  </div>
                </div>
                {isSubmit && exportType == "" ? (
                  <p style={{ color: "red" }}>
                    Export type is a required field.
                  </p>
                ) : (
                  ""
                )}
              </div>
            </div>
            <div className="create-file-btn-section">
              <button
                type="button"
                className="btn btn-secondary btn-default export-edit exportAttributesSubmitBtn"
                value="submit_export"
                name="submit_export"
                onClick={handleSubmitExport}
              >
                Export
              </button>
            </div>
          </div>
          <div className="col-6">
            <div className="export-name">
              <h4 className="output-tab-title">Images</h4>
            </div>
            <div className="create-box-content">
              <p>Images have not yet been imported for this catalog.</p>
              <p>
                Image Versions have not been configured for your organisation.
              </p>
            </div>
            <div className="create-box">
              <div className="create-box-label">Image Path</div>
              <InputField
                type="text"
                name="searchOrganization"
                placeholder=""
              />
            </div>
            <div className="custom-checkbox-right">
              <div className="custom-checkbox right-custom">
                <Input
                  type="checkbox"
                  name="onboardingCharge"
                  onChange={(e) =>
                    setOnBoardingCharge(e.target.checked ? 1 : 0)
                  }
                  value={onBoardingCharge}
                />
                <Label check> Download images</Label>{" "}
              </div>
            </div>
          </div>
        </div>
      </div>
    </>
  );
}

export default CreateLayout;
