import Table from "components/Common/Table";
import { filterFieldData } from "modules/utils";
import moment from "moment";
import React, { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import { fetchCancelExport } from "redux/actions/output/cancelExport";
import { fetchExportHistoryList } from "redux/actions/output/ExportHistory";

function ExportHistory(props) {
  const dispatch = useDispatch();

  const { isLoading = false, exportHistoryList = null } = useSelector(
    (state) => ({
      exportHistoryList: state.exportHistoryList?.data?.data || null,
      isLoading: state.exportHistoryList?.loading || null,
    })
  );

  useEffect(() => {
    dispatch(fetchExportHistoryList());
  }, []);

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, exportHistoryList, [
        "OrganisationName",
        "ExportHistoryDateTime",
        "ExportHistoryUpdateTime",
        "Duration",
        "filePath",
        "status",
        "format",
        "options",
        "FirstName",
      ]);
    }
    return exportHistoryList;
  };

  const handleCancelExport = (id) => {
    dispatch(fetchCancelExport(id)).then((data) => {
      dispatch(fetchExportHistoryList());
    });
  };

  const ReactTableColumns = [
    {
      minWidth: 100,
      Header: "Start Date/ Time",
      id: "ExportHistoryDateTime",
      accessor: "ExportHistoryDateTime",
    },
    {
      minWidth: 100,
      Header: "End Date/ Time",
      id: "ExportHistoryUpdateTime",
      accessor: "ExportHistoryUpdateTime",
    },
    {
      minWidth: 60,
      Header: "Duration",
      id: "duration",
      accessor: (d) => {
        let start = moment(d.ExportHistoryDateTime);
        let end = moment(d.ExportHistoryUpdateTime);
        let diff = end.diff(start);
        let f = moment.utc(diff).format("mm:ss");
        return f;
      },
    },
    {
      minWidth: 160,
      Header: "Filename",
      id: "filePath",
      accessor: (d) => {
        return (
          d.filePath && (
            <a
              style={{ textDecoration: "none" }}
              href={d.s3FilePath}
              target="_blank"
              rel="noopener noreferrer"
              download
            >
              {d.filePath}
              <span>
                <i className="fa fa-download" aria-hidden="true"></i>
              </span>
            </a>
          )
        );
      },
    },
    {
      minWidth: 80,
      Header: "Status",
      id: "status",
      accessor: "status",
      Cell: ({ original, value }) => {
        switch (value) {
          case "Completed":
            return <div className="status-btn label-success">{value}</div>;
          case "Currently In Progress":
            return (
              <>
                <div className="status-btn label-secondary">In Progress</div>
                <div
                  className="status-btn label-danger"
                  style={{ cursor: "pointer" }}
                  onClick={() => handleCancelExport(original.ExportHistoryID)}
                >
                  Cancel
                </div>
              </>
            );
          case "In Progress":
            return (
              <>
                <div className="status-btn label-secondary">In Progress</div>
                <div
                  className="status-btn label-danger"
                  style={{ cursor: "pointer" }}
                  onClick={() => handleCancelExport(original.ExportHistoryID)}
                >
                  Cancel
                </div>
              </>
            );
          default:
            return <div className="status-btn label-danger">{value}</div>;
        }
      },
    },
    {
      minWidth: 100,
      Header: "Format",
      id: "format",
      accessor: "format",
    },
    {
      minWidth: 100,
      Header: "Options",
      id: "options",
      accessor: "options",
    },
    {
      minWidth: 100,
      Header: "Name",
      id: "FirstName",
      accessor: "FirstName",
    },
    {
      minWidth: 100,
      Header: "Organisation",
      id: "OrganisationName",
      accessor: "OrganisationName",
    },
  ];

  return (
    <div>
      <div className="tableorganisation catalog-tbl-section bg-white pt-5 export-history-page product-tableBorder">
        <div className="export-name">
          <b>Export History</b>
        </div>
        <Table
          columns={ReactTableColumns}
          Data={exportHistoryList}
          isLoading={isLoading}
          getFilterData={getFilterData}
        />
      </div>
    </div>
  );
}

export default ExportHistory;
