import React, { useState } from "react";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import AttributeSchema from "./attributeSchema/AttributeSchema";
import CatalogSetup from "./catalogSetup/CatalogSetup";
import LayoutTemplates from "./layoutTemplates/LayoutTemplates";
import PageSetup from "./pageSetup/PageSetup";

function ExportSetup({ handleTab: handleTabChange }) {
  const initialActiveTab = {
    AttributeSchema: "active",
    LayoutTemplates: "",
    PageSetup: "",
    CatalogSetup: "",
    activeTab: "AttributeSchema",
  };
  const [activeTab, setActiveTab] = useState(initialActiveTab);

  const handleTab = (tabName) => {
    if (tabName == "LayoutTemplates") {
      setActiveTab({
        LayoutTemplates: "active",
        AttributeSchema: "",
        PageSetup: "",
        CatalogSetup: "",
        activeTab: "LayoutTemplates",
      });
    } else if (tabName == "AttributeSchema") {
      setActiveTab({
        LayoutTemplates: "",
        AttributeSchema: "active",
        PageSetup: "",
        CatalogSetup: "",
        activeTab: "AttributeSchema",
      });
    } else if (tabName == "PageSetup") {
      setActiveTab({
        LayoutTemplates: "",
        AttributeSchema: "",
        PageSetup: "active",
        CatalogSetup: "",
        activeTab: "PageSetup",
      });
    } else if (tabName == "CatalogSetup") {
      setActiveTab({
        LayoutTemplates: "",
        AttributeSchema: "",
        PageSetup: "",
        CatalogSetup: "active",
        activeTab: "CatalogSetup",
      });
    }
  };

  return (
    <>
      <div>
        <Nav tabs>
          <NavItem>
            <NavLink
              className={activeTab.AttributeSchema}
              onClick={() => handleTab("AttributeSchema")}
            >
              Attribute Schema
            </NavLink>
          </NavItem>
          <NavItem>
            <NavLink
              className={activeTab.LayoutTemplates}
              onClick={() => handleTab("LayoutTemplates")}
            >
              Layout Templates
            </NavLink>
          </NavItem>
          <NavItem className="disabled">
            <NavLink
              className={activeTab.PageSetup}
              onClick={() => handleTab("PageSetup")}
              disabled
            >
              Page Setup
            </NavLink>
          </NavItem>
          <NavItem className="disabled">
            <NavLink
              className={activeTab.CatalogSetup}
              onClick={() => handleTab("CatalogSetup")}
              disabled
            >
              Catalog Setup
            </NavLink>
          </NavItem>
        </Nav>
        <TabContent activeTab={activeTab.activeTab}>
          <TabPane tabId="AttributeSchema">
            {activeTab.activeTab === "AttributeSchema" && (
              <AttributeSchema handleTabChange={handleTabChange} />
            )}
          </TabPane>
          <TabPane tabId="CatalogSetup">
            {activeTab.activeTab === "CatalogSetup" && <CatalogSetup />}
          </TabPane>
          <TabPane tabId="LayoutTemplates">
            {activeTab.activeTab === "LayoutTemplates" && (
              <LayoutTemplates handleTabChange={handleTabChange} />
            )}
          </TabPane>
          <TabPane tabId="PageSetup">
            {activeTab.activeTab === "PageSetup" && <PageSetup />}
          </TabPane>
        </TabContent>
      </div>
    </>
  );
}

export default ExportSetup;
