/* eslint-disable react/react-in-jsx-scope */
import InputField from "components/Common/InputField";
import DeleteModalWithoutHeader from "components/Common/Modal/DeleteModalWithoutHeader";
import SelectField from "components/Common/SelectField";
import { Form, Formik } from "formik";
import {
  attributeSchemaListForm,
  displayFormErrors,
} from "modules/validations";
import { useEffect, useState } from "react";
import { DragDropContext, Draggable, Droppable } from "react-beautiful-dnd";
import { useDispatch, useSelector } from "react-redux";
import { Button, Col, Input, Label, Row } from "reactstrap";
import { fetchAddAttributeSchema } from "redux/actions/masterSetup/addAttributeSchema";
import { fetchGetAllAttributeSchemaDetails } from "redux/actions/output/getAllAttributeSchemaDetails";
import { fetchGetAllAttributeSchemaList } from "redux/actions/output/getAllAttributeSchemaList";
import Loader from "components/Common/Loader";
import {
  filterFieldData,
  isValidArray,
  showSuccessErrorToast,
} from "modules/utils";
import { fetchCloneAttributeSchema } from "redux/actions/manageCatalog/cloneAttributeSchema";
import { fetchDeleteAttributeSchema } from "redux/actions/manageCatalog/deleteAttributeSchema";
import { fetchAddAttributeToSchema } from "redux/actions/output/addAttributeToSchema";
import { fetchAttributeListForSchema } from "redux/actions/output/attributeListForSchema";
import { fetchDeleteAttributeForSchema } from "redux/actions/output/deleteAttributeForSchema";
import { fetchUpdateSchemaAttributesSortOrder } from "redux/actions/output/updateSchemaAttributeSortOrder";
import { fetchUpdateSchemaAttributes } from "redux/actions/output/updateSchemaAttributes";
import ConfirmationModal from "./ConfirmationModal";

function AttributeSchema({ handleTabChange, catalogId }) {
  const [items, setItems] = useState([]);

  const dispatch = useDispatch();
  const [attributeSchemaListOption, setAttributeSchemaListOption] = useState(
    []
  );
  const [selectedAttributeSchemaId, setSelectedAttributeSchemaId] =
    useState("");
  const [selectedAddAttribute, setSelectedAddAttribute] = useState("");
  const [attributeSchemaName, setAttributeSchemaName] = useState("");
  const [deleteAttributeModal, setDeleteAttributeModal] = useState(false);
  const [selectedAttrIdDelete, setSelectedAttrIdDelete] = useState(0);
  const [selectedAttrWidthDelete, setSelectedAttrWidthDelete] = useState(0);
  const [addNewAttributeItems, setAddNewAttributeItems] = useState([]);
  const [isEdit, setIsEdit] = useState(false);
  const [isAddAttribute, setIsAddAttribute] = useState(false);
  const [missingAttribute, setMissingAttribute] = useState([]);
  const [tempDeleteID, setTempDeleteID] = useState();
  const [searchValue, setSearchValue] = useState("");
  const [schemaNameEditable, setSchemaNameEditable] = useState(false);
  const [showConfirmModal, setConfirmModal] = useState();
  const [confirmText, setConfirmText] = useState("");

  useEffect(() => {
    getInitialData();
  }, []);

  const getInitialData = (attributeSchemaName) => {
    dispatch(fetchGetAllAttributeSchemaList()).then((data) => {
      const result = data?.data.map((d, i) => {
        let catlogObj = {
          value: d?.CatalogAttributeSchemaID,
          label: d?.CatalogAttributeSchemaName,
        };
        if (i === 0) {
          setAttributeSchemaName(
            attributeSchemaName || d?.CatalogAttributeSchemaName
          );
        }
        return catlogObj;
      });

      setAttributeSchemaListOption([
        { label: "Please select one", value: "" },
        ...result,
      ]);
    });
  };

  const {
    getAllAttributeSchemaList = null,
    getAttributeListForSchemaLoading = null,
    getAllAttributeSchemaDetails = null,
  } = useSelector((state) => ({
    getAttributeListForSchemaLoading: state.attributeListForSchema?.loading,
    getAllAttributeSchemaList: state.getAllAttributeSchemaList?.data?.data,
    getAllAttributeSchemaDetails:
      state.getAllAttributeSchemaDetails?.data?.data,
  }));

  const handleSubmit = (values) => {
    const result = { CatalogAttributeSchemaName: values.label };

    dispatch(fetchAddAttributeSchema(result)).then(() => {
      handleTabChange("createFile");
    });
  };

  const getAttributeSchemaId = (itemId) => {
    let attributeObj = attributeSchemaListOption.find(
      (o) => o.value === Number(itemId)
    );
    if (itemId) {
      setSelectedAttributeSchemaId(itemId);
      getAttributeSchemaList(itemId);
    }
  };

  const getAttributeSchemaList = (itemId, schemaName) => {
    // setAttributeSchemaId(selectedAttributeSchemaId);
    if (itemId || selectedAttributeSchemaId) {
      dispatch(
        fetchGetAllAttributeSchemaDetails(itemId || selectedAttributeSchemaId)
      ).then((data) => {
        const name = getAllAttributeSchemaList.find(
          (d) =>
            d?.CatalogAttributeSchemaID == (itemId ?? selectedAttributeSchemaId)
        )?.CatalogAttributeSchemaName;
        setAttributeSchemaName(name);
        setItems(data?.data);
      });

      dispatch(
        fetchAttributeListForSchema(itemId || selectedAttributeSchemaId)
      ).then((data) => {
        const options = data?.data?.map((item) => {
          return {
            label: item.AttributeName,
            value: item.AttributeID,
          };
        });
        const single = [{ label: "Add attribute", value: "" }, ...options];
        setMissingAttribute(single);
      });
    } else {
      setAttributeSchemaName("");
      if (!selectedAttributeSchemaId) {
        setItems([]);
      }
      setMissingAttribute([]);
    }
  };

  const handleConfirmModal = () => {
    setConfirmModal(!showConfirmModal);
  };

  const handleCloneAttributeSchema = () => {
    dispatch(fetchCloneAttributeSchema(selectedAttributeSchemaId)).then(
      (data) => {
        handleConfirmModal();
        showSuccessErrorToast(true, data?.message);
        getInitialData();
      }
    );
  };

  const handleDeleteAttributeSchema = () => {
    dispatch(fetchDeleteAttributeSchema(selectedAttributeSchemaId)).then(
      (data) => {
        handleConfirmModal();
        showSuccessErrorToast(data?.flag, data?.message);
        getInitialData();
      }
    );
  };

  const handleSearch = (searchText) => {
    setSearchValue(searchText);

    if (searchText) {
      const data = filterFieldData(searchText, items, [
        "AttributeID",
        "AttributeName",
        "ColumnWidth",
        "SortOrder",
      ]);
      setItems(data);
    } else {
      setItems(getAllAttributeSchemaDetails);
    }
  };

  const onDragEnd = (e) => {
    if (!e.destination) {
      return;
    }
    const sorted = reorder(items, e.source.index, e.destination.index);

    setItems(sorted);
    let attributeId = [];
    sorted.map((d, i) => {
      attributeId = [...attributeId, d.SchemaAttributeID];
    });

    let formData = new FormData();
    formData.append("SchemaID", selectedAttributeSchemaId);
    formData.append("attributesArray", attributeId);

    const passData = {
      attributesArray: attributeId,
      SchemaID: selectedAttributeSchemaId,
    };

    dispatch(fetchUpdateSchemaAttributesSortOrder(formData)).then((data) => {
      getAttributeSchemaList();
    });
  };

  const reorder = (list, startIndex, endIndex) => {
    const result = Array.from(list);
    const [removed] = result.splice(startIndex, 1);
    result.splice(endIndex, 0, removed);

    return result;
  };

  const handleChange = (attributeId, attributeValue) => {
    if (selectedAddAttribute) {
      const attributeData = addNewAttributeItems?.map((item) => {
        if (item.attributeId === attributeId) {
          return {
            ...item,
            width: attributeValue,
          };
        }
        return item;
      });
      setAddNewAttributeItems(attributeData);
    } else {
      const value = items?.map((item) => {
        if (item.AttributeID === attributeId) {
          return {
            ...item,
            ColumnWidth: attributeValue,
          };
        }
        return item;
      });

      setItems(value);
    }
  };

  const handleSave = () => {
    if (isAddAttribute) {
      let formArray = [];

      addNewAttributeItems?.map((item, i) => {
        formArray.push({
          name: String(item.attributeId),
          value: String(item.width),
        });
      });

      const formData = {
        CatalogAttributeSchemaID: selectedAttributeSchemaId,
        data: formArray,
      };
      dispatch(fetchAddAttributeToSchema(formData)).then((data) => {
        getAttributeSchemaList();
        setIsAddAttribute(false);
        setIsEdit(false);
        setAddNewAttributeItems([]);
      });
    } else {
      const formData = new FormData();
      formData.append("schemaID", selectedAttributeSchemaId);
      formData.append("schemaName", attributeSchemaName);
      items?.map((item, i) => {
        formData.append(`data[${i}][name]`, String(item.AttributeID));
        formData.append(`data[${i}][value]`, String(item.ColumnWidth));
      });
      dispatch(fetchUpdateSchemaAttributes(formData)).then((data) => {
        getAttributeSchemaList();
        setIsEdit(false);
        getInitialData(attributeSchemaName);
      });
    }
  };

  const widthTotal = items.reduce(
    (total, currentItem) => (total = total + Number(currentItem.ColumnWidth)),
    0
  );

  const appendNewAttribute = (selectedAddAttribute1) => {
    if (selectedAddAttribute1) {
      var getItemData = missingAttribute.find(
        (item) => item.value == selectedAddAttribute1
      );

      const restItemData = missingAttribute.filter((d) => {
        return d.value != selectedAddAttribute1;
      });

      setMissingAttribute(restItemData);

      let itemArr = {
        attributeId: getItemData.value,
        attributeName: getItemData.label,
        width: "",
      };
      var attributeData = [...addNewAttributeItems, itemArr];

      setAddNewAttributeItems(attributeData);
      setIsAddAttribute(true);
    }
  };

  const handleDeleteAttribute = () => {
    if (isAddAttribute) {
      if (tempDeleteID > -1) {
        addNewAttributeItems.splice(tempDeleteID, 1);
      }
      handleDeleteAttributeModal();
    } else {
      dispatch(
        fetchDeleteAttributeForSchema(
          String(selectedAttributeSchemaId),
          String(selectedAttrIdDelete)
        )
      ).then((data) => {
        getAttributeSchemaList();
        handleDeleteAttributeModal();
      });
    }
    if (addNewAttributeItems.length === 0) {
      setIsEdit(false);
      setIsAddAttribute(false);
    }
  };

  const handleDeleteAttributeModal = () => {
    setDeleteAttributeModal(!deleteAttributeModal);
  };

  {
    showConfirmModal && (
      <ConfirmationModal
        isOpen={showConfirmModal}
        toggle={handleConfirmModal}
        handleConfirm={handleDeleteAttributeSchema}
      />
    );
  }

  return (
    <div className="layout-template-section p-0 m-0">
      <div
        style={{
          alignItems: "center",
          paddingBottom: 20,
          background: "#e1e1e1",
          padding: 10,
        }}
      >
        <Row>
          <Col xs="6">
            <Row className="align-items-center">
              <Col xs="4">
                <Label>Edit Existing Attribute Schema</Label>
              </Col>
              <Col xs="4">
                <SelectField
                  type="select"
                  name="attributeSchemaId"
                  id="attributeSchemaId"
                  options={attributeSchemaListOption}
                  onChange={getAttributeSchemaId}
                  value={selectedAttributeSchemaId}
                />
              </Col>
              <Col xs="4">
                {isEdit || isAddAttribute ? (
                  <>
                    <Button
                      onClick={handleSave}
                      className="primary save-btn confirm-y mr-2"
                      style={{ marginRight: "5px" }}
                    >
                      Save
                    </Button>
                    <Button
                      onClick={() => {
                        setIsEdit(false);
                      }}
                      className="cancel-btn-red"
                    >
                      Cancel
                    </Button>
                  </>
                ) : (
                  <>
                    <Button
                      className="primary save-btn confirm-y mb-1"
                      onClick={() => {
                        getAttributeSchemaList();
                        setIsEdit(true);
                      }}
                      style={{ marginRight: 5 }}
                      disabled={!selectedAttributeSchemaId}
                    >
                      Edit
                    </Button>
                    <Button
                      className="primary save-btn confirm-n mb-1"
                      onClick={() => {
                        handleDeleteAttributeSchema();
                        setConfirmText(
                          "Are you sure you want to delete this schema"
                        );
                        // getAttributeSchemaList();
                        // setIsEdit(true);
                      }}
                      style={{ marginRight: 5 }}
                      disabled={!selectedAttributeSchemaId}
                    >
                      Delete
                    </Button>
                    <Button
                      className="primary save-btn confirm-y mb-1"
                      onClick={() => {
                        // handleConfirmModal();
                        // setConfirmText(
                        //   "Are you sure you want to clone this schema"
                        // );
                        handleCloneAttributeSchema();
                        getAttributeSchemaList();

                        // setIsEdit(true);
                      }}
                      disabled={!selectedAttributeSchemaId}
                    >
                      Clone
                    </Button>
                  </>
                )}
              </Col>{" "}
            </Row>
          </Col>
          <Col xs="6">
            <Formik
              initialValues={{
                label: "",
              }}
              validationSchema={attributeSchemaListForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);

                return (
                  <Form>
                    <Row className="align-items-center">
                      <Col xs="4">
                        <Label>Create New Attribute Schema </Label>
                      </Col>
                      <Col xs="4">
                        <InputField
                          type="text"
                          name="label"
                          placeholder="Create New Schema"
                          onChange={handleChange}
                          value={values.label || ""}
                        />
                        {showError("label")}
                      </Col>
                      <Col xs="4">
                        <Button
                          color="primary save-btn confirm-y"
                          onClick={() => {
                            handleSubmit();
                          }}
                        >
                          Create
                        </Button>
                      </Col>
                    </Row>
                  </Form>
                );
              }}
            </Formik>
          </Col>
        </Row>
      </div>

      {isValidArray(items) || isValidArray(missingAttribute) || isEdit ? (
        <>
          <div className="attributeSchema-table-text">
            <div className="col-lg-3">
              <div className="d-flex align-items-center">
                <Input
                  style={{ marginRight: "2px", width: "45%" }}
                  type="text"
                  value={attributeSchemaName}
                  onChange={(e) => setAttributeSchemaName(e.target.value)}
                  disabled={!schemaNameEditable}
                />
                <i
                  className={
                    schemaNameEditable
                      ? "fa fa-check cc undo-icon"
                      : "fa fa-pencil cc undo-icon"
                  }
                  style={{
                    color: "black",
                  }}
                  onClick={() => {
                    setSchemaNameEditable(!schemaNameEditable);
                  }}
                ></i>
              </div>
            </div>
          </div>

          <div className="tableorganisation category-table attributeschemaTable center-text-tbl">
            <div className="tabcontent bg-white">
              <label className="form-label">Search: </label>
              <input
                name="search"
                type="text"
                className="form-control"
                value={searchValue}
                onChange={(e) => handleSearch(e.target.value)}
              />
            </div>

            {getAttributeListForSchemaLoading ? (
              <Loader />
            ) : (
              <DragDropContext onDragEnd={onDragEnd}>
                <Droppable droppableId="Table">
                  {(provided) => (
                    <table
                      {...provided.droppableProps}
                      ref={provided.innerRef}
                      border={"2px"}
                    >
                      <thead>
                        <tr>
                          <th>Attribute ID</th>
                          <th>Attribute Name</th>
                          <th>Width(mm)</th>
                          <th>Sort</th>
                          <th>Delete</th>
                        </tr>
                      </thead>
                      <tbody>
                        {items.map((item, index) => (
                          <Draggable
                            key={item.AttributeID}
                            draggableId={String(item.AttributeID)}
                            index={index}
                            isDragDisabled={isEdit}
                          >
                            {(provided) => (
                              <tr
                                ref={provided.innerRef}
                                {...provided.draggableProps}
                                {...provided.dragHandleProps}
                              >
                                <td>
                                  {item.AttributeID}{" "}
                                  {item?.ColorCode && (
                                    <div
                                      className="attribute-id-bg"
                                      data-toggle="tooltip"
                                      data-placement="top"
                                      title="Catalog attribute"
                                      style={{
                                        backgroundColor: `${item?.ColorCode}`,
                                      }}
                                    ></div>
                                  )}
                                </td>
                                <td>{item.AttributeName}</td>
                                <td>
                                  {isEdit ? (
                                    <Input
                                      type="text"
                                      onChange={(e) => {
                                        handleChange(
                                          item.AttributeID,
                                          e.target.value
                                        );
                                      }}
                                      value={item.ColumnWidth || ""}
                                    />
                                  ) : (
                                    item.ColumnWidth
                                  )}
                                </td>
                                <td>{item.SortOrder}</td>
                                <td>
                                  <Button
                                    onClick={() => {
                                      handleDeleteAttributeModal();
                                      setSelectedAttrIdDelete(item.AttributeID);
                                      setSelectedAttrWidthDelete(
                                        item.ColumnWidth
                                      );
                                    }}
                                  >
                                    Delete
                                  </Button>
                                </td>
                              </tr>
                            )}
                          </Draggable>
                        ))}
                        {provided.placeholder}

                        {addNewAttributeItems.map((item, index) => (
                          <>
                            <tr key={item.attributeId}>
                              <td>{item.attributeId}</td>
                              <td>{item.attributeName}</td>
                              {isAddAttribute ? (
                                <td>
                                  <InputField
                                    type="text"
                                    // name="data"
                                    onChange={(e) => {
                                      handleChange(
                                        item.attributeId,
                                        e.target.value
                                      );
                                    }}
                                    value={item.width || ""}
                                  />
                                </td>
                              ) : (
                                <td>{item.width}</td>
                              )}
                              <td>{item.sort}</td>
                              <td>
                                <Button
                                  onClick={() => {
                                    handleDeleteAttributeModal();
                                    setTempDeleteID(index);
                                  }}
                                >
                                  Delete
                                </Button>
                              </td>
                            </tr>
                          </>
                        ))}
                        <tr>
                          <td></td>
                          <td></td>
                          <td>
                            <b>{widthTotal}</b>
                          </td>
                          <td></td>
                          <td></td>
                        </tr>
                      </tbody>
                    </table>
                  )}
                </Droppable>
              </DragDropContext>
            )}
          </div>

          <div className="col-lg-2 mt-5 pb-4">
            <SelectField
              isDisabled={!isEdit}
              type="select"
              name="attributeSchemaId"
              id="attributeSchemaId"
              options={missingAttribute}
              onChange={(e) => {
                setSelectedAddAttribute(e);
                appendNewAttribute(e);
              }}
              value={selectedAddAttribute}
            />
          </div>
        </>
      ) : (
        ""
      )}

      {deleteAttributeModal && (
        <DeleteModalWithoutHeader
          toggle={handleDeleteAttributeModal}
          deleteFunction={handleDeleteAttribute}
          isOpen={deleteAttributeModal}
        />
      )}
    </div>
  );
}

export default AttributeSchema;
