import InputField from "components/Common/InputField";
import Table from "components/Common/Table";
import { getLocalStorageItem } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useLocation } from "react-router-dom/cjs/react-router-dom.min";
import { Button } from "reactstrap";
import { fetchGetAllAttributeSchemaDetails } from "redux/actions/output/getAllAttributeSchemaDetails";

function AttributeSchemaList({ attributeSchemaId, attributeSchemaName }) {
  const dispatch = useDispatch();
  const [displayEmptyValue, setDisplayEmptyValue] = useState(false);
  const [isDisabled, setDisabled] = useState(false);
  const [attributeValue, setAttributeValue] = useState("");
  const [manageAttributeData, setManageAttributeList] = useState([]);

  // const ProductId = getLocalStorageItem("ProductId");
  const search = useLocation().search;
  const ProductId = new URLSearchParams(search).get("pid");

  const { isLoading = false, manageAttributeList = null } = useSelector(
    (state) => ({
      manageAttributeList:
        state.getAllAttributeSchemaDetails?.data?.data || null,
      isLoading: state.getAllAttributeSchemaDetails?.loading || null,
    })
  );

  useEffect(() => {
    handleFetchManageAttributeList(attributeSchemaId);
  }, [attributeSchemaId]);

  const handleFetchManageAttributeList = (attributeSchemaId) => {
    dispatch(fetchGetAllAttributeSchemaDetails(attributeSchemaId)).then(
      (data) => {
        let attrList = data?.data.filter(
          ({ AttributeName, value }) => AttributeName != null
        );
        setManageAttributeList(attrList);
      }
    );
  };

  const renderEditable = (value, id) => {
    return (
      <div className="table-edit-input">
        <div
          contentEditable
          suppressContentEditableWarning
          onBlur={(e) => getAttributeData(e.target.innerHTML, id)}
          dangerouslySetInnerHTML={{
            __html: value,
          }}
        />
      </div>
    );
  };

  const ReactTableColumns = [
    {
      minWidth: 300,
      Header: "Attribute ID",
      id: "AttributeID",
      accessor: "AttributeID",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Attribute Name",
      id: "AttributeName",
      accessor: "AttributeName",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Width(mm)",
      id: "width",
      accessor: (d) => {
        return isDisabled
          ? renderEditable(d?.ColumnWidth || "", d.AttributeID)
          : d?.ColumnWidth;
      },
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Sort",
      id: "Sort",
      accessor: (d) => {
        return isDisabled
          ? renderEditable(d?.SortOrder || "", d.AttributeID)
          : d?.SortOrder;
      },
      sortable: true,
    },
  ];
  const getAttributeData = (value, id) => {
    const updated = manageAttributeData.map((d) => ({
      ...d,
      Value: d.AttributeID === id ? value : d.Value,
    }));

    setManageAttributeList(updated);
  };

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return manageAttributeData?.filter(
        ({ attributeName, value }) =>
          attributeName.toString().toLowerCase().search(value) !== -1 ||
          value.toString().toLowerCase().search(value) !== -1
      );
    }
    return manageAttributeData.filter(
      ({ AttributeName, value }) => AttributeName != null
    );
  };

  const handleToggleChange = (item) => {
    setDisplayEmptyValue(item);

    const formData = {
      productID: ProductId,
      displayEmptyValues: item ? "1" : "0",
    };
    handleFetchManageAttributeList(formData);
  };

  const handleEdit = () => {
    setDisabled(true);
  };
  const saveAttribute = () => {
    var formData = new FormData();

    manageAttributeData.map((d, i) => {
      formData.append(`data[${i}][name]`, ProductId + "_" + d.AttributeID);
      formData.append(`data[${i}][value]`, d.Value);
    });

    formData.append("productID", ProductId);

    // dispatch(fetchUpdateEditProductData(formData)).then(() => {
    //   listAttributeList();
    // });
  };

  return (
    <div className="attribute-table-list">
      <div className="manage-attribute-tab">
        <div className="row">
          <div className="col-lg-8">
            <div className="manage-attribute-left">
              {/* <div className="d-flex align-center">
                <Label check>Display Empty Values </Label>{" "}
                <Switch
                  className="switch-btn"
                  uncheckedIcon={false}
                  name="displayValue"
                  checkedIcon={false}
                  width={44}
                  height={20}
                  onChange={(e) => handleToggleChange(e)}
                  checked={displayEmptyValue}
                />
              </div> */}
            </div>
          </div>
          <div className="col-lg-4">
            <div className="right-top-btn-section">
              <InputField
                type="text"
                name="editAttributeSchemaName"
                //  onChange={handleChange}
                value={attributeSchemaName || ""}
              />
              {isDisabled ? (
                <>
                  <Button onClick={() => saveAttribute()}>Save</Button>
                  <Button
                    onClick={() => setDisabled(false)}
                    className="cancel-btn-red"
                  >
                    Cancel
                  </Button>
                </>
              ) : (
                <Button onClick={handleEdit}>Edit</Button>
              )}
            </div>
          </div>
        </div>

        {/* <div className="right-top-btn-section">
          <InputField
            type="text"
            name="editAttributeSchemaName"
            //  onChange={handleChange}
            value={attributeSchemaName || ""}
          />
          {isDisabled ? (
            <>
              <Button onClick={() => saveAttribute()}>Save</Button>
              <Button
                onClick={() => setDisabled(false)}
                className="cancel-btn-red"
              >
                Cancel
              </Button>
            </>
          ) : (
            <Button onClick={handleEdit}>Edit</Button>
          )}
        </div> */}
      </div>

      <div className="tableorganisation manage-catalog-tbl-section bg-white">
        <Table
          columns={ReactTableColumns}
          Data={[...manageAttributeData]}
          isLoading={isLoading}
          getFilterData={getFilterData}
        />
      </div>

      {/* <div className="attribute-id-bg" data-toggle="tooltip" data-placement="top" title="Catalog attribute"></div> */}
    </div>
  );
}

export default AttributeSchemaList;
