import InputField from "components/Common/InputField";
import SelectField from "components/Common/SelectField";
import { Form, Formik } from "formik";
import { isValidArray } from "modules/utils";
import { attributeSchemaForm, displayFormErrors } from "modules/validations";
import React, { useEffect, useRef, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { toast } from "react-toastify";
import { Button, Label } from "reactstrap";
import { fetchAddLayout } from "redux/actions/output/addLayout";
import { fetchLayoutDetails } from "redux/actions/output/layoutDetail";
import { fetchLayoutList } from "redux/actions/output/layoutList";
import { Editor } from "@tinymce/tinymce-react";
import { fetchLayoutItems } from "redux/actions/output/updateLayoutItems";

function LayoutTemplates({ handleTabChange }) {
  const dispatch = useDispatch();

  const [layoutOption, setLayoutOption] = useState([]);
  const [selectedLayout, setSelectedLayout] = useState("");
  const [getLayoutDetails, setLayoutDetails] = useState([]);

  const { layoutList = null, layoutDetails = null } = useSelector((state) => ({
    layoutList: state.layoutList.data?.data,
    layoutDetails: state.layoutDetails.data?.data,
  }));

  useEffect(() => {
    setLayoutDetails(layoutDetails);
  }, [layoutDetails]);

  useEffect(() => {
    dispatch(fetchLayoutList()).then((data) => {
      const updated = data?.data.map((d, i) => {
        if (i === 0) {
          setSelectedLayout(String(d?.LayoutID));
        }
        return {
          label: d?.LayoutName,
          value: d?.LayoutID,
        };
      });
      setLayoutOption(updated);
    });
  }, []);

  const handleSubmit = (values) => {
    dispatch(fetchAddLayout(values)).then(() => {
      handleTabChange("createFile");
    });
  };

  const handleEdit = () => {
    if (selectedLayout) {
      dispatch(fetchLayoutDetails(selectedLayout));
    } else {
      toast.error("Please select layout!");
    }
  };
  const updateLayoutItems = (layoutItems) => {
    const formData = {
      LayoutId: layoutItems?.LayoutID,
      CatalogLevel: layoutItems?.CatalogLevel,
      OutputSchemaContent: layoutItems?.OutputSchemaContent,
    };
    dispatch(fetchLayoutItems(formData));
  };
  const editorRef = useRef(null);
  const log = (e, id) => {
    const updated = getLayoutDetails.map((d) => {
      if (d.CatalogLevel === id) {
        return {
          ...d,
          OutputSchemaContent: e,
        };
      }
      return d;
    });
    setLayoutDetails(updated);
  };

  const tbitems = [
    {
      "name" : 'CategoryName', 
      "buttonName" : 'Category Name', 
      "content": "[[CategoryName]]"
    },
    {
      "name" : 'ProductTable', 
      "buttonName" : 'Product Table', 
      "content": '<table style="border-collapse: collapse; width: 100%; border-color: #000000; border-style: solid;" border="1"><tbody><tr><th style="text-align: center; background: light-grey;" scope="col">[[header]]</th></tr><tr><td style="text-align: center;">[[value]]</td></tr></tbody></table>'
    }
  ];
    

  return (
    <div className="layout-template-section">
      <Formik
        initialValues={{
          LayoutName: "",
        }}
        validationSchema={attributeSchemaForm}
        onSubmit={handleSubmit}
        enableReinitialize
      >
        {({
          values,
          errors,
          touched,
          handleChange,
          handleBlur,
          handleSubmit,
          submitCount,
          setFieldValue,
        }) => {
          const showError = (key) =>
            displayFormErrors(key, errors, touched, submitCount);

          return (
            <Form>
              <div>
                <Label>Create New Layout </Label>
                <div className="row ">
                  <div className="col-lg-4">
                    <InputField
                      type="text"
                      name="LayoutName"
                      placeholder="Add Label"
                      onChange={handleChange}
                      value={values.LayoutName || ""}
                    />
                    {showError("LayoutName")}
                  </div>
                  <div className="col-lg-8">
                    <div className="model-bottom-btn-section">
                      <Button
                        color="primary save-btn confirm-y"
                        onClick={handleSubmit}
                      >
                        Create
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </Form>
          );
        }}
      </Formik>

      <div className="selectcalatlog-tab">
        <div className="tab-selectbox">
          <Label>Edit Existing Layout</Label>
          <div className="row bg-white pb-4">
            <div className="col-lg-4">
              <SelectField
                type="select"
                name="selectedLayout"
                id="selectedLayout"
                placeholder="Select Organization"
                options={isValidArray(layoutOption) && layoutOption}
                onChange={(e) => {
                  setSelectedLayout(e);
                }}
                value={selectedLayout}
                isFirstOption={true}
              />
            </div>
            <div className="col-lg-8">
              <div className="model-bottom-btn-section">
                <Button color="primary save-btn confirm-y" onClick={handleEdit}>
                  Edit
                </Button>
              </div>
            </div>
          </div>
        </div>
      </div>
      {isValidArray(getLayoutDetails) &&
        getLayoutDetails.map((d) => {
          return (
            <>
              <div className="layout-list-table" key={d?.CatalogLevel}>
                <div className="layout-table-section">
                  <div className="row mb-4">
                    <div className="col-lg-3">
                      <p>{d?.CategoryName}</p>
                    </div>
                    <div className="col-lg-9">
                      <Editor
                        onEditorChange={(e) => {
                          log(e, d?.CatalogLevel);
                        }}
                        onInit={(evt, editor) => (editorRef.current = editor)}
                        value={d?.OutputSchemaContent}
                        init={{
                          height: 500,
                          // menubar: false,
                          plugins: [
                            "advlist autolink lists link image charmap print preview anchor",
                            "searchreplace visualblocks code fullscreen",
                            "insertdatetime media table paste code help wordcount",
                          ],
                          toolbar:
                            "undo redo | formatselect | " +
                            "bold italic backcolor | alignleft aligncenter " +
                            "alignright alignjustify | bullist numlist outdent indent | " +
                            "removeformat | help",
                          content_style:
                            "body { font-family:Helvetica,Arial,sans-serif; font-size:14px }",
                          menubar: false,
                          toolbar1: "table | undo redo | styleselect | bold italic forecolor | alignleft aligncenter alignright alignjustify | outdent indent | code",
                          toolbar2: "CategoryName ProductTable",
                          setup: function(editor) {
                            tbitems.forEach(function(items) {
                              editor.ui.registry.addButton(items.name, {
                                  text: items.buttonName,
                                  onAction: function() {
                                      // Add you own code to execute something on click
                                      editor.focus();
                                      editor.selection.setContent(items.content);
                                  }
                              });
                            });
                          }
                        }}
                      />
                      <Button
                        color="primary save-btn confirm-y"
                        onClick={() => {
                          updateLayoutItems(d);
                        }}
                      >
                        Save
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </>
          );
        })}
      {/* <div className="layout-list-table">
        <div className="layout-table-section">
          <div className="row mb-4">
            <div className="col-lg-3">
              <p>Catagory 1</p>
            </div>
            <div className="col-lg-9">
              <Editor
              onInit={(evt, editor) => (editorRef.current = editor)}
              initialValue="<p>This is the initial content of the editor.</p>"
              init={{
                height: 500,
                // menubar: false,
                plugins: [
                  "advlist autolink lists link image charmap print preview anchor",
                  "searchreplace visualblocks code fullscreen",
                  "insertdatetime media table paste code help wordcount",
                ],
                toolbar:
                  "undo redo | formatselect | " +
                  "bold italic backcolor | alignleft aligncenter " +
                  "alignright alignjustify | bullist numlist outdent indent | " +
                  "removeformat | help",
                content_style:
                  "body { font-family:Helvetica,Arial,sans-serif; font-size:14px }",
                menubar: "file edit view insert format tools table",
              }}
              />
              <Button color="primary save-btn confirm-y" onClick={log}>
            Save
          </Button>
            </div>
          </div>
        </div>
      </div> */}
    </div>
  );
}

export default LayoutTemplates;
