import React, { useEffect, useState } from "react";
import logomain from "../../assets/images/logomain.png";
import { Input, Label } from "reactstrap";
import { Formik, Form } from "formik";
import {
  useLocation,
  useParams,
} from "react-router-dom/cjs/react-router-dom.min";
import { fetchGetPlanDetails } from "redux/actions/users/getPlanDetails";
import { useDispatch, useSelector } from "react-redux";
import { displayFormErrors, registerValidation } from "modules/validations";
import { fetchGetEmailVerificationToken } from "redux/actions/users/getEmailVerificationToken";
import { isValidArray, isValidObject } from "modules/utils";
import PlanDetails from "./PlanDetails";
import ReCAPTCHA from "react-google-recaptcha";
import PaymentModal from "./PaymentModal";
import { Elements } from "@stripe/react-stripe-js";
import { loadStripe } from "@stripe/stripe-js";
import { fetchRegister } from "redux/actions/users/register";
import { useHistory } from "react-router-dom";
const stripePromise = loadStripe("pk_test_hswnvd4cMV8BvJpo6rEIYMuJ");

const Register = () => {
  const { ID } = useParams();
  const dispatch = useDispatch();
  const [charge, setCharge] = useState(0);
  const [onBoardingCharge, setOnBoardingCharge] = useState(0);
  const [chargeSum, setChargeSum] = useState(0);
  const [captchaMessageShow, setCaptchaMessageShow] = useState(false);
  const [captchaVal, setCaptchaVal] = useState("");

  const [paymentModalOpen, setPaymentModalOpen] = useState(false);
  const [registerFormData, setRegisterFormData] = useState(false);
  const [verificationMessage, setVerificationMessage] = useState(true);
  const [verificationCode, setVerificationCode] = useState("");
  const [animationCls, setAnimationCls] = useState("");
  const [stripePlanID, setStripePlanID] = useState("");
  const history = useHistory();

  const { emailVerification = null, getPlanDetails = null } = useSelector(
    (state) => ({
      emailVerification: state.getEmailVerificationToken?.data?.data || null,
      isLoading: state.getEmailVerificationToken?.loading || null,
      getPlanDetails: state.getPlanDetails?.data?.data || null,
    })
  );

  useEffect(() => {
    dispatch(fetchGetPlanDetails(ID)).then((data) => {
      setOnBoardingCharge(data?.data?.data?.plan?.OnboardingCharge);
      setCharge(data?.data?.data?.plan?.MonthlyCost);
      setStripePlanID(data?.data?.data?.plan?.MonthlyStripePlanID);
    });
  }, []);
  useEffect(() => {
    const chargeSum = Number(onBoardingCharge) + Number(charge);
    setChargeSum(chargeSum);
  }, [charge, onBoardingCharge]);

  const handleSubmit = (values) => {
    if (captchaVal && verificationCode) {
      const formData = {
        firstName: values.firstName,
        lastName: values.lastName,
        planId: ID,
        // phone: values.phone,
        email: values.email,
        emailVerificationCode: verificationCode,
        OrganisationName: values.organisationName,
        // OrganisationType: values.organisationType,
        password: values.password,
        confirmPassword: values.confirmPassword,
        payment_method: "",
        OnboardingCharge: "",
        stripePlanId: "",
      };
      if (ID == 1) {
        registerApi(formData);
        return;
      }
      setRegisterFormData(formData);
      toggle();
    }
    //
  };
  const submitForm = (payLoadDetails) => {
    const formData = {
      ...registerFormData,
      payment_method: payLoadDetails?.paymentMethod?.id,
      OnboardingCharge: onBoardingCharge,
      stripePlanId: stripePlanID,
    };
    registerApi(formData);
  };
  const registerApi = (formData) => {
    dispatch(fetchRegister(formData)).then((data) => {
      if (data?.data?.flag) {
        toggle();
        history.push("/thankyou");
      }
    });
  };
  const verifyEmail = (email) => {
    const formData = {
      email: email,
    };
    dispatch(fetchGetEmailVerificationToken(formData)).then((data) => {
      setVerificationMessage(data?.data?.CodeSent ? true : false);
      if (data?.data?.CodeSent) {
        setAnimationCls("animation-input-field");
      }
    });
  };
  const handlePlanCharge = (e, planeId) => {
    setCharge(e.target.value);
  };
  const captchaSet = (value) => {
    setCaptchaVal(value);
    setCaptchaMessageShow(false);
  };
  const toggle = () => {
    setPaymentModalOpen(!paymentModalOpen);
  };

  const search = useLocation().search;
  const option = new URLSearchParams(search).get("opt");
  return (
    <div className="register-page singup-page">
      <div className={option ? "hide-product-text" : "product-text "}>
        <img src={logomain} width="200" height="auto" alt="Producty" />
      </div>

      <div className={option ? "hide-product-text" : "product-login"}>
        New User Signup
      </div>
      <div className={option ? "option-simple-text" : "product-text"}>
        This form is for new organizations only. If your organization has an
        existing Producty® subscription, please ask your account manager for an
        invitation.
      </div>
      <Formik
        initialValues={{
          firstName: "",
          lastName: "",
          phone: "",
          email: "",
          organisationName: "",
          // organisationType: "",
          password: "",
          confirmPassword: "",
        }}
        validationSchema={registerValidation()}
        onSubmit={handleSubmit}
      >
        {({
          values,
          errors,
          touched,
          handleChange,
          handleSubmit,
          submitCount,
          isValid,
          dirty,
        }) => {
          const showError = (key) =>
            displayFormErrors(key, errors, touched, submitCount);

          return (
            <Form>
              <div className="signupmodal-section">
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">First Name*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="firstName"
                      className="form-control col-sm-8"
                      placeholder="First Name*"
                      onChange={handleChange}
                      value={values.firstName}
                    />
                    {showError("firstName")}
                  </div>
                </div>
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Last Name*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="lastName"
                      className="form-control col-sm-8"
                      placeholder="Last Name*"
                      onChange={handleChange}
                      value={values.lastName || ""}
                    />
                    {showError("lastName")}
                  </div>
                </div>
                <div className="input-field d-flex align-items-baseline ">
                  <Label className="col-sm-4">Email*</Label>
                  <div className="w-100 error-msg-email">
                    <Input
                      type="email"
                      name="email"
                      className="form-control col-sm-8"
                      placeholder="Email*"
                      onChange={handleChange}
                      value={values.email || ""}
                    />
                    <div className="">
                      {showError("email")}
                      {verificationMessage &&
                        (errors.length > 0 || submitCount > 0) &&
                        isValid && (
                          <div className="text-danger input-feedback font12">
                            Please verify email address.
                          </div>
                        )}
                      {isValidArray(emailVerification?.email) && (
                        <div className="text-danger input-feedback font12">
                          {emailVerification?.email?.[0]}
                        </div>
                      )}
                      {emailVerification?.CodeSent && (
                        <div className="text-danger input-feedback font12">
                          <p style={{ color: emailVerification?.textColor }}>
                            {emailVerification?.text}
                          </p>
                        </div>
                      )}
                      <a
                        className="verfiyemail-pass"
                        href="#"
                        onClick={() => verifyEmail(values.email)}
                      >
                        Verify email
                      </a>
                    </div>
                  </div>
                </div>
                {isValidObject(emailVerification) &&
                  !emailVerification?.CodeSent &&
                  emailVerification?.title &&
                  emailVerification?.text && (
                    <div className="login-error col-sm-8">
                      <h4 style={{ color: emailVerification?.textColor }}>
                        {emailVerification?.title}
                      </h4>
                      <h5 style={{ color: emailVerification?.textColor }}>
                        {emailVerification?.text}
                      </h5>
                    </div>
                  )}
                <div
                  className={`input-field d-flex align-items-center verificationCode-email ${emailVerification?.CodeSent
                    ? "animation-email"
                    : "hide-field"
                    }`}
                >
                  <Label className="col-sm-4">Email Verification Code*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="verificationCode"
                      className="form-control col-sm-8"
                      placeholder="Enter emailed verification code*"
                      onChange={(e) => setVerificationCode(e.target.value)}
                      value={verificationCode || ""}
                    />
                    {showError("verificationCode")}
                  </div>
                </div>
                {/* <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Contact number*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="phone"
                      className="form-control col-sm-8"
                      placeholder="Contact number*"
                      onChange={handleChange}
                      value={values.phone || ""}
                    />
                    {showError("phone")}
                  </div>
                </div> */}

                <div className="input-field d-flex align-items-center mt-3">
                  <Label className="col-sm-4">Organisation name*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="organisationName"
                      className="form-control col-sm-8"
                      placeholder="Organisation name*"
                      onChange={handleChange}
                      value={values.organisationName || ""}
                    />
                    {showError("organisationName")}
                  </div>
                </div>

                {/*
                <div className="input-field d-flex align-items-center mt-3">
                  <Label className="col-sm-4">Organisation Type*</Label>
                  <div className="w-100">
                    <Input
                      type="select"
                      name="organisationType"
                      className="form-select col-sm-8"
                      placeholder="Organisation Type*"
                      onChange={handleChange}
                      value={values.organisationType || ""}
                    >
                      <option value="">Select Closest Organisation Type</option>
                      <option value="1">Camping & Outdoor</option>
                      <option value="2">Early Learning</option>
                      <option value="3">Furniture</option>
                      <option value="4">Office Products</option>
                      <option value="5">Supermarket</option>
                    </Input>
                    {showError("organisationType")}
                  </div>
                </div> */}
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Password*</Label>
                  <div className="w-100">
                    <Input
                      type="password"
                      name="password"
                      className="form-control col-sm-8"
                      placeholder="Password"
                      onChange={handleChange}
                      value={values.password || ""}
                    />
                    {showError("password")}
                  </div>
                </div>
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Confirm password*</Label>
                  <div className="w-100">
                    <Input
                      type="password"
                      name="confirmPassword"
                      className="form-control col-sm-8"
                      placeholder="Confirm password*"
                      onChange={handleChange}
                      value={values.confirmPassword || ""}
                    />
                    {showError("confirmPassword")}
                  </div>
                </div>
              </div>
              {!option ? (
                <PlanDetails
                  planDetails={getPlanDetails?.plan}
                  handlePlanCharge={handlePlanCharge}
                  setOnBoardingCharge={setOnBoardingCharge}
                  onBoardingCharge={onBoardingCharge}
                  chargeSum={chargeSum}
                  charge={charge}
                  setCharge={setCharge}
                  setStripePlanID={setStripePlanID}
                  stripePlanID={stripePlanID}
                />
              ) : (
                <></>
              )}

              <div className="rc-anchor rc-anchor-normal rc-anchor-light">
                <ReCAPTCHA
                  sitekey={process.env.REACT_APP_CAPTCHA_SITEKEY}
                  onChange={captchaSet}
                />
                {!captchaVal && submitCount ? (
                  <div className="text-danger input-feedback font12 recapta-error text-center">
                    Please prove that you are human!
                  </div>
                ) : null}
              </div>

              <div className="signup-btn w-100">
                <button
                  className="loginmodal-submit btn"
                  type="submit"
                // type="button"
                // onClick={() => {
                //   if (!captchaVal) {
                //     setCaptchaMessageShow(true);
                //     if (isValid) return;
                //   }
                //   handleSubmit();
                // }}
                // disabled={!(isValid && dirty && captchaVal)}
                >
                  Sign up
                </button>
              </div>
              <div className={option ? "hide-product-text" : "login-help mt-4"}>
                <h5>Already have an account?</h5>
                <a href="/login">Sign In</a>
              </div>
            </Form>
          );
        }}
      </Formik>
      {paymentModalOpen && (
        <Elements stripe={stripePromise}>
          <PaymentModal
            isOpen={paymentModalOpen}
            toggle={toggle}
            submitForm={submitForm}
          />
        </Elements>
      )}
    </div>
  );
};

export default Register;
