import { isValidArray } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Link } from "react-router-dom";
import { fetchReportList } from "redux/actions/reports/reportList";
import { Steps } from "intro.js-react";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import "intro.js/introjs.css";

const Reports = () => {
  const dispatch = useDispatch();

  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);
  const { reportList = null } = useSelector((state) => ({
    reportList: state.reportList.data?.data,
  }));

  const onExit = () => {
    setStepsEnabled(false);
  };

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = d.elementIDName;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  useEffect(() => {
    document.title = "Reports | Producty®";
    dispatch(fetchReportList());
    dispatch(getIntroJs("reports")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  const getInsideList = (id) => {
    const result =
      isValidArray(reportList?.reportsList) &&
      reportList?.reportsList.filter((data) => {
        if (data?.ReportCategoryID === id) {
          return data;
        }
      });
    return isValidArray(result) ? result : [];
  };

  return (
    <div>
      <div className="report-pb">
        <div className="report-section">
          <div className="row justify-content-center">
            {isValidArray(reportList?.categories) &&
              reportList?.categories.map((d) => {
                return (
                  <div className="col-lg-3" key={d?.ReportCategoryID}>
                    <div className="card report-box">
                      <div className="card-header">
                        <div className="card-icon icon-warning-header">
                          <i className={d?.ReportCategoryIcon}></i>
                        </div>
                        <h2>{d?.ReportCategoryName}</h2>
                        {isValidArray(getInsideList(d?.ReportCategoryID)) &&
                          getInsideList(d?.ReportCategoryID).map((j) => (
                            <>
                              <Steps
                                enabled={stepsEnabled}
                                steps={steps}
                                initialStep={initialStep}
                                onExit={onExit}
                                onComplete={() => setStepsEnabled(false)}
                                options={{ doneLabel: "Done" }}
                              />
                              <div key={j?.ReportCategoryID}>
                                <Link to={`/showReport/${j?.ReportID}`}>
                                  {j?.ReportName}
                                </Link>
                                <p>{j?.ReportDescription}</p>
                              </div>
                            </>
                          ))}
                      </div>
                    </div>
                  </div>
                );
              })}
          </div>
        </div>
      </div>
    </div>
  );
};

export default Reports;
