import Table from "components/Common/Table";
import { filterFieldData, isValidArray, removeAuthToken } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useHistory } from "react-router";
import { useParams } from "react-router-dom/cjs/react-router-dom.min";
import { fetchGetReportData } from "redux/actions/reports/getReportData";

const ShowReport = () => {
  const dispatch = useDispatch();
  const id = useParams();

  const [data, setData] = useState([]);

  const { getReportData = null, isLoading = false } = useSelector((state) => ({
    getReportData: state.getReportData?.data?.data,
    isLoading: state.getReportData?.loading,
  }));

  const getColumns = () => {
    if (getReportData?.reportColumnDefinition !== undefined) {
      const column = JSON.parse(
        getReportData?.reportColumnDefinition.replace("/r/n", "")
      );

      return Object.keys(column).map((key, index) => {
        return {
          Header: column[key].label,
          id: key,
          accessor: key,
          headerStyle: { textAlign: "left" },
        };
      });
    }
  };

  useEffect(() => {
    if (id?.id) {
      dispatch(fetchGetReportData(id?.id)).then((data) => {
        setData(data?.data?.reportData);
        if (data?.flag) {
          document.title = `${data?.data?.reportName} | Producty®`;
        } else {
          document.title = `Producty | Producty®`;
        }
      });
    }
  }, []);

  const getColumnArray = () => {
    const columns = getColumns();
    const single = columns?.map((item) => {
      return item?.accessor;
    });
    return single;
  };

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, data, getColumnArray());
    }
    return data;
  };

  return (
    <div className="report-list-component">
      <div>
        <h4>{getReportData?.reportName}</h4>
      </div>
      <div className="product-report-section productTable-report">
        <p>
          {getReportData?.reportCategory} &gt; {getReportData?.reportName}
        </p>
        <div className="product-table-body tableorganisation product-tableBorder ">
          <Table
            columns={isValidArray(getColumns()) && getColumns()}
            Data={isValidArray(data) && data}
            isLoading={isLoading}
            getFilterData={getFilterData}
            sortColumn={{
              id: isValidArray(getColumns()) && getColumns()[0]?.id,
              desc: false,
            }}
            downloadName={`${getReportData?.reportName} Producty`}
            isDownloadExcel={isValidArray(data)}
          />
        </div>
      </div>
    </div>
  );
};

export default ShowReport;
