import InputField from "components/Common/InputField";
import Loader from "components/Common/Loader";
import { Form, Formik } from "formik";
import { displayFormErrors, registerValidation } from "modules/validations";
import React, { useEffect, useState } from "react";
import ReCAPTCHA from "react-google-recaptcha";
import { useDispatch, useSelector } from "react-redux";
import { Link, useHistory, useLocation, useParams } from "react-router-dom";
import { Input, Label } from "reactstrap";
import { fetchGetSignupTokenDetails } from "redux/actions/users/getSignupTokenDetails";
import { fetchResellerSignupProcess } from "redux/actions/users/resellerSignupProcess";
import { fetchUserSignupProcess } from "redux/actions/users/userSignupProcess";
import logomain from "../../assets/images/logomain.png";

// const staticTokenTemp =
//   "SiQigi64hbYbuyBGTZIHFzcRCvN5H69Hb1XjJ2lMF5rnV1NhJzP3BNxaoQFfMW20jZ3ylzisF0XmziUC";
export default function UserSignup() {
  const { token } = useParams();
  const location = useLocation();
  const isUserSignUp = location.pathname.includes("/userSignup");

  const history = useHistory();

  const dispatch = useDispatch();
  const [captchaMessageShow, setCaptchaMessageShow] = useState(false);
  const [captchaVal, setCaptchaVal] = useState("");

  const {
    signUpTokenLoading = false,
    signUpTokenData = null,
    signUploading = false,
    signUpData = null,
  } = useSelector((state) => ({
    signUpTokenLoading: state?.getSignupTokenDetails?.loading,
    signUpTokenData: state?.getSignupTokenDetails?.data?.data,
    signUploading: state?.userSignupProcess?.loading,
    signUpData: state?.userSignupProcess?.data?.data,
  }));

  useEffect(() => {
    dispatch(fetchGetSignupTokenDetails(token));
  }, []);

  const captchaSet = (value) => {
    setCaptchaVal(value);
    setCaptchaMessageShow(false);
  };

  const signUpUser = (values) => {
    const formData = {
      ...values,
      organisationID: signUpTokenData?.organisationID,
    };
    if (isUserSignUp) {
      dispatch(fetchUserSignupProcess(formData)).then((data) => {
        if (data) {
          history.push("/login");
        }
      });
    } else {
      dispatch(fetchResellerSignupProcess(formData)).then((data) => {
        if (data) {
          history.push("/login");
        }
      });
    }
  };

  const getInitialValues = () => {
    return {
      firstName: "",
      lastName: "",
      organisationName: signUpTokenData?.organisationName || "",
      email: signUpTokenData?.email || "",
      phone: "",
      password: "",
      confirmPassword: "",
    };
  };

  if (signUpTokenLoading) {
    return (
      <div className="register-page singup-page product-text justify-content-center">
        <Loader />
      </div>
    );
  }

  return (
    <div className="register-page singup-page">
      <div className="product-text">
        <img src={logomain} width="200" height="auto" alt="Producty" />
      </div>

      <div className={"product-login"}>New User Signup</div>
      <div className="product-text-signup">
        This form is for new organizations only. If your organization has an
        existing Producty® subscription, please ask your account manager for an
        invitation.
      </div>
      <Formik
        initialValues={getInitialValues()}
        validationSchema={registerValidation()}
        onSubmit={signUpUser}
      >
        {({
          values,
          errors,
          touched,
          handleChange,
          handleSubmit,
          submitCount,
          isValid,
          dirty,
        }) => {
          const showError = (key) =>
            displayFormErrors(key, errors, touched, submitCount);

          return (
            <Form>
              <div className="signupmodal-section">
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">First Name*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="firstName"
                      className="form-control col-sm-8"
                      placeholder="First Name*"
                      onChange={handleChange}
                      value={values.firstName}
                    />
                    {showError("firstName")}
                  </div>
                </div>
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Last Name*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="lastName"
                      className="form-control col-sm-8"
                      placeholder="Last Name*"
                      onChange={handleChange}
                      value={values.lastName || ""}
                    />
                    {showError("lastName")}
                  </div>
                </div>
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Email*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="email"
                      className="form-control col-sm-8"
                      placeholder="email*"
                      value={values.email || ""}
                      readOnly
                    />
                    {showError("organisationName")}
                  </div>
                </div>

                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Contact number*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="phone"
                      className="form-control col-sm-8"
                      placeholder="Contact number*"
                      onChange={handleChange}
                      value={values.phone || ""}
                    />
                    {showError("phone")}
                  </div>
                </div>
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Organisation name*</Label>
                  <div className="w-100">
                    <Input
                      type="text"
                      name="organisationName"
                      className="form-control col-sm-8"
                      placeholder="Organisation name*"
                      value={values.organisationName || ""}
                      onChange={handleChange}
                      disabled={isUserSignUp ? true : false}
                    />
                    {showError("organisationName")}
                  </div>
                </div>
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Password*</Label>
                  <div className="w-100">
                    <Input
                      type="password"
                      name="password"
                      className="form-control col-sm-8"
                      placeholder="Password"
                      onChange={handleChange}
                      value={values.password || ""}
                    />
                    {showError("password")}
                  </div>
                </div>
                <div className="input-field d-flex align-items-center ">
                  <Label className="col-sm-4">Confirm password*</Label>
                  <div className="w-100">
                    <Input
                      type="password"
                      name="confirmPassword"
                      className="form-control col-sm-8"
                      placeholder="Confirm password*"
                      onChange={handleChange}
                      value={values.confirmPassword || ""}
                    />
                    {showError("confirmPassword")}
                  </div>
                </div>
              </div>

              <div className="rc-anchor rc-anchor-normal rc-anchor-light">
                <ReCAPTCHA
                  sitekey={process.env.REACT_APP_CAPTCHA_SITEKEY}
                  onChange={captchaSet}
                />
                {!captchaVal && submitCount ? (
                  <div className="text-danger input-feedback font12 recapta-error text-center">
                    Please prove that you are human!
                  </div>
                ) : null}
              </div>
              {}
              <div className="signup-btn w-100">
                <button
                  className="loginmodal-submit btn"
                  type="submit"
                  // type="button"
                  // onClick={() => {
                  //   if (!captchaVal) {
                  //     setCaptchaMessageShow(true);
                  //     if (isValid) return;
                  //   }
                  //   handleSubmit();
                  // }}
                >
                  Sign up
                </button>
              </div>
              <div className={"login-help mt-4"}>
                <h5>Already have an account?</h5>
                <a href="/login">Sign In</a>
              </div>
            </Form>
          );
        }}
      </Formik>
    </div>
  );
}
