import React, { useEffect, useState } from "react";
import { Formik, Field, Form, ErrorMessage } from "formik";
import {
  displayFormErrors,
  loginValidation,
  wpIntegrationForm,
} from "modules/validations";
import { useDispatch, useSelector } from "react-redux";
import { fetchLogin } from "redux/actions/auth/login";
import logomain from "../../assets/images/logomain.png";
import { valuesIn } from "lodash";
import { Input, Label } from "reactstrap";
import { Redirect, useHistory } from "react-router";
import { getAuthToken } from "modules/utils";
import { fetchAddWordpressIntegration } from "redux/actions/masterAdmin/addWordpressIntegration";
import { fetchGetWordpressIntegration } from "redux/actions/masterAdmin/getWordpressIntegration";

const WpIntegration = () => {
  const dispatch = useDispatch();
  const history = useHistory();

  const [wpIntegrationFormValues, setWpIntegrationFormValues] = useState();

  const { isLoginLoading = false } = useSelector((state) => ({
    loginData: state.login?.data ?? null,
    isLoginLoading: state.login?.loading ?? false,
  }));

  useEffect(() => {
    dispatch(fetchGetWordpressIntegration()).then((data) => {
      setWpIntegrationFormValues(data.data);
    });
  }, []);

  const handleSubmit = (values, { resetForm }) => {
    const formData = {
      integrationCheckbox: values.integrateWp ? "1" : "0",
      storeUrl: values.storeUrl,
      wc_consumerKey: values.consumerKey,
      wc_secretKey: values.secretKey,
    };
    dispatch(fetchAddWordpressIntegration(formData)).then((data) => {
      resetForm();
    });
  };

  return (
    <Formik
      initialValues={{
        storeUrl: wpIntegrationFormValues?.StoreUrl,
        consumerKey: wpIntegrationFormValues?.WC_Consumer_Key,
        secretKey: wpIntegrationFormValues?.WC_Consumer_Secret,
        integrateWp: wpIntegrationFormValues?.WP_IntegrationID ? true : false,
      }}
      validationSchema={wpIntegrationForm()}
      onSubmit={handleSubmit}
      enableReinitialize
    >
      {({
        values,
        errors,
        touched,
        handleChange,
        handleBlur,
        handleSubmit,
        submitCount,
        setFieldValue,
      }) => {
        const showError = (key) =>
          displayFormErrors(key, errors, touched, submitCount);
        return (
          <div className="login-page integration-page">
            <div className="login-page-logo">
              <div className="col-sm-4"></div>
              <div className="product-login col-sm-8">                
                <Input
                  checked={values?.integrateWp}
                  type="checkbox"
                  name="integrateWp"
                  value={values?.integrateWp}
                  onChange={handleChange}
                />
                <span></span>
                 Integrate WooCommerce store            
              </div>
            </div>
            <Form>
              <div className="input-field">
                <Label className="col-sm-4">Store Url*</Label>
                <div className="w-100">
                  <Input
                    type="text"
                    name="storeUrl"
                    className="form-control col-sm-8"
                    placeholder="Store URL*"
                    onChange={handleChange}
                    value={values.storeUrl || ""}
                  />
                  {showError("storeUrl")}
                </div>
              </div>
              <div className="input-field">
                <Label className="col-sm-4">Consumer Key*</Label>
                <div className="w-100">
                  <Input
                    type="text"
                    name="consumerKey"
                    className="form-control col-sm-8"
                    placeholder="Consumer Key*"
                    onChange={handleChange}
                    value={values.consumerKey || ""}
                  />
                  {showError("consumerKey")}
                </div>
              </div>
              <div className="input-field">
                <Label className="col-sm-4">Secret Key*</Label>
                <div className="w-100">
                  <Input
                    type="text"
                    name="secretKey"
                    className="form-control col-sm-8"
                    placeholder="Secret Key*"
                    onChange={handleChange}
                    value={values.secretKey || ""}
                  />
                  {showError("secretKey")}
                </div>
              </div>
              <div className="login-page-btn col-sm-8">
                <button className="loginmodal-submit btn" type="submit">
                  Save
                </button>
              </div>
            </Form>
          </div>
        );
      }}
    </Formik>
  );
};

export default WpIntegration;
