import React, { useEffect, useState } from "react";
import { useDispatch } from "react-redux";
import { useHistory, useParams } from "react-router-dom";
import { Nav, NavItem, NavLink, TabContent, TabPane } from "reactstrap";
import ManageCatalogs from "./manageCatalog/ManageCatalogs";
import ManageJobs from "./manageJob/ManageJobs";
import ManageOrganizations from "./manageOrganization/ManageOrganizations";
import ManageUsers from "./manageUser/ManageUsers";
import { Steps } from "intro.js-react";
import { getIntroJs } from "redux/actions/introJS/fetchGetIntroJS";
import "intro.js/introjs.css";
import { isValidArray } from "modules/utils";
import { fetchGetUserCatalogDetail } from "redux/actions/output/getUserCatalogDetail";

function MasterAdmin(props) {
  const tabName = props?.match?.params?.type;
  const { type } = useParams();
  const history = useHistory();
  const dispatch = useDispatch();

  const initialActiveTab = {
    organization: tabName == "Organisations" ? "active" : "",
    catalog: tabName == "Catalogs" ? "active" : "",
    users: tabName == "Users" ? "active" : "",
    jobs: tabName == "ScheduledJobs" ? "active" : "",
    activeTab: tabName,
  };
  const [activeTab, setActivetab] = useState(initialActiveTab);
  const [stepsEnabled, setStepsEnabled] = useState(false);
  const [initialStep, setInitialStep] = useState(0);
  const [steps, setSteps] = useState([]);

  const onExit = () => {
    setStepsEnabled(false);
  };

  const createStepData = (data) => {
    let steps;
    steps = data?.map((d) => {
      const element = d.elementIDName;
      const intro = d.content;
      return { element, intro };
    });
    return steps;
  };

  useEffect(() => {
    document.title = "Master Admin | Producty®";

    dispatch(getIntroJs("admin")).then((data) => {
      if (isValidArray(data?.data)) {
        const newData = data.data;
        const newSteps = isValidArray(newData) && createStepData(newData);
        setSteps(newSteps);
        setStepsEnabled(true);
      } else {
        setStepsEnabled(false);
      }
    });
  }, []);

  useEffect(() => {
    const masterAdminArr = [
      "Organisations",
      "Catalogs",
      "Users",
      "ScheduledJobs",
    ];

    if (!masterAdminArr.includes(type)) {
      history.push(`/home`);
    }
    setActivetab({
      organization: tabName == "Organisations" ? "active" : "",
      catalog: tabName == "Catalogs" ? "active" : "",
      users: tabName == "Users" ? "active" : "",
      jobs: tabName == "ScheduledJobs" ? "active" : "",
      activeTab: type,
    });
  }, [type]);

  const handleTab = (tabName) => {
    history.push(`/Admin/${tabName}`);
  };

  // const handleTab = (tabName) => {
  //   if (tabName == "organization") {
  //     setActivetab({
  //       organization: "active",
  //       catalog: "",
  //       users: "",
  //       jobs: "",
  //       activeTab: "organization",
  //     });
  //   } else if (tabName == "catalog") {
  //     setActivetab({
  //       organization: "",
  //       catalog: "active",
  //       users: "",
  //       jobs: "",
  //       activeTab: "catalog",
  //     });
  //   } else if (tabName == "users") {
  //     setActivetab({
  //       organization: "",
  //       catalog: "",
  //       users: "active",
  //       jobs: "",
  //       activeTab: "users",
  //     });
  //   } else if (tabName == "jobs") {
  //     setActivetab({
  //       organization: "",
  //       catalog: "",
  //       users: "",
  //       jobs: "active",
  //       activeTab: "jobs",
  //     });
  //   }
  // };

  return (
    <>
      <Steps
        enabled={stepsEnabled}
        steps={steps}
        initialStep={initialStep}
        onExit={onExit}
        onComplete={() => setStepsEnabled(false)}
        options={{ doneLabel: "Done" }}
      />
      <div>
        <Nav tabs>
          <NavItem>
            <NavLink
              className={activeTab.organization}
              onClick={() => handleTab("Organisations")}
            >
              Organisations
            </NavLink>
          </NavItem>
          <NavItem>
            <NavLink
              className={activeTab.catalog}
              onClick={() => handleTab("Catalogs")}
            >
              Catalogs
            </NavLink>
          </NavItem>
          <NavItem>
            <NavLink
              className={activeTab.users}
              onClick={() => handleTab("Users")}
            >
              Users
            </NavLink>
          </NavItem>
          <NavItem>
            <NavLink
              className={activeTab.jobs}
              onClick={() => handleTab("ScheduledJobs")}
            >
              Scheduled Jobs
            </NavLink>
          </NavItem>
        </Nav>
        <TabContent activeTab={activeTab.activeTab}>
          <TabPane tabId="Organisations">
            {activeTab.activeTab === "Organisations" && <ManageOrganizations />}
          </TabPane>
          <TabPane tabId="Catalogs">
            {activeTab.activeTab === "Catalogs" && <ManageCatalogs />}
          </TabPane>
          <TabPane tabId="Users">
            {activeTab.activeTab === "Users" && <ManageUsers />}
          </TabPane>
          <TabPane tabId="ScheduledJobs">
            {activeTab.activeTab === "ScheduledJobs" && <ManageJobs />}
          </TabPane>
        </TabContent>
      </div>
    </>
  );
}

export default MasterAdmin;
