import InputField from "components/Common/InputField";
import InputNormal from "components/Common/InputNormal";
import SelectField from "components/Common/SelectField";
import Table from "components/Common/Table";
import { Form, Formik } from "formik";
import {
  isValidArray,
  getRowPerPageArray,
  filterFieldData,
} from "modules/utils";
import { displayFormErrors, addCatalogForm } from "modules/validations";
import React, { useEffect, useMemo, useState } from "react";
import Pagination from "react-js-pagination";
import { useDispatch, useSelector } from "react-redux";
import ReactTable from "react-table-6";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import DatePicker from "react-datepicker";
import SelectFieldFormik from "components/Common/SelectFieldFormik";
import "react-datepicker/dist/react-datepicker.css";
import { fetchActiveCatalogList } from "redux/actions/masterAdmin/activeCatalogList";
import { fetchAddCatalog } from "redux/actions/masterAdmin/addCatalog";
import { fetchCatalogList } from "redux/actions/masterAdmin/catalogList";
import {
  fetchCatalogDetails,
  fetchResetCatalogDetails,
} from "redux/actions/masterAdmin/getCatalogDetails";
import { fetchUpdateCatalog } from "redux/actions/masterAdmin/updateCatalog";
import moment from "moment";
import { fetchOrganizationList } from "redux/actions/masterAdmin/organizationList";
import Loader from "components/Common/Loader";

function ManageCatalogs() {
  const dispatch = useDispatch();
  const [selectOrganization, setSelectOrganization] = useState("");
  const [catalog, setCatalog] = useState("");
  const [catalogName, setCatalogName] = useState("");
  const [addCatalogModal, setAddCatalogModal] = useState(false);
  const [defaultCatalog, setDefaultCatalog] = useState(0);
  const [visualDesigner, setVisualDesigner] = useState(0);
  const [catalogDataList, setCatalogDataList] = useState([]);
  const [selectedCatalogId, setSelectedCatalogId] = useState(0);
  const [changeDate, setChangeDate] = useState(false);

  const {
    isLoading = false,
    catalogList = null,
    organizationListLoading = false,
    organizationList = null,
    activeCatalogList = null,
    activeIsLoading = false,
    catalogDetailLoading = false,
    catalogDetails = null,
    getUserDetail = null,
    getUserDetailLoading = false,
    organizationLoading = false,
  } = useSelector((state) => ({
    catalogList: state.catalogList?.data?.data || null,
    isLoading: state.catalogList?.loading || null,
    activeCatalogList: state.activeCatalogList?.data?.data || null,
    activeIsLoading: state.activeCatalogList?.loading || null,
    organizationListLoading: state.organizationList?.loading || null,
    organizationList: state.organizationList?.data?.data || null,
    organizationLoading: state.organizationList?.loading || null,
    catalogDetailLoading: state.getCatalogDetails?.loading || null,
    catalogDetails: state.getCatalogDetails?.data?.data || null,
    getUserDetail: state.getUserDetail?.data?.data || null,
    getUserDetailLoading: state.getUserDetail?.loading || null,
  }));

  useEffect(() => {
    if (getUserDetail) {
      dispatch(fetchActiveCatalogList()).then((data) => {
        setCatalogDataList(data?.data);
        dispatch(fetchOrganizationList()).then((res) => {
          console.log("🚀 ~ dispatch ~ res:", res?.data);
          if (getUserDetail && isValidArray(res?.data))
            organizationOptions(res?.data);
          console.log(
            "🚀 ~ dispatch ~ getUserDetail?.organization?.OrganisationID:",
            getUserDetail?.organization?.OrganisationID
          );
          setSelectOrganization(getUserDetail?.organisation?.OrganisationID);
        });
      });
    }
  }, [getUserDetail]);

  console.log("🚀 ~ dispatch ~ getUserDetail:", getUserDetail);
  const handleOnChangeOrg = (itemId) => {
    console.log("🚀 ~ handleOnChangeOrg ~ itemId:", itemId);
    setSelectOrganization(itemId);
    dispatch(fetchCatalogList(Number(itemId))).then((data) => {
      setCatalogDataList(data?.data);
    });
  };

  const handleAddCatalogModal = () => {
    setSelectedCatalogId(0);
    setCatalogName(catalog);
    dispatch(fetchResetCatalogDetails());
    setAddCatalogModal(!addCatalogModal);
  };

  const handleUpdateCatalogModal = (catId = 0, orgId = selectOrganization) => {
    if (!addCatalogModal) {
      const formData = {
        organisationId: orgId,
        catalogId: catId,
      };
      dispatch(fetchCatalogDetails(formData));
    }
    setAddCatalogModal(!addCatalogModal);
  };

  const organizationOptions = (list) => {
    const data = list || organizationList;
    if (isValidArray(data)) {
      let updated = data?.map((item) => {
        return {
          label: item.OrganisationName,
          value: item.OrganisationID,
        };
      });

      updated.sort((a, b) => {
        if (a.label < b.label) {
          return -1;
        }
        if (a.label > b.label) {
          return 1;
        }
        return 0;
      });
      updated = isValidArray(updated)
        ? [{ label: "Select Organization", value: "" }, ...updated]
        : [{ label: "Select Organization", value: "" }];
      return updated;
    }
  };

  const ReactTableColumns = [
    {
      minWidth: 300,
      Header: "Catalog Name",
      id: "CatalogName",
      accessor: "CatalogName",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Organization",
      id: "OrganisationName",
      accessor: "OrganisationName",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "On-sale Date",
      id: "CatalogOnSaleDate",
      accessor: "CatalogOnSaleDate",
      sortable: true,
    },
    {
      minWidth: 200,
      Header: "Status",
      id: "CatalogStatus",
      accessor: "CatalogStatus",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Operation",
      id: "CatalogID",
      accessor: (d) => (
        <Button
          onClick={() => {
            setSelectedCatalogId(d.CatalogID);
            handleUpdateCatalogModal(d.CatalogID, d.OrganisationID);
          }}
        >
          Edit
        </Button>
      ),
    },
  ];

  const catalogStatusOptions = [
    {
      label: "In progress",
      value: "In progress",
    },
    {
      label: "Archived",
      value: "Archived",
    },
    {
      label: "Completed",
      value: "Completed",
    },
  ];

  const getInitialValues = () => {
    return {
      catalogName: catalogDetails?.CatalogName || catalog,
      defaultCatalog: catalogDetails?.DefaultCatalog ? true : false,
      visualDesigner: catalogDetails?.VisualDesigner ? true : false,
      catalogOnSaleDate: catalogDetails?.CatalogOnSaleDate || "",
      catalogStatus: catalogDetails?.CatalogStatus || "",
    };
  };

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, catalogDataList, [
        "CatalogName",
        "OrganisationName",
      ]);
    }
    return catalogDataList;
  };

  const handleSubmit = (values) => {
    if (selectedCatalogId) {
      const date = changeDate
        ? new Date(
            values?.catalogOnSaleDate?.getTime() -
              values?.catalogOnSaleDate?.getTimezoneOffset() * 60000
          )
            ?.toISOString()
            ?.split("T")[0]
        : moment(new Date(values?.catalogOnSaleDate)).format("YYYY-MM-DD");
      const formData = {
        OrganisationID: String(selectOrganization),
        CatalogID: String(selectedCatalogId),
        DefaultCatalog: values?.defaultCatalog ? 1 : 0,
        enableMultiLanguage: 0,
        CatalogName: values?.catalogName,
        VisualDesigner: values?.visualDesigner ? 1 : 0,
        OnSaleDate: date,
        Status: values?.catalogStatus ? values?.catalogStatus : "In progress",
      };

      dispatch(fetchUpdateCatalog(formData)).then((data) => {
        if (data?.flag) {
          handleAddCatalogModal();
          if (selectOrganization) {
            dispatch(fetchCatalogList(Number(selectOrganization))).then(
              (data) => {
                setCatalogDataList(data?.data);
                setChangeDate(false);
              }
            );
          } else {
            dispatch(fetchActiveCatalogList()).then((data) => {
              setCatalogDataList(data?.data);
            });
          }
        }
      });
    } else {
      const formData = {
        OrganisationID: String(selectOrganization),
        CatalogName: values.catalogName,
        DefaultCatalog: values.defaultCatalog ? 1 : 0,
        enableMultiLanguage: 0,
        VisualDesigner: values.visualDesigner ? 1 : 0,
        OnSaleDate: moment(new Date(values?.catalogOnSaleDate)).format(
          "YYYY-MM-DD"
        ),
        Status: values?.catalogStatus ? values?.catalogStatus : "In progress",
      };
      dispatch(fetchAddCatalog(formData)).then((data) => {
        if (data?.flag) {
          handleAddCatalogModal();
          dispatch(fetchCatalogList(Number(selectOrganization))).then(
            (data) => {
              setCatalogDataList(data?.data);
              setChangeDate(false);
            }
          );
        }
      });
    }
    setCatalog("");
  };

  return (
    <div>
      {(isLoading ||
        activeIsLoading ||
        getUserDetailLoading ||
        organizationLoading) && <Loader />}
      <div className="tab-selectbox manage-oraganization-tab">
        <SelectField
          type="select"
          name="selectOrganization"
          id="selectOrganization"
          placeholder="Select Organization"
          options={organizationOptions()}
          onChange={handleOnChangeOrg}
          value={selectOrganization}
          isFirstOpDisable={true}
        />
      </div>
      <div className="tabcontent manage-oraganization-tab">
        <InputNormal
          type="text"
          name="searchCatalog"
          placeholder="Catalog"
          onChange={setCatalog}
          value={catalog}
        />
        <Button disabled={!selectOrganization} onClick={handleAddCatalogModal}>
          Add Catalog
        </Button>
      </div>

      <div className="tableorganisation bg-white manage-catalog-tbl-section masterAdmin-section product-tableBorder">
        <Table
          columns={ReactTableColumns}
          Data={catalogDataList || []}
          isLoading={
            isLoading ||
            activeIsLoading ||
            getUserDetailLoading ||
            organizationLoading
          }
          getFilterData={getFilterData}
          searchField={catalog}
          sortColumn={{
            id: "CatalogName",
            desc: false,
          }}
        />
      </div>

      {addCatalogModal && (
        <Modal
          className="conformation-popup catalog-popup manageOranization-model"
          isOpen={addCatalogModal}
          toggle={handleAddCatalogModal}
          size={"lg"}
        >
          <ModalHeader toggle={handleAddCatalogModal}>
            Add / Edit Catalog
          </ModalHeader>
          <ModalBody>
            <Formik
              initialValues={getInitialValues()}
              validationSchema={addCatalogForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <Form>
                    <div className="model-label-input manage-catalog-model">
                      <div className="row mb-3">
                        <div className="col-4">
                          <Label>Catalog Name : </Label>
                        </div>
                        <div className="col-8">
                          <InputField
                            type="text"
                            name="catalogName"
                            placeholder="Catalog Name"
                            onChange={handleChange}
                            value={values.catalogName || ""}
                          />
                          {showError("catalogName")}
                        </div>
                      </div>
                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>Default Catalog : </Label>{" "}
                        </div>
                        <div className="col-8">
                          <Input
                            type="checkbox"
                            name="defaultCatalog"
                            onChange={handleChange}
                            checked={values.defaultCatalog || ""}
                          />
                        </div>
                      </div>
                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>Visual designer : </Label>{" "}
                        </div>
                        <div className="col-8">
                          <Input
                            type="checkbox"
                            name="visualDesigner"
                            onChange={handleChange}
                            checked={values.visualDesigner || ""}
                          />
                        </div>
                      </div>

                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>On-sale Date : </Label>{" "}
                        </div>
                        <div className="col-8">
                          <DatePicker
                            dateFormat="dd/MM/yyyy"
                            name="catalogOnSaleDate"
                            selected={
                              Date.parse(values.catalogOnSaleDate) || ""
                            }
                            onChange={(val) => {
                              setFieldValue("catalogOnSaleDate", val);
                              setChangeDate(true);
                            }}
                            peekNextMonth
                            showMonthDropdown
                            showYearDropdown
                            dropdownMode="select"
                          />
                          {showError("catalogOnSaleDate")}
                        </div>
                      </div>

                      <div className="row align-center mb-3">
                        <div className="col-4">
                          <Label check>Status : </Label>{" "}
                        </div>
                        <div className="col-8">
                          <SelectFieldFormik
                            type="select"
                            name="catalogStatus"
                            id="status"
                            placeholder="Choose an Option"
                            options={catalogStatusOptions}
                            onChange={(e) =>
                              setFieldValue("catalogStatus", e.target.value)
                            }
                            value={values.catalogStatus || "In progress"}
                            isFirstOption={false}
                          />
                        </div>
                      </div>
                    </div>
                    <div className="model-bottom-btn-section">
                      <Button
                        color="primary cancel-btn confirm-n"
                        onClick={handleAddCatalogModal}
                      >
                        {" "}
                        Cancel
                      </Button>
                      <Button
                        color="primary save-btn confirm-y"
                        onClick={handleSubmit}
                      >
                        {" "}
                        Save changes
                      </Button>
                    </div>
                  </Form>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}
    </div>
  );
}

export default ManageCatalogs;
