import React, { useEffect } from "react";
import DataTable from "react-data-table-component";
import ReactTable from "react-table-6";
import { useDispatch, useSelector } from "react-redux";
import { Button, Input } from "reactstrap";
import { fetchJobList } from "redux/actions/masterAdmin/jobList";
import PaginationContainer from "react-js-pagination";
import "react-table-6/react-table.css";
import Table from "components/Common/Table";
import { filterFieldData } from "modules/utils";
import Loader from "components/Common/Loader";

function ManageJobs() {
  const dispatch = useDispatch();

  const { isLoading = false, jobList = null } = useSelector((state) => ({
    jobList: state.jobList?.data?.data || null,
    isLoading: state.jobList?.loading || false,
  }));
  console.log(
    "🚀 ~ const{isLoading=false,jobList=null}=useSelector ~ isLoading:",
    isLoading
  );

  useEffect(() => {
    dispatch(fetchJobList());
  }, []);

  const ReactTableColumns = [
    {
      minWidth: 20,
      Header: "Job Id",
      id: "JobID",
      accessor: "JobID",
      sortable: true,
    },
    {
      minWidth: 100,
      Header: "Job Name",
      id: "JobName",
      accessor: "JobName",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Job Query",
      id: "JobQuery",
      accessor: "JobQuery",
      style: { whiteSpace: "break-spaces" },
      sortable: true,
    },
    {
      minWidth: 70,
      Header: "Job Trigger",
      id: "JobTrigger",
      accessor: "JobTrigger",
      sortable: true,
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, jobList, [
        "JobName",
        "JobQuery",
        "JobTrigger",
      ]);
    }
    return jobList;
  };

  return (
    <div className="tableorganisation bg-white masterAdmin-section product-tableBorder">
      {isLoading && <Loader />}
      <Table
        columns={ReactTableColumns}
        Data={jobList}
        isLoading={isLoading}
        getFilterData={getFilterData}
      />
    </div>
  );
}

export default ManageJobs;
