import InputField from "components/Common/InputField";
import InputNormal from "components/Common/InputNormal";
import RestrictUserType from "components/Common/RestrictUserType";
import Table from "components/Common/Table";
import strings from "data/strings";
import { Form, Formik } from "formik";
import { displayFormErrors, addOrganizationForm } from "modules/validations";
import { filterFieldData } from "modules/utils";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import { fetchAddOrganization } from "redux/actions/masterAdmin/addOrganization";
import { fetchOrganizationList } from "redux/actions/masterAdmin/organizationList";
import { fetchUpdateOrganization } from "redux/actions/masterAdmin/updateOrganization";

function ManageOrganizations() {
  const dispatch = useDispatch();
  const [searchOrganization, setSearchOrganization] = useState("");
  const [organizationName, setOrganizationName] = useState("");
  const [addOrganizationModal, setAddOrganizationModal] = useState(false);
  const [selectedOrganizationId, setSelectedOrganizationId] = useState(0);

  const { isLoading = false, organizationList = null } = useSelector(
    (state) => ({
      organizationList: state.organizationList?.data?.data || null,
      isLoading: state.organizationList?.loading || null,
    })
  );

  const handleAddOrganizationModal = () => {
    setSelectedOrganizationId(0);
    setOrganizationName(searchOrganization);
    setAddOrganizationModal(!addOrganizationModal);
  };

  const handleUpdateOrganizationModal = () => {
    setAddOrganizationModal(!addOrganizationModal);
  };

  useEffect(() => {
    dispatch(fetchOrganizationList());
  }, []);

  const ReactTableColumns = [
    {
      minWidth: 300,
      Header: "Organisation Name",
      id: "OrganisationName",
      accessor: "OrganisationName",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <Button
          onClick={() => {
            setSelectedOrganizationId(d?.OrganisationID);
            setOrganizationName(d?.OrganisationName);
            handleUpdateOrganizationModal();
          }}
        >
          Edit
        </Button>
      ),
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, organizationList, ["OrganisationName"]);
    }
    return organizationList;
  };

  const handleSubmit = (values) => {
    if (selectedOrganizationId) {
      const formData = {
        OrganisationID: String(selectedOrganizationId),
        OrganisationName: values.organizationName,
      };
      dispatch(fetchUpdateOrganization(formData)).then((data) => {
        if (data?.flag) {
          handleAddOrganizationModal();
          dispatch(fetchOrganizationList());
        }
      });
    } else {
      const formData = {
        organisationName: values.organizationName,
      };
      dispatch(fetchAddOrganization(formData)).then((data) => {
        if (data?.flag) {
          handleAddOrganizationModal();
          dispatch(fetchOrganizationList());
        }
      });
    }
    setSearchOrganization("");
  };

  return (
    <div>
      <div className="tabcontent manage-oraganization-tab ">
        <InputNormal
          type="text"
          name="searchOrganization"
          placeholder="Organisation"
          onChange={setSearchOrganization}
          value={searchOrganization}
        />
        <RestrictUserType userType={strings.loginUserType.admin}>
          <Button onClick={handleAddOrganizationModal}>Add organisation</Button>
        </RestrictUserType>
      </div>
      <div className="tableorganisation bg-white catalog-tbl-section masterAdmin-section product-tableBorder">
        <Table
          columns={ReactTableColumns}
          Data={organizationList}
          isLoading={isLoading}
          getFilterData={getFilterData}
          searchField={searchOrganization}
          sortColumn={{
            id: "OrganisationName",
            desc: false,
          }}
        />
      </div>
      {addOrganizationModal && (
        <Modal
          className="conformation-popup catalog-popup manageOranization-model"
          isOpen={addOrganizationModal}
          toggle={handleAddOrganizationModal}
          size={"lg"}
        >
          <ModalHeader toggle={handleAddOrganizationModal}>
            Add / Edit Organisation
          </ModalHeader>
          <ModalBody>
            <Formik
              initialValues={{ organizationName: organizationName }}
              validationSchema={addOrganizationForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <>
                    <Form inline="true">
                      <div className="model-label-input">
                        <div className="row">
                          <div className="col-4">
                            <Label>Organization Name : </Label>
                          </div>
                          <div className="col-8">
                            <InputField
                              type="text"
                              name="organizationName"
                              placeholder="Organization Name"
                              onChange={handleChange}
                              value={values.organizationName || ""}
                            />
                            {showError("organizationName")}
                          </div>
                        </div>
                      </div>
                      <div className="model-bottom-btn-section">
                        <Button
                          color="primary cancel-btn confirm-n"
                          onClick={handleAddOrganizationModal}
                        >
                          {" "}
                          Cancel
                        </Button>
                        <Button
                          color="primary save-btn confirm-y save-chnages-btn"
                          onClick={handleSubmit}
                        >
                          {" "}
                          Save changes
                        </Button>
                      </div>
                    </Form>
                  </>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}
    </div>
  );
}

export default ManageOrganizations;
