import InputField from "components/Common/InputField";
import InputNormal from "components/Common/InputNormal";
import DeleteModal from "components/Common/Modal/DeleteModal";
import RestrictUserType from "components/Common/RestrictUserType";
import SelectField from "components/Common/SelectField";
import Table from "components/Common/Table";
import { Form, Formik } from "formik";
import { filterFieldData, getStatusArray, isValidArray } from "modules/utils";
import {
  displayFormErrors,
  inviteSellerForm,
  inviteAccountManagerForm,
  inviteUserForm,
} from "modules/validations";
import React, { useEffect, useState } from "react";
import DataTable from "react-data-table-component";
import { useDispatch, useSelector } from "react-redux";
import {
  Button,
  Input,
  Label,
  Modal,
  ModalBody,
  ModalHeader,
} from "reactstrap";
import { fetchDeleteUser } from "redux/actions/masterAdmin/deleteUser";
import { fetchInviteAccountManager } from "redux/actions/masterAdmin/inviteAccountManager";
import { fetchInviteReseller } from "redux/actions/masterAdmin/inviteReseller";
import { fetchInviteUser } from "redux/actions/masterAdmin/inviteUser";
import { fetchUpdateUser } from "redux/actions/masterAdmin/updateUser";
import { fetchUserList } from "redux/actions/masterAdmin/userList";
import strings from "../../../data/strings";

function ManageUsers() {
  const dispatch = useDispatch();

  const [searchResellerEmail, setSearchResellerEmail] = useState("");
  const [searchAccManagerEmail, setSearchAccManagerEmail] = useState("");
  const [searchUserEmail, setSearchUserEmail] = useState("");
  const [onBoardingCharge, setOnBoardingCharge] = useState(false);
  const [selectOrganization, setSelectOrganization] = useState("");
  const [editUserStatus, setEditUserStatus] = useState(0);

  const [resellerModal, setResellerModal] = useState(false);
  const [resellerEmail, setResellerEmail] = useState("");

  const [accManagerEmailModal, setAccManagerEmailModal] = useState(false);
  const [accManagerEmail, setAccManagerEmail] = useState("");

  const [inviteUserModal, setInviteUserModal] = useState(false);
  const [inviteUser, setInviteUser] = useState("");

  const [editUserModal, setEditUserModal] = useState(false);
  const [editUserName, setEditUserName] = useState("");
  const [username, setUserName] = useState("");
  const [userId, setUserId] = useState("");

  const [deleteUserModal, setDeleteUserModal] = useState(false);
  const [deleteUser, setDeleteUser] = useState("");
  const [selectedIdDelete, setSelectedIdDelete] = useState(0);

  const {
    isLoading = false,
    loginUserDetailsLoading = false,
    userList = null,
    loginUserDetails = null,
    organizationList = null,
  } = useSelector((state) => ({
    userList: state.userList?.data?.data || null,
    isLoading: state.userList?.loading || null,
    loginUserDetails: state.getUserDetail?.data || null,
    loginUserDetailsLoading: state.getUserDetail?.loading || null,
    organizationList: state.organizationList?.data?.data || null,
  }));
  console.log("🚀 ~ ManageUsers ~ loginUserDetails:", loginUserDetails);

  useEffect(() => {
    dispatch(fetchUserList(loginUserDetails?.data?.OrganisationID));
  }, [loginUserDetails]);

  const handleInviteResellerModal = () => {
    setResellerModal(!resellerModal);
    setResellerEmail(searchResellerEmail);
  };

  const handleInviteReseller = () => {
    const formData = {
      resellerEmail: resellerEmail,
    };
  };

  const handleInviteAccManagerModal = () => {
    setAccManagerEmail(searchAccManagerEmail);
    setAccManagerEmailModal(!accManagerEmailModal);
  };

  const handleInviteAccManager = () => {
    const formData = {
      resellerEmail: resellerEmail,
    };
  };

  const handleInviteUserModal = () => {
    setInviteUser(searchUserEmail);
    setInviteUserModal(!inviteUserModal);
  };

  const handleInviteUser = () => {
    const formData = {
      inviteUser: inviteUser,
    };
  };

  const handleEditUserModal = (userId, userName, organization, status) => {
    setUserId(String(userId));
    setUserName(userName);
    setSelectOrganization(String(organization));
    setEditUserStatus(String(status));
    setEditUserModal(!editUserModal);
  };

  const handleEditUser = () => {
    const formData = {
      id: userId,
      OrganisationId: selectOrganization,
      IsActive: editUserStatus,
    };
    dispatch(fetchUpdateUser(formData)).then((data) => {
      dispatch(fetchUserList(loginUserDetails?.data?.OrganisationID));
      handleEditUserModal();
    });
  };

  const handleDeleteUserModal = () => {
    setDeleteUserModal(!deleteUserModal);
  };

  const handleDeleteUser = () => {
    const formData = {
      id: selectedIdDelete,
    };

    dispatch(fetchDeleteUser(formData)).then((data) => {
      dispatch(fetchUserList(loginUserDetails?.data?.OrganisationID));
      handleDeleteUserModal();
    });
  };

  const organizationOptions = () => {
    let updated =
      isValidArray(organizationList) &&
      organizationList?.map((item) => {
        return {
          label: item.OrganisationName,
          value: item.OrganisationID,
        };
      });

    updated = isValidArray(updated)
      ? [{ label: "Select Organization", value: "" }, ...updated]
      : [{ label: "Select Organization", value: "" }];

    return updated;
  };

  const ReactTableColumns = [
    {
      minWidth: 300,
      Header: "User Name",
      id: "UserName",
      accessor: "UserName",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Organisation",
      id: "OrganisationName",
      accessor: "OrganisationName",
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Active",
      id: "Active",
      accessor: (d) => (d?.IsActive ? "Yes" : "No"),
      sortable: true,
    },
    {
      minWidth: 300,
      Header: "Operations",
      id: "Operations",
      accessor: (d) => (
        <>
          <Button
            onClick={() => {
              setEditUserStatus();
              handleEditUserModal(
                d.UserId,
                d.UserName,
                d.OrganisationID,
                d.IsActive
              );
            }}
          >
            Edit
          </Button>
          {" | "}
          <Button
            onClick={() => {
              handleDeleteUserModal();
              setSelectedIdDelete(d.UserId);
            }}
          >
            Delete
          </Button>
        </>
      ),
    },
  ];

  const getFilterData = (searchTerm) => {
    if (searchTerm) {
      const value = searchTerm.toLowerCase();
      return filterFieldData(value, userList, ["UserName", "OrganisationName"]);
    }
    return userList;
  };

  const handleSubmit = (values) => {
    dispatch(fetchInviteReseller(values)).then(() => {
      handleInviteResellerModal();
    });
  };

  const handleInviteAccManagerSubmit = (values) => {
    const result = {
      ...values,
      waveOnboardcharge: values?.waveOnboardcharge === true ? "1" : "0",
    };
    dispatch(fetchInviteAccountManager(result)).then(() => {
      handleInviteAccManagerModal();
    });
  };

  const handleInviteUserSubmit = (values) => {
    dispatch(fetchInviteUser(values)).then(() => {
      handleInviteUserModal();
    });
  };

  return (
    <div>
      <div className="tabcontent">
        <InputNormal
          type="text"
          name="resellerMail"
          placeholder="Reseller email"
          value={searchResellerEmail}
          onChange={setSearchResellerEmail}
        />
        <RestrictUserType userType={strings.loginUserType.admin}>
          <Button onClick={handleInviteResellerModal}>Invite a reseller</Button>
        </RestrictUserType>
      </div>
      <div className="tabcontent">
        <InputNormal
          type="text"
          name="accountManagerEmail"
          placeholder="Account Manager Email"
          value={searchAccManagerEmail}
          onChange={setSearchAccManagerEmail}
        />
        <RestrictUserType userType={strings.loginUserType.admin}>
          <Button onClick={handleInviteAccManagerModal}>
            Invite Account Manager
          </Button>
        </RestrictUserType>
      </div>
      <div className="tabcontent">
        <InputNormal
          type="text"
          name="inviteUser"
          placeholder="User email"
          value={searchUserEmail}
          onChange={setSearchUserEmail}
        />
        <RestrictUserType userType={strings.loginUserType.adminAccManager}>
          <Button onClick={handleInviteUserModal}>Invite a user</Button>
        </RestrictUserType>
      </div>
      <div className="tableorganisation bg-white manage-user-tbl-section masterAdmin-section product-tableBorder">
        <Table
          columns={ReactTableColumns}
          Data={userList}
          isLoading={isLoading || loginUserDetailsLoading}
          getFilterData={getFilterData}
          sortColumn={{
            id: "UserName",
            desc: false,
          }}
        />
      </div>

      {resellerModal && (
        <Modal
          className="conformation-popup invite-seller-popup manageOranization-model"
          isOpen={resellerModal}
          toggle={handleInviteResellerModal}
          size={"lg"}
        >
          <ModalHeader toggle={handleInviteResellerModal}>
            Invite Reseller
          </ModalHeader>
          <ModalBody>
            <Formik
              initialValues={{
                email: resellerEmail,
              }}
              validationSchema={inviteSellerForm}
              onSubmit={handleSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);

                return (
                  <Form>
                    <div className="model-label-input">
                      <div className="row">
                        <div className="col-4">
                          <Label>Reseller email: </Label>
                        </div>
                        <div className="col-8">
                          <InputField
                            type="text"
                            name="email"
                            placeholder="Reseller email"
                            onChange={handleChange}
                            value={values.email || ""}
                          />
                          {showError("email")}
                        </div>
                      </div>
                    </div>
                    <div className="model-bottom-btn-section">
                      <Button
                        color="primary cancel-btn confirm-n"
                        onClick={handleInviteResellerModal}
                      >
                        {" "}
                        Cancel
                      </Button>
                      <Button
                        color="primary save-btn confirm-y"
                        onClick={handleSubmit}
                      >
                        {" "}
                        Save invite
                      </Button>
                    </div>
                  </Form>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}

      {accManagerEmailModal && (
        <Modal
          className="conformation-popup manageOranization-model"
          isOpen={accManagerEmailModal}
          toggle={handleInviteAccManagerModal}
          size={"lg"}
        >
          <ModalHeader toggle={handleInviteAccManagerModal}>
            Invite Account Manager
          </ModalHeader>
          <ModalBody>
            <Formik
              initialValues={{
                email: accManagerEmail,
                waveOnboardcharge: false,
              }}
              validationSchema={inviteAccountManagerForm}
              onSubmit={handleInviteAccManagerSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);

                return (
                  <Form>
                    <div className="model-label-input">
                      <div className="row">
                        <div className="col-4">
                          <Label>Account Manager Email : </Label>
                        </div>
                        <div className="col-8">
                          <InputField
                            type="text"
                            name="email"
                            placeholder="Account Manager Email"
                            onChange={handleChange}
                            value={values.email || ""}
                          />
                          {showError("email")}
                        </div>
                      </div>
                      <div className="row">
                        <div className="col-4"></div>
                        <div className="col-8">
                          <div className="mt-3 custom-checkbox-right d-flex align-center">
                            <Input
                              type="checkbox"
                              name="waveOnboardcharge"
                              onChange={handleChange}
                              value={values.waveOnboardcharge || false}
                            />
                            <Label check>Waive off onboarding charge</Label>{" "}
                          </div>
                        </div>
                      </div>
                    </div>

                    <div className="model-bottom-btn-section">
                      <Button
                        color="primary cancel-btn confirm-n"
                        onClick={handleInviteAccManagerModal}
                      >
                        {" "}
                        Cancel
                      </Button>
                      <Button
                        color="primary save-btn confirm-y"
                        onClick={handleSubmit}
                      >
                        {" "}
                        Save invite
                      </Button>
                    </div>
                  </Form>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}

      {inviteUserModal && (
        <Modal
          className="conformation-popup manageOranization-model"
          isOpen={inviteUserModal}
          toggle={handleInviteUserModal}
          size={"lg"}
        >
          <ModalHeader toggle={handleInviteUserModal}>Invite User</ModalHeader>
          <ModalBody>
            <Formik
              initialValues={{
                email: searchUserEmail,
              }}
              validationSchema={inviteUserForm}
              onSubmit={handleInviteUserSubmit}
              enableReinitialize
            >
              {({
                values,
                errors,
                touched,
                handleChange,
                handleBlur,
                handleSubmit,
                submitCount,
                setFieldValue,
              }) => {
                const showError = (key) =>
                  displayFormErrors(key, errors, touched, submitCount);
                return (
                  <Form>
                    <div className="model-label-input">
                      <div className="row">
                        <div className="col-4">
                          <Label>User email :</Label>
                        </div>
                        <div className="col-8">
                          <InputField
                            type="text"
                            name="email"
                            placeholder="User email"
                            onChange={handleChange}
                            value={values.email || ""}
                          />
                          {showError("email")}
                        </div>
                      </div>
                    </div>
                    <div className="model-bottom-btn-section">
                      <Button
                        color="primary cancel-btn confirm-n"
                        onClick={handleInviteUserModal}
                      >
                        {" "}
                        Cancel
                      </Button>
                      <Button
                        color="primary save-btn confirm-y"
                        onClick={handleSubmit}
                      >
                        {" "}
                        Save invite
                      </Button>
                    </div>
                  </Form>
                );
              }}
            </Formik>
          </ModalBody>
        </Modal>
      )}

      {editUserModal && (
        <Modal
          className="conformation-popup manageOranization-model"
          isOpen={editUserModal}
          toggle={handleEditUserModal}
          size={"lg"}
        >
          <ModalHeader toggle={handleEditUserModal}>
            Add User Organisation
          </ModalHeader>
          <ModalBody>
            <div className="model-label-input">
              <div className="row align-center">
                <div className="col-4">
                  <Label>User name :</Label>
                </div>
                <div className="col-8">
                  <InputField
                    type="text"
                    name="userName"
                    placeholder="User Name"
                    onChange={setUserName}
                    value={username}
                    isDisabled={true}
                  />
                </div>
              </div>
            </div>
            <div className="model-label-input">
              <div className="row align-center">
                <div className="col-4">
                  <Label>Organisation :</Label>
                </div>
                <div className="col-8">
                  <SelectField
                    type="select"
                    name="selectOrganization"
                    id="selectOrganization"
                    placeholder="Select Organization"
                    options={organizationOptions()}
                    onChange={setSelectOrganization}
                    value={selectOrganization}
                    isFirstOpDisable={true}
                  />
                </div>
              </div>
            </div>
            <div className="model-label-input">
              <div className="row align-center">
                <div className="col-4">
                  <Label>Active/InActive :</Label>
                </div>
                <div className="col-8">
                  <SelectField
                    type="select"
                    name="activeInactive"
                    id="activeInactive"
                    placeholder="Select Organization"
                    options={getStatusArray}
                    onChange={setEditUserStatus}
                    value={editUserStatus}
                  />
                </div>
              </div>
            </div>
            <div className="model-bottom-btn-section">
              <Button
                color="primary cancel-btn confirm-n"
                onClick={handleEditUserModal}
              >
                {" "}
                Cancel
              </Button>
              <Button
                color="primary save-btn confirm-y"
                onClick={handleEditUser}
              >
                {" "}
                Save changes
              </Button>
            </div>
          </ModalBody>
        </Modal>
      )}

      {deleteUserModal && (
        <DeleteModal
          toggle={handleDeleteUserModal}
          deleteFunction={handleDeleteUser}
          isOpen={deleteUserModal}
        />
      )}
    </div>
  );
}

export default ManageUsers;
