/* eslint-disable react/react-in-jsx-scope */
import BlockBuilder from "components/BlockBuilder/BlockBuilder";
import Header from "components/Common/Header";
import Dashboard from "components/Dashboard/Dashboard";
import ElefantTree from "components/Elefant/ElefantTree";
import Import from "components/Import/Import";
import ManageCatalog from "components/ManageCatalog/ManageCatalog";
import ManageProduct from "components/ManageProduct/ManageProduct";
import EditProduct from "components/ManageProduct/productList/editProduct/EditProduct";
import MasterSetup from "components/MasterSetup/MasterSetup";
import PreviewBlob from "components/MasterSetup/productBlobs/PreviewBlob";
import Media from "components/Media/Media";
import Output from "components/Output/Output";
import Success from "components/Output/Success";
import Reports from "components/Reports/Reports";
import ShowReport from "components/Reports/ShowReport";
import WpIntegration from "components/WpIntegration/WpIntegration";
import GetJSONFlatForCatID from "components/getJSONFlat/GetJSONFlatForCatID";
import MasterAdmin from "components/masterAdmin/MasterAdmin";
import { getLocalStorageItem, removeAuthToken } from "modules/utils";
import { useEffect, useState } from "react";
import IdleTimer from "react-idle-timer";
import { Redirect, Route, Switch, useHistory } from "react-router-dom";
import { useLocation } from "react-router-dom/cjs/react-router-dom.min";
import LogOutConfimationModal from "./LogOutConfimationModal";
import Products from "components/ManageCatalog/tabs/products/Products";
import Planner from "components/ManageCatalog/tabs/planner/Planner";
import DisplaySetup from "components/ManageCatalog/tabs/categorySetup/tabs/DisplaySetup";
import CatalogMedia from "components/ManageCatalog/tabs/media/Media";

const Auth = () => {
  const history = useHistory();

  const location = useLocation();
  const [grid, setGrid] = useState(false);
  const [timeout, setTimeout] = useState(1000 * 900 * 1);
  const [userLoggedIn, setUserLoggedIn] = useState(false);
  const [isTimedOut, setIsTimedOut] = useState(false);
  const [isLogoutPopup, setIsLogoutPopup] = useState(false);
  const [isFirstTime, setFirstTime] = useState(true);

  let idleTimer = null;

  useEffect(() => {
    const isGrid = getLocalStorageItem("isAttributeGrid");
    setGrid(isGrid);
  }, []);

  const handleToggle = () => {
    setIsLogoutPopup(!isLogoutPopup);
    setFirstTime(false);
  };

  const handleOnIdle = (event) => {
    setIsTimedOut(true);

    if (isFirstTime) {
      handleToggle();
    } else {
      removeAuthToken();
      history.push("/login");
    }
    idleTimer.reset();
  };

  const handleOnAction = (event) => { };
  const handleOnActive = (event) => { };

  const continueProcess = () => {
    setIsLogoutPopup(false);
    setFirstTime(true);
  };
  return (
    <>
      <IdleTimer
        crossTab={true}
        ref={(ref) => {
          idleTimer = ref;
        }}
        element={document}
        onActive={handleOnActive}
        onIdle={handleOnIdle}
        onAction={handleOnAction}
        debounce={250}
        timeout={timeout}
      />
      <Header />
      <div
        className={
          location.pathname === "/Products" && grid
            ? "full-body-content product_attribute_grid"
            : "full-body-content"
        }
      >
        <Switch>
          <Route exact path="/home" component={Dashboard} />
          <Route exact path="/Admin/:type" component={MasterAdmin} />
          <Route
            exact
            path="/Catalog/Products:id?"
            component={ManageCatalog}
          />
          <Route
            exact
            path="/Catalog/Planner:id?"
            component={ManageCatalog}
          />
          <Route
            exact
            path="/Catalog/Media:id?"
            component={ManageCatalog}
          />{" "}
          <Route
            exact
            path="/Catalog/CategorySetup:id?"
            component={ManageCatalog}
          />
          {/* <Route path="/Catalog/Products:id?" component={Products} />
          <Route path="/Catalog/Planner:id?" component={Planner} />
          <Route path="/Catalog/Media:id?" component={CategoryMedia} />
          <Route
            path="/Catalog/CatalogCategorySetup:id"
            component={DisplaySetup}
          /> */}
          <Route exact path="/Products" component={ManageProduct} />
          <Route exact path="/Import" component={Import} />
          <Route
            exact
            path={["/Media/:type", "/Media/:type:code"]}
            component={Media}
          />
          <Route exact path="/Setup/:type/:subtype?" component={MasterSetup} />
          <Route exact path="/Reports" component={Reports} />
          <Route exact path="/Output/:activeTab" component={Output} />
          <Route exact path="/Layout" component={BlockBuilder} />
          <Route exact path="/Layout/:layoutID" component={BlockBuilder} />
          <Route exact path="/Product/:productCode" component={EditProduct} />
          <Route
            exact
            path="/previewBlobByBlobID/:productBlobId"
            component={PreviewBlob}
          />
          <Route exact path="/success" component={Success} />
          <Route exact path="/showReport/:id" component={ShowReport} />
          <Route exact path="/WpIntegration" component={WpIntegration} />
          <Route exact path="/elefant" component={ElefantTree} />
          <Route
            exact
            path="/GetJSONFlatForCatID/:id"
            component={GetJSONFlatForCatID}
          />
          <Redirect to="/login" />
        </Switch>
      </div>
      {isLogoutPopup && (
        <LogOutConfimationModal
          toggle={handleToggle}
          isOpen={isLogoutPopup}
          continueProcess={continueProcess}
        />
      )}
    </>
  );
};

export default Auth;
