import { isString } from "lodash";
import { toast } from "react-toastify";
import { isNotBadWord } from "./validations";

export const AUTH_KEY = "AUTH_TOKEN";

export const setAuthToken = (token = "") =>
  localStorage.setItem(AUTH_KEY, token);

export const getAuthToken = () => localStorage.getItem(AUTH_KEY);

export const removeAuthToken = () => localStorage.removeItem(AUTH_KEY);

export const removeLocalStorageItem = (key) => {
  return localStorage.removeItem(key);
};
export const setLocalStorageItem = (key, items) => {
  return localStorage.setItem(key, items);
};
export const getLocalStorageItem = (key) => {
  return localStorage.getItem(key);
};

export const setSessionStorageItem = (key, items) => {
  return window.sessionStorage.setItem(key, items);
};
export const getSessionStorageItem = (key) => {
  return window.sessionStorage.getItem(key);
};

export const isValidArray = (data) => {
  return data && Array.isArray(data) && data.length > 0;
};

export const isValidObject = (data) => {
  return typeof data === "object" && data
    ? Object.keys(data).length > 0
    : false;
};

export const getApiData = (data) => {
  return data?.data?.responseData ?? data?.data ?? data ?? null;
};

export const showSuccessErrorToast = (flag = 0, message) => {
  if (flag) {
    toast.success(message);
  } else {
    toast.error(message);
  }
};

export const handleDecimalsOnValue = (value) => {
  return value
    .split(".")
    .map((el, i) => (i ? el.split("").slice(0, 2).join("") : el))
    .join(".");
};

export const filterFieldData = (searchTerm = "", data = [], fields = []) => {
  return data?.filter((item) =>
    fields.some(
      (col) =>
        // isString(item[col]) &&
        !isNotBadWord(searchTerm) &&
        item[col] != null &&
        item[col].toString().toLowerCase().search(searchTerm.trim()) !== -1
    )
  );
};

export const getRowPerPageArray = [
  { label: "10", value: 10 },
  { label: "25", value: 25 },
  { label: "50", value: 50 },
  { label: "100", value: 100 },
];

export const getStatusArray = [
  { label: "Yes", value: 1 },
  { label: "No", value: 0 },
];

export const commonYesNoArray = [
  { label: "Yes", value: 1 },
  { label: "No", value: 0 },
];

export const preferredAttributeArray = [
  { label: "Yes", value: "Yes" },
  { label: "No", value: "No" },
];

export const isMultiImageOptions = [
  { label: "Yes", value: "1" },
  { label: "No", value: "0" },
];

export const dataTypeArray = [
  { label: "Text", value: "varchar(255)" },
  { label: "Number", value: "int(10)" },
  { label: "Decimal", value: "decimal(10,2)" },
  { label: "Long Description", value: "longtext" },
  { label: "Enum", value: "enum" },
  { label: "Set", value: "set" },
];

export const reorderArray = (list, startIndex, endIndex) => {
  const result = Array.from(list);
  const [removed] = result.splice(startIndex, 1);
  result.splice(endIndex, 0, removed);

  return result;
};

export const fileToBase64 = (e) => {
  return new Promise((resolve, reject) => {
    if (e) {
      const file = e;
      const reader = new FileReader();

      // Read file content on file loaded event
      reader.onload = function (event) {
        resolve({
          file: event.target.result,
          type: getFileType(file.type),
        });
      };

      // Convert data to base64
      reader.readAsDataURL(file);
    } else {
      reject(new Error("Something went wrong."));
    }
  });
};

export const numberWithCommas = (number) => {
  return number.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");
};

export const getFileType = (type) => {
  if (type.startsWith("video/")) {
    return "video";
  }
  if (type.startsWith("image/")) {
    return "image";
  }
  return type;
};

export const bytesToSize = (bytes) => {
  const units = ["bytes", "KiB", "MiB", "GiB", "TiB"];
  let l = 0,
    n = parseInt(bytes, 10) || 0;
  while (n >= 1024 && ++l) {
    n = n / 1024;
  }
  return n.toFixed(1) + " " + units[l];
};

export const isValidUrl = (url) => {
  return url.match(/\.(jpeg|jpg|gif|png)$/) != null;
};

export const compare = (a, b) => {
  if (a.Header < b.Header) {
    return -1;
  }
  if (a.Header > b.Header) {
    return 1;
  }
  return 0;
};

export const extractNumFromString = (str) => {
  return str.match(/\d+/)[0];
};

export const replaceNumFromString = (str, rep) => {
  return str.replace(/[0-9]+./g, rep);
};

export const limitChar = (str, limit) => {
  return ![undefined, null, ""].includes(str) && str.length > limit
    ? `${str.slice(0, limit)}...`
    : str;
};
export const insertParam = (key, value) => {
  const url = new URL(window.location.href);
  url.searchParams.set(key, value);
  window.history.pushState({ path: url.href }, "", url.href);
};

export const mmTopx = (mmValue) => {
  let px = 300 * mmValue;
  px = px / 25.4;
  return px;
};

export const pxTomm = (pxValue) => {
  let mm = pxValue * 25.4;
  mm = mm / 300;
  console.log("🚀 ~ file: utils.js ~ line 199 ~ pxTomm ~ mm", mm);
  return mm;
};

export const oneTrailingZeroes = (val) => {
  return parseFloat(val).toFixed(2).replace(/\.0+$/, "");
};

export const capitalizeFirstLetter = (string) => {
  return string.charAt(0).toUpperCase() + string.slice(1);
};

export const searchIncludes = (string, searchValue) =>
  string?.toLowerCase().includes(searchValue?.toLowerCase());

export const reorder = (list, startIndex, endIndex) => {
  const result = Array.from(list);
  const [removed] = result.splice(startIndex, 1);
  result.splice(endIndex, 0, removed);

  return result;
};
