import axios from "axios";
import strings from "data/strings";
import config from "config";
import { removeAuthToken, getLocalStorageItem, AUTH_KEY } from "modules/utils";

const { API_URL, FRONT_END_API_URL } = config;

export const apiConfig = () => {
  const accessToken = getLocalStorageItem(AUTH_KEY) || "";
  const appConfigData = {
    method: "PUT,DELETE,POST,GET,OPTION",
    headers: {
      accept: "application/json",
      "Cache-Control": "no-cache",
      Pragma: "no-cache",
      Expires: "0",
    },
  };
  if (accessToken)
    appConfigData.headers.Authorization = `Bearer ${accessToken}`;

  return appConfigData;
};

export const apiFormDataConfig = (config = {}) => {
  const accessToken = getLocalStorageItem(AUTH_KEY) || "";
  const appConfigData = {
    ...config,
    method: "PUT,DELETE,POST,GET,OPTION",
    headers: {
      accept: "application/json",
      "Cache-Control": "no-cache",
      contentType: "multipart/form-data",
      Pragma: "no-cache",
      Expires: "0",
    },
  };
  if (accessToken)
    appConfigData.headers.Authorization = `Bearer ${accessToken}`;

  return appConfigData;
};

export const getApi = (url, options = {}) => {
  return axios.get(`${API_URL}${url}`, { ...apiConfig(), ...options });
};

export const postApi = (url, apiData) => {
  return axios.post(`${API_URL}${url}`, apiData, apiConfig());
};

export const postFormDataApi = (url, apiData, config) => {
  return axios.post(`${API_URL}${url}`, apiData, apiFormDataConfig(config));
};

export const putApi = (url, apiData) => {
  return axios.put(`${API_URL}${url}`, apiData, apiConfig());
};

export const patchApi = (url, apiData) => {
  return axios.patch(`${API_URL}${url}`, apiData, apiConfig());
};

export const deleteApi = (url) => {
  return axios.delete(`${API_URL}${url}`, apiConfig());
};

export const getApiError = (error) =>
  typeof error?.response?.data?.error === "string"
    ? error.response.data.error
    : strings.errors.somethingWrong;

export const setupInterceptors = () => {
  axios.interceptors.response.use(
    (response) => response,
    (error) => {
      // WHEN NO ACCESS
      if ([403].includes(error?.response?.status)) {
        removeAuthToken();
        window.location.reload();
      }

      return Promise.reject(error);
    }
  );
};
