import { setAuthToken, setLocalStorageItem } from "modules/utils";
import { toast } from "react-toastify";
import { getApiError, postApi } from "redux/actions/api";
import {
  FETCH_LOGIN_FAILURE,
  FETCH_LOGIN_REQUEST,
  FETCH_LOGIN_SUCCESS,
} from "redux/types/auth";

export const fetchLoginRequest = () => ({
  type: FETCH_LOGIN_REQUEST,
});

export const fetchLoginSuccess = (data) => ({
  type: FETCH_LOGIN_SUCCESS,
  data,
});

export const fetchLoginFailure = (error) => ({
  type: FETCH_LOGIN_FAILURE,
  error,
});

export const fetchLogin = (formData) => (dispatch) => {
  dispatch(fetchLoginRequest());
  return postApi('/loginCheck', formData)
    .then((data) =>{
        if(data?.data?.flag){
            toast.success(data?.data?.message);
            setAuthToken(data?.data?.data?.api_token);
        }else{
            toast.error(data?.data?.message);
        }
        dispatch(fetchLoginSuccess(data))
        return data;
    })
    .catch((error) => {
      toast.error(getApiError(error));
      dispatch(fetchLoginFailure(error));
    });
};
