import axios from "axios";
import { getApiData, setAuthToken } from "modules/utils";
import { toast } from "react-toastify";
import { getApi, getApiError, postApi } from "redux/actions/api";
import {
  FETCH_PRODUCT_NOT_IN_COLLECTION_REQUEST,
  FETCH_PRODUCT_NOT_IN_COLLECTION_SUCCESS,
  FETCH_PRODUCT_NOT_IN_COLLECTION_FAILURE,
} from "redux/types/manageCatelog";

export const fetchProductNotInCollectionRequest = (cancelToken) => ({
  type: FETCH_PRODUCT_NOT_IN_COLLECTION_REQUEST,
  cancelToken,
});

export const fetchProductNotInCollectionSuccess = (data) => ({
  type: FETCH_PRODUCT_NOT_IN_COLLECTION_SUCCESS,
  data,
});

export const fetchProductNotInCollectionFailure = (error) => ({
  type: FETCH_PRODUCT_NOT_IN_COLLECTION_FAILURE,
  error,
});

export const fetchProductNotInCollection =
  (id, searchText = "") =>
  (dispatch, getState) => {
    const state = getState();
    const cancelToken = axios.CancelToken.source();

    if (state?.productNotInCollection?.cancelToken && searchText) {
      state.productNotInCollection.cancelToken.cancel(
        "Operation canceled due to new request."
      );
    }

    const options = { cancelToken: cancelToken.token };

    dispatch(fetchProductNotInCollectionRequest(cancelToken));
    return getApi(
      `/getProductsNotInCollection/${id}?searchText=${encodeURIComponent(
        searchText
      )}`,
      options
    )
      .then((data) => {
        dispatch(fetchProductNotInCollectionSuccess(data));
        return getApiData(data);
      })
      .catch((error) => {
        // toast.error(getApiError(error));
        dispatch(fetchProductNotInCollectionFailure(error));
      });
  };
