import { getApiData, setAuthToken, showSuccessErrorToast } from "modules/utils";
import { toast } from "react-toastify";
import { getApi, getApiError, postApi } from "redux/actions/api";
import {
  FETCH_ADD_ORGANIZATION_REQUEST,
  FETCH_ADD_ORGANIZATION_SUCCESS,
  FETCH_ADD_ORGANIZATION_FAILURE,
} from "redux/types/masterAdmin";

export const fetchAddOrganizationRequest = () => ({
  type: FETCH_ADD_ORGANIZATION_REQUEST,
});

export const fetchAddOrganizationSuccess = (data) => ({
  type: FETCH_ADD_ORGANIZATION_SUCCESS,
  data,
});

export const fetchAddOrganizationFailure = (error) => ({
  type: FETCH_ADD_ORGANIZATION_FAILURE,
  error,
});

export const fetchAddOrganization = (formData) => (dispatch) => {
  dispatch(fetchAddOrganizationRequest());
  return postApi("/addOrganisation", formData)
    .then((data) => {
      showSuccessErrorToast(data?.data?.flag, data?.data?.message);
      dispatch(fetchAddOrganizationSuccess(data));
      return getApiData(data);
    })
    .catch((error) => {
      toast.error(getApiError(error));
      dispatch(fetchAddOrganizationFailure(error));
    });
};
