import { getApiData, setAuthToken } from "modules/utils";
import { toast } from "react-toastify";
import { getApi, getApiError, postApi } from "redux/actions/api";
import {
  FETCH_UPDATE_ATTRIBUTE_REQUEST,
  FETCH_UPDATE_ATTRIBUTE_SUCCESS,
  FETCH_UPDATE_ATTRIBUTE_FAILURE,
} from "redux/types/masterSetup";

export const fetchUpdateAttributeRequest = () => ({
  type: FETCH_UPDATE_ATTRIBUTE_REQUEST,
});

export const fetchUpdateAttributeSuccess = (data) => ({
  type: FETCH_UPDATE_ATTRIBUTE_SUCCESS,
  data,
});

export const fetchUpdateAttributeFailure = (error) => ({
  type: FETCH_UPDATE_ATTRIBUTE_FAILURE,
  error,
});

export const fetchUpdateAttribute = (formData) => (dispatch) => {
  dispatch(fetchUpdateAttributeRequest());
  return postApi("/updateAttribute", formData)
    .then((data) => {
      if (data?.data?.flag) {
        toast.success(data?.data?.flag, data?.data?.message);
      }
      dispatch(fetchUpdateAttributeSuccess(data));
      return getApiData(data);
    })
    .catch((error) => {
      toast.error(getApiError(error));
      dispatch(fetchUpdateAttributeFailure(error));
    });
};
