import { getApiData, setAuthToken, showSuccessErrorToast } from "modules/utils";
import { toast } from "react-toastify";
import {
  getApi,
  getApiError,
  postApi,
  postFormDataApi,
} from "redux/actions/api";
import {
  FETCH_ADD_IMAGE_REQUEST,
  FETCH_ADD_IMAGE_SUCCESS,
  FETCH_ADD_IMAGE_FAILURE,
} from "redux/types/media";

export const fetchAddImageRequest = () => ({
  type: FETCH_ADD_IMAGE_REQUEST,
});

export const fetchAddImageSuccess = (data) => ({
  type: FETCH_ADD_IMAGE_SUCCESS,
  data,
});

export const fetchAddImageFailure = (error) => ({
  type: FETCH_ADD_IMAGE_FAILURE,
  error,
});

export const fetchAddImage =
  (formData, onUploadProgress = () => {}) =>
  (dispatch) => {
    dispatch(fetchAddImageRequest());

    const config = { onUploadProgress };

    return postFormDataApi(`/addImage`, formData, config)
      .then((data) => {
        dispatch(fetchAddImageSuccess(data));
        showSuccessErrorToast(data?.data?.flag, data?.data?.message);

        return getApiData(data);
      })
      .catch((error) => {
        toast.error(getApiError(error));
        dispatch(fetchAddImageFailure(error));
      });
  };
