import { getApiData, setAuthToken, showSuccessErrorToast } from "modules/utils";
import { toast } from "react-toastify";
import { getApi, getApiError, postApi } from "redux/actions/api";
import {
  FETCH_DELETE_IMAGE_SIZE_REQUEST,
  FETCH_DELETE_IMAGE_SIZE_SUCCESS,
  FETCH_DELETE_IMAGE_SIZE_FAILURE,
} from "redux/types/media";

export const fetchDeleteImageSizeRequest = () => ({
  type: FETCH_DELETE_IMAGE_SIZE_REQUEST,
});

export const fetchDeleteImageSizeSuccess = (data) => ({
  type: FETCH_DELETE_IMAGE_SIZE_SUCCESS,
  data,
});

export const fetchDeleteImageSizeFailure = (error) => ({
  type: FETCH_DELETE_IMAGE_SIZE_FAILURE,
  error,
});

export const fetchDeleteImageSize = (id) => (dispatch) => {
  dispatch(fetchDeleteImageSizeRequest());
  return getApi(`/deleteImageSize/${id}`)
    .then((data) => {
      showSuccessErrorToast(data?.data?.flag, data?.data?.message);
      dispatch(fetchDeleteImageSizeSuccess(data));
      return getApiData(data);
    })
    .catch((error) => {
      toast.error(getApiError(error));
      dispatch(fetchDeleteImageSizeFailure(error));
    });
};
