import { getApiData, setAuthToken, showSuccessErrorToast } from "modules/utils";
import { toast } from "react-toastify";
import { getApi, getApiError, postApi } from "redux/actions/api";
import {
  FETCH_DELETE_ATTRIBUTE_FOR_SCHEMA_REQUEST,
  FETCH_DELETE_ATTRIBUTE_FOR_SCHEMA_SUCCESS,
  FETCH_DELETE_ATTRIBUTE_FOR_SCHEMA_FAILURE,
} from "redux/types/output";

export const fetchDeleteAttributeForSchemaRequest = () => ({
  type: FETCH_DELETE_ATTRIBUTE_FOR_SCHEMA_REQUEST,
});

export const fetchDeleteAttributeForSchemaSuccess = (data) => ({
  type: FETCH_DELETE_ATTRIBUTE_FOR_SCHEMA_SUCCESS,
  data,
});

export const fetchDeleteAttributeForSchemaFailure = (error) => ({
  type: FETCH_DELETE_ATTRIBUTE_FOR_SCHEMA_FAILURE,
  error,
});

export const fetchDeleteAttributeForSchema = (schemaID, attributeID) => (dispatch) => {
  dispatch(fetchDeleteAttributeForSchemaRequest());
  return getApi(`/deleteAttributeForSchema/${schemaID}/${attributeID}`)
    .then((data) => {
      showSuccessErrorToast(data?.data?.flag, data?.data?.message);
      dispatch(fetchDeleteAttributeForSchemaSuccess(data));
      return getApiData(data);
    })
    .catch((error) => {
      toast.error(getApiError(error));
      dispatch(fetchDeleteAttributeForSchemaFailure(error));
    });
};
