import { setAuthToken, setLocalStorageItem } from "modules/utils";
import { toast } from "react-toastify";
import { getApi, getApiError, postApi } from "redux/actions/api";
import {
  FETCH_GET_EMAIL_VERIFICATION_TOKEN_FAILURE,
  FETCH_GET_EMAIL_VERIFICATION_TOKEN_REQUEST,
  FETCH_GET_EMAIL_VERIFICATION_TOKEN_SUCCESS,
} from "redux/types/users";

export const fetchGetEmailVerificationTokenRequest = () => ({
  type: FETCH_GET_EMAIL_VERIFICATION_TOKEN_REQUEST,
});

export const fetchGetEmailVerificationTokenSuccess = (data) => ({
  type: FETCH_GET_EMAIL_VERIFICATION_TOKEN_SUCCESS,
  data,
});

export const fetchGetEmailVerificationTokenFailure = (error) => ({
  type: FETCH_GET_EMAIL_VERIFICATION_TOKEN_FAILURE,
  error,
});

export const fetchGetEmailVerificationToken = (formData) => (dispatch) => {
  dispatch(fetchGetEmailVerificationTokenRequest());
  return postApi("/getEmailVerificationToken", formData)
    .then((data) => {
      if (data?.data?.flag) {
        toast.success(data?.data?.message);
      } else {
        toast.error(data?.data?.message);
      }
      dispatch(fetchGetEmailVerificationTokenSuccess(data));
      return data;
    })
    .catch((error) => {
      toast.error(getApiError(error));
      dispatch(fetchGetEmailVerificationTokenFailure(error));
    });
};
