import { setAuthToken, setLocalStorageItem } from "modules/utils";
import { toast } from "react-toastify";
import { getApiError, postApi } from "redux/actions/api";
import {
  FETCH_REGISTER_FAILURE,
  FETCH_REGISTER_REQUEST,
  FETCH_REGISTER_SUCCESS,
} from "redux/types/users";

export const fetchRegisterRequest = () => ({
  type: FETCH_REGISTER_REQUEST,
});

export const fetchRegisterSuccess = (data) => ({
  type: FETCH_REGISTER_SUCCESS,
  data,
});

export const fetchRegisterFailure = (error) => ({
  type: FETCH_REGISTER_FAILURE,
  error,
});

export const fetchRegister = (formData) => (dispatch) => {
  dispatch(fetchRegisterRequest());
  return postApi("/register", formData)
    .then((data) => {
      if (data?.data?.flag) {
        toast.success(data?.data?.message);
      } else {
        toast.error(data?.data?.message);
      }
      dispatch(fetchRegisterSuccess(data));
      return data;
    })
    .catch((error) => {
      toast.error(getApiError(error));
      dispatch(fetchRegisterFailure(error));
    });
};
