import { setAuthToken, setLocalStorageItem } from "modules/utils";
import { toast } from "react-toastify";
import { getApiError, postApi } from "redux/actions/api";
import {
  FETCH_RESET_PASSWORD_FAILURE,
  FETCH_RESET_PASSWORD_REQUEST,
  FETCH_RESET_PASSWORD_SUCCESS,
} from "redux/types/users";

export const fetchResetPasswordRequest = () => ({
  type: FETCH_RESET_PASSWORD_REQUEST,
});

export const fetchResetPasswordSuccess = (data) => ({
  type: FETCH_RESET_PASSWORD_SUCCESS,
  data,
});

export const fetchResetPasswordFailure = (error) => ({
  type: FETCH_RESET_PASSWORD_FAILURE,
  error,
});

export const fetchResetPassword = (formData) => (dispatch) => {
  dispatch(fetchResetPasswordRequest());
  return postApi("/resetPassword", formData)
    .then((data) => {
      if (data?.data?.flag) {
        toast.success(data?.data?.message);
      } else {
        toast.error(data?.data?.message);
      }
      dispatch(fetchResetPasswordSuccess(data));
      return data;
    })
    .catch((error) => {
      toast.error(getApiError(error));
      dispatch(fetchResetPasswordFailure(error));
    });
};
