import { combineReducers } from "redux";
import getUserDetail from "./auth/getUserDetail";
import loginReducer from "./auth/login";
import addUpdateElement from "./blockBuilder/addUpdateElement";
import addUpdateSingleElement from "./blockBuilder/addUpdateSingleElement";
import blockAdd from "./blockBuilder/blockAdd";
import blockDelete from "./blockBuilder/blockDelete";
import blockEdit from "./blockBuilder/blockEdit";
import blockListing from "./blockBuilder/blockListing";
import blockPreviewData from "./blockBuilder/blockPreviewData";
import blockUpdate from "./blockBuilder/blockUpdate";
import deleteElementReducer from "./blockBuilder/deleteElement";
import getAllToolbars from "./blockBuilder/getAllToolbars";
import getBlock from "./blockBuilder/getBlock";
import getBuildPageDetails from "./blockBuilder/getBuildPagesDetails";
import getBuildPageOptions from "./blockBuilder/getBuildPagesOptions";
import getCatalogPreviewReducer from "./blockBuilder/getCatalogPreview";
import getCategoryColors from "./blockBuilder/getCategoryColors";
import getCategoryMergeLevels from "./blockBuilder/getCategoryMergeLevels";
import getDefaultBlockSizeOptions from "./blockBuilder/getDefaultBlockSizeOptions";
import getLayoutOptionsReducer from "./blockBuilder/getLayoutOptions";
import getMergeFieldReducer from "./blockBuilder/getMergeFields";
import getPageOptionReducer from "./blockBuilder/getPageOptions";
import getPagePlannerByPage from "./blockBuilder/getPagePlannerByPage";
import getSectionDataReducer from "./blockBuilder/getSectionData";
import moveCategoryPages from "./blockBuilder/moveCategoryPages";
import saveBuildPagesOptions from "./blockBuilder/saveBuildPageOptions";
import getSchemaTableReducer from "./blockBuilder/schemaTable";
import getJSONFlatForCatID from "./getJSONFlat/getJSONFlatForCatID";
import dashboardItem from "./home/getDashboardItem";
import updateDashboardItem from "./home/updateDashboardItem";
import addImportFile from "./import/addImportFile";
import cancelImportFile from "./import/cancelImportFile";
import getPastImportDetails from "./import/getPastImportDetails";
import importConfirmSetup from "./import/importConfirmSetup";
import importCountProduct from "./import/importCountProduct";
import importHistory from "./import/importHistory";
import importNameRange from "./import/importNameRange";
import importSchedule from "./import/importSchedule";
import pastImportList from "./import/pastImportList";
import getIntroJs from "./introJS/fetchGetIntroJS";
import addCategory from "./manageCatalog/addCategory";
import addProductFromTextToCollectionReducer from "./manageCatalog/addProductFromTextToCollection";
import addProductToCollection from "./manageCatalog/addProductToCollection";
import attributeDisplayData from "./manageCatalog/attributeDisplayData";
import attributeSetupData from "./manageCatalog/attributeSetupData";
import breadCrumb from "./manageCatalog/breadCrumb";
import buildSinglePage from "./manageCatalog/buildSinglePage";
import catalogPlanner from "./manageCatalog/catalogPlanner";
import catalogTree from "./manageCatalog/catalogTree";
import categoryDisplaySetup from "./manageCatalog/categoryDisplaySetup";
import categoryProducts from "./manageCatalog/categoryProducts";
import categorySetupData from "./manageCatalog/categorySetupData";
import categoryTextData from "./manageCatalog/categoryTextData";
import checkCategoryCatalog from "./manageCatalog/checkCategoryCatalog";
import checkIfBlockSizeExist from "./manageCatalog/checkIfBlockSizeExist";
import cloneAttributeSchema from "./manageCatalog/cloneAttributeSchema";
import copyBlockIdForCategoryReducer from "./manageCatalog/copyBlockIdForCategory";
import deleteAttributeSchema from "./manageCatalog/deleteAttributeSchema";
import deleteAttributeSetup from "./manageCatalog/deleteAttributeSetup";
import deleteCategory from "./manageCatalog/deleteCategory";
import deleteCategoryTextBlock from "./manageCatalog/deleteCategoryTextBlock";
import deleteTextSetup from "./manageCatalog/deleteTextSetup";
import disablePagePlannerForCatalog from "./manageCatalog/disablePagePlannerForCatalog";
import enablePagePlannerForCatalog from "./manageCatalog/enablePagePlannerForCatalog";
import getAttributesNotInCategory from "./manageCatalog/getAttributesNotInCategory";
import getBlockListForCategoryReducer from "./manageCatalog/getBlockListForCategory";
import getBlockSizes from "./manageCatalog/getBlockSizes";
import getCatalogTreeForBlocks from "./manageCatalog/getCatalogTreeForBlocks";
import getCatalogTreeWithPageNumbers from "./manageCatalog/getCatalogTreeWithPageNumbers";
import getCategoryDetails from "./manageCatalog/getCategoryDetails";
import getCategoryMedia from "./manageCatalog/getCategoryMedia";
import getCategoryStatistics from "./manageCatalog/getCategoryStatistics";
import linkAttribute from "./manageCatalog/linkAttribute";
import linkParentColor from "./manageCatalog/linkParentColor";
import linkParentTextBlock from "./manageCatalog/linkParentTextBlock";
import linkTemplate from "./manageCatalog/linkTemplate";
import productNotInCollection from "./manageCatalog/productNotInCollection";
import renameCategory from "./manageCatalog/renameCategory";
import textSetupData from "./manageCatalog/textSetupData";
import unlinkParentAttribute from "./manageCatalog/unlinkParentAttribute";
import unlinkParentColor from "./manageCatalog/unLinkParentColor";
import unlinkParentTextBlock from "./manageCatalog/unlinkParentTextBlock";
import unlinkTemplate from "./manageCatalog/unlinkTemplate";
import updateAttributeSetupData from "./manageCatalog/updateAttributeSetupData";
import updateAttributeWidthForCategory from "./manageCatalog/updateAttributeWidthForCategory";
import updateCatalogPlannerCategoryPosition from "./manageCatalog/updateCatalogPlannerCategoryPosition";
import updateCategoryAttributeSchema from "./manageCatalog/updateCategoryAttributeSchema";
import updateCategoryText from "./manageCatalog/updateCategoryText";
import updateCategoryTextSchemaReducer from "./manageCatalog/updateCategoryTextSchema";
import updateDisplaySetup from "./manageCatalog/updateDisplaySetup";
import updateProductCollectionSortOrder from "./manageCatalog/updateProductCollectionSortOrder";
import updateTextSetupSortOrder from "./manageCatalog/updateTextSetupSortOrder";
import addProduct from "./manageProduct/addProduct";
import addProductValidation from "./manageProduct/addProductValidation";
import blobList from "./manageProduct/editProduct/blobList";
import editProductAttHistory from "./manageProduct/editProduct/editProductAttHistory";
import manageAttributeList from "./manageProduct/editProduct/manageAttributeList";
import productCollectionList from "./manageProduct/editProduct/productCollectionList";
import updateManageAttribute from "./manageProduct/editProduct/updateManageAttribute";
import previewBlob from "./manageProduct/previewBlob";
import productAttrGrid from "./manageProduct/productAttrGrid";
import productAttrHistory from "./manageProduct/productAttrHistory";
import productCategoryList from "./manageProduct/productCategoryList";
import productList from "./manageProduct/productList";
import restoreOldValue from "./manageProduct/restoreOldValue";
import searchProduct from "./manageProduct/searchProduct";
import updateProductAttrGridData from "./manageProduct/updateProductAttrGridData";
import activeCatalogList from "./masterAdmin/activeCatalogList";
import addCatalog from "./masterAdmin/addCatalog";
import addOrganization from "./masterAdmin/addOrganization";
import catalogChildList from "./masterAdmin/catalogChildList";
import catalogList from "./masterAdmin/catalogList";
import deleteUser from "./masterAdmin/deleteUser";
import getCatalogDetails from "./masterAdmin/getCatalogDetails";
import inviteAccountManager from "./masterAdmin/inviteAccountManager";
import inviteReseller from "./masterAdmin/inviteReseller";
import inviteUser from "./masterAdmin/inviteUser";
import jobList from "./masterAdmin/jobList";
import organizationList from "./masterAdmin/organizationList";
import updateCatalog from "./masterAdmin/updateCatalog";
import updateOrganization from "./masterAdmin/updateOrganization";
import updateUser from "./masterAdmin/updateUser";
import userList from "./masterAdmin/userList";
import addAttribute from "./masterSetup/addAttribute";
import addProductBlob from "./masterSetup/addProductBlob";
import addTextBlock from "./masterSetup/addTextBlock";
import addUnit from "./masterSetup/addUnit";
import attributeDetail from "./masterSetup/attributeDetails";
import attributeList from "./masterSetup/attributeList";
import attributeWithoutVirtualList from "./masterSetup/attributeWithoutVirtualList";
import catalogLanguageList from "./masterSetup/catalogLanguageList";
import deleteAttribute from "./masterSetup/deleteAttribute";
import deleteProductBlob from "./masterSetup/deleteProductBlob";
import deleteTextBlock from "./masterSetup/deleteTextBlock";
import disableMultiLanguage from "./masterSetup/disableMultiLanguage";
import enableMultiLanguage from "./masterSetup/enableMultiLanguage";
import flagList from "./masterSetup/flagList";
import getBlobDetail from "./masterSetup/getBlobDetail";
import getDashboardItemsList from "./masterSetup/getDashboardItemsList";
import getLanguageDetails from "./masterSetup/getLanguageDetails";
import getTemplateDetails from "./masterSetup/getTemplateDetails";
import getUnitDetails from "./masterSetup/getUnitDetails";
import languageList from "./masterSetup/languageList";
import productBlobList from "./masterSetup/productBlobList";
import regionList from "./masterSetup/regionList";
import searchProductBlob from "./masterSetup/searchProductBlob";
import templateList from "./masterSetup/templateList";
import textBlocksDetail from "./masterSetup/textBlockDetail";
import addCategoryTextSchemaReducer from "./masterSetup/textBlockSchema/addCategorySchema";
import addTextBlockToSchemaReducer from "./masterSetup/textBlockSchema/addTextBlockToSchema";
import cloneCategoryTextSchemaReducer from "./masterSetup/textBlockSchema/cloneCategoryTextSchema";
import deleteCategoryTextSchemaReducer from "./masterSetup/textBlockSchema/deleteCategoryTextSchema";
import deleteTextBlockForSchemaReducer from "./masterSetup/textBlockSchema/deleteTextBlockForSchema";
import getAllCategoryTextSchemaListReducer from "./masterSetup/textBlockSchema/getAllCategoryTextSchemaList";
import getCategoryTextSchemaDetailsByIdReducer from "./masterSetup/textBlockSchema/getCategoryTextSchemaDetailsById";
import getTextBlockListForSchemaReducer from "./masterSetup/textBlockSchema/getTextBlockListForSchema";
import updateCategoryTextSchemaSortOrderReducer from "./masterSetup/textBlockSchema/updateCategoryTextSchemaSortOrder";
import updateSchemaTextBlocksReducer from "./masterSetup/textBlockSchema/updateSchemaTextBlocks";
import textBlocksList from "./masterSetup/textBlocksList";
import unitList from "./masterSetup/unitList";
import updateAttribute from "./masterSetup/updateAttribute";
import updateLanguageSortOrder from "./masterSetup/updateLanguageSortOrder";
import updateProductBlob from "./masterSetup/updateProductBlob";
import updateTextBlock from "./masterSetup/updateTextBlock";
import updateUserCatalog from "./masterSetup/updateUserCatalog";
import addImage from "./media/addImage";
import addImageLabel from "./media/addImageLabel";
import addImageSize from "./media/addImageSize";
import deleteImage from "./media/deleteImage";
import deleteImageLabel from "./media/deleteImageLabel";
import deleteImageSize from "./media/deleteImageSize";
import allImages from "./media/getAllImages";
import getMediaValetHistory from "./media/getMediaValetHistory";
import imageLabelList from "./media/imageLabelList";
import imageSizeList from "./media/imageSizeList";
import searchImage from "./media/searchImage";
import storeImage from "./media/storeImage";
import storeMediaValetToken from "./media/storeMediaValetToken";
import updateImageLabel from "./media/updateImageLabel";
import notificationList from "./notification/notificationList";
import notificationMarkRead from "./notification/notificationMarkRead";
import addAttributeToSchema from "./output/addAttributeToSchema";
import addLayout from "./output/addLayout";
import attributeListForSchema from "./output/attributeListForSchema";
import cancelExport from "./output/cancelExport";
import deleteAttributeForSchema from "./output/deleteAttributeForSchema";
import exportHistoryList from "./output/exportHistory";
import getAllAttributeSchemaDetails from "./output/getAllAttributeSchemaDetails";
import getAllAttributeSchemaList from "./output/getAllAttributeSchemaList";
import getUserCatalogDetail from "./output/getUserCatalogDetail";
import layoutDetails from "./output/layoutDetail";
import layoutList from "./output/layoutList";
import updateLayoutItems from "./output/updateLayoutItems";
import getReportData from "./reports/getReportData";
import reportList from "./reports/reportList";
import getEmailVerificationToken from "./users/getEmailVerificationToken";
import getPasswordResetLink from "./users/getPasswordResetLink";
import getPasswordResetTokenDetail from "./users/getPasswordResetTokenDetail";
import getPlanDetails from "./users/getPlanDetails";
import getSignupTokenDetails from "./users/getSignupTokenDetails";
import resetPassword from "./users/resetPassword";
import userSignupProcess from "./users/userSignupProcess";

const rootReducer = combineReducers({
  login: loginReducer,
  exportHistoryList: exportHistoryList,
  organizationList: organizationList,
  catalogList: catalogList,
  jobList: jobList,
  userList: userList,
  addOrganization: addOrganization,
  addCatalog: addCatalog,
  updateOrganization: updateOrganization,
  activeCatalogList: activeCatalogList,
  productListReducer: productList,
  getUserDetail: getUserDetail,
  productAttrHistory: productAttrHistory,
  updateCatalog: updateCatalog,
  importHistory: importHistory,
  getAllToolbars: getAllToolbars,
  blockAdd: blockAdd,
  blockDelete: blockDelete,
  blockEdit: blockEdit,
  blockListing: blockListing,
  addUpdateElement: addUpdateElement,
  blockUpdate: blockUpdate,
  deleteCategoryTextBlock: deleteCategoryTextBlock,
  catalogTree: catalogTree,
  addProduct: addProduct,
  getBlock: getBlock,
  getPastImportDetails: getPastImportDetails,
  attributeList: attributeList,
  attributeWithoutVirtualList: attributeWithoutVirtualList,
  unitList: unitList,
  textBlocksList: textBlocksList,
  inviteAccountManager: inviteAccountManager,
  inviteReseller: inviteReseller,
  inviteUser: inviteUser,
  allImages: allImages,
  addImage: addImage,
  deleteImage: deleteImage,
  breadCrumb: breadCrumb,
  addProductToCollection: addProductToCollection,
  attributeDisplayData: attributeDisplayData,
  attributeSetupData: attributeSetupData,
  catalogPlanner: catalogPlanner,
  categoryDisplaySetup: categoryDisplaySetup,
  categorySetupData: categorySetupData,
  categoryProducts: categoryProducts,
  categoryTextData: categoryTextData,
  storeImage: storeImage,
  templateList: templateList,
  productBlobList: productBlobList,
  languageList: languageList,
  catalogChildList: catalogChildList,
  deleteAttribute: deleteAttribute,
  addAttribute: addAttribute,
  updateAttribute: updateAttribute,
  addUnit: addUnit,
  addProductValidation: addProductValidation,
  editProductAttHistory: editProductAttHistory,
  productCollectionList: productCollectionList,
  updateProductCollectionSortOrder: updateProductCollectionSortOrder,
  blobList: blobList,
  previewBlob: previewBlob,
  getUnitDetails: getUnitDetails,
  attributeDetail: attributeDetail,
  manageAttributeList: manageAttributeList,
  productCategoryList: productCategoryList,
  productAttrGrid: productAttrGrid,
  updateManageAttribute: updateManageAttribute,
  textBlocksDetail: textBlocksDetail,
  updateTextBlock: updateTextBlock,
  deleteTextBlock: deleteTextBlock,
  imageSizeList: imageSizeList,
  addTextBlock: addTextBlock,
  addProductBlob: addProductBlob,
  deleteProductBlob: deleteProductBlob,
  updateProductBlob: updateProductBlob,
  getBlobDetail: getBlobDetail,
  imageLabelList: imageLabelList,
  addImageSize: addImageSize,
  deleteImageLabel: deleteImageLabel,
  addImageLabel: addImageLabel,
  updateImageLabel: updateImageLabel,
  searchProduct: searchProduct,
  getTemplateDetails: getTemplateDetails,
  updateUserCatalog: updateUserCatalog,
  catalogLanguageList: catalogLanguageList,
  enableMultiLanguage: enableMultiLanguage,
  regionList: regionList,
  addAttributeToSchema: addAttributeToSchema,
  flagList: flagList,
  getLanguageDetails: getLanguageDetails,
  getAllAttributeSchemaList: getAllAttributeSchemaList,
  addLayout: addLayout,
  layoutDetails: layoutDetails,
  layoutList: layoutList,
  updateLayoutItems: updateLayoutItems,
  getAllAttributeSchemaDetails: getAllAttributeSchemaDetails,
  reportList: reportList,
  getReportData: getReportData,
  dashboardItem: dashboardItem,
  updateDashboardItem: updateDashboardItem,
  getCatalogDetails: getCatalogDetails,
  addImportFile: addImportFile,
  importNameRange: importNameRange,
  importCountProduct: importCountProduct,
  deleteImageSize: deleteImageSize,
  updateUser: updateUser,
  deleteUser: deleteUser,
  disableMultiLanguage: disableMultiLanguage,
  restoreOldValue: restoreOldValue,
  pastImportList: pastImportList,
  importConfirmSetup: importConfirmSetup,
  importSchedule: importSchedule,
  notificationList: notificationList,
  notificationMarkRead: notificationMarkRead,
  searchImage: searchImage,
  updateDisplaySetup: updateDisplaySetup,
  unlinkParentAttribute: unlinkParentAttribute,
  cancelExport: cancelExport,
  deleteAttributeForSchema: deleteAttributeForSchema,
  updateCategoryText: updateCategoryText,
  productNotInCollection: productNotInCollection,
  updateAttributeSetupData: updateAttributeSetupData,
  addCategory: addCategory,
  unlinkTemplate: unlinkTemplate,
  linkTemplate: linkTemplate,
  linkAttribute: linkAttribute,
  textSetupData: textSetupData,
  deleteTextSetup: deleteTextSetup,
  deleteAttributeSetup: deleteAttributeSetup,
  getCategoryDetails: getCategoryDetails,
  deleteCategory: deleteCategory,
  updateTextSetupSortOrder: updateTextSetupSortOrder,
  getUserCatalogDetail: getUserCatalogDetail,
  attributeListForSchema: attributeListForSchema,
  cancelImportFile: cancelImportFile,
  getAttributesNotInCategory: getAttributesNotInCategory,
  updateAttributeWidthForCategory: updateAttributeWidthForCategory,
  searchProductBlob: searchProductBlob,
  getPasswordResetLink: getPasswordResetLink,
  getPasswordResetTokenDetail: getPasswordResetTokenDetail,
  resetPassword: resetPassword,
  updateProductAttrGridData: updateProductAttrGridData,
  getPlanDetails: getPlanDetails,
  getEmailVerificationToken: getEmailVerificationToken,
  checkCategoryCatalog: checkCategoryCatalog,
  getDashboardItemsList: getDashboardItemsList,
  getIntroJs: getIntroJs,
  getSchemaTableData: getSchemaTableReducer,
  deleteElement: deleteElementReducer,
  getMergeField: getMergeFieldReducer,
  blockPreviewData: blockPreviewData,
  addUpdateSingleElement: addUpdateSingleElement,
  categoryMedia: getCategoryMedia,
  getCategoryMergeLevels: getCategoryMergeLevels,
  getCategoryColors: getCategoryColors,
  getCatalogTreeForBlocks: getCatalogTreeForBlocks,
  linkParentTextBlock: linkParentTextBlock,
  unlinkParentTextBlock: unlinkParentTextBlock,
  unlinkParentColor: unlinkParentColor,
  linkParentColor: linkParentColor,
  updateLanguageSortOrder: updateLanguageSortOrder,
  getSignupTokenDetails: getSignupTokenDetails,
  userSignupProcess: userSignupProcess,
  getLayoutOptions: getLayoutOptionsReducer,
  getPageOption: getPageOptionReducer,
  getBlockListForCategory: getBlockListForCategoryReducer,
  copyBlockIdForCategory: copyBlockIdForCategoryReducer,
  addProductFromTextToCollection: addProductFromTextToCollectionReducer,
  getSectionData: getSectionDataReducer,
  getCatalogPreview: getCatalogPreviewReducer,
  getDefaultBlockSizeOptions: getDefaultBlockSizeOptions,
  saveBuildPagesOptions: saveBuildPagesOptions,
  getBuildPageOptions: getBuildPageOptions,
  getBuildPageDetails: getBuildPageDetails,
  getPagePlannerByPage: getPagePlannerByPage,
  getCatalogTreeWithPageNumbers: getCatalogTreeWithPageNumbers,
  moveCategoryPages: moveCategoryPages,
  getJSONFlatForCatId: getJSONFlatForCatID,
  getCategoryStatistics: getCategoryStatistics,
  updateCatalogPlannerCategoryPosition: updateCatalogPlannerCategoryPosition,
  renameCategory: renameCategory,
  enablePagePlannerForCatalog: enablePagePlannerForCatalog,
  disablePagePlannerForCatalog: disablePagePlannerForCatalog,
  getBlockSizes: getBlockSizes,
  checkIfBlockSizeExist: checkIfBlockSizeExist,
  buildSinglePage: buildSinglePage,
  storeMediaValetToken: storeMediaValetToken,
  getMediaValetHistory: getMediaValetHistory,
  updateCategoryAttributeSchema: updateCategoryAttributeSchema,
  cloneAttributeSchema: cloneAttributeSchema,
  deleteAttributeSchema: deleteAttributeSchema,
  updateCategoryTextSchemaReducer: updateCategoryTextSchemaReducer,

  //Setup -> TextBLock Schema
  addCategoryTextSchema: addCategoryTextSchemaReducer,
  addTextBlockToSchema: addTextBlockToSchemaReducer,
  cloneCategoryTextSchema: cloneCategoryTextSchemaReducer,
  deleteCategoryTextSchema: deleteCategoryTextSchemaReducer,
  deleteTextBlockForSchema: deleteTextBlockForSchemaReducer,
  getAllCategoryTextSchemaList: getAllCategoryTextSchemaListReducer,
  getCategoryTextSchemaDetailsById: getCategoryTextSchemaDetailsByIdReducer,
  getTextBlockListForSchema: getTextBlockListForSchemaReducer,
  updateCategoryTextSchemaSortOrder: updateCategoryTextSchemaSortOrderReducer,
  updateSchemaTextBlocks: updateSchemaTextBlocksReducer,
});

export default rootReducer;
